(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13063,        445]*)
(*NotebookOutlinePosition[     14063,        475]*)
(*  CellTagsIndexPosition[     14019,        471]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\

Bases and Schreier-Sims

overview\

\>", "Title"],

Cell["Strong Bases", "Subsubsection"],

Cell[TextData[{

  "Given a set of permutations ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  " acting on a finite set ",

  Cell[BoxData[

      FormBox["\[CapitalOmega]", TraditionalForm]]],

  ":"

}], "Emphasis"],

Cell[TextData[{

  "Define the group generated by ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  " as ",

  Cell[BoxData[

      FormBox[

        RowBox[{"G", "=", 

          RowBox[{

            RowBox[{"\[LeftAngleBracket]", "W", "\[RightAngleBracket]"}], "=",

             

            RowBox[{GridBox[{

                  {"words"},

                  {

                    RowBox[{"on", " ", "W"}]}

                  }], "=", 

              RowBox[{"{", 

                RowBox[{

                  SubscriptBox["w", "1"], 

                  SubscriptBox["w", "2"], 

                  RowBox[{

                    SubscriptBox["\[Ellipsis]w", "k"], ":", 

                    RowBox[{

                      SubscriptBox["w", "i"], "\[Element]", "W"}]}]}], 

                "}"}]}]}]}], TraditionalForm]]]

}], "Emphasis"],

Cell[TextData[{

  "-products of elements of ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  ". Since ",

  Cell[BoxData[

      FormBox["\[CapitalOmega]", TraditionalForm]]],

  " is finite, all elements of ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  " have finite order, so we dont need to use inverses."

}], "SmallText"],

Cell[TextData[{

  "Define the stabilizer of ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  " at ",

  Cell[BoxData[

      FormBox[

        RowBox[{"x", "\[Element]", "\[CapitalOmega]"}], TraditionalForm]]],

  "  as: \n",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["W", "x"], "=", 

          RowBox[{GridBox[{

                {

                  RowBox[{"elements", " ", "of", " ", "W"}]},

                {

                  RowBox[{"that", " ", "leave", " ", "x", " ", "fixed"}]}

                }], "=", 

            RowBox[{"{", 

              RowBox[{

                RowBox[{"\[Sigma]", "\[Element]", 

                  RowBox[{"W", ":", " ", 

                    RowBox[{"\[Sigma]", "(", "x", ")"}]}]}], "=", "x"}], 

              "}"}]}]}], TraditionalForm]]],

  ". "

}], "Emphasis"],

Cell[TextData[{

  "The stability ",

  StyleBox["group",

    FontWeight->"Bold"],

  " of ",

  Cell[BoxData[

      FormBox["x", TraditionalForm]]],

  " is ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["G", "x"], TraditionalForm]]],

  "."

}], "Emphasis"],

Cell["\<\

The \"loop\" method we've considered allows us to compute a set of generators \

for a stability group. \

\>", "Emphasis"],

Cell[TextData[{

  "Let ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["W", "0"], "=", "W"}], TraditionalForm]]],

  ".\nWe can start with an element ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["x", "1"], TraditionalForm]]],

  ",\n -compute ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["W", "1"], TraditionalForm]]],

  " s.t. ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          RowBox[{"\[LeftAngleBracket]", 

            SubscriptBox["W", "1"], "\[RightAngleBracket]"}], "=", 

          SubscriptBox[

            RowBox[{"\[LeftAngleBracket]", "W", "\[RightAngleBracket]"}], 

            SubscriptBox["x", "1"]]}], TraditionalForm]]],

  ",\n -choose another element ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["x", "2"], TraditionalForm]]],

  " and compute ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["W", "2"], TraditionalForm]]],

  " s.t. ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          RowBox[{"\[LeftAngleBracket]", 

            SubscriptBox["W", "2"], "\[RightAngleBracket]"}], "=", 

          SubscriptBox[

            RowBox[{"\[LeftAngleBracket]", 

              SubscriptBox["W", "1"], "\[RightAngleBracket]"}], 

            SubscriptBox["x", "2"]]}], TraditionalForm]]],

  ",\n -\[Ellipsis]\n until ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["W", "k"], "=", "\[EmptySet]"}], TraditionalForm]]],

  ".\n At this point we have a sequence of \"basis\" points ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["x", "1"], ",", "\[Ellipsis]", ",", 

          SubscriptBox["x", "n"]}], TraditionalForm]]],

  " such that no element of ",

  Cell[BoxData[

      FormBox["G", TraditionalForm]]],

  " fixes these points. For each initial sequence we have generators ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["W", 

          RowBox[{"k", "+", "1"}]], TraditionalForm]]],

  "of the stabilizer group ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["G", 

          RowBox[{

            SubscriptBox["x", "1"], ",", "\[Ellipsis]", ",", 

            SubscriptBox["x", "k"]}]], TraditionalForm]]],

  "."

}], "Emphasis"],

Cell[TextData[{

  "This constitutes a ",

  StyleBox["strong basis",

    FontWeight->"Bold"],

  "."

}], "Emphasis"],

Cell["\<\

A strong basis makes many computations in group theory quite simple.\

\>", "Emphasis"],

Cell["Membership and Residues", "Subsubsection"],

Cell[TextData[{

  "In particular we can determine whether any permutation ",

  Cell[BoxData[

      FormBox["\[Sigma]", TraditionalForm]]],

  " is in ",

  Cell[BoxData[

      FormBox["G", TraditionalForm]]],

  "\n(i.e. can be constructed from the ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  ")."

}], "Emphasis"],

Cell[TextData[{

  "Given ",

  Cell[BoxData[

      FormBox["\[Sigma]", TraditionalForm]]],

  ":\n find a word ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["\[Gamma]", "0"], TraditionalForm]]],

  " on ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["W", "0"], TraditionalForm]]],

  " that moves ",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Sigma]", "(", 

          SubscriptBox["x", "1"], ")"}], TraditionalForm]]],

  " back to ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["x", "1"], TraditionalForm]]],

  "\n  (if there is none then clearly ",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Sigma]", "\[NotElement]", "G"}], TraditionalForm]]],

  ")\n  now ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[Sigma]", "1"], "=", 

          RowBox[{

            RowBox[{"\[Sigma]", "  ", 

              SubscriptBox["\[Gamma]", "0"]}], "\[Element]", 

            SubscriptBox["G", 

              SubscriptBox["x", "1"]]}]}], TraditionalForm]]],

  ",\n find a word ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["\[Gamma]", "1"], TraditionalForm]]],

  " on ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["W", "1"], TraditionalForm]]],

  " that moves ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[Sigma]", "1"], "(", 

          SubscriptBox["x", "2"], ")"}], TraditionalForm]]],

  " back to ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["x", "2"], TraditionalForm]]],

  "\n  (if there is none then clearly ",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Sigma]", "\[NotElement]", "G"}], TraditionalForm]]],

  ")\n  now ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[Sigma]", "2"], "=", 

          RowBox[{

            RowBox[{

              SubscriptBox["\[Sigma]", "1"], "  ", 

              SubscriptBox["\[Gamma]", "1"]}], "\[Element]", 

            SubscriptBox["G", 

              RowBox[{

                SubscriptBox["x", "1"], ",", 

                SubscriptBox["x", "2"]}]]}]}], TraditionalForm]]],

  ",\n  \[Ellipsis]\n  until either:\n   -we have expressed \[Sigma] in terms \

of ",

  Cell[BoxData[

      FormBox["W", TraditionalForm]]],

  " (",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Sigma]", "=", 

          RowBox[{

            SubsuperscriptBox["\[Gamma]", "0", 

              RowBox[{"-", "1"}]], 

            SubsuperscriptBox["\[Ellipsis]\[Gamma]", "k", 

              RowBox[{"-", "1"}]]}]}], TraditionalForm]]],

  ")\n   -or we have reduced ",

  Cell[BoxData[

      FormBox["\[Sigma]", TraditionalForm]]],

  " to a product from the stabalizer groups and a \"residue\" that is not in \

G."

}], "Emphasis"],

Cell["The Basis Algorithm", "Subsubsection"],

Cell["How complex is the basis algorithm we have proposed?", "Emphasis"],

Cell[TextData[{

  "For ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["W", 

          SubscriptBox["x", "1"]], TraditionalForm]]],

  ", our generators were loops consisting of a path ",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Gamma]", "\[Element]", 

          RowBox[{"\[LeftAngleBracket]", "W", "\[RightAngleBracket]"}]}], 

        TraditionalForm]]],

  " to an ",

  Cell[BoxData[

      FormBox[

        RowBox[{"x", "=", 

          RowBox[{

            RowBox[{"\[Gamma]", "(", 

              SubscriptBox["x", "1"], ")"}], "\[Element]", " ", 

            RowBox[{"G", ".", 

              SubscriptBox["x", "1"]}], "\[SubsetEqual]", 

            "\[CapitalOmega]"}]}], TraditionalForm]]],

  ",\nand a jump corresponding to some ",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Sigma]", "\[Element]", "W"}], TraditionalForm]]],

  " ( and the return path from ",

  Cell[BoxData[

      FormBox[

        RowBox[{"\[Sigma]", "(", 

          RowBox[{"\[Gamma]", "(", 

            SubscriptBox["x", "1"], ")"}], ")"}], TraditionalForm]]],

  ").\nThus there are up to ",

  Cell[BoxData[

      FormBox[

        RowBox[{"#", "\[CapitalOmega]", " ", "\[Times]", " ", "#", "W"}], 

        TraditionalForm]]],

  " possible generators.\ni.e. ",

  Cell[BoxData[

      FormBox[

        RowBox[{"#", 

          SubscriptBox["W", "1"]}], TraditionalForm]]],

  " may be this product."

}], "Emphasis"],

Cell[TextData[{

  "Let ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["w", "k"], "=", 

          RowBox[{"#", 

            SubscriptBox["W", "k"]}]}], TraditionalForm]]],

  ". Potentially ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["w", "k"], "=", 

          RowBox[{

            RowBox[{"(", 

              RowBox[{"n", "-", "k"}], ")"}], "\[Times]", 

            SubscriptBox["w", 

              RowBox[{"k", "-", "1"}]]}]}], TraditionalForm]]],

  "."

}], "Text"],

Cell["\<\

Continuing we see an exponential explosion in the complexity.\

\>", "Emphasis"],

Cell[TextData[{

  "-Judicious use of the membership algorithm above, \n-construction of a \

basis \"in reverse\",\n-a caching of path information,\n-optimizations on the \

addition of new generators\ngives a deeply recursive algorithm  that \

nevertheless is polynomial time ( ",

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          RowBox[{"(", 

            RowBox[{"#", "\[CapitalOmega]"}], ")"}], "5"], 

        TraditionalForm]]],

  ")."

}], "Emphasis"],

Cell["This is the Schreier-Sims algorithm.", "Emphasis"],

Cell["\<\

A strong basis makes computations involving permutation groups tractable.\

\>", "Emphasis"],

Cell["Schreier:Efficiency is the heart of GAP.", "Text"],

Cell["Symbolic paths", "Subsubsection"],

Cell[TextData[{

  "The implementation in ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " also retains a full symbolic description of all the paths used.\nThis \

enables us to express elements in terms of the original generators."

}], "Emphasis"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
CellGrouping->Manual,
WindowSize->{537, 465},
WindowMargins->{{Automatic, 110}, {Automatic, 4}},
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[], "StylesFolder"}, \
"Talk Style.nb", CharacterEncoding -> "MacintoshRoman"],
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 57, 3, 246, "Title"],
Cell[1777, 54, 37, 0, 43, "Subsubsection"],
Cell[1817, 56, 225, 8, 47, "Emphasis"],
Cell[2045, 66, 831, 25, 100, "Emphasis"],
Cell[2879, 93, 347, 11, 24, "SmallText"],
Cell[3229, 106, 830, 26, 96, "Emphasis"],
Cell[4062, 134, 260, 12, 49, "Emphasis"],
Cell[4325, 148, 131, 3, 72, "Emphasis"],
Cell[4459, 153, 2175, 68, 307, "Emphasis"],
Cell[6637, 223, 114, 5, 49, "Emphasis"],
Cell[6754, 230, 96, 2, 49, "Emphasis"],
Cell[6853, 234, 48, 0, 45, "Subsubsection"],
Cell[6904, 236, 326, 11, 84, "Emphasis"],
Cell[7233, 249, 2684, 88, 422, "Emphasis"],
Cell[9920, 339, 44, 0, 45, "Subsubsection"],
Cell[9967, 341, 72, 0, 49, "Emphasis"],
Cell[10042, 343, 1405, 43, 200, "Emphasis"],
Cell[11450, 388, 522, 19, 29, "Text"],
Cell[11975, 409, 89, 2, 49, "Emphasis"],
Cell[12067, 413, 469, 12, 212, "Emphasis"],
Cell[12539, 427, 56, 0, 49, "Emphasis"],
Cell[12598, 429, 101, 2, 49, "Emphasis"],
Cell[12702, 433, 56, 0, 29, "Text"],
Cell[12761, 435, 39, 0, 45, "Subsubsection"],
Cell[12803, 437, 256, 6, 107, "Emphasis"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

