(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    564759,      17224]*)
(*NotebookOutlinePosition[    580791,      17663]*)
(*  CellTagsIndexPosition[    580572,      17652]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Graphics of Group Action Paths", "Title",
  CellTags->"start"],

Cell[CellGroupData[{

Cell["inactive", "Commentary"],

Cell["\<\
The  libraries for this notebook are not in the package folder, so all cells \
are unevaluable.\
\>", "Commentary"]
}, Closed]],

Cell[CellGroupData[{

Cell["Comments", "Commentary",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell["presumption:", "Commentary",
  CellTags->"enfold"],

Cell["\<\
The  parent directory of the  ToolsFolder has been added to $Path\
\>", "SmallText",
  CellTags->"enfold"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load permutation group functions", "Commentary",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "Get", "[", "\"\<ToolsFolder`PermGroupFolder`PermGroupFns`\>\"", "]"}], 
      ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection"],

Cell["\<\
We start with a more interesting example. 
The given generators are labelled a,b,\[Ellipsis] in this case. 
Each generartor corresponds to a permutation (of the vertices labelled 1,2,\
\[Ellipsis]).
The permutations are given in a rule format, and wrapped up with their labels \
in a labelled permutation rules \"LPerm\" action data.\
\>", "Emphasis",
  CellTags->"emphasis"]
}, Open  ]],

Cell[CellGroupData[{

Cell["the initial actions:theGpGens", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"theGpGens", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"LPerm", "[", 
                  RowBox[{"\"\<a\>\"", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"1", "\[Rule]", "2"}], ",", 
                        RowBox[{"2", "\[Rule]", "10"}], ",", 
                        RowBox[{"3", "\[Rule]", "4"}], ",", 
                        RowBox[{"4", "\[Rule]", "3"}], ",", 
                        RowBox[{"5", "\[Rule]", "6"}], ",", 
                        RowBox[{"6", "\[Rule]", "9"}], ",", 
                        RowBox[{"7", "\[Rule]", "7"}], ",", 
                        RowBox[{"8", "\[Rule]", "8"}], ",", 
                        RowBox[{"9", "\[Rule]", "1"}], ",", 
                        RowBox[{"10", "\[Rule]", "5"}]}], "}"}]}], "]"}], ",",
                 
                RowBox[{"LPerm", "[", 
                  RowBox[{"\"\<b\>\"", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"1", "\[Rule]", "1"}], ",", 
                        RowBox[{"2", "\[Rule]", "6"}], ",", 
                        RowBox[{"3", "\[Rule]", "8"}], ",", 
                        RowBox[{"4", "\[Rule]", "5"}], ",", 
                        RowBox[{"5", "\[Rule]", "9"}], ",", 
                        RowBox[{"6", "\[Rule]", "2"}], ",", 
                        RowBox[{"7", "\[Rule]", "3"}], ",", 
                        RowBox[{"8", "\[Rule]", "7"}], ",", 
                        RowBox[{"9", "\[Rule]", "4"}], ",", 
                        RowBox[{"10", "\[Rule]", "10"}]}], "}"}]}], "]"}], 
                ",", 
                RowBox[{"LPerm", "[", 
                  RowBox[{"\"\<c\>\"", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"1", "\[Rule]", "9"}], ",", 
                        RowBox[{"2", "\[Rule]", "3"}], ",", 
                        RowBox[{"3", "\[Rule]", "10"}], ",", 
                        RowBox[{"4", "\[Rule]", "8"}], ",", 
                        RowBox[{"5", "\[Rule]", "4"}], ",", 
                        RowBox[{"6", "\[Rule]", "6"}], ",", 
                        RowBox[{"7", "\[Rule]", "2"}], ",", 
                        RowBox[{"8", "\[Rule]", "1"}], ",", 
                        RowBox[{"9", "\[Rule]", "5"}], ",", 
                        RowBox[{"10", "\[Rule]", "7"}]}], "}"}]}], "]"}], ",",
                 
                RowBox[{"LPerm", "[", 
                  RowBox[{"\"\<d\>\"", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"1", "\[Rule]", "10"}], ",", 
                        RowBox[{"2", "\[Rule]", "6"}], ",", 
                        RowBox[{"3", "\[Rule]", "5"}], ",", 
                        RowBox[{"4", "\[Rule]", "1"}], ",", 
                        RowBox[{"5", "\[Rule]", "4"}], ",", 
                        RowBox[{"6", "\[Rule]", "3"}], ",", 
                        RowBox[{"7", "\[Rule]", "8"}], ",", 
                        RowBox[{"8", "\[Rule]", "7"}], ",", 
                        RowBox[{"9", "\[Rule]", "2"}], ",", 
                        RowBox[{"10", "\[Rule]", "9"}]}], "}"}]}], "]"}], ",",
                 
                RowBox[{"LPerm", "[", 
                  RowBox[{"\"\<e\>\"", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"1", "\[Rule]", "1"}], ",", 
                        RowBox[{"2", "\[Rule]", "4"}], ",", 
                        RowBox[{"3", "\[Rule]", "2"}], ",", 
                        RowBox[{"4", "\[Rule]", "7"}], ",", 
                        RowBox[{"5", "\[Rule]", "5"}], ",", 
                        RowBox[{"6", "\[Rule]", "9"}], ",", 
                        RowBox[{"7", "\[Rule]", "3"}], ",", 
                        RowBox[{"8", "\[Rule]", "6"}], ",", 
                        RowBox[{"9", "\[Rule]", "8"}], ",", 
                        RowBox[{"10", "\[Rule]", "10"}]}], "}"}]}], "]"}]}], 
              "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"LPerm", "[", 
                RowBox[{"l_", ",", "\[Sigma]_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"LPerm", "[", 
                RowBox[{"l", ",", 
                  RowBox[{
                  "NonTrivialEdgesofPermRules", "[", "\[Sigma]", "]"}]}], 
                "]"}]}]}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell["Here are the permutations in cycle form:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Cases", "[", 
      RowBox[{"theGpGens", ",", 
        RowBox[{
          RowBox[{"LPerm", "[", 
            RowBox[{"_", ",", "\[Sigma]_"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"CyclesOfRules", "[", "\[Sigma]", "]"}]}]}], "]"}]], "Input",\

  Evaluatable->False,
  CellTags->"calc"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
              "1", ",", "2", ",", "10", ",", "5", ",", "6", ",", "9"}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2", ",", "6"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", "8", ",", "7"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"4", ",", "5", ",", "9"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "9", ",", "5", ",", "4", ",", "8"}], "}"}], 
            ",", 
            RowBox[{"{", 
              RowBox[{"2", ",", "3", ",", "10", ",", "7"}], "}"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
              "1", ",", "10", ",", "9", ",", "2", ",", "6", ",", "3", ",", 
                "5", ",", "4"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"7", ",", "8"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"2", ",", "4", ",", "7", ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"6", ",", "9", ",", "8"}], "}"}]}], "}"}]}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell["Spanning Tree", "Section"],

Cell[CellGroupData[{

Cell["Spanning Trees and \"Jumps\"", "Subsubsection"],

Cell["\<\
Fix a vertex, 1  say. We are interested in all the \"paths\" from 1.
It is easier if we choose one path from 1 to each of the  other vertices \
(that we can reach).
In fact we construct a spanning tree starting from 1. 
All the other possible edges between these vertices we will call \"jumps\".\
\>", "Emphasis",
  CellTags->"emphasis"]
}, Open  ]],

Cell[CellGroupData[{

Cell["load Graphics Of Trees", "Subsubsection",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "Get", "[", "\"\<ToolsFolder`DiscreteFolder`GraphicsOfTreesFns`\>\"", 
        "]"}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "init", "calc"}]
}, Closed]],

Cell[CellGroupData[{

Cell["reln and action tree", "Subsubsection"],

Cell["\<\
We use a generic rule based construction of trees. 
For this purpose we first turn the group actions into a relational form.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"reln", "=", 
        RowBox[{"Flatten", "[", 
          RowBox[{
            RowBox[{"theGpGens", "/.", 
              RowBox[{
                RowBox[{"LPerm", "[", 
                  RowBox[{"l_", ",", "\[Sigma]_"}], "]"}], "\[RuleDelayed]", 
                "\[IndentingNewLine]", 
                RowBox[{"Cases", "[", 
                  RowBox[{"\[Sigma]", ",", 
                    RowBox[{
                      RowBox[{"HoldPattern", "[", 
                        RowBox[{"i_", "\[Rule]", "j_"}], "]"}], "\[Rule]", 
                      RowBox[{"{", 
                        RowBox[{"i", ",", "l", ",", "j"}], "}"}]}]}], 
                  "]"}]}]}], ",", "1"}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell[CellGroupData[{

Cell[BoxData["reln"], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"1", ",", "\<\"a\"\>", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", "\<\"a\"\>", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", "\<\"a\"\>", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", "\<\"a\"\>", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5", ",", "\<\"a\"\>", ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6", ",", "\<\"a\"\>", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"9", ",", "\<\"a\"\>", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"10", ",", "\<\"a\"\>", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", "\<\"b\"\>", ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", "\<\"b\"\>", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", "\<\"b\"\>", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5", ",", "\<\"b\"\>", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6", ",", "\<\"b\"\>", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7", ",", "\<\"b\"\>", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"8", ",", "\<\"b\"\>", ",", "7"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"9", ",", "\<\"b\"\>", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"1", ",", "\<\"c\"\>", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", "\<\"c\"\>", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", "\<\"c\"\>", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", "\<\"c\"\>", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5", ",", "\<\"c\"\>", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7", ",", "\<\"c\"\>", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"8", ",", "\<\"c\"\>", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"9", ",", "\<\"c\"\>", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"10", ",", "\<\"c\"\>", ",", "7"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"1", ",", "\<\"d\"\>", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", "\<\"d\"\>", ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", "\<\"d\"\>", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", "\<\"d\"\>", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"5", ",", "\<\"d\"\>", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6", ",", "\<\"d\"\>", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7", ",", "\<\"d\"\>", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"8", ",", "\<\"d\"\>", ",", "7"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"9", ",", "\<\"d\"\>", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"10", ",", "\<\"d\"\>", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"2", ",", "\<\"e\"\>", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"3", ",", "\<\"e\"\>", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", "\<\"e\"\>", ",", "7"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"6", ",", "\<\"e\"\>", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"7", ",", "\<\"e\"\>", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"8", ",", "\<\"e\"\>", ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"9", ",", "\<\"e\"\>", ",", "8"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["Here we construct the spanning tree and jumps.", "Emphasis",
  CellTags->"emphasis"],

Cell[BoxData[
    RowBox[{
      RowBox[{"astatestree", "=", 
        RowBox[{"StatesTreeOf", "[", 
          RowBox[{"1", ",", "\[IndentingNewLine]", 
            RowBox[{"branchesofof", "[", "reln", "]"}]}], "]"}]}], 
      ";"}]], "Input",
  CellTags->{"pathinit", "calc"}],

Cell["Extract the tree and vertex labelling we want:", "SmallText"],

Cell[BoxData[
    RowBox[{
      RowBox[{"actiontree", "=", 
        RowBox[{"astatestree", "/.", 
          RowBox[{
            RowBox[{"TStatesTree", "[", 
              RowBox[{"states_", ",", "tr_"}], "]"}], "\[RuleDelayed]", 
            RowBox[{"(", 
              RowBox[{"tr", "/.", 
                RowBox[{"Thread", "[", 
                  RowBox[{
                    RowBox[{"Range", "[", 
                      RowBox[{"Length", "[", "states", "]"}], "]"}], 
                    "\[Rule]", "states"}], "]"}]}], ")"}]}]}]}], 
      ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["print tree", "Subsubsection",
  CellTags->"enfold"],

Cell[BoxData["actiontree"], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}],

Cell[BoxData[
    RowBox[{"Fork", "[", 
      RowBox[{"1", ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Branch", "[", 
              RowBox[{"\<\"a\"\>", ",", 
                RowBox[{"Fork", "[", 
                  RowBox[{"2", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"a\"\>", ",", "10"}], "]"}], ",", 
                        RowBox[{"Branch", "[", 
                          RowBox[{"\<\"b\"\>", ",", 
                            RowBox[{"Fork", "[", 
                              RowBox[{"6", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"a\"\>", ",", "9"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"b\"\>", ",", "2"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"d\"\>", ",", "3"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"e\"\>", ",", "9"}], 
                                      "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
                        RowBox[{"Branch", "[", 
                          RowBox[{"\<\"c\"\>", ",", 
                            RowBox[{"Fork", "[", 
                              RowBox[{"3", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"a\"\>", ",", "4"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"b\"\>", ",", "8"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"c\"\>", ",", "10"}], "]"}],
                                     ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"d\"\>", ",", "5"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"e\"\>", ",", "2"}], 
                                      "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"d\"\>", ",", "6"}], "]"}], ",", 
                        RowBox[{"Branch", "[", 
                          RowBox[{"\<\"e\"\>", ",", 
                            RowBox[{"Fork", "[", 
                              RowBox[{"4", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"a\"\>", ",", "3"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"b\"\>", ",", "5"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"c\"\>", ",", "8"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"d\"\>", ",", "1"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"e\"\>", ",", "7"}], 
                                      "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
                      "}"}]}], "]"}]}], "]"}], ",", 
            RowBox[{"Branch", "[", 
              RowBox[{"\<\"c\"\>", ",", 
                RowBox[{"Fork", "[", 
                  RowBox[{"9", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"a\"\>", ",", "1"}], "]"}], ",", 
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"b\"\>", ",", "4"}], "]"}], ",", 
                        RowBox[{"Branch", "[", 
                          RowBox[{"\<\"c\"\>", ",", 
                            RowBox[{"Fork", "[", 
                              RowBox[{"5", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"a\"\>", ",", "6"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"b\"\>", ",", "9"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"c\"\>", ",", "4"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"d\"\>", ",", "4"}], 
                                      "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"d\"\>", ",", "2"}], "]"}], ",", 
                        RowBox[{"Branch", "[", 
                          RowBox[{"\<\"e\"\>", ",", 
                            RowBox[{"Fork", "[", 
                              RowBox[{"8", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"b\"\>", ",", "7"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"c\"\>", ",", "1"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"d\"\>", ",", "7"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"e\"\>", ",", "6"}], 
                                      "]"}]}], "}"}]}], "]"}]}], "]"}]}], 
                      "}"}]}], "]"}]}], "]"}], ",", 
            RowBox[{"Branch", "[", 
              RowBox[{"\<\"d\"\>", ",", 
                RowBox[{"Fork", "[", 
                  RowBox[{"10", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"a\"\>", ",", "5"}], "]"}], ",", 
                        RowBox[{"Branch", "[", 
                          RowBox[{"\<\"c\"\>", ",", 
                            RowBox[{"Fork", "[", 
                              RowBox[{"7", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"b\"\>", ",", "3"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"c\"\>", ",", "2"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"d\"\>", ",", "8"}], "]"}], 
                                    ",", 
                                    RowBox[{"Jump", "[", 
                                      RowBox[{"\<\"e\"\>", ",", "3"}], 
                                      "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
                        RowBox[{"Jump", "[", 
                          RowBox[{"\<\"d\"\>", ",", "9"}], "]"}]}], "}"}]}], 
                  "]"}]}], "]"}]}], "}"}]}], "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["box form of tree", "Subsubsection"],

Cell["Here is the tree in a notational form.", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"actiontree", "//.", "boxoftreerule"}], "//", 
      "DisplayForm"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell[BoxData[
    TagBox[
      OverscriptBox[
        OverscriptBox[GridBox[{
              {
                OverscriptBox[
                  OverscriptBox[
                    OverscriptBox[GridBox[{
                          {GridBox[{
                                {"a"},
                                {"\[DownArrow]"},
                                {"10"}
                                }], 
                            OverscriptBox[
                              OverscriptBox[
                                OverscriptBox[GridBox[{
                                      {GridBox[{
                                        {"a"},
                                        {"\[DownArrow]"},
                                        {"9"}
                                        }], GridBox[{
                                        {"b"},
                                        {"\[DownArrow]"},
                                        {"2"}
                                        }], GridBox[{
                                        {"d"},
                                        {"\[DownArrow]"},
                                        {"3"}
                                        }], GridBox[{
                                        {"e"},
                                        {"\[DownArrow]"},
                                        {"9"}
                                        }]}
                                      }], "\[OverBrace]"], "6"], 
                              UnderscriptBox["b", "|"]], 
                            OverscriptBox[
                              OverscriptBox[
                                OverscriptBox[GridBox[{
                                      {GridBox[{
                                        {"a"},
                                        {"\[DownArrow]"},
                                        {"4"}
                                        }], GridBox[{
                                        {"b"},
                                        {"\[DownArrow]"},
                                        {"8"}
                                        }], GridBox[{
                                        {"c"},
                                        {"\[DownArrow]"},
                                        {"10"}
                                        }], GridBox[{
                                        {"d"},
                                        {"\[DownArrow]"},
                                        {"5"}
                                        }], GridBox[{
                                        {"e"},
                                        {"\[DownArrow]"},
                                        {"2"}
                                        }]}
                                      }], "\[OverBrace]"], "3"], 
                              UnderscriptBox["c", "|"]], GridBox[{
                                {"d"},
                                {"\[DownArrow]"},
                                {"6"}
                                }], 
                            OverscriptBox[
                              OverscriptBox[
                                OverscriptBox[GridBox[{
                                      {GridBox[{
                                        {"a"},
                                        {"\[DownArrow]"},
                                        {"3"}
                                        }], GridBox[{
                                        {"b"},
                                        {"\[DownArrow]"},
                                        {"5"}
                                        }], GridBox[{
                                        {"c"},
                                        {"\[DownArrow]"},
                                        {"8"}
                                        }], GridBox[{
                                        {"d"},
                                        {"\[DownArrow]"},
                                        {"1"}
                                        }], GridBox[{
                                        {"e"},
                                        {"\[DownArrow]"},
                                        {"7"}
                                        }]}
                                      }], "\[OverBrace]"], "4"], 
                              UnderscriptBox["e", "|"]]}
                          }], "\[OverBrace]"], "2"], 
                  UnderscriptBox["a", "|"]], 
                OverscriptBox[
                  OverscriptBox[
                    OverscriptBox[GridBox[{
                          {GridBox[{
                                {"a"},
                                {"\[DownArrow]"},
                                {"1"}
                                }], GridBox[{
                                {"b"},
                                {"\[DownArrow]"},
                                {"4"}
                                }], 
                            OverscriptBox[
                              OverscriptBox[
                                OverscriptBox[GridBox[{
                                      {GridBox[{
                                        {"a"},
                                        {"\[DownArrow]"},
                                        {"6"}
                                        }], GridBox[{
                                        {"b"},
                                        {"\[DownArrow]"},
                                        {"9"}
                                        }], GridBox[{
                                        {"c"},
                                        {"\[DownArrow]"},
                                        {"4"}
                                        }], GridBox[{
                                        {"d"},
                                        {"\[DownArrow]"},
                                        {"4"}
                                        }]}
                                      }], "\[OverBrace]"], "5"], 
                              UnderscriptBox["c", "|"]], GridBox[{
                                {"d"},
                                {"\[DownArrow]"},
                                {"2"}
                                }], 
                            OverscriptBox[
                              OverscriptBox[
                                OverscriptBox[GridBox[{
                                      {GridBox[{
                                        {"b"},
                                        {"\[DownArrow]"},
                                        {"7"}
                                        }], GridBox[{
                                        {"c"},
                                        {"\[DownArrow]"},
                                        {"1"}
                                        }], GridBox[{
                                        {"d"},
                                        {"\[DownArrow]"},
                                        {"7"}
                                        }], GridBox[{
                                        {"e"},
                                        {"\[DownArrow]"},
                                        {"6"}
                                        }]}
                                      }], "\[OverBrace]"], "8"], 
                              UnderscriptBox["e", "|"]]}
                          }], "\[OverBrace]"], "9"], 
                  UnderscriptBox["c", "|"]], 
                OverscriptBox[
                  OverscriptBox[
                    OverscriptBox[GridBox[{
                          {GridBox[{
                                {"a"},
                                {"\[DownArrow]"},
                                {"5"}
                                }], 
                            OverscriptBox[
                              OverscriptBox[
                                OverscriptBox[GridBox[{
                                      {GridBox[{
                                        {"b"},
                                        {"\[DownArrow]"},
                                        {"3"}
                                        }], GridBox[{
                                        {"c"},
                                        {"\[DownArrow]"},
                                        {"2"}
                                        }], GridBox[{
                                        {"d"},
                                        {"\[DownArrow]"},
                                        {"8"}
                                        }], GridBox[{
                                        {"e"},
                                        {"\[DownArrow]"},
                                        {"3"}
                                        }]}
                                      }], "\[OverBrace]"], "7"], 
                              UnderscriptBox["c", "|"]], GridBox[{
                                {"d"},
                                {"\[DownArrow]"},
                                {"9"}
                                }]}
                          }], "\[OverBrace]"], "10"], 
                  UnderscriptBox["d", "|"]]}
              }], "\[OverBrace]"], "1"],
      DisplayForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D graphics of tree", "Section"],

Cell[CellGroupData[{

Cell["Construction of the graphics for the tree.", "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell["a point tree", "Subsubsection",
  CellTags->"enfold"],

Cell["\<\
Construct the width tree, then the point tree that lays out the points of the \
tree.\
\>", "SmallText",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"aptree", "=", 
        RowBox[{"PtTreeOf", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"WidthTreeOf", "[", "actiontree", "]"}]}], "]"}]}], 
      ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{

Cell["2D graphics of tree", "Subsubsection",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell["\<\
Now define the rules for positioning the nodes and construct the abstract \
arrows for the branches. 
We also need the plotrange and image size to scale the arrows.\
\>", "SmallText",
  CellTags->"enfold"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"ptrules", "=", 
        RowBox[{"PtRulesOfPtTree", "[", "aptree", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"arrs", "=", 
        RowBox[{"ArrowsOf", "[", "actiontree", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"imagesize", "=", 
        RowBox[{"{", 
          RowBox[{"400", ",", "200"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  
    RowBox[{
      RowBox[{"treerange", "=", 
        RowBox[{"rangeofTree", "[", "aptree", "]"}]}], ";"}]}], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{

Cell["2D graphics elements", "SmallText",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"treearrs2D", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"arrs", ",", 
            RowBox[{
              RowBox[{"ArrowIndex", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              "\[IndentingNewLine]", 
              RowBox[{"ArrowLabelled", "[", 
                RowBox[{
                  RowBox[{"ShrinkSeg", "[", 
                    RowBox[{
                      RowBox[{"ij", "/.", "ptrules"}], ",", ".9"}], "]"}], 
                  ",", "a", ",", 
                  RowBox[{"{", 
                    RowBox[{"treerange", ",", "imagesize"}], "}"}]}], "]"}]}],
             ",", "Infinity"}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"nodes2D", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"ptrules", ",", 
            RowBox[{
              RowBox[{"HoldPattern", "[", 
                RowBox[{"i_", "\[Rule]", "p_"}], "]"}], "\[RuleDelayed]", 
              "\[IndentingNewLine]", 
              RowBox[{"Text", "[", 
                RowBox[{"i", ",", "p"}], "]"}]}]}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"lines2D", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"arrs", ",", 
            RowBox[{
              RowBox[{"ArrowIndex", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
                  RowBox[{"Line", "[", 
                    RowBox[{"ij", "/.", "ptrules"}], "]"}]}], "}"}]}], ",", 
            "Infinity"}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2D Graphics of the spanning tree", "Subsection"],

Cell["Here is the spaning tree:", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            RowBox[{"nodes2D", ",", "treearrs2D"}], "}"}], "]"}], "]"}], 
      ";"}]], "Input",
  Evaluatable->False,
  CellTags->"calc"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.21325 0.304281 0.114662 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .97619 .01763 0 0 Mshowa
[(3)] .97619 .13229 0 0 Mshowa
[(4)] .97619 .24695 0 0 Mshowa
[(2)] .64214 .13229 0 0 Mshowa
[(5)] .91937 .36161 0 0 Mshowa
[(8)] .91937 .47627 0 0 Mshowa
[(9)] .64214 .41894 0 0 Mshowa
[(7)] .89838 .59094 0 0 Mshowa
[(10)] .64214 .59094 0 0 Mshowa
[(1)] .02381 .30428 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.65884 .12656 m
.95949 .02336 L
s
.95254 .03859 m
.95949 .02336 L
.94725 .01472 L
s
gsave
.80652 .06302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.65884 .13229 m
.95949 .13229 L
s
.94954 .14467 m
.95949 .13229 L
.94954 .11991 L
s
gsave
.80917 .11991 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.65884 .13802 m
.95949 .24122 L
s
.94725 .24986 m
.95949 .24122 L
.95254 .22599 L
s
gsave
.81181 .17768 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.656 .41608 m
.9055 .36448 L
s
.89732 .37872 m
.9055 .36448 L
.89406 .35429 L
s
gsave
.77912 .37806 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.656 .42181 m
.9055 .47341 L
s
.89406 .48359 m
.9055 .47341 L
.89732 .45916 L
s
gsave
.78238 .43539 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.65495 .59094 m
.88557 .59094 L
s
.87562 .60332 m
.88557 .59094 L
.87562 .57855 L
s
gsave
.77026 .57855 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05473 .29568 m
.61122 .14089 L
s
.60368 .15567 m
.61122 .14089 L
.59934 .1315 L
s
gsave
.3308 .2062 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05473 .31001 m
.61122 .41321 L
s
.59992 .42363 m
.61122 .41321 L
.60285 .39914 L
s
gsave
.33444 .34936 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05473 .31861 m
.61122 .5766 L
s
.59843 .58388 m
.61122 .5766 L
.60537 .56068 L
s
gsave
.33645 .436 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{452.312, 279.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007400015a000`40O003h00OogooaGoo003oOoo5
Ool00?moolEoo`00ogooaGoo003oOoo5Ool00?mookMoo`<000]oo`00ogoo]Woo00D007ooOomoo`00
00Yoo`00ogoo[7oo0P0027oo00D007ooOomoo`0000Yoo`00ogoo[Woo0P001Woo10002goo003oOon`
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00?mook1oo`8000Eoo`03001oogoo00]oo`00ogoo[Goo
0`0000=oo`00Ool01Goo0P002goo003oOonZOol30003Ool00`00Oomoo`0BOol00?moojMoo`<000Io
o`03001oogoo019oo`00ogooY7oo0`0027oo00<007ooOol04goo003oOonQOol3000;Ool00`00Oomo
o`0COol00?mooiioo`<000ioo`03001oogoo01=oo`00ogooVgoo0`0047oo00<007ooOol057oo003o
OonIOol2000ZOol00?mooiIoo`<002aoo`00ogooTgoo0`00;goo003oOon@Ool3000bOol00?mooheo
o`<003Eoo`00ogooRWoo0`00>7oo003oOon7Ool3000kOol00?moohAoo`<003ioo`00ogooJGoo1000
5Goo0P00@Goo003oOomZOol01000Oomoo`004Goo0`00@goo003oOomZOol01000Oomoo`003Woo0`00
AWoo003oOomZOol01000Oomoo`002goo0`00BGoo003oOomZOol30009Ool3001<Ool00?moofYoo`03
001oogoo00Ioo`<004moo`00ogooJGoo0P001Goo0`00DWoo003oOom]Ool3001EOol00?moof]oo`80
05Qoo`00ogooJ7oo0`00FWoo003oOomUOol3001MOol00?moof9oo`<0061oo`00ogooGgoo0`00Hgoo
003oOomLOol3001VOol00?mooeUoo`<006Uoo`00ogooEgoo0P00K7oo003oOomDOol3001^Ool00?mo
oe5oo`<0075oo`00ogooCWoo0`00M7oo003oOom;Ool3001gOol00?moodQoo`<007Yoo`00ogooAGoo
0`00OGoo003oOom2Ool30020Ool00?mood1oo`8008=oo`00ogoo?Goo0`00QGoo003oOoljOol30028
Ool00?moocMoo`<0039oo`<005Ioo`00ogoo=7oo0`00=7oo00D007ooOomoo`0005Eoo`00ogoo<Goo
0`00=goo00<007ooOol0?goo00<007ooOol05Goo003oOol^Ool3000jOol01@00Oomoogoo0000?Goo
00<007ooOol05Goo003oOol[Ool3000nOol3000oOol00`00Oomoo`0DOol00?mooamoo`D000Ioo`03
001oogoo089oo`03001oogoo00Eoo`<000]oo`00ogoo87oo00@007ooOol008]oo`03001oogoo00Ao
o`05001oogooOol0000:Ool00?moo`moo`80011oo`03001oogoo08aoo`03001oogoo00Moo`03001o
ogoo00Qoo`00ogoo4Goo00<007ooOol03Woo00<007ooOol01GooR0001Woo0P002goo003oOolBOol0
0`00Oomoo`0:Ool01@00Oomoogoo0000SGoo00<007ooOol01Woo00<007ooOol027oo003oOolCOol0
0`00Oomoo`09Ool01@00Oomoogoo00001Woo0P00Q7oo00<007ooOol00goo00D007ooOomoo`0000Yo
o`00ogoo4Woo0`002goo0`002Goo0`00P7oo00<007ooOol01Goo0`002goo003oOol?Ool30002Ool0
0`00Oomoo`0HOol3001lOol00`00Oomoo`0DOol00?moo`]oo`@000Aoo`03001oogoo01aoo`<007Qo
o`03001oogoo01Eoo`00ogoo1goo100027oo00<007ooOol07goo0`00SGoo003oOol4Ool3000;Ool0
0`00Oomoo`0SOol3002:Ool00?moo`@000ioo`03001oogoo02Ioo`<008Moo`00o7oo0`004Woo00<0
07ooOol0:Goo0`00Q7oo003hOol4000DOol00`00Oomoo`0]Ool20022Ool00?Eoo`<004Yoo`<007mo
o`00lGoo1000D7oo0`00O7oo003]Ool4001GOol3001iOol00>Yoo`<005ioo`<007Ioo`00iWoo1000
I7oo0`00Lgoo003SOol3001[Ool3001`Ool00=moo`@0075oo`<006eoo`00fgoo1000N7oo0P004goo
0`00EGoo003HOol3001nOol3000?Ool00`00Oomoo`1FOol00=Aoo`@008Aoo`<000aoo`D005Aoo`00
dGoo0`00Rgoo0`002Goo00D007ooOomoo`0005Aoo`00cGoo1000TGoo0`001goo0`00EGoo0039Ool4
002HOol3001LOol00<Ioo`<009moo`<005Uoo`00`Woo1000YGoo0`00EWoo002oOol3002/Ool2001D
Ool00;]oo`@00;5oo`<0055oo`00^7oo0`00^7oo0`00CWoo002dOol4002nOol3001;Ool00;1oo`@0
0<Eoo`<004Qoo`00Tgoo10005Woo0`00c7oo0`00AGoo002BOol01000Oomoo`004goo1000dWoo0`00
@Woo002COol3000@Ool3003IOol20010Ool0099oo`04001oogoo000<Ool4003NOol3000mOol009=o
o`8000Uoo`@00>Eoo`<003Yoo`00Vgoo0`00k7oo0`00=goo002GOol4003bOol3000dOol009Aoo`<0
0?Uoo`<0035oo`00T7oo1000ogoo0`00;Woo002=Ool3003oOol7Ool3000[Ool008Uoo`@00?moo`eo
o`8002Uoo`00QGoo1000ogoo4goo0`003goo00<007ooOol057oo0022Ool3003oOolJOol3000<Ool0
0`00Oomoo`0DOol007ioo`@00?moob1oo`<000Yoo`03001oogoo01=oo`00Ngoo0`00ogoo9goo0`00
1goo00<007ooOol04goo001gOol4003oOol]Ool30005Ool00`00Oomoo`0BOol007=oo`@00?moocAo
o`<0009oo`03001oogoo019oo`00L7oo0`00ogoo>goo0`0057oo001/Ool4003oOom0Ool20006Ool3
000:Ool006Uoo`<00?mood=oo`03001oogoo00Moo`03001oogoo00Uoo`00IGoo1000ogooAGoo00<0
07ooOol01Goo1@002Woo001ROol3003oOom8Ool00`00Oomoo`06Ool01000Oomoo`002goo001NOol4
003oOom:Ool00`00Oomoo`08Ool00`00Ool0000;Ool005Yoo`@00?mooeYoo`8000]oo`00Egoo0`00
ogooGgoo00<007ooOol02Goo001COol4003oOom^Ool0051oo`<00?moog9oo`00C7oo1000ogooMGoo
0018Ool4003oOomiOol004Eoo`<00?moogeoo`00@Goo1000ogooP7oo000nOol3003oOon4Ool003Yo
o`@00?moohMoo`00=Woo1000ogooRgoo000cOol3003oOon?Ool002moo`@00?mooi9oo`00;7oo0`00
ogooUWoo000XOol4003oOonIOol002Eoo`<00?mooieoo`008Goo1000ogooX7oo000MOol4003oOonT
Ool001Yoo`<00?moojQoo`0067oo0P00ogooZgoo003oOoo5Ool000Uoo`<00?mookUoo`002Woo00<0
07ooOol0ogoo^7oo000:Ool00`00Oomoo`3oOonhOol000Yoo`03001oogoo0?mookQoo`002Woo00<0
07ooOol0ogoo^7oo0009Ool2000=Ool4003oOonYOol000Yoo`03001oogoo00moo`D00?moojAoo`00
8Goo1P00ogooWWoo000WOol5003oOonIOol001Qoo`80019oo`H00?mooi=oo`006Woo0P005Woo1@00
ogooSWoo000LOol2000IOol5003oOon9Ool001ioo`<001]oo`H00?mooh=oo`008Goo0P007goo1@00
ogooOWoo000SOol2000ROol6003oOomhOol002Eoo`8002Ioo`D00?moog=oo`009goo0P00:Goo1P00
ogooKGoo000YOol2000]Ool5003oOomXOol002]oo`<002moo`H00?moof9oo`00;Woo0P00<goo1@00
ogooGGoo000`Ool2000fOol6000WOol3003oOol]Ool0039oo`8003Yoo`D0025oo`05001oogooOol0
003oOol/Ool003Aoo`8003eoo`D001aoo`03001oogoo0?moobioo`00=Woo0P00@7oo1P005Woo00D0
07ooOomoo`000?moobaoo`00>7oo0`00@goo1@004Woo0`00ogoo;Goo000kOol20016Ool6003oOol;
Ool20007Ool3000UOol003eoo`8004Yoo`D00?moo`Qoo`03001oogoo00=oo`05001oogooOol0000T
Ool003moo`8004eoo`H00?moo`=oo`03001oogoo00Ioo`03001oogoo029oo`00@Goo0P00DGoo1@00
oWoo00<007ooOol01Goo00<007ooOol08Woo0013Ool2001DOol6003gOol30002Ool4000UOol004Eo
o`<005Moo`D00>eoo`D0009oo`04001oogoo000XOol004Qoo`8005Yoo`H00>9oo`D000Ioo`04001o
ogooOol5000TOol004Yoo`8005ioo`D00=Qoo`D000]oo`03001oogoo02Yoo`00C7oo0P00HGoo1P00
Z7oo0`008Woo1@003goo00<007ooOol0:goo001>Ool2001UOol5002ROol01@00Oomoogoo000077oo
1@004goo00<007ooOol0;7oo001@Ool2001XOol5002MOol00`00Oomoo`0IOol5000HOol00`00Oomo
o`0/Ool0059oo`<006Yoo`H009Moo`05001oogooOol0000BOol5000LOol00`00Oomoo`0]Ool005Eo
o`8006ioo`D009=oo`<000ioo`D0055oo`00Egoo0P00LGoo1P00VGoo1@00EWoo001IOol2001eOol5
002?Ool5001KOol005]oo`8007Qoo`H008Aoo`D0061oo`00GGoo0P00O7oo1@00Ngoo1000IGoo001O
Ool2001oOol6001`Ool5001YOol0065oo`<0089oo`D006Ioo`D006ioo`00I7oo0P00QGoo1P00Fgoo
1@00Lgoo001VOol20029Ool5000JOol00`00Oomoo`0dOol5001hOol006Qoo`8008aoo`D001Eoo`03
001oogoo02moo`D007eoo`00JWoo0P00Sgoo1P0047oo00<007ooOol0:Goo1@00PWoo001/Ool2002C
Ool5000;Ool00`00Oomoo`0TOol50027Ool006ioo`<009Eoo`H000Ioo`03001oogoo01ioo`D008ao
o`00LGoo0P00VGoo1@0000=oo`00Ool06Woo1@00TGoo001cOol2002LOol3000;Ool20008Ool5002F
Ool007Eoo`8009]oo`03001oogoo00aoo`03001oogoo00=oo`8009]oo`00Mgoo0P00V7oo00<007oo
Ool03Woo00<007ooOol0Wgoo001iOol2002EOol00`00Oomoo`0<Ool4002QOol007]oo`<0095oo`03
001oogoo00aoo`05001oogooOol00004Ool3002JOol007ioo`8008ioo`03001oogoo00eoo`05001o
ogooOol00007Ool5002EOol0081oo`8009eoo`<000eoo`D0091oo`00PWoo0P00/7oo1@00Rgoo0024
Ool2000?Ool4002POol5000POol3001SOol008Ioo`8000aoo`04001oogoo002VOol5000JOol00`00
Oomoo`1TOol008Qoo`<000Uoo`04001oogoo002[Ool5000EOol5001ROol008]oo`8000Moo`04001o
ogoo002`Ool5000@Ool01@00Oomoogoo0000HWoo002=Ool20006Ool3002eOol5000<Ool3001SOol0
08moo`8000Ioo`03001oogoo0;Qoo`D006eoo`00TGoo0P000goo0P00_goo1@00J7oo002COol20037
Ool5001SOol009Eoo`<00<Uoo`@005moo`00V7oo0P00bgoo1@00FWoo002JOol2003>Ool5001EOol0
09aoo`800=5oo`D0051oo`00WWoo0P00e7oo1@00Bgoo002POol2003GOol5000FOol00`00Oomoo`0]
Ool00:9oo`<00=Uoo`D0015oo`03001oogoo02eoo`00YGoo0P00g7oo1@003Goo00<007ooOol0;7oo
002WOol2003OOol50009Ool00`00Oomoo`0[Ool00:Uoo`800>9oo`D000Aoo`03001oogoo02]oo`00
Zgoo0P00iGoo1P0017oo0`009Goo002]Ool2003XOol20002Ool01@00Oomoogoo000097oo002_Ool3
003UOol01@00Oomoogoo00000goo00<007ooOol08Woo002bOol2003ROol00`00Oomoo`03Ool3000U
Ool00;Aoo`800=moo`03001oogoo00=oo`05001oogooOol0000TOol00;Ioo`800=aoo`03001oogoo
00Aoo`05001oogooOol0000TOol00;Qoo`800=Uoo`03001oogoo00Ioo`<002Eoo`00^Woo0P00ogoo
2Goo002lOol3003oOol6Ool00;moo`800?moo`Aoo`00`Goo0P00ogoo0Woo0033Ool2003oOol00<Eo
o`800?eoo`00agoo0P00ngoo0039Ool3003hOol00<aoo`800?Ioo`00cWoo0P00m7oo003@Ool2003b
Ool00=9oo`800?1oo`00e7oo0P00kWoo003FOol2003/Ool00=Qoo`<00>Uoo`00fgoo0P00igoo003M
Ool2003UOol00=moo`800>=oo`00hGoo0P00hGoo003SOol2003OOol00>Eoo`<00=aoo`00j7oo0P00
fWoo003ZOol2003HOol00>aoo`800=Ioo`00kWoo0P00e7oo003`Ool2003BOol00?9oo`<00<moo`00
mGoo0P00cGoo003gOol2003;Ool00?Uoo`800<Uoo`00ngoo0P00agoo003mOol20035Ool00?moo`<0
0<9oo`00ogoo0goo0P00`7oo003oOol5Ool2000;Ool00`00Oomoo`2`Ool00?moo`Moo`8000Uoo`03
001oogoo0;1oo`00ogoo2Goo0P001goo00<007ooOol0/7oo003oOol;Ool20006Ool00`00Oomoo`2_
Ool00?moo`eoo`<000=oo`03001oogoo0:moo`00ogoo47oo0P0000=oo`00Ool0/7oo003oOolBOol3
0015Ool3001XOol00?mooa=oo`8004Aoo`05001oogooOol0001WOol00?mooa5oo`8004Ioo`03001o
ogoo02moo`03001oogoo03Moo`00ogoo47oo00<007ooOol0AWoo00D007ooOomoo`0002ioo`03001o
ogoo03Ioo`00ogoo3goo00<007ooOol0B7oo0`00<7oo00<007ooOol0=Goo003oOolMOol30004Ool2
001XOol00`00Oomoo`04Ool00`00Oomoo`0]Ool00?mooaioo`03001oogoo009oo`04001oogoo001X
Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00?mooaioo`03001oogoo009oo`05001oogoo001oo`1Y
0005Ool00`00Oomoo`0/Ool00?mooaioo`03001oogoo009oo`04001oogoo001YOol00`00Oomoo`03
Ool00`00Oomoo`0/Ool00?mooaioo`03001oogoo009oo`04001oogoo001XOol00`00Oomoo`05Ool0
0`00Oomoo`0[Ool00?mooaeoo`8000Aoo`04001oogoo001WOol00`00Oomoo`02Ool01@00Oomoogoo
0000;Goo003oOolNOol00`00Oomoo`03Ool2001WOol00`00Oomoo`03Ool5000]Ool00?moohaoo`03
001oogoo03Ioo`00ogooRgoo00<007ooOol0=goo003oOoo5Ool00?moolEoo`00ogooaGoo003oOoo5
Ool00?moolEoo`00ogooaGoo0000\
\>"],
  ImageRangeCache->{{{0, 451.312}, {278.562, 0}} -> {-0.114722, -2.65375, \
0.010404, 0.0193496}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D spanning tree with jumps", "Subsection",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell["lines of jumps", "SmallText",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"jumps2D", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"arrs", ",", 
            RowBox[{
              RowBox[{"ArrowJump", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
                  RowBox[{"Line", "[", 
                    RowBox[{"ij", "/.", "ptrules"}], "]"}]}], "}"}]}], ",", 
            "Infinity"}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]],

Cell["Here the \"jump\" lines are superposed:", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{"Graphics", "[", 
          RowBox[{"{", 
            RowBox[{
            "nodes2D", ",", "lines2D", ",", "treearrs2D", ",", "jumps2D"}], 
            "}"}], "]"}], "]"}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->"calc"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.21325 0.304281 0.114662 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .97619 .01763 0 0 Mshowa
[(3)] .97619 .13229 0 0 Mshowa
[(4)] .97619 .24695 0 0 Mshowa
[(2)] .64214 .13229 0 0 Mshowa
[(5)] .91937 .36161 0 0 Mshowa
[(8)] .91937 .47627 0 0 Mshowa
[(9)] .64214 .41894 0 0 Mshowa
[(7)] .89838 .59094 0 0 Mshowa
[(10)] .64214 .59094 0 0 Mshowa
[(1)] .02381 .30428 0 0 Mshowa
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.64214 .13229 m
.97619 .01763 L
s
.64214 .13229 m
.97619 .13229 L
s
.64214 .13229 m
.97619 .24695 L
s
.64214 .41894 m
.91937 .36161 L
s
.64214 .41894 m
.91937 .47627 L
s
.64214 .59094 m
.89838 .59094 L
s
.02381 .30428 m
.64214 .13229 L
s
.02381 .30428 m
.64214 .41894 L
s
.02381 .30428 m
.64214 .59094 L
s
0 g
.65884 .12656 m
.95949 .02336 L
s
.95254 .03859 m
.95949 .02336 L
.94725 .01472 L
s
gsave
.80652 .06302 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.65884 .13229 m
.95949 .13229 L
s
.94954 .14467 m
.95949 .13229 L
.94954 .11991 L
s
gsave
.80917 .11991 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.65884 .13802 m
.95949 .24122 L
s
.94725 .24986 m
.95949 .24122 L
.95254 .22599 L
s
gsave
.81181 .17768 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.656 .41608 m
.9055 .36448 L
s
.89732 .37872 m
.9055 .36448 L
.89406 .35429 L
s
gsave
.77912 .37806 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.656 .42181 m
.9055 .47341 L
s
.89406 .48359 m
.9055 .47341 L
.89732 .45916 L
s
gsave
.78238 .43539 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.65495 .59094 m
.88557 .59094 L
s
.87562 .60332 m
.88557 .59094 L
.87562 .57855 L
s
gsave
.77026 .57855 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05473 .29568 m
.61122 .14089 L
s
.60368 .15567 m
.61122 .14089 L
.59934 .1315 L
s
gsave
.3308 .2062 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05473 .31001 m
.61122 .41321 L
s
.59992 .42363 m
.61122 .41321 L
.60285 .39914 L
s
gsave
.33444 .34936 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05473 .31861 m
.61122 .5766 L
s
.59843 .58388 m
.61122 .5766 L
.60537 .56068 L
s
gsave
.33645 .436 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.97619 .01763 m
.64214 .41894 L
s
.97619 .01763 m
.64214 .13229 L
s
.97619 .01763 m
.97619 .13229 L
s
.97619 .01763 m
.64214 .41894 L
s
.97619 .13229 m
.97619 .24695 L
s
.97619 .13229 m
.91937 .47627 L
s
.97619 .13229 m
.64214 .59094 L
s
.97619 .13229 m
.91937 .36161 L
s
.97619 .13229 m
.64214 .13229 L
s
.97619 .24695 m
.97619 .13229 L
s
.97619 .24695 m
.91937 .36161 L
s
.97619 .24695 m
.91937 .47627 L
s
.97619 .24695 m
.02381 .30428 L
s
.97619 .24695 m
.89838 .59094 L
s
.64214 .13229 m
.64214 .59094 L
s
.64214 .13229 m
.97619 .01763 L
s
.91937 .36161 m
.97619 .01763 L
s
.91937 .36161 m
.64214 .41894 L
s
.91937 .36161 m
.97619 .24695 L
s
.91937 .36161 m
.97619 .24695 L
s
.91937 .47627 m
.89838 .59094 L
s
.91937 .47627 m
.02381 .30428 L
s
.91937 .47627 m
.89838 .59094 L
s
.91937 .47627 m
.97619 .01763 L
s
.64214 .41894 m
.02381 .30428 L
s
.64214 .41894 m
.97619 .24695 L
s
.64214 .41894 m
.64214 .13229 L
s
.89838 .59094 m
.97619 .13229 L
s
.89838 .59094 m
.64214 .13229 L
s
.89838 .59094 m
.91937 .47627 L
s
.89838 .59094 m
.97619 .13229 L
s
.64214 .59094 m
.91937 .36161 L
s
.64214 .59094 m
.64214 .41894 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?mooaIoo`<000Qoo`00ogoo5Goo00D007ooOomoo`0000Moo`00ogoo47oo0P000goo00D007oo
Oomoo`0000Moo`00ogoo4Woo0P0000=oo`0000000W`027oo003oOolCOol01P00O01l07`0Ooml00Qo
o`00ogoo47oo00L007`0O01l0000Ool00002O008Ool00?moo`eoo`04001l07`0O002Ool01P00Oomo
og`0001l00Qoo`00ogoo2Woo00@007`0O01l00Eoo`04001oog`0Ool2O008Ool00?moo`Moo`04001l
07`0O008Ool01000O01oogoo0W`027oo003oOol4Ool01000O01l07`02Woo00<007`0Ool00Woo0W`0
27oo003oOol1Ool01000O01l07`03Woo00Al07ooOomoo`9l00Qoo`00oGoo00@007`0O01l011oo`03
O01oogoo009oo`9l00Qoo`00nWoo00@007`0O01l019oo`03O01oogoo00=oo`9l00Qoo`00mgoo00@0
07`0O01l01Aoo`03O01oogoo00=oo`=l00Qoo`00i7oo10003Goo0g`05Woo00=l07ooOol017oo0g`0
27oo003UOol01000Oomoo`002Goo0g`067oo00=l07ooOol01Goo0g`027oo003UOol01000Oomoo`00
1Woo0g`06goo00=l07ooOol01Goo00=l07ooO00027oo003UOol01000Oomoo`000goo0g`07Goo00=l
07ooOol01Woo00=l07ooO00027oo003UOol3000017ooO01l07`07goo00=l07ooOol01goo00=l07oo
O00027oo003UOol01000O01l07`08Goo00=l07ooOol01goo0W`000=oog`0Ool01goo003SOol3O00S
Ool00g`0Oomoo`08Ool2O0000gooO01oo`07Ool00>1oo`=l02Eoo`03O01oogoo00Uoo`9l0003Ooml
07oo00Moo`00gGoo0g`0:7oo00=l07ooOol02Goo0W`000=oog`0Ool01goo003JOol3O00ZOol00g`0
Oomoo`0:Ool2O0000gooO01oo`07Ool00=Moo`=l02aoo`03O01oogoo00]oo`04O01oogooO008Ool0
0=Aoo`=l0003001oogoo02]oo`03O01oogoo00]oo`9l009oo`03O01oogoo00Ioo`00dGoo0g`000<0
07ooOol0;Goo00=l07ooOol037oo0W`00Woo00=l07ooOol01Woo003>Ool3O0000`00Oomoo`0_Ool0
0g`0Oomoo`0=Ool2O002Ool00g`0Oomoo`06Ool00<]oo`=l0003001oogoo039oo`03O01oogoo00eo
o`9l009oo`03O01oogoo00Ioo`00b7oo0g`000<007ooOol0=7oo00=l07ooOol03Woo0W`00Woo00=l
07ooOol01Woo0035Ool3O0000`00Oomoo`0KOol3000HOol00g`0Oomoo`0?Ool2O002Ool00g`0Oomo
o`06Ool00<9oo`=l0003001oogoo01eoo`05001oogooOol0000FOol00g`0Oomoo`0@Ool2O002Ool0
0g`0Oomoo`06Ool00;moo`=l0003001oogoo021oo`03001oogoo01Moo`03O01oogoo00ioo`05001o
og`0Ooml0002Ool00g`0Oomoo`06Ool00;Eoo`D0009oo`=l0003001oogoo02=oo`05001oogooOol0
000DOol00g`0Oomoo`0@Ool01000O01l07oo0P0000=l07ooOol01Woo002fOol00`00Oomoo`03O000
0`00Oomoo`0WOol3000EOol00g`0Oomoo`0AOol2O0001@00Oomoog`000001goo002[Ool20009OomR
O0000`00Oomoo`05Ool00:eoo`03001oogoo00=oo`=l009oo`03O01oog`0009l03moo`03O01oogoo
01=oo`9l009oo`03001l07oo00Moo`00[Woo00<007`0O0000W`00Woo00<007ooOol00W`00Woo0P00
0W`0>goo00=l07ooOol057oo0W`00Woo0W`000<007ooOol01Goo002/Ool017`0000000001Goo00<0
07ooOol00W`017oo0`000W`0=goo00=l07ooOol057oo00Al07ooO00000=l0003001oogoo00Eoo`00
Z7oo0W`00`000Woo00<007ooOol017oo0P0000=l07ooO0001Woo0`000W`0<goo00=l07ooOol057oo
00<007`0Ool00W`000<007`0O00027oo002UOol00g`0000000020004Ool00`00Oomoo`07Ool00g`0
Ooml0009Ool30002O00`Ool00g`0Oomoo`0EOol01G`0Ooml07`0Ool00W`027oo002QOol00g`00000
00020008Ool00`00Oomoo`07Ool017`0Oomoog`02goo0`000W`0;7oo00=l07ooOol05Woo0g`00Woo
0W`027oo002MOol2O003000;Ool00`00Oomoo`08Ool01G`0OomoogooO0003Goo0`000W`0:7oo00=l
07ooOol05goo0W`00Woo0g`027oo002JOol00g`000000002000IOol01G`0OomoogooO00047oo0`00
00=l07ooOol08goo00=l07ooOol067oo0W`00Woo0g`027oo002FOol2O003000MOol00g`0Oomoo`02
Ool00g`0Oomoo`0@Ool300000g`0Oomoo`0OOol00g`0Oomoo`0HOol3O002Ool3O008Ool009=oo`03
O00000000080021oo`03O01oogoo009oo`03O01oogoo01=oo`<00003O01oogoo01]oo`03O01oogoo
01Uoo`03O01oog`0009oo`03O01oog`000Qoo`00Sgoo00=l000000000P0097oo00=l07ooOol00goo
00=l07ooOol05Goo0`0000=l07ooOol067oo00=l07ooOol067oo0W`000=oog`0Ool00W`000=oog`0
Ool01goo002<Ool017`000000000:7oo00=l07ooOol00goo00=l07ooOol067oo0P000W`02Goo0`00
2Woo00=l07ooOol06Goo0W`000=oog`0Ool00W`000=oog`0Ool01goo0028Ool00g`000000002000[
Ool00g`0Oomoo`04Ool00g`0Oomoo`0IOol30002O005Ool00`00Oomoo`0:Ool00g`0Oomoo`0IOol0
1W`0Ooml07ooO01oo`9l0003Ooml07oo00Moo`00QGoo1000;goo00=l07ooOol017oo00=l07ooOol0
77oo0`000W`00Woo1@001goo00=l07ooOol06Goo00=l07ooOol00W`00Woo0W`000=oog`0Ool01goo
0021Ool017`000000000<goo00=l07ooOol01Goo00=l07ooOol07Woo0`0000=l0000Ool00Woo00<0
07ooOol017oo00=l07ooOol06Woo00]l07ooO01oog`0Ooml07ooO01oog`000Qoo`00OWoo1000=Woo
00=l07ooOol01Woo00=l07ooOol087oo1@001Woo00=l07ooOol06Woo00Ml07ooOoml07ooO01oo`02
O002Ool00g`0Oomoo`06Ool007Yoo`04O0000000000jOol00g`0Oomoo`06Ool00g`0Oomoo`0SOol3
00000g`0Oomoo`02Ool00g`0Oomoo`0IOol027`0OomoogooO01oog`0Ool2O002Ool00g`0Oomoo`06
Ool007Moo`@003eoo`03O01oogoo00Moo`03O01oogoo02Eoo`<0009l01]oo`03O01oogoo009oo`04
O01oog`0Ool2O002Ool00g`0Oomoo`06Ool007=oo`@0045oo`03O01oogoo00Moo`03O01oogoo02Qo
o`04O0000000O00IOol00g`0Oomoo`02Ool017`0Ooml07oo0W`00Woo00=l07ooOol01Woo001MOol4
000>Ool017`000000000AGoo00=l07ooOol027oo00=l07ooOol09Woo00Al07ooOomoo`<00003O01o
ogoo01=oo`03O01oogoo00=oo`06O01oog`0O01oog`00Woo00=l07ooOol01Woo001LOol01000Oomo
o`0037oo1000B7oo00=l07ooOol027oo00=l07ooOol09Goo00=l07ooOol01Goo0`0000=l07ooOol0
3goo00=l07ooOol00goo00=l07ooOol00W`000Eoog`0Oomoog`000Qoo`00GGoo0`0027oo00Al0000
000004aoo`03O01oogoo00Uoo`03O01oogoo02=oo`03O01oogoo00Uoo`80009l00ioo`03O01oogoo
00=oo`04O01oog`0Ool3O002Ool00g`0Oomoo`06Ool005aoo`04001oogoo0005Ool4001?Ool00g`0
Oomoo`09Ool00g`0Oomoo`0SOol00g`0Oomoo`0;Ool30002O00:Ool00g`0Oomoo`04Ool017`0Ooml
07oo0W`00goo00=l07ooOol01Woo001MOol20002Ool4001COol00g`0Oomoo`0:Ool00g`0Oomoo`0Q
Ool00g`0Oomoo`0?Ool30002O006Ool00g`0Oomoo`05Ool01W`0Ooml07`0Ooml00=oo`03O01oogoo
00Ioo`00GWoo0`00Egoo00=l07ooOol02goo00=l07ooOol07goo00=l07ooOol04goo0`0000El07oo
Oomoog`000Qoo`06O01oog`0O01oog`00goo00=l07ooOol01Woo001JOol4001JOol00g`0Oomoo`0;
Ool00g`0Oomoo`0NOol00g`0Oomoo`0GOol30002O008Ool01W`0Ooml07`0Ooml00=oo`03O01oogoo
00Ioo`00EWoo1000GWoo00=l07ooOol037oo00=l07ooOol077oo00=l07ooOol06goo00Al0000001l
00Eoo`03O01oogoo009l0003Ooml07oo009oo`03O01oogoo00Ioo`00Dgoo0`0000=l07ooOol0Ggoo
00=l07ooOol037oo00=l07ooOol06goo00=l07ooOol06goo00Al07ooOomoo`<00004O01oogooO002
Ool017`0001l07`00goo00=l07ooOol01Woo001?Ool4001UOol00g`0Oomoo`0=Ool00g`0Oomoo`0J
Ool00g`0Oomoo`0JOol00g`0Oomoo`05Ool300001W`0Oomoog`0Ooml00Aoo`03O01oogoo00Ioo`00
C7oo0`0000=l07ooOol0IWoo00=l07ooOol03Goo00=l07ooOol06Goo00=l07ooOol06goo00=l07oo
Ool027oo00Il0000O01l07ooO004Ool00g`0Oomoo`06Ool004Qoo`@006aoo`03O01oogoo00ioo`03
O01oogoo01Moo`03O01oogoo01]oo`03O01oogoo00Uoo`05O01oog`0O0000002O002Ool00`00O000
0007Ool004Aoo`@0071oo`03O01oogoo00ioo`03O01oogoo01Ioo`03O01oogoo01]oo`03O01oogoo
00Yoo`03O01oog`0009oo`03O00007`000=l00Qoo`00@Goo0`0000=l07ooOol0LGoo00=l07ooOol0
3goo00=l07ooOol057oo00=l07ooOol077oo00=l07ooOol02Goo00=l07ooOol02G`000<007ooOol0
1Goo000mOol4001gOol00g`0Oomoo`0@Ool00g`0Oomoo`0BOol00g`0Oomoo`0LOolAO00017ooO01l
07oo0W`000=oog`0Ool01goo000jOol300000g`0Oomoo`1hOol00g`0Oomoo`0@Ool00g`0Oomoo`0B
Ool00g`0Oomoo`0<Ool@O00=Ool01G`0Oomoog`0Ool00g`000Aoo`00O01l00Qoo`00=Woo1000OWoo
00=l07ooOol04Goo00=l07ooOol047oo47`03Woo00=l07ooOol037oo00=l07ooO0000g`017oo00=l
0000Ool01goo000bOol400000g`0Oomoo`1oOol00g`0Oomoo`0AOol00g`0Oomoo`0@O00NOol00g`0
Oomoo`0<Ool01W`0Ooml07`0Ooml00=oo`9l0003001oogoo00Ioo`00;goo0`0000=l07ooOol0Pgoo
00=l07ooOol017oo47`03Woo00=l07ooOol077oo00=l07ooOol03Goo17`000=oog`0Ool00Woo0W`0
2Goo000[Ool400000g`0Oomoo`1mOol@O00>Ool00g`0Oomoo`0<Ool00g`0Oomoo`0LOol00g`0Oomo
o`0<Ool2O002Ool017`0Oomoog`00Woo00=l07ooO0002Goo000WOol400000g`0Oomoo`1aOol@O009
Ool00g`0Oomoo`0COol00g`0Oomoo`0:Ool00g`0Oomoo`0MOol00g`0Oomoo`0:Ool2O0000gooO01o
o`02O0000gooO01l0002Ool3O009Ool002Aoo`<0009l06Iooa1l01Uoo`03O01oogoo01=oo`03O01o
ogoo00Yoo`03O01oogoo01aoo`03O01oogoo00Yoo`06O01oogooOoml07oo0W`000Moog`0Oomoog`0
Ooml000:Ool0021oo`@00003O01oogoo05Qooa1l02Uoo`03O01oogoo01Aoo`03O01oogoo00Qoo`03
O01oogoo01aoo`03O01oogoo00Uoo`9l00Aoo`06O01oog`0O01oog`00Woo00=l07ooO0002Woo000M
Ool30002O01=Ool@O00iOol00g`0Oomoo`0EOol00g`0Oomoo`06Ool00g`0Oomoo`0LOol00g`0Oomo
o`08Ool2O006Ool027`0Ooml07`0Ooml07ooO002Ool00g`0Oomoo`08Ool001Uoo`@00003O01oogoo
03mooa1l04Uoo`03O01oogoo01Eoo`03O01oogoo00Eoo`03O01oogoo01eoo`03O01oogoo00Ioo`9l
00Qoo`9l0007Ooml07ooO01oog`0Ool00W`02Woo000EOol400000g`0Oomoo`0cOol@O01IOol00g`0
Oomoo`0FOol00g`0Oomoo`03Ool00g`0Oomoo`0MOol00g`0Oomoo`05Ool2O00:Ool2O0000gooO01o
o`02O002Ool00g`0Oomoo`09Ool0019oo`<0009l02Qooa1l06Uoo`03O01oogoo01Ioo`03O01oogoo
009oo`03O01oogoo01eoo`03O01oogoo00Aoo`9l00]oo`04O01oog`0Ool4O002Ool00g`0Oomoo`09
Ool000Eoo`<000Qoo`800003O01oogoo01Yooa1l07Uoo`03O01oogoo01Moo`05O01oogooOoml000O
Ool00g`0Oomoo`02Ool2O00=Ool01G`0Ooml07`0Ool00W`00goo00=l07ooOol02Goo0006Ool00`00
Oomoo`03Ool4O00?Ool@O029Ool00g`0Oomoo`0GOol017`0Oomoog`07goo00Al07ooOomoo`9l00mo
o`9l0003Ooml07oo009l009oo`9l00]oo`001Woo00<007ooOol00g`00goo47`0VGoo00=l07ooOol0
67oo0W`07goo00=l07ooOol00W`04Goo0W`000Aoog`0Ooml00=oo`9l00]oo`001Woo00<007`0O000
1W`0ZGoo00=l07ooOol067oo00=l07ooOol07Goo00Al07ooO01l01=oo`9l0004Ooml07ooO003Ool0
0g`0Oomoo`0:Ool000Ioo`03001oogoo00Ml00@00:Aoo`03O01oogoo01Moo`03O01oog`001ioo`9l
01Eoo`9l0004Ooml07ooO003Ool00g`0Oomoo`0:Ool000Eoo`8000Aoo`9l00=oo`Il00<009moo`03
O01oogoo01Ioo`04O01oogooO00LOol2O00FOol017`0Ooml07oo0g`00goo00=l07ooOol02Woo0006
Ool00`00Oomoo`04Ool3O005Ool6O003002JOol00g`0Oomoo`0FOol01G`0OomoogooO0006Goo0g`0
5goo0W`00Woo0g`00Woo0W`037oo000@Ool20008Ool7O003002DOol00g`0Oomoo`0EOol00g`0Oomo
o`03Ool00g`0Oomoo`0DOol2O0000gooO01oo`0GOol2O002Ool2O003Ool00g`0Oomoo`0;Ool0019o
o`8000aoo`Il00<008moo`03O01oogoo01Aoo`03O01oogoo00Aoo`03O01oogoo019oo`9l00=oo`03
O01oogoo01Ioo`9l0004Ooml07`0O003Ool00g`0Oomoo`0;Ool001Aoo`8000moo`Ml008008Yoo`03
O01oogoo01=oo`03O01oogoo00Ioo`03O01oogoo00moo`9l00Aoo`03O01oogoo01Moo`9l0004Ooml
07ooO003Ool00g`0Oomoo`0;Ool001Ioo`<0015oo`Ml008008Eoo`03O01oogoo019oo`03O01oogoo
00Moo`03O01oogoo00eoo`9l00Eoo`03O01oogoo01Qoo`06O01oogooO01oog`00Woo0W`03Goo000H
Ool00g`00000000DOol8O002001oOol00g`0Oomoo`0AOol00g`0Oomoo`09Ool00g`0Oomoo`0;Ool0
0g`0Oomoo`05Ool00g`0Oomoo`0GOol2O0000gooO01l0002O002Ool2O00=Ool001Yoo`03O0000000
01Moo`Ul0003001oogoo07Qoo`03O01oogoo015oo`03O01oogoo00Uoo`03O01oogoo00Uoo`9l00Mo
o`03O01oogoo01Qoo`9l0003Ooml07`0009l009oo`03O01oogoo00aoo`007Goo0P006goo27`000<0
07ooOol0Lgoo00=l07ooOol047oo00=l07ooOol02goo00=l07ooOol01Woo0W`027oo00=l07ooOol0
6Goo0g`000=oog`0O0000goo00=l07ooOol037oo000OOol2000NOol9O0000`00Oomoo`0COol3001G
Ool00g`0Oomoo`0?Ool00g`0Oomoo`0<Ool00g`0Oomoo`04Ool2O009Ool00g`0Oomoo`0JOol017`0
Ooml07oo0W`00Woo0W`03Woo000QOol2000QOol9O0000`00Oomoo`0=Ool01@00Oomoogoo0000EWoo
00=l07ooOol03Woo00=l07ooOol03Woo00Al07ooOomoo`9l00]oo`03O01oogoo01Yoo`9l009oo`9l
009oo`9l00ioo`008goo0P0097oo2W`02Woo00<007ooOol0F7oo00=l07ooOol03Goo00=l07ooOol0
47oo0g`037oo00=l07ooOol06goo0W`000Aoog`0Ooml009oo`03O01oogoo00eoo`009Goo0`009goo
2G`000<007ooOol00Woo00D007ooOomoo`0005Ioo`03O01oogoo00aoo`03O01oogoo011oo`9l00eo
o`03O01oogoo01Aoo`03001oogoo009oo`80009l009oo`=l009oo`03O01oogoo00eoo`009goo00=l
00000000:Woo2W`00`00Egoo00=l07ooOol037oo00=l07ooOol03Woo0W`00Woo00=l07ooOol02Woo
00=l07ooOol05Goo00@007ooOol0009oo`9l009oo`=l0003Ooml07`000moo`00:Goo00=l00000000
;Goo2W`0EGoo00=l07ooOol02goo00=l07ooOol03Goo0W`017oo00=l07ooOol02Goo00=l07ooOol0
5goo00<007ooOol00g`000<007ooOol00W`00Woo0W`03goo000/Ool2000`Ool;O01?Ool00g`0Oomo
o`0:Ool00g`0Oomoo`0<Ool2O007Ool00g`0Oomoo`07Ool00g`0Oomoo`0FOol6O002Ool00`00Oomo
o`02O002Ool2O00?Ool002ioo`8003=oo`]l04Yoo`03O01oogoo00Uoo`03O01oogoo00]oo`9l00Uo
o`03O01oogoo00Ioo`03O01oogoo019oo`El0005001oogoo001l00030003Ool2O002Ool00g`0Oomo
o`0>Ool0031oo`8003Moo`]l04Aoo`03O01oogoo00Qoo`03O01oogoo00Yoo`9l00]oo`03001l0000
00Ioo`03O01oogoo00eoo`El0003001oogoo00Aoo`03001l000000Ioo`9l0003Ooml07`0011oo`00
<Woo0P00>Woo1G`000<007`0O0000g`0?goo00=l07ooOol01goo00=l07ooOol02Goo0W`037oo00D0
07ooO01oo`0000Aoo`03O01oogoo00Uoo`El0003001oogoo00Uoo`03O01oo`0000@0009oo`9l0003
Ooml07`0011oo`00=7oo0`00?7oo1G`000<007`0O00017`0>Goo00=l07ooOol01goo00=l07ooOol0
1goo0W`03Woo00@007ooOoml00Aoo`03O01oogoo00Eoo`El0003001oogoo00aoo`9l00Qoo`=l0003
Ooml07`0011oo`00=Woo00=l00000000?goo1W`000<007`0O0000g`0=7oo00=l07ooOol01Woo00=l
07ooOol01Woo0W`047oo00D007ooOomoog`000=oo`03O01oogoo00El0080015oo`03O01oogoo00Qo
o`9l009oo`03O01oogoo00moo`00>Goo0P00@goo1G`000<007`0O00017`0;Woo00=l07ooOol01Goo
00=l07ooOol01Goo0W`04goo0`0000=l07ooO00017`00P005Goo00=l07ooOol02Goo0W`000=oog`0
O0004Goo000kOol20016Ool5O0020006O00XOol00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomo
o`0COol6O0000`00Oomoo`0GOol00g`0Oomoo`0:Ool2O0000gooO01l000AOol003eoo`8004Uoo`El
0003Ool0000000El02=oo`03O01oogoo00=oo`03O01oogoo00Aoo`9l015oo`El0080009oo`03O01o
ogoo01Qoo`03O01oogoo00]oo`9l0003Ooml07`0015oo`00?goo0P00C7oo1G`000=oo`0000001W`0
7Goo00=l07ooOol00Woo00=l07ooOol00goo0W`03Woo1G`00`001Woo0W`05goo0W`03Woo0W`000=o
og`0O0004Goo0011Ool2001?Ool6O0030005O00<Ool00`00Oomoo`09Ool00g`0Oomoo`02Ool017`0
Oomoogoo0W`02goo1G`00`002Woo00=l07ooO0005Woo00=l07ooOol03Woo17`04Woo0013Ool3001B
Ool5O0030006O006Ool00`00Oomoo`09Ool01G`0OomoogooO0000Woo0W`027oo1G`00`003Woo00El
07ooOomoog`001Aoo`03O01oogoo00moo`04O01oog`0O00BOol004Ioo`8005Eoo`El0004Ool00000
0005O002Ool00`00Oomoo`08Ool01G`0Oomoog`0Ool00W`01Goo1G`010004Woo00El07ooOomoog`0
01=oo`03O01oogoo011oo`04O01oog`0O00BOol004Qoo`8005Qoo`El0004Ool000000006O005Ool2
00000g`0Ooml0002O002Ool5O004000FOol00g`0Oomoo`03Ool00g`0Oomoo`0?Ool00g`0Oomoo`0@
Ool2O0000gooO01l000BOol004Yoo`8005]oo`Il00<00003Ooml07`000=l009oo`Ml00@001Yoo`03
O01oogoo00Eoo`03O01oogoo00aoo`9l01=oo`Al01=oo`00C7oo0P00Ggoo1G`017oo1G`000=oo`00
00007Woo00=l07ooOol01Woo00=l07ooOol02goo00=l07ooOol04goo17`04goo001>Ool2001MOol0
0`00Oomoo`02Ool5O0001@00O00007ooO0000`0000=l07ooOol06Woo00=l07ooOol01goo00=l07oo
Ool02Goo00=l07ooOol057oo17`04goo001@Ool3001IOol00`00Oomoo`06Ool00`00Ooml0004O003
Ool500000g`0Oomoo`0DOol00g`0Oomoo`08Ool00g`0Oomoo`08Ool00g`0Oomoo`0EOol4O00COol0
059oo`03O0000000061oo`05001oogooO0000002Ool5O003Ool5000AOol00g`0Oomoo`0:Ool00g`0
Oomoo`06Ool00g`0Oomoo`0FOol017`0Ooml07`04goo001EOol20007Ool4001DOol200000g`0Oomo
o`06Ool6O002Ool5000;Ool00g`0Oomoo`02Ool30006Ool00g`0Oomoo`04Ool2O00IOol3O00DOol0
05Moo`8000Aoo`04001oogoo001GOol00g`0Oomoo`0<Ool5O002Ool400000g`0Oomoo`04Ool01G`0
Oomoogoo00002Woo00=l07ooOol00Woo00=l07ooOol06Goo0g`057oo001IOol20002Ool01000Oomo
o`00Egoo00=l07ooOol04Goo1G`000=oo`0000000`0000=oog`0Ool00goo1@001Woo00El07ooOomo
og`001]oo`Al01Aoo`00Fgoo0`000Woo00<007ooOol0EGoo00=l07ooOol05Woo1G`000=oog`00000
0`0000=oo`00Ool00Woo00<007ooOol01Goo00=l07ooO00077oo17`057oo001MOol4001GOol00g`0
Oomoo`0KOol6O0050008Ool2O00MOol3O00EOol005moo`<005Ioo`03O01oogoo01]oo`03O01oogoo
00=oo`El00@000=oo`=l01eoo`=l01Eoo`00Ggoo0P0000=oo`000000E7oo00=l07ooOol06Woo00=l
07ooOol02Goo1G`000H007`0000007ooO00LOol3O00EOol006Aoo`80059oo`03O01oogoo01Uoo`03
O01oogoo00moo`Il00<001Uoo`=l01Eoo`00IWoo0P00D7oo00=l07ooOol06Goo00=l07ooOol03Woo
00=l07ooOol00goo1G`00`003Woo00<007ooOol00goo0W`000=oog`0Ool057oo001XOol2001>Ool0
0g`0Oomoo`0HOol00g`0Oomoo`0>Ool00g`0Oomoo`05Ool017`0Oomoogoo1W`00P002Goo00<007oo
Ool00goo0g`05Woo001ZOol2001<Ool00g`0Oomoo`0GOol00g`0Oomoo`0=Ool2O009Ool00g`0Oomo
o`06Ool5O0020005Ool00`00Oomoo`020003O00FOol006aoo`800003O01oogoo04Moo`03O01oogoo
01Moo`03O01oogoo00aoo`03O01oogoo00Uoo`03O01oogoo00]oo`El00<00004Ool007ooOol3O00F
Ool006ioo`<004Moo`03O01oogoo01Ioo`03O01oogoo00aoo`03O01oogoo00]oo`03O01oogoo00mo
o`Il0004Ooml0000O00FOol0075oo`8004Eoo`03O01oogoo01Eoo`03O01oogoo00aoo`03O01oogoo
00aoo`03O01oogoo015oo`03001oogoo00Al01Moo`00Lgoo0P00@goo00=l07ooOol057oo00=l07oo
Ool037oo00=l07ooOol03Woo00=l07ooOol03goo00D007ooOol007oo00=l01Moo`00MGoo0P00@Goo
00=l07ooOol057oo00=l07ooOol02goo00=l07ooOol047oo00=l07ooOol03Goo00H007ooOomoo`00
Ool3O00GOol007Moo`8003moo`03O01oogoo01=oo`03O01oogoo00Yoo`9l01=oo`03O01oogoo019o
o`04001l07`0O00GOol007Uoo`8003eoo`03O01oogoo019oo`03O01oogoo00Yoo`03O01oogoo01Ao
o`03O01oogoo019oo`03O01oog`001Moo`00Ngoo0`00>Woo00=l07ooOol04Woo00=l07ooOol02Goo
00=l07ooOol05Goo00=l07ooOol04Woo0W`067oo001nOol2000hOol00g`0Oomoo`0AOol00g`0Oomo
o`09Ool00g`0Oomoo`0GOol00g`0Oomoo`0AOol2O00HOol0081oo`8003Ioo`03O01oogoo011oo`03
O01oogoo00Uoo`03O01oogoo01Qoo`03O01oogoo011oo`=l01Qoo`00PWoo0P00=7oo00=l07ooOol0
3goo00=l07ooOol027oo0W`077oo00=l07ooOol03goo0g`067oo0024Ool2000bOol00g`0Oomoo`0?
Ool00g`0Oomoo`07Ool00g`0Oomoo`0LOol00g`0Oomoo`0?Ool2O00IOol008Ioo`80031oo`03O01o
ogoo00ioo`03O01oogoo00Moo`03O01oogoo01ioo`03O01oogoo00ioo`9l01Uoo`00R7oo0P0000=l
07ooOol0:goo00=l07ooOol03Goo00=l07ooOol01goo00=l07ooOol087oo00=l07ooOol03Goo0W`0
6Goo002:Ool3000[Ool00g`0Oomoo`0<Ool00g`0Oomoo`07Ool00g`0Oomoo`0QOol00g`0Oomoo`0=
Ool2O00IOol008eoo`8002Uoo`03O01oogoo00aoo`03O01oogoo00Eoo`9l02Eoo`03O01oogoo00]o
o`=l01Uoo`00Sgoo0P009goo00=l07ooOol02goo00=l07ooOol01Goo00=l07ooOol09Goo00=l07oo
Ool02goo0W`06Woo002AOol2000UOol00g`0Oomoo`0:Ool00g`0Oomoo`05Ool00g`0Oomoo`0WOol0
0g`0Oomoo`0:Ool2O00JOol009=oo`8002=oo`03O01oogoo00Yoo`03O01oogoo00Aoo`03O01oogoo
02Qoo`03O01oogoo00Yoo`9l01Yoo`00UGoo0P0000=l07ooOol07Woo00=l07ooOol02Goo00=l07oo
Ool017oo00=l07ooOol0:Woo00=l07ooOol02Goo0W`06Woo002GOol200000g`0Oomoo`0LOol00g`0
Oomoo`08Ool00g`0Oomoo`03Ool2O00]Ool00g`0Oomoo`09Ool00g`0Oomoo`0IOol009Uoo`<001ao
o`03O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo02ioo`03O01oogoo00Moo`9l01]oo`00W7oo
0P006Woo00=l07ooOol01goo00=l07ooOol00Woo00=l07ooOol0<7oo00=l07ooOol01Woo0W`06goo
002NOol2000HOol00g`0Oomoo`06Ool00g`0Oomoo`02Ool00g`0Oomoo`0aOol00g`0Oomoo`06Ool2
O00KOol00:1oo`8001Ioo`03O01oogoo00Eoo`03O01oogoo009oo`03O01oogoo03=oo`03O01oogoo
00Eoo`9l01]oo`00XWoo0P0057oo00=l07ooOol01Goo00=l07ooOol00W`0=Woo00=l07ooOol01Goo
00=l07ooOol06Woo002TOol200000g`0Oomoo`04Ool00`00Oomoo`08Ool00g`0Oomoo`04Ool017`0
Oomoog`0>Goo00=l07ooOol017oo00=l07ooOol06Woo002VOol200000g`0Oomoo`02Ool00`00Oomo
o`08Ool00g`0Oomoo`03Ool017`0Oomoog`0>Woo00=l07ooOol00goo0W`077oo002XOol30003Ool0
0`00Oomoo`07Ool00g`0Oomoo`02Ool017`0Oomoog`0?7oo00=l07ooOol00Woo0W`077oo002[Ool2
00000goo001oo`08Ool00g`0Oomoo`02Ool00g`0Ooml000mOol00g`0Oomoo`02Ool00g`0Oomoo`0K
Ool00:eoo`8000Uoo`04O01oogooOol3O00KOol3000QOol01G`0OomoogooO0007Goo002^Ool20000
0g`0Oomoo`05Ool00g`0Oomoo`02O00LOol01@00Oomoogoo00007Goo00D007ooOomoog`0009oo`03
O01oogoo01]oo`00[7oo0P000goo0g`00P000Woo00Al07oo001l01eoo`03001oogoo01moo`08001o
ogooOoml0000Ooml01eoo`00Zgoo00<007ooOol01Woo0W`00Woo00El0000O01oo`0001aoo`05001o
ogooOol0000NOol01000Oomoogoo0g`07Goo002dOol00`00Ooml0003O002Ool00`00Oomoo`0KOol3
000OOol01000Oomoogoo0W`07Woo002dOol01000Oomoogoo0g`0@`0017`07Woo002dOol00`00Oomo
o`02Ool01000Oomoo`00@7oo00<007ooOol00Woo00<007ooOol06goo002cOol20004Ool01000Oomo
o`00?goo00<007oo00000goo00<007ooOol06goo002dOol00`00Oomoo`03Ool2000oOol00`00Oomo
o`05000MOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.117466, -2.65375, \
0.0163797, 0.0304631}}]
}, Open  ]],

Cell["Can we visualize these in a less confusing way?", "Emphasis",
  CellTags->{"emphasis", "enfold"}],

Cell["\<\
NB with different colors there is still the problem of \"overlaid\" lines.\
\>", "SmallText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D graphics of tree", "Section"],

Cell["\<\
We can display  the jumps between nodes of the spanning trees as arcs in 3D, \
adjusted to avoid overlapping:\
\>", "Emphasis",
  CellTags->"emphasis"],

Cell[BoxData[
    RowBox[{
      RowBox[{"tree3D", "=", 
        RowBox[{"Graphics3DOfR", "[", 
          RowBox[{"reln", ",", "1"}], "]"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"Graphics3D", "[", "tree3D", "]"}], ",", 
          RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->"calc"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88326 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.6704e-16 1.05593 -0.0358286 1.05593 [
[ 0 0 0 0 ]
[ 1 .88326 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .88326 L
0 .88326 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7309 .51491 m
.73434 .50885 L
s
.73434 .50885 m
.73714 .56002 L
s
.73691 .53701 m
.73434 .50885 L
s
.73416 .5267 m
.73434 .50885 L
s
.73434 .50885 m
.73387 .55698 L
s
.73434 .50885 m
.72406 .50095 L
s
.26568 .448 m
.73434 .50885 L
s
.73434 .50885 m
.87204 .46665 L
s
.73132 .54033 m
.73416 .5267 L
s
.74085 .55799 m
.73691 .53701 L
s
.72595 .54873 m
.73132 .54033 L
s
.73387 .55698 m
.72611 .59486 L
s
.87174 .47545 m
.87204 .46665 L
s
.73714 .56002 m
.7388 .59916 L
s
.87273 .47862 m
.87204 .46665 L
s
.88584 .51167 m
.87204 .46665 L
s
.86358 .51699 m
.87204 .46665 L
s
.8718 .51826 m
.87204 .46665 L
s
.87204 .46665 m
.86996 .47908 L
s
.87204 .46665 m
.87546 .47776 L
s
.87204 .46665 m
.87428 .50294 L
s
.87204 .46665 m
.86136 .46115 L
s
.71833 .55119 m
.72595 .54873 L
s
.74598 .57018 m
.74085 .55799 L
s
.86996 .47908 m
.86675 .48838 L
s
.87213 .48749 m
.87273 .47862 L
s
.87546 .47776 m
.87744 .48583 L
s
.86675 .48838 m
.86261 .49389 L
s
.70895 .54741 m
.71833 .55119 L
s
.26568 .448 m
.27072 .50655 L
s
.26568 .448 m
.26876 .50458 L
s
.26568 .448 m
.26911 .488 L
s
.26568 .448 m
.65283 .40861 L
s
.26568 .448 m
.49541 .21502 L
s
.87026 .49264 m
.87213 .48749 L
s
.87744 .48583 m
.87781 .49027 L
s
.87428 .50294 m
.8729 .53048 L
s
.86261 .49389 m
.85779 .49517 L
s
.752 .57237 m
.74598 .57018 L
s
.86722 .49363 m
.87026 .49264 L
s
.72611 .59486 m
.71107 .61947 L
s
.85011 .55608 m
.86358 .51699 L
s
.87781 .49027 m
.87653 .49072 L
s
.8598 .56062 m
.8718 .51826 L
s
.69841 .53747 m
.70895 .54741 L
s
.89404 .54577 m
.88584 .51167 L
s
.7388 .59916 m
.73912 .62307 L
s
.85779 .49517 m
.85263 .49207 L
s
.69841 .53747 m
.6978 .54482 L
s
.26911 .488 m
.28563 .52488 L
s
.8632 .49034 m
.86722 .49363 L
s
.87653 .49072 m
.87364 .48706 L
s
.70868 .54153 m
.69841 .53747 L
s
.68746 .52196 m
.69841 .53747 L
s
.65187 .417 m
.65283 .40861 L
s
.85263 .49207 m
.84747 .48472 L
s
.27072 .50655 m
.29512 .56128 L
s
.85846 .4829 m
.8632 .49034 L
s
.26876 .50458 m
.28745 .5527 L
s
.87364 .48706 m
.86933 .47948 L
s
.8729 .53048 m
.8678 .54712 L
s
.85846 .4829 m
.8554 .48965 L
s
.65283 .40861 m
.65562 .42568 L
s
.65283 .40861 m
.64302 .45462 L
s
.65283 .40861 m
.66577 .45358 L
s
.65283 .40861 m
.65504 .43035 L
s
.65556 .43472 m
.65283 .40861 L
s
.6516 .439 m
.65283 .40861 L
s
.64753 .45032 m
.65283 .40861 L
s
.65283 .40861 m
.64118 .40144 L
s
.65283 .40861 m
.83429 .39412 L
s
.65283 .40861 m
.78126 .31993 L
s
.86805 .48843 m
.85846 .4829 L
s
.75853 .56394 m
.752 .57237 L
s
.6769 .50193 m
.68746 .52196 L
s
.84747 .48472 m
.85051 .47794 L
s
.83781 .47917 m
.84747 .48472 L
s
.84747 .48472 m
.84268 .47357 L
s
.83234 .40252 m
.83429 .39412 L
s
.85333 .47179 m
.85846 .4829 L
s
.28563 .52488 m
.31454 .5559 L
s
.86933 .47948 m
.87245 .47267 L
s
.8597 .47391 m
.86933 .47948 L
s
.86933 .47948 m
.86387 .46846 L
s
.65504 .43035 m
.66005 .45434 L
s
.66753 .47882 m
.6769 .50193 L
s
.65562 .42568 m
.6625 .4389 L
s
.84268 .47357 m
.83861 .45938 L
s
.83211 .58086 m
.85011 .55608 L
s
.83429 .39412 m
.83617 .40878 L
s
.83331 .40928 m
.83429 .39412 L
s
.839 .40787 m
.83429 .39412 L
s
.83621 .44313 m
.83429 .39412 L
s
.82961 .45523 m
.83429 .39412 L
s
.83429 .39412 m
.83553 .41849 L
s
.83429 .39412 m
.83587 .43073 L
s
.83429 .39412 m
.82326 .3867 L
s
.66005 .45434 m
.66753 .47882 L
s
.84818 .45776 m
.85333 .47179 L
s
.83603 .59043 m
.8598 .56062 L
s
.86387 .46846 m
.85765 .45475 L
s
.71107 .61947 m
.68923 .62823 L
s
.83861 .45938 m
.83555 .44314 L
s
.66153 .45391 m
.65556 .43472 L
s
.83374 .42603 m
.83331 .40928 L
s
.83617 .40878 m
.83927 .42506 L
s
.84474 .4233 m
.839 .40787 L
s
.84338 .4418 m
.84818 .45776 L
s
.64541 .46198 m
.6516 .439 L
s
.83555 .44314 m
.83374 .42603 L
s
.62872 .49142 m
.64753 .45032 L
s
.85765 .45475 m
.85112 .43932 L
s
.89573 .5661 m
.89404 .54577 L
s
.83927 .42506 m
.84338 .4418 L
s
.85112 .43932 m
.84474 .4233 L
s
.6625 .4389 m
.6731 .44731 L
s
.29512 .56128 m
.33812 .60802 L
s
.31454 .5559 m
.35415 .57858 L
s
.83553 .41849 m
.83429 .4364 L
s
.76513 .54502 m
.75853 .56394 L
s
.64302 .45462 m
.63281 .4886 L
s
.73912 .62307 m
.73798 .62893 L
s
.66577 .45358 m
.67776 .48659 L
s
.8678 .54712 m
.85911 .55113 L
s
.28745 .5527 m
.32154 .58865 L
s
.83587 .43073 m
.83314 .45816 L
s
.6731 .44731 m
.6868 .45021 L
s
.5974 .52882 m
.62872 .49142 L
s
.67049 .4647 m
.66153 .45391 L
s
.80453 .51595 m
.82961 .45523 L
s
.35415 .57858 m
.40176 .59098 L
s
.63445 .47577 m
.64541 .46198 L
s
.83198 .48046 m
.83621 .44313 L
s
.77107 .55353 m
.76513 .54502 L
s
.83429 .4364 m
.83055 .44649 L
s
.6868 .45021 m
.7027 .44729 L
s
.55566 .55957 m
.5974 .52882 L
s
.81043 .5887 m
.83211 .58086 L
s
.76513 .54502 m
.75643 .54661 L
s
.7713 .51658 m
.76513 .54502 L
s
.33812 .60802 m
.39739 .64281 L
s
.8013 .60476 m
.83603 .59043 L
s
.40176 .59098 m
.45389 .59192 L
s
.45389 .59192 m
.46504 .5973 L
s
.68923 .62823 m
.66161 .61929 L
s
.50656 .58118 m
.55566 .55957 L
s
.68196 .46601 m
.67049 .4647 L
s
.45556 .5853 m
.45389 .59192 L
s
.45389 .59192 m
.50656 .58118 L
s
.7027 .44729 m
.71973 .43861 L
s
.85911 .55113 m
.84723 .54148 L
s
.8903 .5702 m
.89573 .5661 L
s
.83314 .45816 m
.82605 .47423 L
s
.78331 .33104 m
.78126 .31993 L
s
.63281 .4886 m
.6228 .50773 L
s
.76008 .57152 m
.80453 .51595 L
s
.67776 .48659 m
.68802 .50485 L
s
.61925 .47904 m
.63445 .47577 L
s
.83055 .44649 m
.82446 .44778 L
s
.71973 .43861 m
.73039 .44137 L
s
.77653 .48051 m
.7713 .51658 L
s
.32154 .58865 m
.36973 .60905 L
s
.71828 .42967 m
.71973 .43861 L
s
.71973 .43861 m
.73667 .42469 L
s
.78126 .31993 m
.78204 .3445 L
s
.78508 .33173 m
.78126 .31993 L
s
.7788 .33268 m
.78126 .31993 L
s
.78213 .35686 m
.78126 .31993 L
s
.7804 .34035 m
.78126 .31993 L
s
.78126 .31993 m
.78196 .33242 L
s
.78126 .31993 m
.78285 .35586 L
s
.78126 .31993 m
.76966 .31532 L
s
.39739 .64281 m
.46893 .66241 L
s
.73798 .62893 m
.73533 .61469 L
s
.82141 .50304 m
.83198 .48046 L
s
.73667 .42469 m
.75228 .40649 L
s
.77573 .34167 m
.7788 .33268 L
s
.77499 .36269 m
.7804 .34035 L
s
.78196 .33242 m
.78186 .34117 L
s
.78794 .33983 m
.78508 .33173 L
s
.69524 .45736 m
.68196 .46601 L
s
.7804 .43951 m
.77653 .48051 L
s
.6991 .61731 m
.76008 .57152 L
s
.75228 .40649 m
.76538 .38529 L
s
.76538 .38529 m
.77499 .36269 L
s
.78285 .35586 m
.78257 .39681 L
s
.78204 .3445 m
.7801 .36222 L
s
.82446 .44778 m
.81637 .43982 L
s
.77223 .34625 m
.77573 .34167 L
s
.78631 .57773 m
.81043 .5887 L
s
.75738 .60146 m
.8013 .60476 L
s
.78186 .34117 m
.78097 .34553 L
s
.78962 .34363 m
.78794 .33983 L
s
.78257 .39681 m
.7804 .43951 L
s
.46893 .66241 m
.54732 .66475 L
s
.60066 .47103 m
.61925 .47904 L
s
.82605 .47423 m
.81481 .4772 L
s
.84723 .54148 m
.83285 .51808 L
s
.77833 .38404 m
.78213 .35686 L
s
.66161 .61929 m
.62992 .59202 L
s
.54732 .66475 m
.55845 .67009 L
s
.62622 .64932 m
.6991 .61731 L
s
.76855 .34601 m
.77223 .34625 L
s
.54946 .65828 m
.54732 .66475 L
s
.54732 .66475 m
.62622 .64932 L
s
.78097 .34553 m
.77932 .34513 L
s
.78999 .34278 m
.78962 .34363 L
s
.6228 .50773 m
.61365 .50964 L
s
.70947 .43893 m
.69524 .45736 L
s
.87752 .5564 m
.8903 .5702 L
s
.7801 .36222 m
.77549 .37171 L
s
.68802 .50485 m
.69574 .50601 L
s
.36973 .60905 m
.42936 .61127 L
s
.81637 .43982 m
.80676 .42283 L
s
.76491 .34088 m
.76855 .34601 L
s
.77932 .34513 m
.777 .33988 L
s
.789 .33724 m
.78999 .34278 L
s
.57989 .4518 m
.60066 .47103 L
s
.71388 .44852 m
.70947 .43893 L
s
.8047 .50821 m
.82141 .50304 L
s
.83285 .51808 m
.83649 .51117 L
s
.82254 .51192 m
.83285 .51808 L
s
.83285 .51808 m
.81697 .48204 L
s
.76158 .33112 m
.76491 .34088 L
s
.73533 .61469 m
.73122 .57966 L
s
.76985 .39924 m
.77833 .38404 L
s
.777 .33988 m
.77418 .33007 L
s
.78667 .32731 m
.789 .33724 L
s
.77103 .3395 m
.76158 .33112 L
s
.70708 .57961 m
.75738 .60146 L
s
.81481 .4772 m
.79997 .46607 L
s
.70947 .43893 m
.69921 .43863 L
s
.72359 .41173 m
.70947 .43893 L
s
.76158 .33112 m
.75581 .33691 L
s
.77549 .37171 m
.76838 .37199 L
s
.80676 .42283 m
.81054 .41566 L
s
.7964 .41618 m
.80676 .42283 L
s
.80676 .42283 m
.79632 .39775 L
s
.79603 .33573 m
.78667 .32731 L
s
.76137 .54735 m
.78631 .57773 L
s
.78667 .32731 m
.78082 .33312 L
s
.62992 .59202 m
.63029 .58419 L
s
.61851 .58771 m
.62992 .59202 L
s
.62992 .59202 m
.59645 .54742 L
s
.75881 .31732 m
.76158 .33112 L
s
.57989 .4518 m
.57975 .46023 L
s
.77418 .33007 m
.78003 .32423 L
s
.7647 .3216 m
.77418 .33007 L
s
.77418 .33007 m
.77104 .31629 L
s
.78317 .3136 m
.78667 .32731 L
s
.59143 .45646 m
.57989 .4518 L
s
.75538 .23675 m
.7584 .22784 L
s
.55844 .42237 m
.57989 .4518 L
s
.7568 .30044 m
.75881 .31732 L
s
.42936 .61127 m
.49641 .59398 L
s
.77104 .31629 m
.7678 .29949 L
s
.7584 .22784 m
.76309 .24295 L
s
.7584 .22784 m
.75654 .24398 L
s
.7636 .27424 m
.7584 .22784 L
s
.7618 .25872 m
.7584 .22784 L
s
.75983 .24368 m
.7584 .22784 L
s
.75838 .24014 m
.7584 .22784 L
s
.75336 .29461 m
.7584 .22784 L
s
.7584 .22784 m
.75856 .26111 L
s
.7584 .22784 m
.74636 .2181 L
s
.49541 .21502 m
.7584 .22784 L
s
.73651 .3776 m
.72359 .41173 L
s
.4999 .22755 m
.49541 .21502 L
s
.77871 .29707 m
.78317 .3136 L
s
.79632 .39775 m
.78581 .36629 L
s
.81697 .48204 m
.8008 .43573 L
s
.75571 .28167 m
.7568 .30044 L
s
.61365 .50964 m
.60606 .49275 L
s
.75654 .24398 m
.75562 .26238 L
s
.7678 .29949 m
.76471 .28088 L
s
.70708 .57961 m
.71201 .58868 L
s
.76198 .26181 m
.75983 .24368 L
s
.76309 .24295 m
.76829 .26039 L
s
.8578 .52434 m
.87752 .5564 L
s
.77363 .27888 m
.77871 .29707 L
s
.75562 .26238 m
.75571 .28167 L
s
.76838 .37199 m
.75919 .36267 L
s
.75636 .24884 m
.75838 .24014 L
s
.69574 .50601 m
.70017 .48855 L
s
.76471 .28088 m
.76198 .26181 L
s
.76829 .26039 m
.77363 .27888 L
s
.49541 .21502 m
.50221 .27808 L
s
.49541 .21502 m
.49855 .23539 L
s
.49541 .21502 m
.49732 .23801 L
s
.49541 .21502 m
.49804 .25324 L
s
.49963 .27651 m
.49541 .21502 L
s
.49541 .21502 m
.48277 .21061 L
s
.49541 .21502 m
.69757 .14026 L
s
.49541 .21502 m
.63153 .04518 L
s
.76784 .29394 m
.7618 .25872 L
s
.78581 .36629 m
.77606 .33076 L
s
.75856 .26111 m
.75474 .29919 L
s
.74719 .33908 m
.73651 .3776 L
s
.75695 .40074 m
.76985 .39924 L
s
.71735 .57953 m
.70708 .57961 L
s
.65415 .5399 m
.70708 .57961 L
s
.53798 .3847 m
.55844 .42237 L
s
.79997 .46607 m
.78241 .44082 L
s
.77294 .32731 m
.7636 .27424 L
s
.75242 .25332 m
.75636 .24884 L
s
.77606 .33076 m
.76784 .29394 L
s
.59645 .54742 m
.56397 .48833 L
s
.8008 .43573 m
.7857 .3827 L
s
.76137 .54735 m
.75852 .55462 L
s
.75474 .29919 m
.74719 .33908 L
s
.77233 .55315 m
.76137 .54735 L
s
.49855 .23539 m
.50827 .2522 L
s
.78255 .49415 m
.8047 .50821 L
s
.49641 .59398 m
.50834 .59789 L
s
.73122 .57966 m
.73864 .57579 L
s
.72249 .5713 m
.73122 .57966 L
s
.73122 .57966 m
.72589 .52501 L
s
.49804 .25324 m
.50649 .29659 L
s
.49732 .23801 m
.50353 .25446 L
s
.73755 .49859 m
.76137 .54735 L
s
.49546 .58572 m
.49641 .59398 L
s
.49641 .59398 m
.56568 .55761 L
s
.7857 .3827 m
.77294 .32731 L
s
.52017 .34162 m
.53798 .3847 L
s
.72925 .36706 m
.75336 .29461 L
s
.7468 .25317 m
.75242 .25332 L
s
.75919 .36267 m
.74848 .34402 L
s
.50649 .29659 m
.52017 .34162 L
s
.51328 .34665 m
.49963 .27651 L
s
.50827 .2522 m
.52409 .26422 L
s
.50221 .27808 m
.5236 .34807 L
s
.60301 .48494 m
.65415 .5399 L
s
.56397 .48833 m
.53538 .41942 L
s
.8578 .52434 m
.85452 .5318 L
s
.73984 .24832 m
.7468 .25317 L
s
.86859 .53029 m
.8578 .52434 L
s
.50353 .25446 m
.51377 .2631 L
s
.78241 .44082 m
.78535 .43293 L
s
.7713 .43459 m
.78241 .44082 L
s
.78241 .44082 m
.76337 .40265 L
s
.83226 .47531 m
.8578 .52434 L
s
.53538 .41942 m
.51328 .34665 L
s
.56568 .55761 m
.6313 .50457 L
s
.74028 .38754 m
.75695 .40074 L
s
.52409 .26422 m
.54505 .27048 L
s
.68746 .43915 m
.72925 .36706 L
s
.60606 .49275 m
.60076 .45679 L
s
.74848 .34402 m
.75218 .33626 L
s
.73748 .33682 m
.74848 .34402 L
s
.74848 .34402 m
.73701 .31711 L
s
.73202 .23901 m
.73984 .24832 L
s
.5236 .34807 m
.55816 .4191 L
s
.73202 .23901 m
.73117 .24875 L
s
.70017 .48855 m
.70069 .45224 L
s
.55816 .4191 m
.60301 .48494 L
s
.74363 .24439 m
.73202 .23901 L
s
.69818 .15235 m
.69757 .14026 L
s
.71695 .4345 m
.73755 .49859 L
s
.6313 .50457 m
.68746 .43915 L
s
.72388 .22584 m
.73202 .23901 L
s
.73202 .23901 m
.73288 .22918 L
s
.72035 .2336 m
.73202 .23901 L
s
.54505 .27048 m
.56978 .27042 L
s
.72589 .52501 m
.71971 .45417 L
s
.51377 .2631 m
.52752 .26303 L
s
.69757 .14026 m
.71687 .19882 L
s
.69757 .14026 m
.69143 .2061 L
s
.69757 .14026 m
.69941 .15572 L
s
.70252 .18738 m
.69757 .14026 L
s
.70067 .17177 m
.69757 .14026 L
s
.70162 .20834 m
.69757 .14026 L
s
.69517 .16342 m
.69757 .14026 L
s
.69757 .14026 m
.69724 .15262 L
s
.69757 .14026 m
.68446 .1327 L
s
.75619 .46036 m
.78255 .49415 L
s
.73701 .31711 m
.72564 .28376 L
s
.716 .20971 m
.72388 .22584 L
s
.76337 .40265 m
.74433 .35412 L
s
.69941 .15572 m
.7033 .17331 L
s
.56978 .27042 m
.59657 .26391 L
s
.70897 .19176 m
.716 .20971 L
s
.69724 .15262 m
.69475 .16114 L
s
.7033 .17331 m
.70897 .19176 L
s
.6857 .18788 m
.69517 .16342 L
s
.59657 .26391 m
.60868 .2693 L
s
.70671 .2081 m
.70067 .17177 L
s
.8028 .41261 m
.83226 .47531 L
s
.72564 .28376 m
.71526 .24645 L
s
.5968 .25407 m
.59657 .26391 L
s
.59657 .26391 m
.62347 .25133 L
s
.72084 .35972 m
.74028 .38754 L
s
.70151 .36001 m
.71695 .4345 L
s
.66977 .21185 m
.6857 .18788 L
s
.71255 .24177 m
.70252 .18738 L
s
.69475 .16114 m
.69022 .16519 L
s
.71526 .24645 m
.70671 .2081 L
s
.52752 .26303 m
.54395 .25394 L
s
.74433 .35412 m
.72688 .29897 L
s
.69143 .2061 m
.69274 .28154 L
s
.62347 .25133 m
.6485 .23354 L
s
.6485 .23354 m
.66977 .21185 L
s
.71971 .45417 m
.71321 .37282 L
s
.60076 .45679 m
.60881 .45309 L
s
.59153 .44721 m
.60076 .45679 L
s
.60076 .45679 m
.59834 .40321 L
s
.70699 .28826 m
.70162 .20834 L
s
.71687 .19882 m
.74236 .26784 L
s
.72688 .29897 m
.71255 .24177 L
s
.70069 .45224 m
.70895 .44853 L
s
.69193 .44262 m
.70069 .45224 L
s
.70069 .45224 m
.69695 .39859 L
s
.69274 .28154 m
.70151 .36001 L
s
.69022 .16519 m
.68392 .16441 L
s
.75619 .46036 m
.75374 .46865 L
s
.77189 .34133 m
.8028 .41261 L
s
.76785 .46639 m
.75619 .46036 L
s
.71321 .37282 m
.70699 .28826 L
s
.72084 .35972 m
.71806 .36822 L
s
.54395 .25394 m
.56196 .23614 L
s
.72751 .40815 m
.75619 .46036 L
s
.73255 .36644 m
.72084 .35972 L
s
.68392 .16441 m
.67623 .15874 L
s
.74236 .26784 m
.77189 .34133 L
s
.70002 .31865 m
.72084 .35972 L
s
.56592 .24753 m
.56196 .23614 L
s
.67623 .15874 m
.66769 .14849 L
s
.56196 .23614 m
.57386 .23816 L
s
.63616 .06001 m
.63153 .04518 L
s
.55796 .22462 m
.56196 .23614 L
s
.56196 .23614 m
.58027 .21066 L
s
.56196 .23614 m
.55005 .2341 L
s
.59834 .40321 m
.59919 .33547 L
s
.66769 .14849 m
.66827 .1378 L
s
.65535 .14261 m
.66769 .14849 L
s
.66769 .14849 m
.65888 .1343 L
s
.69695 .39859 m
.689 .33112 L
s
.63153 .04518 m
.63762 .10931 L
s
.63153 .04518 m
.63592 .09322 L
s
.63319 .06093 m
.63153 .04518 L
s
.62036 .107 m
.63153 .04518 L
s
.64726 .10555 m
.63153 .04518 L
s
.62991 .07454 m
.63153 .04518 L
s
.63153 .04518 m
.61841 .04078 L
s
.65888 .1343 m
.65044 .11716 L
s
.67945 .26709 m
.70002 .31865 L
s
.58027 .21066 m
.59748 .17927 L
s
.69884 .34093 m
.72751 .40815 L
s
.63711 .07908 m
.63319 .06093 L
s
.65044 .11716 m
.643 .09829 L
s
.643 .09829 m
.63711 .07908 L
s
.62332 .10844 m
.62991 .07454 L
s
.59748 .17927 m
.61222 .14429 L
s
.59919 .33547 m
.6034 .25896 L
s
.61222 .14429 m
.62332 .10844 L
s
.63592 .09322 m
.64596 .14939 L
s
.689 .33112 m
.67737 .25524 L
s
.66089 .20905 m
.67945 .26709 L
s
.61068 .18042 m
.62036 .107 L
s
.66302 .17769 m
.64726 .10555 L
s
.63762 .10931 m
.65172 .18447 L
s
.67276 .2641 m
.69884 .34093 L
s
.64596 .14939 m
.66089 .20905 L
s
.6034 .25896 m
.61068 .18042 L
s
.67737 .25524 m
.66302 .17769 L
s
.65172 .18447 m
.67276 .2641 L
s
[(5)] .63153 .04518 0 0 Mshowa
[(6)] .69757 .14026 0 0 Mshowa
[(7)] .7584 .22784 0 0 Mshowa
[(2)] .49541 .21502 0 0 Mshowa
[(8)] .78126 .31993 0 0 Mshowa
[(9)] .83429 .39412 0 0 Mshowa
[(3)] .65283 .40861 0 0 Mshowa
[(10)] .87204 .46665 0 0 Mshowa
[(4)] .73434 .50885 0 0 Mshowa
[(1)] .26568 .448 0 0 Mshowa
gsave
.55202 .12436 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58756 .16873 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62221 .21202 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70868 .35769 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73834 .39351 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79701 .48096 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36538 .33062 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45122 .42085 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49945 .47168 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63059 .61554 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56208 .24679 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45354 .60913 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58011 .46596 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71011 .45105 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69879 .5454 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76601 .55814 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56208 .24679 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70687 .47478 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59622 .47976 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.66794 .15407 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59676 .27273 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73269 .60539 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73237 .24452 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74924 .35545 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78371 .45834 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49617 .62107 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73237 .24452 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7746 .33569 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80768 .43407 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83435 .53535 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72015 .44612 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72187 .37756 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76072 .33683 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78836 .33265 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54746 .69101 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75781 .48478 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87094 .48441 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84686 .49016 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70833 .60447 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75813 .57197 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.86494 .54682 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.85896 .48817 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704.688, 622.375},
  ImageMargins->{{0, 0}, {0, 5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00002KQ000`40O003h00Oogooogoo`Woo003o
OoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo
`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00
ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomo
ol9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool0
0?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOooo
Ooo2Ool00?mookAoo`<000Aoo`<00?moo`Aoo`00ogoo]goo10000goo00<007ooOol0ogoo0Goo003o
OonjOol300000goo001oo`3oOol2Ool00?mookeoo`800?moo`=oo`00ogoo^Woo1000ogoo17oo003o
OonjOol01000Ool00000ogoo17oo003oOonjOol5003oOol3Ool00?mookYoo`03001oo`0000800?mo
o`=oo`00ogoo^Goo00<007ooOol00`00ogoo0goo003oOoniOol00`00Oomoo`04003oOol2Ool00?mo
okQoo`04001oogooOol4003oOol2Ool00?mookMoo`03001oogoo009oo`@00?moo`9oo`00ogoo]Woo
00<007ooOol00Woo00<007oo00000`00ogoo0Goo003oOoneOol00`00Oomoo`03Ool00`00Ool00003
003oOol1Ool00?mookEoo`03001oogoo00=oo`800004Ool007oo003oOol1Ool00?mookAoo`03001o
ogoo00Aoo`800004Ool007oo003oOol1Ool00?mook=oo`03001oogoo00Eoo`800004Ool007oo003o
Ool1Ool00?mook9oo`03001oogoo00Eoo`04001oo`00Ool200000goo001oo`3nOol00?mook5oo`03
001oogoo00Ioo`04001oo`00Ool200000goo001oo`3nOol00?mook1oo`03001oogoo00Moo`04001o
o`00Ool200000goo001oo`3nOol00?mook1oo`03001oogoo00Moo`04001oo`00Ool200000goo001o
o`3nOol00?moojmoo`03001oogoo00Qoo`03001oo`00009oo`800003Ool007oo0?eoo`00ogoo[Woo
00<007ooOol02Goo00<007oo00000Woo0P0000=oo`00Ool0oGoo003oOon]Ool00`00Oomoo`09Ool0
1000Oomoo`000Woo0P0000=oo`00Ool0oGoo003oOon/Ool00`00Oomoo`0:Ool01000Oomoo`000Woo
0P0000=oo`00Ool0oGoo003oOon/Ool00`00Oomoo`0:Ool01000Oomoo`000Woo0P000Woo00<007oo
Ool0ngoo003oOon[Ool00`00Oomoo`0;Ool01000Oomoo`000Woo00D007oo001oo`000?eoo`00ogoo
ZWoo00<007ooOol037oo00<007oo00000goo00D007oo001oo`000?eoo`00ogooZGoo00<007ooOol0
37oo00@007ooOol000=oo`05001oo`00Ool0003mOol00?moojQoo`03001oogoo00eoo`04001oogoo
0003Ool00`00Ool00002Ool00`00Oomoo`3jOol00?moojQoo`03001oogoo00eoo`04001oogoo0003
Ool01P00Oomoo`00Ool00?aoo`00ogooYgoo00<007ooOol03Woo00@007ooOol000=oo`06001oogoo
001oo`00o7oo003oOonVOol00`00Oomoo`0?Ool00`00Ool00005Ool01@00Ool007oo0000o7oo003o
OonUOol00`00Oomoo`0@Ool00`00Ool00005Ool01P00Oomoo`00Ool00?]oo`00ogooY7oo00<007oo
Ool047oo00@007ooOol000Eoo`06001oogoo001oo`00ngoo003oOonTOol00`00Oomoo`0@Ool01000
Oomoo`001Goo00H007ooOol007oo003kOol00?mooj=oo`03001oogoo015oo`03001oo`0000Ioo`07
001oogooOol007oo0000nWoo003oOonROol00`00Oomoo`0BOol00`00Ool00006Ool01`00Oomoogoo
001oo`000?Yoo`00ogooXGoo00<007ooOol04goo00<007oo00001Woo00L007ooOomoo`00Ool0003j
Ool00?mooj1oo`03001oogoo01=oo`04001oogoo0006Ool00`00Oomoo`02Ool2003jOol00?mooj1o
o`03001oogoo01=oo`04001oogoo0006Ool00`00Oomoo`02Ool00`00Ool0003iOol00?mooimoo`03
001oogoo01Aoo`03001oo`0000Moo`8000=oo`03001oo`000?Uoo`00ogooWWoo00<007ooOol05Goo
00<007oo00001goo0P0017oo0P00nGoo003oOonMOol00`00Oomoo`0FOol00`00Ool00008Ool00`00
Oomoo`02Ool2003iOol00?mooiaoo`03001oogoo01Ioo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Ool0003hOol00?mooiaoo`03001oogoo01Ioo`04001oogoo0008Ool00`00Oomoo`03Ool2003h
Ool00?mooi]oo`03001oogoo01Moo`03001oo`0000Uoo`8000Aoo`800?Qoo`00ogooVWoo00<007oo
Ool067oo00<007oo00002Goo0P0017oo0P00n7oo003oOonIOol00`00Oomoo`0IOol00`00Ool00009
Ool20005Ool2003gOol00?mooiQoo`03001oogoo01Yoo`03001oo`0000Uoo`8000Eoo`800?Moo`00
ogooUgoo00<007ooOol06goo0P002Woo0P001Goo0P00mgoo003oOonGOol00`00Oomoo`0JOol00`00
Ool0000:Ool20006Ool00`00Oomoo`3eOol00?mooiIoo`03001oogoo01]oo`03001oo`0000]oo`80
00Eoo`03001oogoo0?Eoo`00ogooUGoo00<007ooOol077oo0P0037oo0P001Goo0P00mWoo003oOonD
Ool00`00Oomoo`0MOol2000<Ool20006Ool00`00Oomoo`3dOol00?mooi=oo`03001oogoo01ioo`80
00aoo`8000Ioo`03001oogoo0?Aoo`00ogooTgoo00<007ooOol07Woo00<007ooOol02goo0P001Woo
0P00mGoo003oOon2Ool4000<Ool00`00Oomoo`0OOol00`00Oomoo`0<Ool20005Ool2003eOol00?mo
oh=oo`04001oogoo000:Ool00`00Oomoo`0OOol2000>Ool20006Ool2003dOol00?mooh=oo`04001o
ogoo0009Ool00`00Oomoo`0POol00`00Oomoo`0=Ool20006Ool2003dOol00?mooh=oo`04001oogoo
0008Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool20006Ool00`00Ool0003cOol00?mooh=oo`<000Uo
o`03001oogoo025oo`03001oogoo00eoo`8000Ioo`03001oo`000?=oo`00ogooPgoo00<007ooOol0
27oo00<007ooOol08Woo00<007ooOol03Woo00<007ooOol01Goo00<007oo0000lWoo003oOon2Ool2
0009Ool00`00Oomoo`0ROol2000@Ool20006Ool00`00Ool0003bOol00?moohaoo`03001oogoo02=o
o`80011oo`8000Ioo`04001oogoo000BOol2003MOol00?mooh]oo`03001oogoo02Aoo`80011oo`80
00Ioo`04001oogoo000DOol00`00Oomoo`3JOol00?mooh]oo`03001oogoo02=oo`80015oo`8000Io
o`05001oogooOol0000DOol2003JOol00?moohYoo`03001oogoo02Aoo`80015oo`8000Moo`04001o
ogoo000FOol00`00Ool00002003EOol00?moohUoo`03001oogoo02Eoo`80019oo`03001oogoo00Eo
o`05001oogooOol00005Ool00`00Oomoo`0>Ool20002Ool00`00Oomoo`3BOol00?moohQoo`03001o
ogoo02Eoo`03001oo`00019oo`8000Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00io
o`05001oo`00Ool0003DOol00?moohMoo`03001oogoo02Ioo`03001oo`00019oo`8000Ioo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00ioo`@00=Eoo`00ogooQgoo00<007ooOol09Woo00<0
07oo00004Woo0P001goo0P000goo00D007ooOomoo`0000moo`<00003Ool007oo0=Aoo`00ogooQWoo
00<007ooOol09Woo00@007ooOol0019oo`8000Moo`03001oo`00009oo`05001oogooOol0000<Ool3
0002Ool01000Ool00000e7oo003oOon5Ool00`00Oomoo`0WOol00`00Ool0000DOol00`00Oomoo`05
Ool00`00Oomoo`02000017oo001oo`002Woo0`001Woo0`00e7oo003oOon4Ool00`00Oomoo`0XOol0
0`00Ool0000DOol20006Ool00`00Oomoo`02Ool40008Ool2000:Ool2003DOol00?mooh=oo`03001o
ogoo02Qoo`04001oogoo000DOol20006Ool00`00Oomoo`04Ool20005Ool3000<Ool3003COol00?mo
oh=oo`03001oogoo02Qoo`04001oogoo000DOol20007Ool00`00Oomoo`04Ool00`00Oomoo`03000?
Ool3003COol00?mooh9oo`03001oogoo02Uoo`04001oogoo000DOol20007Ool00`00Oomoo`04Ool3
000AOol4003COol00?mooh5oo`03001oogoo02Uoo`05001oogooOol0000EOol00`00Oomoo`05Ool0
0`00Oomoo`02Ool4000BOol300000goo001oo`3AOol00?mooh1oo`03001oogoo02Yoo`05001oogoo
Ool0000EOol20006Ool00`00Ool000020002Ool00`00Ool0000AOol5003BOol00?moogmoo`03001o
ogoo02Yoo`05001oogooOol0000FOol20005Ool30002Ool01000Oomoo`000Woo00<007ooOol03Woo
00<007oo00000P00dWoo003oOomnOol00`00Oomoo`0[Ool01@00Oomoogoo00005Woo0P000goo0P00
0Woo00@007ooOol0009oo`05001oogooOol0000?Ool01P00Ool00000Ool00=5oo`00ogooOWoo00<0
07ooOol0:Woo00<007ooOol00Woo00<007ooOol057oo1@0017oo00@007ooOomoo`<000Aoo`03001o
ogoo00aoo`06001oo`00001oo`00dGoo003oOommOol00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00
Oomoo`0COol40006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000;Ool200001Goo000007oo0000
dGoo003oOomlOol00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool30002Ool20006Ool0
0`00Oomoo`02Ool20007Ool00`00Oomoo`08Ool200000goo00000002Ool00`00Oomoo`3>Ool00?mo
og]oo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo00ioo`8000Eoo`8000Moo`03001oogoo
00]oo`8000Moo`04001oo`00Ool300000goo001oo`3?Ool00?moogYoo`03001oogoo02eoo`03001o
ogoo00=oo`03001oogoo00]oo`<000Moo`8000Moo`03001oogoo00eoo`03001oogoo00=oo`05001o
ogoo001oo`0300000goo001oo`3?Ool00?moogYoo`03001oogoo02aoo`03001oogoo00Aoo`03001o
ogoo00Qoo`<000Yoo`03001oo`0000Ioo`03001oogoo00ioo`D000=oo`03001oo`000080009oo`03
001oogoo0<eoo`00ogooNGoo00<007ooOol087oo0`002Woo00<007ooOol00goo00<007ooOol01Woo
0`003Goo00<007oo00001Woo00<007ooOol05Goo00<007ooOol00`000Woo00<007ooOol0cGoo003o
OomhOol00`00Oomoo`0POol01@00Oomoogoo00002Goo00<007ooOol00goo00<007ooOol017oo0P00
4Goo0P001Woo00<007ooOol05Goo00<007ooOol00`000Woo00<007ooOol0cGoo003oOomgOol00`00
Oomoo`0QOol00`00Oomoo`0:Ool00`00Oomoo`04Ool01000Oomoogoo0`004goo00<007oo00001Woo
00<007ooOol057oo00<007ooOol00`000goo00<007ooOol0c7oo003oOomfOol00`00Oomoo`0ROol0
1@00Oomoogoo000027oo00<007ooOol017oo10005Woo00<007oo00001Woo00<007ooOol04goo0P00
0Woo10000Woo00<007ooOol0c7oo003oOomfOol00`00Oomoo`0SOol30008Ool00`00Oomoo`04Ool2
000IOol00`00Ool00006Ool00`00Oomoo`0COol20002Ool01000Ool000000Woo00<007ooOol0c7oo
003oOomeOol00`00Oomoo`0_Ool01000Oomoogoo0`0000=oo`00Ool067oo00<007oo00001Woo00<0
07ooOol04Woo00<007oo00000Woo00@007oo000000=oo`03001oogoo0<]oo`00ogooM7oo00<007oo
Ool0;goo00<007oo00000P0017oo00<007ooOol067oo00<007oo00001Goo00<007ooOol04Woo00<0
07oo00000Woo00@007oo000000=oo`03001oogoo0<]oo`00ogooLgoo00<007ooOol0;goo0`001Woo
00<007ooOol06Goo00<007oo00001Woo00<007ooOol047oo00@007ooOol000=oo`<000=oo`03001o
ogoo0<]oo`00ogooLWoo00<007ooOol0;Woo0P0000=oo`00Ool01Woo00<007ooOol06Goo00<007oo
00001Woo00<007ooOol047oo00@007ooOol000=oo`@000=oo`03001oogoo0<Yoo`00ogooLWoo00<0
07ooOol0:goo0`000Woo00<007ooOol01Woo00<007ooOol06Goo00<007oo00001Woo00<007ooOol0
47oo00@007ooOol000=oo`@000=oo`03001oogoo0<Yoo`00ogooLGoo00<007ooOol0:Goo0`001Goo
00<007ooOol01Woo00<007ooOol06Goo00@007ooOol000Eoo`03001oogoo00moo`05001oogooOol0
0003Ool40003Ool00`00Oomoo`3:Ool00?moog1oo`03001oogoo02Moo`<000Moo`03001oogoo00Mo
o`03001oogoo01Yoo`03001oo`0000Eoo`03001oogoo00moo`05001oogooOol00003Ool300000goo
001oo`02Ool00`00Oomoo`39Ool00?moofmoo`03001oogoo02Ioo`8000Yoo`03001oogoo00Moo`03
001oogoo01Yoo`03001oo`0000Ioo`03001oogoo00eoo`05001oogooOol00004Ool01@00Ool007oo
00000goo00<007ooOol0bGoo003oOom^Ool00`00Oomoo`0TOol3000;Ool00`00Oomoo`08Ool00`00
Oomoo`0JOol00`00Ool00006Ool00`00Oomoo`0=Ool01@00Oomoogoo000017oo00D007oo001oo`00
00=oo`03001oogoo0<Uoo`00ogooKWoo00<007ooOol08Goo0`003Woo00<007ooOol027oo00<007oo
Ool06Woo00@007ooOol000Eoo`03001oogoo00eoo`05001oogooOol00004Ool00`00Ool00002Ool0
1@00Oomoogoo0000bWoo003oOom]Ool00`00Oomoo`0POol2000@Ool00`00Oomoo`09Ool00`00Oomo
o`0JOol01000Oomoo`001Goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol00Woo00H007oo
000007oo0003Ool00`00Oomoo`38Ool00?moofaoo`03001oogoo01ioo`<0015oo`03001oogoo00Uo
o`03001oogoo01aoo`03001oo`0000Eoo`03001oogoo00aoo`03001oogoo009oo`03001oogoo009o
o`06001oo`00001oo`000goo00<007ooOol0b7oo003oOom[Ool00`00Oomoo`0LOol3000DOol00`00
Oomoo`09Ool00`00Oomoo`0LOol00`00Ool00006Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool01000Ool000000Woo00D007ooOomoo`000<Uoo`00ogooJWoo00<007ooOol06Woo0`00
5Woo00<007ooOol02Woo00<007ooOol077oo00@007ooOol000Eoo`03001oogoo00Uoo`03001oogoo
00Aoo`03001oogoo009oo`04001oo`000002Ool01@00Oomoogoo0000bGoo003oOomZOol00`00Oomo
o`0HOol2000IOol00`00Oomoo`0:Ool00`00Oomoo`0LOol01000Oomoo`001Goo00<007ooOol02Goo
00<007ooOol017oo00<007ooOol00Woo00@007ooOol0009oo`05001oogooOol00039Ool00?moofUo
o`03001oogoo01Ioo`<001Yoo`03001oogoo00]oo`03001oogoo01eoo`03001oo`0000Eoo`03001o
ogoo00Qoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool01@00Oomoogoo0000b7oo
003oOomXOol00`00Oomoo`0DOol3000MOol00`00Oomoo`0;Ool00`00Oomoo`0MOol01000Oomoo`00
17oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00P000Woo00D007oo
Oomoo`000<Qoo`00ogooIgoo00<007ooOol04Woo0`007goo00<007ooOol037oo00<007ooOol07Goo
00@007ooOol000Aoo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo0080
009oo`05001oogooOol00038Ool00?moofIoo`03001oogoo015oo`80029oo`03001oogoo00aoo`03
001oogoo01ioo`03001oo`0000Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Aoo`04
001oo`000003Ool01@00Oomoogoo0000agoo003oOomUOol00`00Oomoo`0?Ool3000SOol00`00Oomo
o`0=Ool00`00Oomoo`0NOol00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool01000Oomoo`000goo00D007ooOomoo`000<Moo`00ogooIGoo00<007ooOol037oo0`009Woo
00<007ooOol03Goo00<007ooOol07Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Mo
o`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000aWoo003oOomTOol00`00Oomoo`0:
Ool3000XOol00`00Oomoo`0>Ool00`00Oomoo`0NOol01000Oomoo`0017oo00<007ooOol00goo00<0
07ooOol027oo00<007ooOol017oo00@007ooOol000Aoo`05001oogooOol00036Ool00?moof=oo`03
001oogoo00Uoo`8002Yoo`03001oogoo00ioo`03001oogoo021oo`03001oo`0000Aoo`03001oogoo
00=oo`03001oogoo00Qoo`03001oogoo00Aoo`04001oogoo0004Ool01@00Oomoogoo0000aWoo003o
OomROol00`00Oomoo`07Ool3000/Ool00`00Oomoo`0>Ool00`00Oomoo`0POol00`00Ool00005Ool0
1@00Oomoogoo00002goo00<007ooOol017oo00<007ooOol00P0017oo00D007ooOomoo`000<Eoo`00
ogooHGoo00<007ooOol01Goo0`00;Woo00<007ooOol03goo00<007ooOol087oo00@007ooOol000Ao
o`04001oogoo000<Ool00`00Oomoo`04Ool00`00Oomoo`020004Ool01@00Oomoogoo0000aGoo003o
OomQOol00`00Oomoo`03Ool2000aOol00`00Oomoo`0?Ool00`00Oomoo`05Ool3000HOol01000Oomo
o`0017oo00@007ooOol000aoo`03001oogoo00Aoo`05001oogooOol00004Ool01@00Oomoogoo0000
aGoo003oOomDOol30009Ool01000Oomoogoo0`00<Woo00<007ooOol047oo00<007ooOol017oo00<0
07ooOol06Woo00<007oo000017oo00<007oo00003Goo00<007ooOol017oo00D007ooOomoo`0000Eo
o`05001oogooOol00034Ool00?mooeMoo`T00004Ool00000000eOol00`00Oomoo`0@Ool00`00Oomo
o`04Ool5000HOol00`00Ool00004Ool2000>Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo00D0
07ooOomoo`000<Aoo`00ogooFWoo0`0000Aoo`00000003Moo`03001oogoo015oo`03001oogoo00Ao
o`05001oogooOol0000HOol01000Oomoo`000goo00<007ooOol03Goo00<007ooOol017oo00@007oo
Oomoo`8000Eoo`04001oogoo0034Ool00?mooeaoo``002moo`03001oogoo019oo`03001oogoo00Eo
o`<001Uoo`04001oogoo0002Ool00`00Ool0000>Ool00`00Oomoo`04Ool01000Oomoogoo0P001Goo
00D007ooOomoo`000<=oo`00ogooGGoo00<007ooOol027oo5@006Goo00<007ooOol04goo00<007oo
Ool08Woo00D007oo001oo`00009oo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Aoo`04001oogoo0033Ool00?mooeYoo`03001oo`00008001iooa@000Eoo`03001oogoo
01=oo`03001oogoo029oo`04001oogoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool01@00Oomoogoo0000`Woo003oOomJOol200000goo0000000bOolE0006
Ool00`00Oomoo`0ROol01000Ool000000goo00<007ooOol037oo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol01Goo00@007ooOol000moo`800;5oo`00ogooFWoo1@00=Goo00<007ooOol03goo
5@005goo00<007oo00000goo00<007ooOol037oo00<007ooOol01Goo00@007ooOomoo`8000Moo`03
001oo`00015oo`03001oogoo0:ioo`00ogooFGoo00@007ooOomoo`<003Aoo`03001oogoo01Aoo`03
001oogoo00eooa@0009oo`80009oo`05001oogooOol0000=Ool00`00Oomoo`05Ool01000Oomoogoo
0P001goo00@007ooOol0015oo`03001oogoo0:eoo`00ogooF7oo00<007ooOol00Woo0`00<goo00<0
07ooOol05Goo00<007ooOol08Goo5@000goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
1Woo00<007oo00004Woo0P00[Goo003oOomGOol00`00Oomoo`03Ool3000YOol00`00Oomoo`06Ool0
0`00Oomoo`0FOol00`00Oomoo`0QOol01000Oomoo`000Woo00D007ooOomoo`0000Yooa@000Eoo`03
001oo`0001Aoo`800:]oo`00ogooEWoo00<007ooOol017oo0P0000=oo`00Ool09goo00<007ooOol0
1Goo00<007ooOol05goo00<007ooOol087oo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo
00]oo`03001oogoo00Eoo`03001oogoo009oo`80009ooaD000Qoo`03001oogoo0:Uoo`00ogooEGoo
00<007ooOol01Woo00<007oo0000:Goo00<007ooOol017oo00<007ooOol05goo00<007ooOol07goo
00<007ooOol00goo00@007ooOol0009oo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo009o
o`8000Qoo`03001oo`0000aoo`X00:Yoo`00ogooE7oo00<007ooOol01goo00<007ooOol0:Goo00<0
07ooOol00goo00<007ooOol067oo00<007ooOol07Woo00<007ooOol017oo00@007ooOol0009oo`03
001oogoo00]oo`03001oogoo00Eoo`03001oogoo009oo`8000Uoo`03001oo`00009oo`03001oogoo
00moo`03001oogoo0:Qoo`00ogooDgoo00<007ooOol027oo00<007ooOol0:Goo00<007ooOol00Woo
00<007ooOol06Goo00<007ooOol07Goo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo009oo`8000Yoo`80009oo`03001oogoo00moo`800:Uoo`00
ogooDWoo00<007ooOol02Goo0P00:goo00D007ooOomoo`0001]oo`03001oogoo01aoo`03001oogoo
00Moo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`08Ool20002Ool00`00Oomoo`0<Ool00`00Ool00002002YOol00?mooe5oo`03001oogoo00Yoo`80
02]oo`04001oogoo000LOol00`00Oomoo`0JOol2000:Ool01000Oomoo`000Woo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol00goo0P0017oo0P0017oo0P0000=oo`00Ool03Goo1@00ZGoo003o
Oom@Ool00`00Oomoo`0;Ool2000TOol50002Ool00`00Ool0000MOol00`00Oomoo`0IOol00`00Oomo
o`0:Ool01`00Oomoogoo001oo`0000aoo`03001oogoo00Eoo`03001oogoo00=oo`8000Ioo`8000=o
o`03001oo`00011oo`<00:Uoo`00ogooCgoo00<007ooOol037oo0P00:Goo1P006goo00<007ooOol0
6Goo00<007ooOol037oo00H007ooOol007oo000<Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20008
Ool400000goo001oo`0>Ool00`00Ool00002002XOol00?moodioo`03001oogoo00eoo`8002]oo`80
009oo`@001Moo`03001oogoo01Moo`8000moo`04001oogoo0002Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool2000;Ool3000?Ool5002XOol00?moodeoo`03001oogoo00ioo`<002Uo
o`04001oogoo0005Ool2000EOol00`00Oomoo`0FOol00`00Oomoo`0?Ool01`00Oomoogoo001oo`00
00]oo`03001oogoo00Eoo`03001oogoo00Aoo`8000]oo`<000moo`@00:Qoo`00ogooC7oo00<007oo
Ool03goo0`00:7oo00D007ooOomoo`0001aoo`03001oogoo01Aoo`80019oo`07001oogooOol007oo
00002goo00<007ooOol01Woo00<007ooOol00goo0P002goo0P0000=oo`0000003Goo1000Z7oo003o
Oom;Ool00`00Oomoo`0@Ool200000goo001oo`0UOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00
Oomoo`0COol00`00Oomoo`0COol01P00Oomoo`00Ool000]oo`03001oogoo00Ioo`03001oogoo00=o
o`8000Yoo`@0009oo`8000]oo`<00003Ool007oo0:Ioo`00ogooBWoo00<007ooOol04Goo0P000Woo
00<007ooOol08Woo00<007ooOol017oo00<007ooOol06Goo00<007ooOol04Woo00<007ooOol057oo
00H007ooOol007oo000;Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20009Ool01P00Oomoo`00Ool0
00=oo`8000Uoo`<00003Ool007oo0:Ioo`00ogooBGoo00<007ooOol04Woo0`0000=oo`00Ool08Woo
00<007ooOol01P006goo00<007ooOol047oo0P005goo00@007ooOomoo`8000aoo`03001oogoo00Eo
o`03001oogoo00=oo`8000Yoo`@00003Ool007oo00=oo`03001oogoo00Ioo`D00:Moo`00ogooB7oo
00<007ooOol04goo0`000Woo00<007ooOol07goo00@007ooOomoo`800004Ool00000000KOol00`00
Oomoo`0?Ool00`00Oomoo`0GOol01`00Oomoogoo001oo`0000]oo`03001oogoo00Eoo`03001oogoo
00Aoo`8000Qoo`03001oo`0000800003Ool007oo00aoo`@00003Ool007oo0:Eoo`00ogooAgoo00<0
07ooOol05Goo0`0000=oo`00Ool07goo00<007ooOol00Woo0P0000Eoo`00001oo`0001Yoo`03001o
ogoo00eoo`8001]oo`06001oogoo001oo`002goo00<007ooOol01Goo00<007ooOol017oo0P002Goo
0P0000Eoo`00Oomoo`0000aoo`@00003Ool007oo0:Eoo`00ogooAWoo00<007ooOol05Woo0`000Woo
00<007ooOol077oo00<007ooOol00goo0P0000=oo`00000077oo00<007ooOol037oo00<007ooOol0
6goo00@007ooOomoo`8000]oo`03001oogoo00Eoo`03001oogoo00Aoo`8000Yoo`04001oogoo0002
Ool2000:Ool400000goo001oo`2UOol00?moodEoo`03001oogoo01Moo`<000=oo`03001oogoo01Yo
o`03001oogoo00Eoo`<001eoo`03001oogoo00]oo`03001oogoo01aoo`04001oogooOol2000;Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool2000=Ool00`00Oomoo`02Ool20007Ool300001Goo001oogoo
0000YGoo003oOom4Ool00`00Oomoo`0HOol200001Goo001oogoo00006goo00<007ooOol01Woo00<0
07oo000077oo00<007ooOol02Woo0P007goo00@007ooOomoo`8000]oo`03001oogoo00Eoo`03001o
ogoo00Eoo`8000aoo`03001oogoo00Aoo`03001oogoo00=oo`06001oo`00001oo`000Woo00<007oo
Ool0Xgoo003oOom3Ool00`00Oomoo`0IOol200000goo001oo`02Ool2000HOol00`00Oomoo`06Ool4
000LOol00`00Oomoo`08Ool2000ROol01000Oomoogoo0P002Woo00<007ooOol01Goo00<007ooOol0
1Goo0P003Goo00<007ooOol017oo1@000Woo0P0000Eoo`00Oomoo`000:Eoo`00ogoo@Woo00<007oo
Ool06Woo0P000Woo0P000goo00<007ooOol04goo0P0097oo00<007ooOol00Woo00<007ooOol01Woo
0P0097oo00@007ooOomoo`8000Yoo`03001oogoo00Eoo`03001oogoo00Eoo`8000eoo`03001oogoo
00Yoo`<00003Ool00000009oo`03001oogoo0:9oo`00ogoo@Goo00<007ooOol06goo0P0017oo00D0
07ooOomoo`00019oo`8002Ioo`03001oogoo009oo`03001oogoo00Aoo`8002Ioo`04001oogooOol2
000:Ool00`00Oomoo`05Ool00`00Oomoo`05Ool2000>Ool00`00Oomoo`09Ool300000goo00000002
Ool00`00Oomoo`2ROol00?mood1oo`03001oogoo01aoo`8000Eoo`04001oogooOol2000>Ool2000X
Ool00`00Oomoo`02Ool01000Oomoogoo0`00:Goo00D007ooOomoo`0000Yoo`03001oogoo00Eoo`03
001oogoo00Ioo`8000eoo`03001oogoo00Uoo`<00003Ool00000009oo`03001oogoo0:9oo`00ogoo
?goo00<007ooOol07Goo0P001Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0:7oo00<0
07ooOol00Woo00@007oo000002aoo`05001oogooOol0000:Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool2000=Ool00`00Oomoo`09Ool30002Ool01@00Oomoogoo0000Xgoo003oOolnOol00`00Oomoo`0N
Ool30006Ool00`00Oomoo`02Ool20008Ool2000[Ool00`00Oomoo`02Ool2000^Ool01@00Oomoogoo
00002Woo00<007ooOol01Woo00<007ooOol01Goo0P003Woo00<007ooOol027oo0`000Woo00D007oo
Oomoo`000:=oo`00ogoo?Goo00<007ooOol07goo0`001goo00<007ooOol00goo00<007ooOol00goo
0P00;Goo00<007ooOol00`00;goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01Goo00<007oo00003Goo00<007ooOol027oo00<007oo00000Woo00D007ooOomoo`000:=o
o`00ogoo?7oo00<007ooOol087oo0`0027oo2`00;goo0`000Woo00<007ooOol0;Woo00D007ooOomo
o`0000Uoo`03001oogoo00Ioo`03001oogoo00Ioo`8000eoo`03001oogoo00Qoo`03001oo`00009o
o`05001oogooOol0002SOol00?mooc]oo`03001oogoo025oo`<000moo`<002ioo`@000=oo`03001o
ogoo02ioo`05001oogooOol00009Ool00`00Oomoo`06Ool00`00Oomoo`06Ool2000>Ool00`00Oomo
o`07Ool00`00Ool00002Ool20003Ool00`00Oomoo`2POol00?moocYoo`03001oogoo029oo`03001o
o`00019oo`@002Eoo`D000Aoo`800003Ool007oo02moo`04001oogooOol20008Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool2000>Ool00`00Oomoo`07Ool00`00Ool00002Ool20003Ool00`00Oomoo`2P
Ool00?moocUoo`03001oogoo02=oo`03001oo`0001Ioo`<001eoo`D000]oo`<0031oo`03001oogoo
008000Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oo`0000eoo`03001oogoo00Moo`03001o
o`00009oo`8000=oo`03001oogoo0:1oo`00ogoo>7oo00<007ooOol09Goo0P006Goo100057oo1@00
4Goo00@007oo000002ioo`03001oogoo008000Qoo`03001oogoo00Ioo`03001oogoo00Moo`8000io
o`03001oogoo00Ioo`03001oo`00009oo`8000Aoo`03001oogoo09moo`00ogoo=goo00<007ooOol0
9Woo0P007Goo50003goo0`0017oo00D007ooOomoo`0002eoo`06001oogoo001oo`001goo00<007oo
Ool01Woo00<007ooOol01goo0P003Woo00<007ooOol01Woo00<007oo00000goo00<007ooOol00Woo
00<007ooOol0Wgoo003oOolfOol00`00Oomoo`0WOol2000oOol00`00Oomoo`05Ool00`00Oomoo`0`
Ool00`00Oomoo`020007Ool00`00Oomoo`06Ool00`00Oomoo`07Ool2000?Ool00`00Oomoo`05Ool0
0`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`2OOol00?moocEoo`03001oogoo02Qoo`03001o
o`0003ioo`D0009oo`03001oogoo035oo`03001oogoo008000Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oo`0000ioo`03001oogoo00Eoo`8000Aoo`8000Aoo`03001oogoo09ioo`00ogoo=7oo
00<007ooOol0:Goo00<007oo0000?Woo00D007ooOomoo`00009oo`03001oogoo035oo`06001oogoo
001oo`001Woo00<007ooOol01Woo00<007ooOol027oo0P003Woo00<007ooOol01Goo0P0017oo0P00
17oo00<007ooOol0WWoo003oOolcOol00`00Oomoo`0ZOol00`00Ool0000oOol30003Ool00`00Oomo
o`0bOol01@00Ool007oo00001Woo00<007ooOol01Woo00<007ooOol027oo0P003goo00<007ooOol0
17oo0P0017oo0P0017oo00<007ooOol0WWoo003oOolbOol00`00Oomoo`0[Ool00`00Ool00015Ool0
0`00Oomoo`0bOol00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Ool0000>Ool00`00Oomoo`04Ool20004Ool20005Ool00`00Oomoo`2MOol00?mooc5oo`03001o
ogoo02aoo`03001oo`0004Eoo`03001oogoo039oo`03001oo`00009oo`03001oogoo00=oo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oo`0000moo`03001oogoo00=oo`8000Aoo`8000Eoo`03001o
ogoo09eoo`00ogoo<7oo00<007ooOol0;Goo00@007oo000004Aoo`03001oogoo03=oo`80009oo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00Qoo`8000moo`03001oogoo00=oo`8000Eoo`03
001oogoo00=oo`03001oogoo09eoo`00ogoo;goo00<007ooOol0;goo0`00A7oo00<007ooOol0<goo
00<007oo00000Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol027oo0P0047oo00<007oo
Ool00Woo0P001Goo00<007ooOol00goo00<007ooOol0WGoo003oOol^Ool00`00Oomoo`0`Ool00`00
Ool00014Ool00`00Oomoo`0cOol00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Ool0000?Ool00`00Oomoo`02Ool20005Ool20005Ool00`00Oomoo`2LOol00?mo
obeoo`03001oogoo035oo`03001oo`0004Aoo`03001oogoo03Aoo`80009oo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00Qoo`03001oo`0000moo`04001oogooOol30005Ool20005Ool00`00
Oomoo`2LOol00?moobaoo`03001oogoo039oo`03001oo`0004Aoo`03001oogoo03Aoo`8000=oo`05
001oogooOol00009Ool00`00Oomoo`09Ool2000@Ool00`00Oomoo`030005Ool20005Ool00`00Oomo
o`2LOol00?moob]oo`03001oogoo03=oo`04001oogoo0013Ool00`00Oomoo`0dOol20003Ool01@00
Oomoogoo00002Goo00<007ooOol02Goo00<007oo00003goo00<007ooOol00`001Goo0P001Goo00<0
07ooOol0W7oo003oOolZOol00`00Oomoo`0eOol00`00Ool00013Ool00`00Oomoo`0eOol00`00Oomo
o`02Ool01000Oomoo`002Goo00<007ooOol02Goo00<007oo000047oo00<007oo00000P001Woo00<0
07ooOol017oo00<007ooOol0Vgoo003oOolYOol00`00Oomoo`0fOol00`00Ool00013Ool00`00Oomo
o`0eOol20003Ool01@00Oomoogoo000027oo00<007ooOol02Goo00<007oo000047oo00<007oo0000
0P001Woo00<007ooOol017oo00<007ooOol0Vgoo003oOolXOol00`00Oomoo`0gOol01000Ool00000
@Woo00<007ooOol0=Goo0P000goo00D007ooOomoo`0000Qoo`03001oogoo00Yoo`03001oo`0000mo
o`03001oo`00008000Ioo`8000Eoo`03001oogoo09]oo`00ogoo9goo00<007ooOol0>7oo00@007oo
0000049oo`03001oogoo03Ioo`03001oogoo009oo`04001oogoo0008Ool00`00Oomoo`0:Ool00`00
Ool0000@Ool40006Ool20005Ool00`00Oomoo`2KOol00?moobMoo`03001oogoo03Qoo`04001oogoo
0012Ool00`00Oomoo`0fOol00`00Oomoo`02Ool01000Oomoo`0027oo00<007ooOol02Woo00<007oo
000047oo10001Woo0P001Goo00<007ooOol0Vgoo003oOolVOol00`00Oomoo`0jOol01000Ool00000
@Goo00<007ooOol0=Woo00<007ooOol00goo00<007oo000027oo00<007ooOol02Woo00@007ooOol0
011oo`<000Ioo`8000Ioo`03001oogoo09Yoo`00ogoo9Goo00<007ooOol0>goo00@007oo0000045o
o`03001oogoo03Ioo`8000Aoo`03001oo`0000Qoo`03001oogoo00]oo`03001oo`0000moo`@000Mo
o`03001oogoo00Aoo`03001oogoo09Yoo`00ogoo97oo00<007ooOol0?7oo00@007oo0000041oo`03
001oogoo03Moo`8000Aoo`03001oo`0000Qoo`03001oogoo00]oo`03001oo`0000moo`@000Moo`80
00Eoo`03001oogoo09Yoo`00ogoo8goo00<007ooOol0?Goo00@007oo0000041oo`03001oogoo03Qo
o`03001oogoo00=oo`8000Uoo`03001oogoo00Yoo`04001oogoo000>Ool01000Ool000001goo0P00
1Woo00<007ooOol0VGoo003oOolROol00`00Oomoo`0nOol00`00Oomoo`02000oOol00`00Oomoo`0h
Ool20004Ool20009Ool00`00Oomoo`0:Ool01000Oomoo`003Goo00<007ooOol00P001goo0P001Woo
00<007ooOol0VGoo003oOolQOol00`00Oomoo`10Ool01000Ool00000?goo00<007ooOol0>7oo0P00
1Goo0P0027oo00<007ooOol02goo00<007oo00003Goo00<007ooOol00P001goo0P001Woo00<007oo
Ool0VGoo003oOolPOol00`00Oomoo`11Ool01000Ool00000?goo00<007ooOol0>7oo0P001Goo0P00
27oo00<007ooOol02goo00@007ooOol000aoo`05001oo`00Ool00007Ool00`00Ool00006Ool00`00
Oomoo`2HOol00?mooamoo`03001oogoo049oo`03001oogoo008003ioo`03001oogoo03Qoo`03001o
o`0000Aoo`8000Qoo`03001oogoo00]oo`04001oogoo000;Ool01@00Oomoo`00Ool00P001Woo0`00
1Woo00<007ooOol0V7oo003oOolNOol00`00Oomoo`13Ool00`00Oomoo`02000nOol00`00Oomoo`0h
Ool00`00Ool00005Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Ool0000;Ool01@00Oomoo`00
Ool00P001goo0P001Woo00<007ooOol0V7oo003oOolMOol00`00Oomoo`14Ool00`00Oomoo`02000n
Ool00`00Oomoo`0iOol20005Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool01000Oomoo`002Woo00D0
07ooOol007oo008000Moo`8000Moo`03001oogoo09Moo`00ogoo77oo00<007ooOol0AWoo00<007oo
Ool00P00?Goo00<007ooOol0>Goo00<007oo000017oo00<007ooOol01Woo00<007ooOol037oo00@0
07ooOol000Uoo`05001oogooOol00002Ool20006Ool20007Ool00`00Oomoo`2GOol00?mooa]oo`03
001oogoo04Moo`03001oogoo008003eoo`03001oogoo03Uoo`03001oo`0000Aoo`8000Moo`03001o
ogoo00eoo`03001oo`0000Uoo`04001oogoo0003Ool20006Ool00`00Ool00006Ool00`00Oomoo`2G
Ool00?mooaYoo`03001oogoo04Qoo`03001oogoo008003eoo`03001oogoo03Uoo`03001oo`0000Ao
o`8000Moo`03001oogoo00eoo`04001oogoo0008Ool01000Oomoo`000goo00<007oo00001Goo00<0
07oo00001goo00<007ooOol0UWoo003oOolIOol00`00Oomoo`19Ool01000Oomoogoo0P00?7oo00<0
07ooOol0>Goo00@007ooOol000=oo`03001oo`0000Ioo`03001oogoo00eoo`04001oogoo0007Ool0
1@00Oomoogoo00000goo00<007oo00001Goo0`001goo00<007ooOol0UWoo003oOolHOol00`00Oomo
o`1:Ool01000Oomoogoo0P00?7oo00<007ooOol0>Goo00@007ooOol000Aoo`8000Ioo`03001oogoo
00ioo`03001oo`0000Moo`05001oogooOol00003Ool00`00Ool00005Ool30007Ool00`00Oomoo`2F
Ool00?mooaMoo`03001oogoo04aoo`03001oogoo008003aoo`03001oogoo03Uoo`04001oogoo0004
Ool20006Ool00`00Oomoo`0>Ool01000Oomoo`001Woo00D007ooOomoo`0000=oo`04001oogoo0005
Ool400001Woo00000000Ool009Qoo`00ogoo5Woo00<007ooOol0CGoo00D007ooOomoo`0003aoo`03
001oogoo03Yoo`04001oogoo0003Ool00`00Ool00005Ool00`00Oomoo`0>Ool01000Oomoo`001Goo
00D007ooOomoo`0000Aoo`04001oogoo0005Ool01000Ool007oo0`0000Aoo`00Ool009Moo`00ogoo
5Goo00<007ooOol0CWoo00@007ooOomoo`8003]oo`03001oogoo03Yoo`04001oogoo0003Ool00`00
Ool00005Ool00`00Oomoo`0>Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool01P00Ool007oo001oo`<00003Ool007oo09Ioo`00ogoo57oo00<007ooOol0Cgoo00@0
07ooOomoo`8003]oo`03001oogoo03Yoo`04001oogoo0003Ool01000Oomoo`001Goo00<007ooOol0
3Woo00@007ooOol000Aoo`05001oogooOol00005Ool00`00Oomoo`020003Ool30002Ool30002Ool0
0`00Oomoo`2EOol00?mooa=oo`03001oogoo051oo`03001oogoo009oo`03001oogoo03Uoo`03001o
ogoo03Yoo`05001oogooOol00002Ool01000Oomoo`001Goo00<007ooOol03Woo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo00=oo`06001oogoo001oo`000Woo0P0000=oo`0000000Woo0P00
00=oo`00Ool0UWoo003oOolBOol00`00Oomoo`1BOol01000Oomoogoo0P00>Goo00<007ooOol0>goo
00D007ooOomoo`00009oo`05001oogooOol00004Ool00`00Oomoo`0>Ool01@00Oomoogoo00000Woo
00D007ooOomoo`0000Ioo`07001oogooOol007oo00000Woo100000Ioo`00000007oo002GOol00?mo
oa5oo`03001oogoo05=oo`04001oogooOol2000iOol00`00Oomoo`0kOol01@00Oomoogoo00000Woo
00D007ooOomoo`0000Aoo`03001oogoo00moo`04001oogoo0002Ool01@00Oomoogoo00001Woo00D0
07ooOomoo`00009oo`06001oo`00Ool007oo10000Woo00<007ooOol0U7oo003oOol@Ool00`00Oomo
o`1DOol00`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`0kOol00`00Oomoo`02Ool00`00Ool0
0004Ool01@00Oomoogoo00004Goo00@007ooOomoo`8000Aoo`03001oogoo00Aoo`03001oogoo009o
o`03001oo`0000800004Ool00000Ool400000goo0000002EOol00?moo`@000]oo`03001oogoo05Eo
o`03001oogoo009oo`8003Qoo`03001oogoo03aoo`05001oogooOol00002Ool01@00Oomoogoo0000
0goo00<007ooOol03goo00@007ooOomoo`8000Aoo`03001oogoo00Eoo`04001oogooOol20002Ool3
0002Ool600000goo001oo`2COol00?ioo`04001oogoo000;Ool00`00Oomoo`1FOol00`00Oomoo`02
Ool2000hOol00`00Oomoo`0lOol01@00Oomoogoo00000Woo00<007ooOol00Woo00@007ooOol0019o
o`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`030002Ool200000goo001oo`09002C
Ool00?moo`<000Yoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo03Ioo`03001oogoo03ao
o`03001oogoo009oo`03001oo`0000Aoo`04001oogoo000BOol00`00Oomoo`020003Ool00`00Oomo
o`06Ool30002Ool01P00Oomoogoo001oo`800003Ool0000000800005Ool007ooOol0002BOol00?io
o`04001oogoo0009Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`0fOol00`00Oomoo`0l
Ool00`00Oomoo`02Ool00`00Ool00005Ool00`00Ool0000BOol00`00Oomoo`020003Ool00`00Oomo
o`05Ool40002Ool00`00Ool0000500000goo0000000200000goo001oo`02Ool00`00Oomoo`2?Ool0
0?moo`8000Uoo`03001oogoo05Yoo`03001oogoo009oo`8003Moo`03001oogoo03aoo`03001oogoo
009oo`03001oo`0000Eoo`03001oo`0001=oo`05001oo`00Ool00002Ool00`00Oomoo`04Ool40000
1Woo001oogoo001oo`D00005Ool00000001oo`020004Ool00`00Oomoo`2>Ool00?moo`Yoo`03001o
ogoo05]oo`03001oogoo00=oo`03001oogoo03Eoo`03001oogoo03aoo`03001oogoo00=oo`8000Io
o`8001=oo`80009oo`04001oogoo0005Ool20002Ool01`00Oomoo`00Ool007oo00D00004Ool00000
Ool40004Ool00`00Oomoo`2=Ool00?moo`Uoo`03001oogoo05aoo`03001oogoo00=oo`03001oogoo
03Eoo`03001oogoo03aoo`03001oogoo00=oo`8000Ioo`80019oo`<000=oo`03001oo`00009oo`04
001oo`000004Ool01@00Oomoo`00Ool00P0000Eoo`00000007oo0080009oo`<009Aoo`00ogoo27oo
00<007ooOol0GWoo00<007ooOol00Woo0P00=Woo00<007ooOol0?Goo00<007ooOol00Woo0P001goo
00<007ooOol04Goo0P000goo0P000goo0P0000=oo`00Ool00Woo0P000goo1`0000=oo`0000000Woo
0`00U7oo003oOol7Ool00`00Oomoo`1OOol00`00Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`0m
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool2000BOol40002Ool00`00Oomoo`020003Ool300000goo
001oo`03Ool200001Goo00000000Ool00P000goo0P00U7oo003oOol6Ool00`00Oomoo`1POol00`00
Oomoo`03Ool00`00Oomoo`0dOol00`00Oomoo`0mOol00`00Oomoo`03Ool20006Ool2000BOol20002
Ool300000goo001oo`09Ool01000Oomoogoo0P0000Aoo`00001oo`<000=oo`8009Aoo`00ogoo1Goo
00<007ooOol0HGoo00<007ooOol00goo0P00=Goo00<007ooOol0?Goo00<007ooOol00goo0P001goo
0P004Goo0P0017oo0`002Woo00<007ooOol00Woo00@007oo001oo`@000Aoo`03001oogoo099oo`00
ogoo17oo00<007ooOol0HWoo00<007ooOol017oo00<007ooOol0<goo00<007ooOol0?Goo00<007oo
Ool017oo00<007ooOol01Goo0P0047oo00@007ooOol0009oo`03001oo`0000aoo`03001oogoo009o
o`03001oo`0000@000Aoo`03001oogoo099oo`00ogoo0goo00<007ooOol0I7oo00<007ooOol00goo
00<007ooOol0<goo00<007ooOol0?Goo00<007ooOol017oo00<007ooOol01Goo00<007oo00003goo
00D007ooOol007oo00800003Ool007oo00]oo`03001oogoo009oo`04001oo`00Ool3002IOol00?mo
o`9oo`03001oogoo06Eoo`03001oogoo00=oo`8003Aoo`03001oogoo03eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oo`0000moo`03001oogoo00800005Ool007ooOol0000<Ool500000goo001o
o`03002IOol00?moo`5oo`03001oogoo06Ioo`03001oogoo00Aoo`03001oogoo039oo`03001oogoo
03eoo`03001oogoo00Aoo`8000Ioo`04001oogoo000=Ool02000Oomoo`00Ool007oo0003Ool00`00
Oomoo`0>Ool2000017oo00000000VGoo003oOol00`00Oomoo`1WOol00`00Oomoo`04Ool00`00Oomo
o`0bOol00`00Oomoo`0nOol00`00Oomoo`03Ool20006Ool01000Oomoo`003Goo0`000Woo0P0017oo
00<007ooOol03Woo00<007oo00000`00VGoo003nOol00`00Oomoo`1YOol00`00Oomoo`04Ool00`00
Oomoo`0aOol00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Ool00005Ool01@00Oomoogoo000037oo
00<007ooOol00Woo0P001Goo00<007ooOol03Woo0P0000=oo`000000VGoo003mOol00`00Oomoo`1Z
Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Ool00005
Ool01@00Oomoogoo00002Woo0P001Woo00<007oo0000100047oo0P0000=oo`000000VGoo003lOol0
0`00Oomoo`1[Ool00`00Oomoo`04Ool2000bOol00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Ool0
0004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00006Ool20002Ool01000Oomoo`0047oo
00@007oo000009Uoo`00ngoo00<007ooOol0KGoo00<007ooOol017oo00<007ooOol0<7oo00<007oo
Ool0?Woo00<007ooOol017oo00<007oo00000`0000=oo`00Ool00goo00<007ooOol01Goo00@007oo
Ool000Eoo`<0009oo`05001oogooOol0000>Ool5002IOol00?Yoo`03001oogoo06ioo`03001oogoo
00Aoo`80035oo`03001oogoo03ioo`03001oogoo00Aoo`03001oo`0000=oo`8000Eoo`03001oogoo
009oo`80009oo`03001oogoo00Aoo`03001oo`00009oo`05001oogooOol0000>Ool5002IOol00?Uo
o`03001oogoo06moo`03001oogoo00Aoo`80035oo`03001oogoo03ioo`03001oogoo00Aoo`04001o
o`000003Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00000`00
17oo00<007ooOol02goo00<007oo00000P00VGoo003hOol00`00Oomoo`1aOol00`00Oomoo`04Ool2
000`Ool00`00Oomoo`0nOol00`00Oomoo`04Ool01000Ool000000Woo0P001Woo0`001Goo00<007oo
Ool00goo00@007ooOol0009oo`03001oogoo009oo`03001oogoo00]oo`04001oo`00Ool2002HOol0
0?Moo`03001oogoo079oo`03001oogoo00Aoo`80031oo`03001oogoo03moo`03001oogoo00=oo`03
001oogoo00<00003Ool007oo00Eoo`03001oo`0000Aoo`03001oogoo00Aoo`04001oogooOol30005
Ool00`00Oomoo`09Ool00`00Oomoo`04002HOol00?Ioo`03001oogoo07=oo`03001oogoo00Eoo`80
02moo`03001oogoo03moo`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`02Ool20000
0goo001oo`020002Ool00`00Oomoo`04Ool01@00Oomoogoo000027oo00<007ooOol027oo00<007oo
Ool01000V7oo003eOol00`00Oomoo`1dOol00`00Oomoo`05Ool2000_Ool00`00Oomoo`0oOol00`00
Oomoo`04Ool01@00Oomoogoo00000Woo00H007ooOol007oo0002Ool00`00Oomoo`030006Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`04002HOol00?Aoo`03001oogoo
07Ioo`03001oogoo00Aoo`03001oo`0002ioo`03001oogoo03moo`03001oogoo00Aoo`05001oogoo
Ool00002Ool00`00Ool00002Ool01000Oomoo`000goo0P001Goo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol01Woo00D007ooOol007oo00800003Ool007oo09Ioo`00lgoo00<007ooOol0Mgoo
00<007ooOol01Goo0P00;Woo00<007ooOol0?goo00<007ooOol017oo00D007ooOomoo`00009oo`80
009oo`03001oogoo009oo`06001oogoo001oo`0017oo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol01Goo00D007ooOol007oo00800003Ool007oo09Ioo`00lWoo00<007ooOol0N7oo00<007oo
Ool01Goo0P00;Woo00<007ooOol0?goo00<007ooOol017oo00<007ooOol00Woo0`000goo00<007oo
Ool00goo00<007oo00001Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00@007oo
Ool0009oo`@009Moo`00lGoo00<007ooOol0NWoo00<007ooOol01Goo0P00;Goo00<007ooOol0?goo
00<007ooOol017oo00@007ooOomoo`800003Ool007oo00Qoo`8000Moo`03001oogoo00Aoo`03001o
ogoo00Qoo`03001oogoo009oo`04001oogoo0002Ool300000goo001oo`2EOol00?5oo`03001oogoo
07Yoo`03001oogoo00Eoo`8002eoo`03001oogoo03moo`03001oogoo00Eoo`03001oo`00009oo`80
00Yoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qoo`05001oogooOol00002Ool01P00
Ool007oo001oo`8009Ioo`00l7oo00<007ooOol0Ngoo00<007ooOol01Goo00<007oo0000;7oo00<0
07ooOol0@7oo00<007ooOol017oo0P000goo0P002Goo00<007oo00001Goo00<007ooOol01Woo00<0
07ooOol02Goo1P000Woo00@007oo001oo`8009Ioo`00kgoo00<007ooOol0O7oo00<007ooOol01Woo
0P00;7oo00<007ooOol0@7oo00<007ooOol00goo0P001Goo00<007ooOol01Woo00@007ooOol000Eo
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00=oo`03001oo`0000800003Ool007oo09Ao
o`00kWoo00<007ooOol0OWoo00<007ooOol01Goo00<007oo0000:goo00<007ooOol0@7oo00<007oo
Ool00Woo00<007oo00001Goo00@007ooOomoo`@00003Ool007oo009oo`03001oogoo009oo`03001o
ogoo00Moo`03001oogoo00Uoo`03001oogoo00Aoo`05001oo`00001oo`02002EOol00>eoo`03001o
ogoo07moo`03001oogoo00Eoo`03001oo`0002]oo`03001oogoo041oo`03001oogoo0080009oo`03
001oogoo00=oo`04001oogoo0002Ool00`00Ool00004Ool01@00Oomoogoo00002Woo00<007ooOol0
2Goo00<007ooOol017oo00D007oo000007oo008009Eoo`00k7oo00<007ooOol0P7oo00<007ooOol0
1Woo00<007oo0000:Woo00<007ooOol0@7oo00<007oo00001Goo00<007ooOol00Woo0P000Woo0`00
00=oo`00Ool017oo00@007ooOol000]oo`03001oogoo00Moo`03001oogoo00Eoo`04001oo`000002
Ool2002DOol00>]oo`03001oogoo089oo`03001oogoo00Eoo`03001oo`0002Yoo`03001oogoo041o
o`8000Ioo`03001oogoo009oo`800004Ool007ooOol20007Ool00`00Ool0000;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool01000Ool000000Woo0P00U7oo003ZOol00`00Oomoo`23Ool00`00Oomoo`06
Ool00`00Ool0000YOol00`00Oomoo`0oOol20007Ool00`00Oomoo`02Ool01000Ool007oo0`0027oo
0P003Goo00<007ooOol01Woo00<007ooOol017oo00H007ooOol007oo0002Ool00`00Oomoo`2BOol0
0>Uoo`03001oogoo08Aoo`03001oogoo00Ioo`03001oo`0002Uoo`03001oogoo03eoo`800003Ool0
07oo00Ioo`03001oogoo00=oo`8000=oo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Eo
o`03001oogoo00Eoo`06001oogoo001oo`000Woo0P00Tgoo003XOol00`00Oomoo`26Ool00`00Oomo
o`05Ool01000Oomoo`00:7oo00<007ooOol0?7oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool00goo00D007oo001oo`0000Yoo`8000aoo`03001oogoo00Eoo`03001oogoo00Eoo`06001oogoo
001oo`000Woo0P00Tgoo003WOol00`00Oomoo`27Ool00`00Oomoo`06Ool00`00Ool0000XOol00`00
Oomoo`0kOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01@00Ool007oo00002Goo
00<007oo00003Goo00<007ooOol00goo00<007ooOol01Woo00H007ooOol007oo0003Ool2002BOol0
0>Ioo`03001oogoo08Qoo`03001oogoo00Ioo`04001oogoo000WOol00`00Oomoo`0iOol20006Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01000Ool000002Woo00@007ooOol000aoo`03001oogoo00=o
o`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`02000EOol2001kOol00>Eoo`03001o
ogoo08Uoo`03001oogoo00Moo`03001oo`0002Moo`03001oogoo03Qoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo009oo`04001oo`00000:Ool01000Oomoogoo0P002goo00D007ooOomoo`00
00Qoo`05001oogooOol00002Ool01@00Oomoogoo00005goo00<007ooOol0N7oo003TOol00`00Oomo
o`2;Ool00`00Oomoo`06Ool01000Oomoo`009Woo00<007ooOol0=Woo0P002Goo00<007ooOol01Goo
00<007ooOol00Woo00@007oo000000Uoo`03001oogoo00Aoo`03001oogoo00Qoo`04001oogoo0008
Ool00`00Oomoo`02Ool01000Oomoo`000goo0P005goo0P00N7oo003SOol00`00Oomoo`2<Ool00`00
Oomoo`07Ool00`00Ool0000VOol00`00Oomoo`0eOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool20002Ool00`00Oomoo`06Ool00`00Ool000020003Ool00`00Oomoo`08Ool00`00Ool0
0008Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo0P006Goo0`00MGoo003ROol00`00Oomoo`2=
Ool00`00Oomoo`07Ool01000Oomoo`009Goo00<007ooOol0<goo0P0037oo00<007ooOol01Woo00@0
07ooOomoo`80009oo`03001oogoo00Eoo`03001oo`0000Moo`8000Qoo`8000Qoo`03001oogoo00=o
o`05001oogooOol00003Ool00`00Oomoo`0IOol2001dOol00>5oo`03001oogoo08moo`03001oogoo
00Moo`03001oo`0002Eoo`03001oogoo039oo`03001oogoo00aoo`03001oogoo00Ioo`05001oogoo
Ool00004Ool00`00Oomoo`04Ool00`00Ool000040005Ool00`00Oomoo`05Ool20007Ool00`00Oomo
o`04Ool01@00Oomoogoo00000goo0P005Goo2000Lgoo003POol00`00Oomoo`2@Ool00`00Oomoo`08
Ool00`00Ool0000TOol00`00Oomoo`0aOol00`00Oomoo`0>Ool00`00Oomoo`05Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007oo00000goo00<007ooOol017oo00<007ooOol017oo0P001goo
00<007ooOol017oo00D007ooOomoo`0000Aoo`03001oogoo00Qoo`/000Aoo`@007=oo`00ggoo00<0
07ooOol0TGoo00<007ooOol027oo00<007oo000097oo00<007ooOol0;goo0P004Goo00<007ooOol0
1Goo00<007ooOol00P0017oo00<007ooOol00goo00@007ooOomoo`<000Qoo`8000=oo`03001oo`00
00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00`000ioo`03001oo`00008007=oo`00
gWoo00<007ooOol0TWoo00<007ooOol02Goo00<007oo00008goo00<007ooOol0;Woo00<007ooOol0
4Goo00<007ooOol01Woo0P000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol03Woo00@0
07ooOol0009oo`03001oogoo00=oo`04001oogooOol<0002Ool00`00Oomoo`0EOol00`00Ool00002
001cOol00=eoo`03001oogoo09Aoo`03001oogoo00Qoo`03001oo`0002=oo`03001oogoo02aoo`80
01Aoo`03001oogoo00Ioo`80009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00moo`80
009oo`/000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Ioo`@007=oo`00g7oo00<0
07ooOol0UGoo00<007ooOol02Goo00<007oo00008Woo00<007ooOol0:goo00<007ooOol057oo00<0
07ooOol01Woo00D007ooOomoo`0000Eoo`04001oogoo000:Ool>000=Ool00`00Oomoo`03Ool01000
Oomoogoo0P005goo00@007oo000007=oo`00fgoo00<007ooOol0UWoo00<007ooOol02Goo00<007oo
00008Woo00<007ooOol06goo0P0037oo0P005goo00<007ooOol01Woo00D007ooOomoo`0000Eoo`03
001oo`0000/000Qoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo01Eoo`D0079oo`00fWoo00<007ooOol0V7oo00<007ooOol02Goo0P008Woo00<007oo
Ool07Goo00<007ooOol027oo00<007ooOol05goo00<007ooOol01Goo3P004Woo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol05Woo1000LWoo003IOol0
0`00Oomoo`2IOol00`00Oomoo`09Ool00`00Ool0000QOol00`00Oomoo`0NOol2000017oo00000000
0goo00<007ooOol05Woo3@000Woo00<007ooOol017oo0P004Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol05Goo1000LWoo003HOol00`00Oomoo`2J
Ool00`00Oomoo`0:Ool2000QOol00`00Oomoo`0POol20002Ool3000=Ool<0002Ool00`00Oomoo`04
Ool01000Oomoo`000Woo00<007ooOol017oo0P004Goo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol05Goo0`0000=oo`00Ool0L7oo003GOol00`00Oomo
o`2LOol00`00Oomoo`09Ool00`00Ool0000POol00`00Oomoo`0ROol00`00Ool00004Ool;000>Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007ooOol017oo0P004Goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol017oo00<007ooOol00goo00<007ooOol057oo0`0000=oo`00Ool0L7oo
003FOol00`00Oomoo`2MOol00`00Oomoo`0:Ool2000POol00`00Oomoo`0NOol;000JOol00`00Oomo
o`02Ool01@00Oomoogoo00000Woo00<007ooOol017oo0P0047oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol017oo00<007ooOol00goo00<007ooOol057oo0`0000=oo`00Ool0L7oo003EOol0
0`00Oomoo`2NOol00`00Oomoo`0:Ool00`00Ool0000OOol00`00Oomoo`0DOol:0005Ool2000NOol0
1@00Oomoogoo000017oo00@007ooOol000Ioo`03001oo`0000ioo`03001oogoo00Yoo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo01Aoo`<0009oo`03001oogoo06ioo`00
e7oo00<007ooOol0Wgoo00<007ooOol02goo0P007goo00<007ooOol02Woo2P0037oo00<007ooOol0
0P007Woo00@007ooOol000Ioo`03001oo`0000Eoo`04001oogoo000=Ool00`00Oomoo`0;Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0COol30002Ool00`00Oomoo`1^
Ool00==oo`03001oogoo0:5oo`03001oogoo00]oo`8001ioo`03001oogoo00X001Moo`@001ioo`04
001oogoo0006Ool00`00Ool00005Ool01@00Oomoogoo00002goo00<007ooOol03Goo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol04goo0`000Woo00<007ooOol0KWoo003B
Ool00`00Oomoo`2ROol00`00Oomoo`0;Ool2000GOol:000ROol3000NOol00`00Ool00007Ool01000
Oomoo`000goo00<007ooOol00goo00<007ooOol01goo00<007ooOol03Woo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol00Woo0P0057oo10000Woo00<007ooOol0KGoo003AOol00`00Oomoo`2S
Ool00`00Oomoo`0<Ool2000<Ool:0007Ool00`00Oomoo`0ROol3000NOol00`00Ool00007Ool01000
Oomoo`000goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol047oo00<007ooOol01Goo00<0
07ooOol01Woo0`000goo00<007ooOol00Woo00<007ooOol03Goo10000Woo00<007ooOol0KGoo003@
Ool00`00Oomoo`1XOol3000jOol00`00Oomoo`0;Ool20002Ool:000AOol00`00Oomoo`0ROol4000M
Ool20008Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol047oo00<0
07ooOol01Goo00<007ooOol01Woo00@007ooOol0009oo`8000=oo`03001oogoo00aoo`D0009oo`03
001oogoo06eoo`00cgoo00<007ooOol0J7oo00D007ooOomoo`0003Uoo`03001oogoo00Aoo`/001]o
o`03001oogoo029oo`@001eoo`8000Uoo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo019oo`03001oogoo00=oo`03001oogoo00Moo`04001oogooOol200001Goo001oogoo
00003goo1@000goo00<007ooOol0K7oo003>Ool00`00Oomoo`1YOol00`00Oomoo`0hOol:0008Ool2
000LOol00`00Oomoo`0QOol5000MOol00`00Oomoo`08Ool01@00Ool007oo00002Goo00<007ooOol0
0Woo00<007ooOol04goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00Woo100047oo1@00
0goo00<007ooOol0K7oo003=Ool00`00Oomoo`1ZOol01@00Oomoogoo0000;7oo2P0017oo00<007oo
Ool037oo0P006goo00<007ooOol08Goo1@0077oo0P002Woo00D007oo001oo`0000Uoo`05001oogoo
Ool0000GOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`03Ool3000@Ool400001Goo001o
ogoo0000KWoo003<Ool00`00Oomoo`1/Ool3000SOol:000>Ool00`00Oomoo`0<Ool00`00Ool0000J
Ool00`00Oomoo`0QOol6000KOol2000:Ool01000Ool000002goo00<007oo000067oo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol017oo0P0047oo100000=oo`00Ool00Woo00<007ooOol0Jgoo
003;Ool00`00Oomoo`29Ool:000HOol00`00Oomoo`0=Ool2000JOol00`00Oomoo`0QOol2000017oo
000000006Woo00<007oo00002Woo00@007oo000000]oo`8001Uoo`03001oogoo009oo`03001oogoo
00Uoo`03001oogoo00=oo`80011oo`@00003Ool007oo009oo`03001oogoo06]oo`00bWoo00<007oo
Ool0P7oo2P008goo00<007ooOol03Goo0P006Goo00<007ooOol087oo0`0000Aoo`00000001Yoo`04
001oogoo000:Ool2000;Ool00`00Ool0000JOol01@00Oomoogoo00002goo00<007ooOol017oo00<0
07ooOol03Woo100000=oo`00Ool00goo00<007ooOol0JWoo0039Ool00`00Oomoo`1gOol:000]Ool0
0`00Oomoo`0>Ool2000HOol00`00Oomoo`0POol300001Goo000007oo000067oo00D007ooOomoo`00
00Yoo`8000Yoo`05001oogooOol0000IOol01@00Oomoogoo00002goo00<007ooOol017oo0P003goo
100000=oo`00Ool00goo00<007ooOol0JWoo0038Ool00`00Oomoo`1^Ool:000hOol00`00Oomoo`0=
Ool00`00Ool0000GOol00`00Oomoo`0POol300000goo00000002000GOol00`00Oomoo`02Ool00`00
Oomoo`08Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01000Oomoo`002goo00<007ooOol0
1Goo00<007ooOol03Goo10000Woo00D007ooOomoo`0006aoo`00agoo00<007ooOol0IGoo2P00@Woo
00<007ooOol03Woo0P0067oo00<007ooOol07goo0`0000=oo`0000000P005goo00<007ooOol00Woo
00<007ooOol01goo10001goo00<007ooOol017oo00<007ooOol05goo00@007ooOol000aoo`04001o
ogooOol300000goo001oo`0=Ool40002Ool00`00Oomoo`02Ool00`00Oomoo`1YOol00<Ioo`03001o
ogoo05aoo`X004aoo`03001oogoo00moo`8001Moo`03001oogoo01moo`<00004Ool00000Ool2000E
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool200000goo001oo`04Ool20007Ool00`00Oomoo`0HOol0
0`00Ool0000<Ool01000Oomoo`000goo0P003Woo10000Woo00<007ooOol00Woo00<007ooOol0JGoo
0035Ool00`00Oomoo`1COol:001GOol00`00Oomoo`0?Ool2000FOol00`00Oomoo`0NOol01@00Ool0
0000Ool00P000Woo00<007ooOol04goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00P00
17oo00<007ooOol027oo00<007ooOol05goo00<007oo00000Woo00<007ooOol01goo00@007ooOol0
00Eoo`03001oogoo00Yoo`03001oo`000080009oo`03001oogoo009oo`03001oogoo06Uoo`00a7oo
00<007ooOol0BWoo2P00HGoo00<007ooOol03goo0P005Woo00<007ooOol07Woo00@007oo0000009o
o`04001oogoo000DOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`030002Ool00`00Oomo
o`0:Ool00`00Oomoo`0AOol20004Ool20002Ool00`00Oomoo`08Ool00`00Ool00003Ool00`00Ool0
000<Ool00`00Ool000020003Ool00`00Oomoo`02Ool00`00Oomoo`1XOol00<=oo`03001oogoo045o
o`X006aoo`03001oogoo00moo`8001Eoo`03001oogoo01ioo`800005Ool007ooOol00002Ool2000B
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool01000Oomoogoo0`0000=oo`00Ool037oo00<007ooOol0
4goo0P000Woo0P0000=oo`00Ool02Woo00<007ooOol00`000goo00<007ooOol02Goo00<007ooOol0
0P000goo00<007ooOol00Woo00<007ooOol0J7oo0032Ool00`00Oomoo`0gOol;001fOol00`00Oomo
o`0@Ool2000DOol00`00Oomoo`0NOol200001Goo001oogoo00000goo00<007ooOol047oo00<007oo
Ool01Goo00<007ooOol01Goo00@007ooOomoo`@000moo`03001oogoo01Aoo`800004Ool007oo000;
Ool00`00Oomoo`06Ool2000:Ool00`00Oomoo`020003Ool00`00Oomoo`02Ool00`00Oomoo`1XOol0
0<5oo`03001oogoo02ioo`X0089oo`03001oogoo011oo`03001oogoo019oo`03001oogoo01ioo`80
0004Ool007ooOol20002Ool3000?Ool00`00Oomoo`05Ool90005Ool4000>Ool00`00Oomoo`0FOol2
00000goo001oo`0;Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool000020003Ool00`00Oomo
o`03Ool00`00Oomoo`1WOol00<1oo`03001oogoo02Eoo`X008aoo`03001oogoo015oo`03001oogoo
015oo`03001oogoo01eoo`05001oo`00Ool00003Ool01000Oomoo`000Woo00<007ooOol037oo00<0
07ooOol01Woo00<007ooOol017oo00@007ooOomoo`<000=oo`<000aoo`03001oogoo01Ioo`8000eo
o`03001oogoo00Ioo`<000Qoo`03001oo`00008000Aoo`03001oogoo009oo`03001oogoo06Moo`00
_goo00<007ooOol077oo2P00UWoo00<007ooOol04Goo0P004Woo00<007ooOol07Goo00D007oo001o
o`0000=oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Ool000020002Ool00`00Oomoo`04Ool2000:Ool00`00Oomoo`0FOol2000=Ool00`00Oomoo`07
Ool00`00Ool00007Ool200000goo00000004Ool00`00Oomoo`03Ool00`00Oomoo`1VOol00;ioo`03
001oogoo01=oo`X00:5oo`03001oogoo015oo`03001oogoo011oo`03001oogoo01eoo`04001oo`00
0004Ool20002Ool01@00Oomoogoo00002Woo00<007ooOol00Woo0P0017oo00<007ooOol00Woo00@0
07oo0000009oo`@0019oo`03001oogoo01Eoo`03001oo`0000eoo`03001oogoo00Ioo`04001oogoo
0006Ool200000goo00000004Ool00`00Oomoo`03Ool00`00Oomoo`1VOol00;Uoo`<00003Ool007oo
00]oo`X00:]oo`03001oogoo019oo`03001oogoo00moo`03001oogoo01eoo`04001oo`000004Ool2
0002Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomo
o`030002Ool00`00Oomoo`04000AOol00`00Oomoo`0EOol01000Oomoo`0037oo00<007ooOol01goo
00@007ooOol000Eoo`800003Ool0000000Aoo`03001oogoo00Aoo`03001oogoo06Eoo`00^Woo00<0
07oo00000goo2P00]Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol077oo00D007oo001o
o`0000Aoo`80009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`06001oogooOol0
07oo0P0017oo00<007ooOol010004Woo00<007ooOol057oo00@007ooOol000aoo`03001oogoo00Mo
o`05001oogooOol00002Ool30002Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1UOol00;Yoo`H0
0<1oo`03001oogoo019oo`8000Uoo`03001oogoo00=oo`03001oogoo01aoo`05001oo`00Ool00005
Ool20002Ool00`00Oomoo`03Ool400000goo001oo`0:Ool:00001Woo001oogoo001oo`8001=oo`03
001oogoo019oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo009oo`80
009oo`03001oogoo008000Eoo`03001oogoo00Aoo`03001oogoo06Aoo`00^Woo0P0017oo1`00^Goo
00<007ooOol04goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol077oo00@007oo000000Io
o`80009oo`03001oogoo00Moo`D000Aoo`H00003Ool00000009oo`800005Ool007oo001oo`04000C
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04
Ool01000Oomoogoo0P001Goo00<007ooOol017oo00<007ooOol0I7oo002jOol2000;Ool8002bOol0
0`00Oomoo`0COol00`00Oomoo`08Ool01@00Oomoogoo00007Woo00@007oo000000Ioo`80009oo`03
001oogoo00Moo`03001oogoo009oo`@000Ioo`H0009oo`06001oogooOol007oo0P0057oo00<007oo
Ool04Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00@007oo
Oomoo`8000Ioo`03001oogoo00=oo`03001oogoo06Aoo`00^Goo0`004goo2000ZWoo00<007ooOol0
57oo0P002Goo00@007ooOol001ioo`04001oo`000006Ool00`00Ool00002Ool00`00Oomoo`05Ool0
0`00Oomoo`0=Ool20003Ool01000Oomoo`000Woo0P0000Aoo`00Ool001=oo`03001oogoo015oo`03
001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00800003
Ool007oo00Aoo`03001oogoo00Aoo`03001oogoo06=oo`00^Woo0P006goo1`00Y7oo00<007ooOol0
4goo00<007oo00000P001goo00<007oo000017oo0P005goo00D007oo001oo`0000Moo`80009oo`03
001oogoo00Aoo`03001oogoo00ioo`8000=oo`<000Ioo`03001oo`0001Aoo`03001oogoo011oo`03
001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00800003
Ool007oo00Aoo`03001oogoo00Aoo`03001oogoo06=oo`00^goo00<007ooOol087oo2000W7oo00<0
07ooOol04goo0P0000=oo`00Ool00`001Goo0P0000Aoo`00000001Uoo`04001oo`000008Ool20002
Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Ool00003Ool00`00Oomoo`06Ool00`00Ool0000D
Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`0200000goo001oo`04Ool00`00Oomoo`05Ool00`00Oomoo`1ROol00;]oo`03001o
ogoo02Qoo`P009Aoo`03001oogoo01=oo`05001oo`00Ool00003Ool00`00Oomoo`03Ool2000LOol2
00000goo001oo`07Ool00`00Ool00002Ool01@00Oomoogoo000047oo00@007ooOol0009oo`8000Qo
o`04001oogoo000DOol00`00Oomoo`0?Ool40005Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`0200000goo001oo`05Ool00`00Oomoo`04Ool00`00Oomoo`1ROol00;]o
o`03001oogoo031oo`L008ioo`03001oogoo015oo`04001oogoo0002Ool00`00Oomoo`06Ool00`00
Oomoo`0KOol200000goo001oo`07Ool01P00Oomoo`00Ool0009oo`03001oogoo00eoo`8000=oo`03
001oogoo00Yoo`04001oogoo000EOol00`00Oomoo`0>Ool20002Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool01000Oomoo`000goo0P000Woo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol0HGoo002kOol2000hOol80026Ool00`00Oomoo`0AOol01@00Oomoogoo00000Woo00<0
07ooOol01Goo00<007ooOol06Woo00D007oo001oo`0000Uoo`03001oogoo0080009oo`03001oogoo
00]oo`8000Eoo`03001oogoo00Yoo`04001oogoo000EOol00`00Oomoo`0>Ool20002Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`08Ool01000Oomoo`000goo0P000Woo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol0HGoo002kOol20010Ool8001oOol00`00Oomoo`0@Ool00`00Oomo
o`02Ool01000Oomoo`001Woo00<007ooOol06Woo0P0000=oo`00Ool02Goo00D007ooOol007oo0080
00eoo`03001oogoo00Eoo`03001oogoo00Yoo`04001oogoo000FOol2000=Ool00`00Ool00002Ool0
0`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Ool00002Ool00`00Ool00002Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`1QOol00;]oo`8004Qoo`L007Qoo`03001oogoo
01Ioo`04001oogoo0006Ool00`00Oomoo`0IOol200000goo001oo`09Ool01000Oomoogoo0P0037oo
0P0027oo00<007ooOol02Woo00D007ooOomoo`0001Eoo`04001oo`00000;Ool00`00Ool000020008
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool20003Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool3001POol00;aoo`03001oogoo04eoo`P0071oo`03001oogoo00moo`@000=oo`05001o
ogooOol00005Ool00`00Oomoo`0HOol20002Ool00`00Oomoo`09Ool00`00Oomoo`02000:Ool2000:
Ool00`00Oomoo`0:Ool01@00Oomoogoo000057oo00<007oo00000Woo0P002Goo00<007oo00002Woo
00<007ooOol01Woo00<007ooOol02Goo00@007ooOomoo`8000Aoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00<000Aoo`8005Moo`00_7oo00<007ooOol0EGoo2000JGoo00<007ooOol03Goo
00@007ooOol000Eoo`05001oogooOol00004Ool00`00Oomoo`0HOol200000goo001oo`0;Ool00`00
Ool00002Ool50004Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01000Oomoo`0057oo00@007ooOol0
00=oo`8000Moo`<000]oo`03001oogoo00Ioo`03001oogoo00Moo`80009oo`03001oo`0000Aoo`03
001oogoo00Aoo`03001oogoo00Eoo`05001oogoo001oo`0200001Goo001oogoo0000EWoo002lOol0
0`00Oomoo`1MOol7001ROol00`00Oomoo`0=Ool01000Oomoo`001Woo00D007ooOomoo`0000=oo`03
001oogoo01Qoo`03001oo`0000eoo`8000=oo`03001oogoo009oo`@000eoo`03001oogoo00]oo`05
001oogooOol0000COol01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol037oo0P001Woo
00<007ooOol01goo00L007oo001oo`00Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00
Oomoo`00Ool010000Woo00<007ooOol0E7oo002lOol00`00Oomoo`1TOol8001KOol00`00Oomoo`0<
Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOol001Yoo`8000ioo`8000=oo`03001oogoo
01=oo`03001oogoo00]oo`05001oogooOol0000BOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Ool000000Woo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol017oo00<007oo00000P000Woo0P000Woo00<007ooOol0E7oo002lOol0
0`00Oomoo`1/Ool8000ZOol4000UOol00`00Oomoo`0=Ool30007Ool00`00Oomoo`02Ool00`00Ool0
000IOol2000?Ool20004Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool01@00Oomoogoo00004Woo00<0
07ooOol00goo00<007ooOol027oo00<007ooOol03goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol00P000Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00goo0`0000=oo`00Ool0
0Woo0P000Woo00<007ooOol0E7oo002lOol00`00Oomoo`1dOol7000ROol01000Oomoo`009Woo00<0
07ooOol03goo00<007ooOol01Woo00<007ooOol00Woo0P006Goo0P003Woo00<007oo000017oo00<0
07ooOol04Woo00<007ooOol02goo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol01goo00<0
07ooOol047oo0P000goo00<007ooOol01Goo00<007ooOol00P000Woo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol00`000Woo0`000goo0P000Woo00<007ooOol0E7oo002lOol00`00Oomoo`1k
Ool8000JOol01000Oomoo`009goo00<007ooOol03Goo0P0027oo00<007ooOol017oo0P005Woo0P00
3Woo00@007ooOol000Aoo`03001oogoo015oo`03001oogoo00@000Qoo`03001oogoo009oo`03001o
ogoo01Moo`03001oogoo00Ioo`03001oogoo019oo`04001oogoo0006Ool01000Oomoogoo0P000Woo
00<007ooOol00goo00<007ooOol00goo10001Woo0P000Woo1@00Egoo002lOol00`00Oomoo`23Ool8
000BOol01000Oomoo`009goo00<007ooOol067oo00<007ooOol00goo00@007oo000001Aoo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo011oo`03001oo`00009oo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00Ioo`03001oogoo01=oo`800003
Ool007oo00Aoo`09001oogooOol007oo001oo`0000Eoo`03001oogoo00<0009oo`03001oogoo00Eo
o`04001oogooOol3001IOol00;aoo`03001oogoo08]oo`L000aoo`<002Qoo`03001oogoo01Qoo`03
001oogoo009oo`04001oogooOol3000@Ool2000=Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0@Ool00`00Oomoo`030009Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`04Ool0
0`00Oomoo`0FOol20005Ool40002Ool00`00Ool00005Ool30006Ool00`00Oomoo`020003Ool00`00
Oomoo`04001HOol00;aoo`03001oogoo099oo`P000Ioo`03001oogoo02Ioo`03001oogoo01Qoo`03
001oogoo009oo`03001oogoo00Aoo`8000Yoo`H000aoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo011oo`03001oo`00009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo01Qoo`03
001oogoo00=oo`03001oogoo01Moo`03001oogoo00@000Ioo`04001oogooOol300000goo001oo`06
Ool00`00Oomoo`02Ool300000goo001oo`04001HOol00;aoo`8009]oo`P002Qoo`03001oogoo01Eo
o`@000=oo`03001oogoo00Ioo`8000=oo`D000Aoo`03001oogoo00]oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00moo`03001oogoo008000Yoo`03001oogoo00=oo`03001oogoo01Uoo`03
001oogoo009oo`03001oogoo00Uoo`<000aoo`80009oo`03001oogoo00Eoo`@000Aoo`03001oogoo
009oo`05001oogooOol00006Ool200000goo00000002001HOol00;aoo`800:=oo`L0025oo`03001o
ogoo01Aoo`03001oogoo009oo`04001oogoo000:Ool30008Ool2000<Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0IOol00`00
Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo00@007ooOol000Eoo`D0009oo`8000=o
o`05001oogooOol00003Ool00`00Oomoo`06Ool6001GOol00;aoo`800:Yoo`P001Uoo`03001oogoo
01Aoo`D00005Ool007ooOol0000DOol2000;Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0IOol01@00Oomoogoo00002Woo00<0
07ooOol03Goo00@007ooOol0009oo`<000=oo`8000Aoo`800005Ool007ooOol00005Ool00`00Oomo
o`05Ool400000goo001oo`1FOol00;aoo`800;9oo`L001=oo`03001oogoo01=oo`07001oogooOol0
07oo00000Woo00<007ooOol04Goo00<007oo00002Woo00<007ooOol02Goo00<007ooOol00Woo00<0
07ooOol03Woo00<007ooOol03Goo00<007ooOol00goo00<007ooOol03Woo0`002Goo00@007ooOol0
00Yoo`05001oogooOol0000<Ool00`00Ool000020006Ool00`00Ool00005Ool01@00Ool007oo0000
1Goo00<007ooOol00goo1P0000=oo`00Ool0EWoo002lOol2002iOol8000;Ool00`00Oomoo`0DOol3
0003Ool00`00Ool0000COol2000:Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool0
0`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Ool0000;Ool3
000<Ool30008Ool01000Oomoo`001Woo0P0000=oo`00Ool01Goo0P0017oo1@0000=oo`000000EWoo
002lOol20031Ool80004Ool00`00Oomoo`0JOol2000BOol00`00Ool00009Ool00`00Oomoo`0<Ool0
1@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo1@002Goo00<0
07oo00005Woo10000Woo00<007ooOol01Woo00D007ooOomoo`0000Moo`03001oogoo00Eoo`03001o
o`0000=oo`800003Ool00000009oo`03001oogoo05Aoo`00_7oo0P00bGoo1`006Woo0P004Woo00<0
07oo000027oo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol037oo00D007ooOomoo`0000Yoo`03001oogoo019oo`<000Eoo`8000Mo
o`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00=oo`@00004Ool00000Ool200000goo0000
0002Ool00`00Oomoo`1DOol00;aoo`800<eoo`03001oogoo00P001=oo`03001oogoo011oo`8000Uo
o`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Ao
o`03001oogoo00eoo`<000]oo`80011oo`<000Qoo`03001oo`0000Ioo`03001oogoo00=oo`04001o
ogooOol50003Ool2000017oo001oo`000Woo1P000Woo0P00EGoo002lOol2003>Ool00`00Oomoo`07
Ool8000;Ool2000@Ool00`00Ool00008Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Ool0000<Ool3000;Ool00`00
Ool00005Ool00`00Oomoo`05Ool00`00Ool00002Ool01000Oomoo`000Woo0P0000Aoo`00Ool0009o
o`80009oo`<00003Ool0000005Eoo`00_7oo0`00cGoo00<007ooOol03goo1`001Goo0P003goo00<0
07oo00001goo00<007ooOol047oo00<007ooOol00goo00<007ooOol02goo00<007ooOol03Goo00<0
07ooOol01Goo00<007ooOol06Woo00<007oo000027oo10003Goo00D007ooOomoo`0000Aoo`03001o
ogoo00Eoo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo10000Woo0P0000Aoo`00
000005Eoo`00_Goo0P00cWoo00<007ooOol05Goo20003Goo00<007oo00001goo00<007ooOol04Woo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol06Woo
00@007ooOol000Aoo`<0015oo`05001oogooOol00003Ool00`00Oomoo`07Ool20002Ool01000Oomo
ogoo0P0000Aoo`00000000=oo`<00004Ool000000003Ool00`00Oomoo`1COol00;eoo`03001oo`00
0<eoo`03001oogoo01Yoo`03001oogoo00P000Eoo`03001oo`0000Ioo`03001oogoo01=oo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo01Uoo`04001o
ogooOol4000DOol01@00Oomoogoo00000goo00<007ooOol01goo00<007oo00000P001Goo0P0000Eo
o`00Oomoo`00009oo`D000Aoo`03001oogoo059oo`00_Goo00<007oo0000cWoo00<007ooOol06Goo
00D007ooOomoo`0000Ioo`L000Ioo`03001oogoo01Eoo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo00ioo`03001oogoo00Ioo`03001oogoo01Uoo`03001oo`0000@001Aoo`03001oogoo00=o
o`03001oo`0000]oo`04001oogoo0007Ool40003Ool01P00Oomoo`00Ool000=oo`03001oogoo059o
o`00_Goo00@007ooOol00<ioo`03001oogoo01Uoo`05001oogooOol00008Ool00`00Oomoo`09000F
Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0G
Ool40005Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Ool0000;Ool01000Ool000003Woo00H0
07ooOol007oo0003Ool00`00Oomoo`1BOol00;eoo`800003Ool007oo0<eoo`03001oogoo01Uoo`03
001oogoo009oo`03001oogoo00Aoo`04001oogoo0006Ool00`00Oomoo`08000>Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`0COol300000goo001o
o`07Ool2000@Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo055oo`00_Goo0P0000=oo`00Ool0cWoo00<007ooOol067oo00<007ooOol0
0goo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Uoo`L000Qoo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00moo`03001oogoo00Moo`03001oogoo011oo`<000Aoo`03001oogoo
00Qoo`8000ioo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00eoo`07001oogooOol007oo
000017oo00<007ooOol0DGoo002mOol20002Ool00`00Oomoo`3<Ool00`00Oomoo`0IOol00`00Oomo
o`03Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol04Goo2@001Woo00<007ooOol01Goo
00<007ooOol047oo00<007ooOol01Woo00<007ooOol03Goo0`001goo00<007ooOol02Woo00<007oo
Ool02goo00<007ooOol017oo00<007oo00003Goo00<007ooOol037oo00L007ooOomoo`00Ool00004
Ool00`00Oomoo`1AOol00;eoo`80009oo`03001oogoo0<eoo`03001oogoo01Qoo`03001oogoo00Ao
o`8000=oo`03001oogoo00=oo`03001oogoo01Yoo`P000Moo`03001oogoo011oo`8000Qoo`03001o
ogoo00Uoo`<000Yoo`03001oogoo00]oo`8000Yoo`03001oogoo00Eoo`03001oo`0000eoo`03001o
ogoo00aoo`07001oogooOol007oo00001Goo00<007ooOol0D7oo002mOol20003Ool00`00Oomoo`3<
Ool00`00Oomoo`0IOol00`00Oomoo`04Ool01@00Oomoogoo000017oo00<007ooOol077oo00<007oo
Ool017oo20004Woo00<007oo00001goo00<007ooOol01Goo10003Goo00<007ooOol03Goo00<007oo
Ool01goo00<007ooOol00goo0P000goo00<007ooOol02goo00<007ooOol02goo00L007ooOomoo`00
Ool00005Ool00`00Oomoo`1@Ool00;eoo`8000=oo`03001oogoo0<eoo`03001oogoo01Qoo`03001o
ogoo00=oo`80009oo`04001oogooOol2000POol00`00Oomoo`04Ool400000goo00000007000;Ool0
0`00Oomoo`020006Ool01000Oomoogoo0`0047oo00<007ooOol03goo0P001Woo00@007ooOomoo`<0
00Eoo`03001oogoo00]oo`03001oogoo00]oo`07001oogooOol007oo00001Goo00<007ooOol0D7oo
002mOol20004Ool00`00Oomoo`3<Ool00`00Oomoo`0IOol01@00Oomoogoo00000Woo00<007oo0000
0Woo00<007ooOol087oo00<007ooOol027oo0P0027oo20000goo00<007ooOol00Woo10000Woo1000
4goo00<007ooOol04Goo0P0017oo10002Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol0
0Woo00<007oo00001Woo00<007ooOol0Cgoo002nOol00`00Oomoo`02Ool00`00Oomoo`3=Ool00`00
Oomoo`0HOol01000Oomoo`000Woo0`000Woo00<007ooOol08Woo00<007ooOol06Goo1`000Woo0P00
00=oo`0000000P005Goo00<007ooOol04goo00<007oo00000P0037oo00<007ooOol02goo00<007oo
Ool02Goo00<007ooOol00Woo00<007oo00001Woo00<007ooOol0Cgoo002nOol20004Ool00`00Oomo
o`3=Ool00`00Oomoo`0GOol00`00Ool000030003Ool2000UOol00`00Oomoo`0LOol01000Oomoogoo
1@000goo00<007ooOol04goo00<007ooOol057oo00<007oo00003Woo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol00Woo00<007oo00001Woo00<007ooOol0Cgoo002nOol20004Ool00`00Oomo
o`3=Ool00`00Oomoo`0HOol20005Ool3000VOol00`00Oomoo`0KOol01@00Oomoogoo00000Woo00<0
07ooOol00goo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol027oo00<007ooOol00Woo00<007oo00001goo00<007ooOol0CWoo002oOol20004Ool00`00
Oomoo`3=Ool00`00Oomoo`0GOol00`00Oomoo`03Ool01@00Oomoogoo00009Goo00<007ooOol06goo
00<007ooOol00Woo0`001Goo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol027oo0P000goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol00Woo00<007oo00001goo
00<007ooOol0CWoo002oOol20004Ool00`00Oomoo`3=Ool00`00Oomoo`0FOol00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`0SOol00`00Oomoo`0JOol00`00Oomoo`03Ool20006Ool00`00Oomo
o`0AOol00`00Oomoo`0EOol00`00Oomoo`0:Ool01@00Oomoogoo00000goo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol00Woo00<007oo00001goo00<007ooOol0CWoo002oOol20005Ool00`00
Oomoo`3=Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0ROol00`00
Oomoo`0JOol00`00Oomoo`02Ool00`00Ool00006Ool00`00Oomoo`0@Ool00`00Oomoo`0FOol00`00
Oomoo`0;Ool200001Goo001oogoo00002goo00<007ooOol01Goo00<007ooOol00goo00<007oo0000
1goo00<007ooOol0CWoo0030Ool20004Ool00`00Oomoo`3=Ool00`00Oomoo`0COol00`00Oomoo`02
Ool20009Ool00`00Oomoo`0ROol00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`0?Ool00`00Oomoo`0EOol00`00Oomoo`0>Ool300000goo001oo`0;Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Ool00008Ool00`00Oomoo`1=Ool00<1oo`8000Aoo`03001oogoo0<ioo`03
001oogoo015oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo025oo`03001oogoo01Yoo`03
001oogoo00=oo`8000Ioo`03001oogoo00moo`03001oogoo01Eoo`03001oogoo011oo`03001oo`00
00aoo`03001oogoo00Aoo`03001oogoo00=oo`8000Uoo`03001oogoo04eoo`00`Goo0P0017oo00<0
07ooOol0cWoo00<007ooOol03goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol08Goo00<0
07ooOol06Goo00<007ooOol00goo0P001goo00<007ooOol03Woo00<007ooOol057oo00<007ooOol0
4Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol00goo0P002Goo00<007ooOol0CGoo0031
Ool20004Ool00`00Oomoo`3>Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00
Oomoo`0POol00`00Oomoo`0IOol00`00Oomoo`03Ool20007Ool00`00Oomoo`0>Ool00`00Oomoo`0C
Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20009Ool00`00
Oomoo`1=Ool00<5oo`03001oo`0000Aoo`03001oogoo0<ioo`03001oogoo00eoo`03001oogoo0080
019oo`03001oogoo021oo`03001oogoo01Qoo`03001oogoo00=oo`8000Qoo`03001oogoo00aoo`03
001oogoo01=oo`03001oogoo01Eoo`03001oogoo00aoo`05001oogooOol00006Ool2000:Ool00`00
Oomoo`1<Ool00<9oo`8000Aoo`03001oogoo0<ioo`03001oogoo00aoo`04001oogoo000DOol00`00
Oomoo`0POol00`00Oomoo`0HOol00`00Oomoo`03Ool20008Ool00`00Oomoo`0<Ool00`00Oomoo`0B
Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool01@00Oomoogoo00001Goo00<007oo00002Woo00<007oo
Ool0C7oo0032Ool20005Ool00`00Oomoo`3>Ool00`00Oomoo`0:Ool01000Oomoo`005Woo00<007oo
Ool087oo00<007ooOol05goo00<007ooOol00goo0P002Goo00<007ooOol02goo00<007ooOol04Goo
00<007ooOol067oo00<007ooOol037oo0`001Woo00<007oo00002Woo00<007ooOol0C7oo0033Ool2
0004Ool00`00Oomoo`3>Ool00`00Oomoo`09Ool01000Oomoo`0067oo00<007ooOol087oo00<007oo
Ool05Woo00<007ooOol00goo0P002Goo00<007ooOol02goo00<007ooOol04Goo00<007ooOol06Goo
00<007ooOol02goo00@007oo000000Eoo`03001oo`0000Yoo`03001oogoo04aoo`00`goo0P001Goo
00<007ooOol0cWoo00<007ooOol01goo00@007oo000001Yoo`03001oogoo021oo`03001oogoo01Eo
o`03001oogoo00=oo`8000Yoo`03001oogoo00Yoo`03001oogoo011oo`03001oogoo01Yoo`03001o
ogoo00Yoo`05001oo`00001oo`020002Ool01000Oomoo`002goo00<007ooOol0Bgoo0033Ool00`00
Ool00005Ool00`00Oomoo`3=Ool00`00Oomoo`05Ool200000goo001oo`0LOol00`00Oomoo`0OOol0
0`00Oomoo`0EOol00`00Oomoo`03Ool2000:Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomo
o`0LOol00`00Oomoo`09Ool01000Ool000000goo0`000Woo00<007ooOol02Goo00<007ooOol0Bgoo
0034Ool20006Ool00`00Oomoo`3=Ool00`00Oomoo`03Ool01000Oomoo`007goo00<007ooOol07goo
00<007ooOol057oo00<007ooOol00goo0P002goo00<007ooOol027oo00<007ooOol03goo00<007oo
Ool07Woo00<007ooOol027oo00@007oo000000Eoo`04001oogoo000;Ool00`00Oomoo`1;Ool00<Ao
o`03001oo`0000Ioo`03001oogoo0<eoo`05001oogooOol00002Ool00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0COol00`00Oomoo`02Ool4000:Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool0
0`00Oomoo`0OOol00`00Oomoo`07Ool01P00Oomoo`00Ool000=oo`05001oogooOol0000;Ool00`00
Oomoo`1;Ool00<Aoo`03001oo`0000Moo`03001oogoo0<aoo`04001oo`000002Ool00`00Oomoo`0Q
Ool00`00Oomoo`0NOol00`00Oomoo`0DOol01000Oomoogoo10002goo00<007ooOol01goo00<007oo
Ool03Woo00<007ooOol06Goo0`0017oo00<007ooOol027oo00@007ooOol000=oo`04001oogoo000=
Ool00`00Oomoo`1:Ool00<Eoo`03001oo`0000Moo`03001oogoo0<aoo`03001oogoo008002Eoo`03
001oogoo01ioo`03001oogoo01=oo`04001oogooOol4000;Ool00`00Oomoo`07Ool00`00Oomoo`0=
Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00@007oo
Ool000eoo`03001oogoo04Yoo`00aGoo00<007oo000027oo00<007ooOol0bWoo0P0000=oo`00Ool0
9goo00<007ooOol07Woo00<007ooOol04Woo00@007ooOomoo`@000aoo`03001oogoo00Eoo`03001o
ogoo00eoo`03001oogoo01Yoo`D000Aoo`03001oogoo00Moo`03001oogoo009oo`03001oo`00009o
o`03001oogoo00]oo`03001oogoo04Yoo`00aWoo0P002Goo00<007ooOol0agoo0P000Woo00<007oo
Ool0:7oo00<007ooOol07Woo0P004Woo00@007ooOomoo`@000aoo`03001oogoo00Eoo`03001oogoo
00aoo`03001oogoo01]oo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20002
Ool00`00Oomoo`0<Ool00`00Oomoo`1:Ool00<Ioo`03001oo`0000Uoo`03001oogoo0<Eoo`04001o
ogooOol2000[Ool00`00Oomoo`0MOol5000?Ool01@00Oomoo`00Ool00`003Goo00<007ooOol017oo
00<007ooOol02goo00<007ooOol07Goo0`001Woo00<007ooOol01Goo00<007ooOol017oo00@007oo
Ool000moo`03001oogoo04Uoo`00aWoo00<007oo00002Woo00<007ooOol0`goo00<007ooOol00P00
0Woo00<007ooOol0:Goo0P007Goo00<007oo00000Woo0P003Goo00D007ooOol007oo00<000eoo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo02Qoo`03001oogoo00Aoo`03001oogoo00Aoo`04
001oogoo000?Ool00`00Oomoo`19Ool00<Moo`03001oo`0000Uoo`03001oogoo0<5oo`80009oo`03
001oogoo009oo`03001oogoo02]oo`03001oogoo01Uoo`05001oogooOol00003Ool00`00Oomoo`0:
Ool01@00Oomoo`00Ool00P0000=oo`00Ool037oo00<007ooOol00goo00<007ooOol02Woo00<007oo
Ool0:Goo0P000goo00<007ooOol017oo00@007oo0000011oo`03001oogoo04Uoo`00agoo00<007oo
00002Woo00<007ooOol0_goo00D007ooOomoo`0000Ioo`03001oogoo02]oo`03001oogoo01Moo`@0
009oo`03001oogoo00eoo`03001oo`00009oo`800003Ool007oo00aoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo02aoo`04001oogoo0006Ool01000Oomoo`0047oo00<007ooOol0BGoo0038
Ool00`00Ool0000:Ool00`00Oomoo`2mOol01@00Oomoogoo000027oo00<007ooOol0:goo0P005Woo
00@007oo000000Aoo`03001oogoo00aoo`8000=oo`800003Ool007oo00eoo`05001oogooOol0000;
Ool00`00Oomoo`0^Ool00`00Ool00004Ool30002Ool00`00Oomoo`0?Ool00`00Oomoo`18Ool00<Qo
o`03001oo`0000]oo`03001oogoo0;]oo`03001oogoo008000Uoo`03001oogoo02eoo`03001oogoo
01=oo`04001oogoo0005Ool00`00Oomoo`0;Ool20003Ool200000goo001oo`0=Ool5000:Ool00`00
Oomoo`0`Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000@Ool00`00Oomoo`18Ool00<Qo
o`03001oo`0000aoo`03001oogoo0;Qoo`80009oo`03001oogoo00Yoo`03001oogoo02eoo`03001o
ogoo019oo`04001oogoo0006Ool2000;Ool20003Ool200000goo001oo`0;Ool500000goo001oo`08
Ool00`00Oomoo`0aOol20003Ool600000goo001oo`0?Ool00`00Oomoo`18Ool00<Uoo`03001oo`00
00aoo`03001oogoo0;Ioo`05001oogooOol0000=Ool00`00Oomoo`0^Ool2000COol30008Ool30006
Ool200000goo001oo`02Ool01@00Ool007oo00003Woo00<007oo00000P0027oo00<007ooOol0<Goo
00<007oo00000Woo00<007oo00000P000goo00<007ooOol03Goo00<007ooOol0B7oo0039Ool00`00
Ool0000=Ool00`00Oomoo`2dOol01@00Oomoogoo00003goo00<007ooOol0;goo00<007ooOol04Woo
00<007ooOol02Goo0P0000Aoo`00000000=oo`09001oogooOol007oo001oo`0000eoo`05001oo`00
001oo`020006Ool00`00Oomoo`0aOol01P00Oomoogoo001oo`@000Eoo`03001oogoo00aoo`03001o
ogoo04Qoo`00bGoo00@007ooOol000eoo`03001oogoo0;5oo`80009oo`80015oo`03001oogoo02mo
o`03001oogoo011oo`8000eoo`03001oogoo00Aoo`09001oogooOol007oo001oo`0000eoo`04001o
ogoo0002Ool30003Ool00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Ool00007Ool00`00Oomoo`0<
Ool00`00Oomoo`18Ool00<Yoo`03001oo`0000ioo`03001oogoo0:moo`05001oogooOol0000DOol0
0`00Oomoo`0_Ool2000VOol02@00Oomoogoo001oo`00Ool0000=Ool01@00Ool007oo00000Woo00D0
07oo001oo`0003Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo04Qo
o`00bWoo00@007ooOol000ioo`03001oogoo0:eoo`05001oogooOol0000EOol00`00Oomoo`0aOol0
0`00Oomoo`0SOol02@00Oomoogoo001oo`00Ool0000<Ool01000Oomoo`000Woo00H007ooOol007oo
000eOol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`18Ool00<]oo`03
001oo`0000moo`800:]oo`8000=oo`03001oogoo01Eoo`03001oogoo035oo`03001oogoo029oo`07
001oogooOol007oo00000Woo00<007ooOol02goo1P000Woo00<007ooOol0=7oo00<007ooOol017oo
00<007ooOol027oo00<007ooOol02Woo00<007ooOol0B7oo003<Ool2000AOol2002XOol01000Oomo
ogoo0P006Goo00<007ooOol0<Goo0P008Woo00L007ooOomoo`00Ool00002Ool00`00Oomoo`0;Ool0
1P00Oomoo`00Ool0009oo`03001oogoo03Aoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo04Moo`00cGoo0P004Woo00<007ooOol0Y7oo00<007ooOol00P0077oo00<007oo
Ool0<Woo00<007ooOol07goo00L007ooOomoo`00Ool00002Ool00`00Oomoo`0;Ool40002Ool2000f
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`17Ool00<ioo`03001o
ogoo015oo`800:9oo`800003Ool0000001ioo`03001oogoo03=oo`03001oogoo01moo`06001oogoo
001oo`000Woo00<007ooOol02Woo0P000Woo00<007ooOol00P00=Goo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol027oo00<007ooOol0Agoo003?Ool00`00Oomoo`0BOol2002MOol300000goo
0000000QOol00`00Oomoo`0cOol00`00Oomoo`0NOol00`00Ool00002Ool01@00Oomoogoo00002goo
00@007oo0000009oo`04001oogoo000cOol00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool00`00Oomoo`17Ool00<moo`8001Eoo`8009Uoo`8000=oo`03001oogoo029oo`03001oogoo03=o
o`8001ioo`03001oo`00009oo`05001oogooOol0000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0`Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`17Ool0
0=1oo`8001Ioo`03001oogoo09Aoo`8000=oo`8002Ioo`03001oogoo03Aoo`03001oogoo01]oo`03
001oo`00009oo`05001oogooOol0000:Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0_
Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`17Ool00=5oo`8001Io
o`80095oo`<000=oo`8002Qoo`03001oogoo03Eoo`03001oogoo01Yoo`03001oo`00009oo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo02eoo`03001o
ogoo00Ioo`03001oogoo019oo`03001oogoo00=oo`8004Uoo`00dWoo0P005goo0P00SGoo0P0017oo
0P00:goo00<007ooOol0=Goo0P006Woo00<007oo00000Woo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0;7oo00<007ooOol01Goo00<007ooOol057oo
00D007ooOomoo`0004]oo`00dgoo0P0067oo0P00RGoo0P0017oo0P00;Woo00<007ooOol0=Woo00<0
07ooOol05goo0P000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol0:Woo00<007ooOol01Goo00<007ooOol05Woo00<007oo0000C7oo003DOol2000I
Ool00`00Oomoo`23Ool30004Ool2000aOol00`00Oomoo`0fOol00`00Oomoo`0FOol20003Ool00`00
Oomoo`03Ool20004Ool400000goo001oo`0;Ool00`00Oomoo`0XOol00`00Oomoo`06Ool00`00Oomo
o`0GOol00`00Oomoo`1;Ool00=Eoo`8001Uoo`80085oo`8000Eoo`8003=oo`03001oogoo03Moo`80
015oo`03001oogoo009oo`8000=oo`03001oogoo00Eoo`<00004Ool00000Ool2000>Ool00`00Oomo
o`0VOol00`00Oomoo`06Ool00`00Oomoo`1VOol00=Ioo`8001Yoo`8007eoo`8000Eoo`8003Ioo`03
001oogoo03Qoo`03001oogoo00moo`04001oogooOol20003Ool00`00Oomoo`08Ool01P00Ool00000
Ool000ioo`03001oogoo02Ioo`03001oogoo00Eoo`03001oogoo06Moo`00egoo0P006goo0P00N7oo
0`001Goo0P00>Goo00<007ooOol0>7oo00<007ooOol03goo00<007ooOol00P000goo00<007ooOol0
2Woo00@007ooOol000moo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo06Qoo`00f7oo0P00
77oo00<007ooOol0Lgoo0P001goo00<007ooOol0>Woo00<007ooOol0>7oo0P0047oo00@007oo0000
00=oo`8000Uoo`D0015oo`03001oogoo029oo`03001oogoo00Eoo`03001oogoo06Uoo`00fGoo0P00
77oo0P00LGoo0P001goo0P00?Goo00<007ooOol0>Woo00<007ooOol03Woo0`0000Aoo`00000000Uo
o`04001oogoo000DOol00`00Oomoo`0QOol00`00Oomoo`05Ool00`00Oomoo`1YOol00=Uoo`03001o
o`0001eoo`<006]oo`<000Moo`80041oo`03001oogoo03Yoo`03001oogoo00ioo`<0009oo`03001o
ogoo00Ioo`03001oogoo008001Eoo`80021oo`03001oogoo00Eoo`03001oogoo06Yoo`00fWoo00<0
07oo00007goo1000IGoo0P0027oo0P00@goo00<007ooOol0>Woo200027oo0P000goo00<007ooOol0
17oo0P0077oo0`0077oo00<007ooOol01Goo00<007ooOol0Jgoo003KOol00`00Ool0000ROol3001O
Ool30008Ool20016Ool00`00Oomoo`0iOol00`00Ool00002000:Ool00`00Ool00004Ool00`00Oomo
o`02Ool00`00Oomoo`0OOol2000HOol20007Ool00`00Oomoo`1/Ool00=aoo`03001oo`0002Aoo`@0
05Ioo`D000Uoo`8004Qoo`03001oogoo03Yoo`04001oogooOol20008Ool00`00Ool00004Ool01@00
Oomoogoo000097oo0`004Woo0`0027oo00<007ooOol0KGoo003MOol00`00Ool0000WOol4001=Ool5
000<Ool2001;Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`03Ool20006Ool00`00Ool0
0004Ool01000Ool00000:7oo0P003Goo0`002goo00<007ooOol0KGoo003NOol00`00Ool0000ZOol3
000bOol00`00Oomoo`0AOol40004Ool00`00Oomoo`08Ool2001>Ool01@00Oomoogoo0000=goo00<0
07ooOol017oo0`000goo00<007oo000017oo0P00;7oo0P0027oo0`003Goo00<007ooOol0KWoo003O
Ool00`00Ool0000/Ool4000^Ool00`00Oomoo`0<Ool50008Ool00`00Oomoo`06Ool2001AOol01000
Oomoo`00=goo00<007ooOol01goo0`000goo00D007ooOomoo`0002moo`<0009oo`<000moo`03001o
ogoo06moo`00h7oo00@007oo000002ioo`@002Yoo`03001oogoo00Qoo`@000eoo`03001oogoo00Eo
o`03001oogoo04aoo`8000=oo`04001oogoo000hOol00`00Oomoo`08Ool20002Ool00`00Ool00002
000bOol2000AOol00`00Oomoo`1`Ool00>5oo`03001oogoo0080031oo`<002Ioo`03001oogoo00Ao
o`D0015oo`03001oogoo00=oo`80055oo`<00004Ool007oo0013Ool00`00Ool000030002Ool00`00
Oomoo`11Ool2001cOol00>9oo`04001oogooOol3000`OolE000AOol00`00Ool00004000GOol00`00
Oomoo`02001FOol40013Ool01000Oomoogoo0`0000=oo`00Ool0@7oo0P00MGoo003SOol00`00Oomo
o`03Ool20013OolC000LOol3001KOol20012Ool00`00Ool000020002Ool2000nOol3001gOol00>=o
o`03001oogoo00Eoo`8005Aoo`<001Moo`@005ioo`03001oogoo03ioo`03001oo`00009oo`04001o
ogooOol4000iOol2001jOol00>Aoo`03001oogoo00Ioo`8005Eoo`<0011oo`@000Aoo`<005aoo`03
001oogoo03eoo`8000=oo`05001oogooOol00003Ool2000eOol2001lOol00>Eoo`03001oogoo00Mo
o`<005Eoo`03001oogoo00Uoo`@000]oo`<005Yoo`03001oogoo03]oo`8000Aoo`05001oogooOol0
0005Ool2000`Ool3001nOol00>Ioo`03001oogoo00Uoo`8005]oo`@0019oo`03001oogoo05Qoo`03
001oogoo03Uoo`8000Ioo`04001oogoo0007Ool3000[Ool20021Ool00>Moo`03001oogoo00Yoo`80
05Eoo`@0079oo`03001oogoo03Ioo`800003Ool007oo00Eoo`04001oogoo000:Ool2000WOol20023
Ool00>Qoo`03001oogoo00]oo`<004ioo`@007Moo`8002aoo`<000Ioo`04001oogoo0007Ool01000
Oomoo`0037oo1P007goo0P00QGoo003YOol00`00Oomoo`0=Ool20019Ool3001mOol00`00Oomoo`0X
Ool01@00Oomoogoo000017oo00@007ooOol000Eoo`@0009oo`03001oogoo011oo`/0015oo`<008Mo
o`00jWoo00<007ooOol03Woo0P00@goo1000PGoo00<007ooOol09goo00<007ooOol017oo0P000goo
00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01]oo`X000Eoo`8008Yoo`00jgoo00<0
07ooOol03goo0P00?Goo1000QWoo00<007ooOol09Woo00L007ooOomoo`00Ool00004Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00<007ooOol09Goo1@00S7oo003/Ool00`00Oomoo`0@Ool3000f
Ool400000goo000000020026Ool00`00Oomoo`0VOol300000goo001oo`04Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000Woo00<007ooOol0]Woo003]Ool2000COol2000`Ool40004Ool01000Oomoo`00
R7oo00<007ooOol09goo0P001Goo00<007ooOol01Goo10000Woo00<007ooOol0]Woo003_Ool2000C
OolF000FOol40009Ool30029Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`09Ool01000
Oomoo`00^7oo003aOol00`00Oomoo`0VOolF000<Ool01000Oomoo`00RWoo0P0097oo00<007ooOol0
1Goo00<007ooOol02Woo00<007oo0000^7oo003bOol20019Ool2001jOol4000?Ool00`00Oomoo`0O
Ool20007Ool00`00Oomoo`0;Ool01000Oomoo`00]goo003dOol20032Ool01000Oomoo`004Goo00<0
07ooOol07Goo00<007ooOol01goo00<007ooOol02goo00@007ooOol00;Moo`00mWoo0P00`Goo0`00
4Woo00<007ooOol06goo00<007ooOol01goo00<007ooOol037oo00@007ooOol00;Moo`00n7oo00<0
07ooOol0_Goo00@007ooOol001=oo`03001oogoo01Qoo`8000Uoo`03001oogoo00eoo`04001oogoo
002gOol00?Uoo`80061oo`@005Yoo`8001Eoo`03001oogoo01Eoo`8000]oo`03001oogoo00eoo`04
001oogoo002gOol00?]oo`8005eoo`04001oogoo001cOol3000AOol3000;Ool2000AOol00`00Ool0
002gOol00?eoo`8005]oo`04001oogoo001fOol3000<Ool2000;Ool3000COol00`00Ool0002gOol0
0?moo`03001oogoo05Qoo`04001oogoo001iOol30007Ool2000:Ool3000FOol00`00Ool0002gOol0
0?moo`5oo`8005Uoo`<007aoo`<0009oo`8000Yoo`8001Uoo`03001oo`000;Moo`00ogoo0goo0P00
FGoo00<007ooOol0OGoo0`0027oo0`006goo00<007oo0000]goo003oOol5Ool2001FOol2001lOol3
0003Ool30002Ool3000OOol00`00Oomoo`2fOol00?moo`Moo`03001oogoo0<moo`8000Uoo`80029o
o`03001oogoo0;Ioo`00ogoo27oo0P00cGoo0P00;goo00<007ooOol0]Woo003oOol:Ool20039Ool2
003ZOol00?moo`aoo`800<Aoo`<00>aoo`00ogoo3Woo00<007ooOol0_goo0P00kgoo003oOol?Ool2
002mOol2003aOol00?mooa5oo`800;Uoo`800?=oo`00ogoo4goo0P00]Goo0P00mGoo003oOolEOol0
0`00Oomoo`2_Ool3003gOol00?mooaIoo`800:eoo`800?Yoo`00ogoo67oo0`00Z7oo0P00o7oo003o
OolKOol3002SOol2003nOol00?mooaioo`@009eoo`800?moo`5oo`00ogoo8Woo1000UWoo0`00ogoo
0goo003oOolVOol3002AOol2003oOol6Ool00?moobUoo`@008Yoo`<00?moo`Qoo`00ogoo;Goo0`00
PWoo1@00ogoo2goo003oOol`Ool4001iOol5003oOol@Ool00?moocAoo`<0075oo`D00?mooaEoo`00
ogoo=goo1000J7oo1@00ogoo6Woo003oOolkOol4001OOol5003oOolOOol00?moocmoo`<0045oo`03
001oogoo01=oo`D00?moobAoo`00ogoo@Woo1000?Goo00<007ooOol03Woo1@00ogoo:Goo003oOom6
Ool3000jOol00`00Oomoo`09Ool5003oOol^Ool00?moodUooa0002Uoo`03001oogoo00Eoo`D00?mo
oc=oo`00ogooFGoo70003Goo00<007ooOol01@00ogoo>7oo003oOomeOol@003oOolmOol00?moohAo
o`800?moocaoo`00ogooQWoo00<007ooOol0ogoo>Goo003oOon7Ool2003oOoliOol00?moohUoo`03
001oogoo0?moocIoo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003o
OoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo
`Woo003oOoooOoo2Ool00?mooh1oo`<00?moocmoo`00ogooOgoo00D007ooOomoo`000?moocioo`00
ogooOgoo00<007ooOol0ogoo@7oo003oOomoOol01@00Oomoogoo0000ogoo?Woo003oOon0Ool3003o
OoloOol00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo
003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogoo
ogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9o
o`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mo
oomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2
Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003o
OoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo
`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00
ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomo
ol9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool0
0?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOooo
Ooo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo
003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogoo
ogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9o
o`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mo
oomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2
Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003o
OoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo
`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00
ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomo
ol9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool0
0?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOooo
Ooo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo
003oOoooOoo2Ool00?mooomool9oo`00ogooogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00ogoo
ogoo`Woo003oOoooOoo2Ool00?mooomool9oo`00\
\>"],
  ImageRangeCache->{{{0, 703.688}, {621.375, 0}} -> {-0.000129728, 0.0339267, \
0.00134618, 0.00134618}}]
}, Open  ]],

Cell["We are interested in the paths thru this graph.", "Text"]
}, Open  ]],

Cell["Loops", "Section"],

Cell[CellGroupData[{

Cell["Word Paths and basic loops", "Subsubsection"],

Cell["\<\
We want to describe all the possible loops from 1.
Any loop from the potential fixed point, 1 here, along the spanning tree to a \
node, 
 then jumping to another node and returning to 1 will be called a basic loop.\
\
\>", "Emphasis",
  CellTags->"emphasis"],

Cell[TextData[{
  " e.g. below we go along edge ",
  Cell[BoxData[
      FormBox["d", TraditionalForm]]],
  " to 10, then jump ",
  Cell[BoxData[
      FormBox["d", TraditionalForm]]],
  " to 9,\n  then return to 1 using the inverse of the path ",
  Cell[BoxData[
      FormBox["c", TraditionalForm]]],
  " from 1 to 9."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93746 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.14996e-017 1.05825 -0.0109014 1.05825 [
[ 0 0 0 0 ]
[ 1 .93746 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05179 .2399 m
0 .59246 L
s
0 .59246 m
.42939 .93746 L
s
.42939 .93746 m
.43745 .61846 L
s
.43745 .61846 m
.05179 .2399 L
s
.6524 0 m
.95854 .45797 L
s
.95854 .45797 m
1 .79278 L
s
1 .79278 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.05179 .2399 m
0 .59246 L
s
0 .59246 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.6524 0 m
.05179 .2399 L
s
.43745 .61846 m
.95854 .45797 L
s
.95854 .45797 m
1 .79278 L
s
1 .79278 m
.42939 .93746 L
s
.42939 .93746 m
.43745 .61846 L
s
0 0 m
1 0 L
1 .93746 L
0 .93746 L
closepath
clip
newpath
.5 Mabswid
.72285 .50645 m
.72632 .50015 L
s
.75633 .50106 m
.88284 .46171 L
s
.72632 .50015 m
.71578 .49194 L
s
.29684 .44339 m
.72632 .50015 L
s
0 1 0 r
.02 w
.32137 .44663 m
.70311 .49708 L
s
1 0 0 r
.5 Mabswid
.74159 .4933 m
.67564 .41021 L
s
0 g
.88252 .4708 m
.88284 .46171 L
s
.88284 .46171 m
.87199 .45602 L
s
.02 w
.75596 .60689 m
.67128 .50558 L
s
.26439 .54543 m
.75596 .60689 L
s
.5 Mabswid
.29159 .43814 m
.64686 .40139 L
s
1 0 0 r
.62678 .40347 m
.31099 .43613 L
s
0 g
.28278 .42932 m
.49447 .21201 L
s
.64592 .41007 m
.64686 .40139 L
s
.64686 .40139 m
.63497 .39397 L
s
.67617 .39857 m
.84268 .38505 L
s
.67328 .39491 m
.79155 .31215 L
s
.84069 .39374 m
.84268 .38505 L
s
.84268 .38505 m
.83145 .37736 L
s
.02 w
.26439 .54543 m
.67128 .50558 L
s
.5 Mabswid
.7936 .32362 m
.79155 .31215 L
s
.79155 .31215 m
.77976 .30739 L
s
.49903 .22485 m
.49447 .21201 L
s
.75925 .22043 m
.76232 .21117 L
s
.49447 .21201 m
.48166 .20749 L
s
.76232 .21117 m
.75004 .20106 L
s
.52108 .1992 m
.76232 .21117 L
s
.5176 .19477 m
.70348 .12497 L
s
.5141 .19033 m
.63983 .03174 L
s
.70408 .13746 m
.70348 .12497 L
s
.70348 .12497 m
.69013 .11714 L
s
.6445 .04701 m
.63983 .03174 L
s
.63983 .03174 m
.62651 .0272 L
s
[(6)] .64735 .02226 0 0 Mshowa
[(3)] .71415 .12096 0 0 Mshowa
[(4)] .77565 .21183 0 0 Mshowa
[(2)] .5076 .19853 0 0 Mshowa
[(5)] .7984 .30736 0 0 Mshowa
[(8)] .852 .38429 0 0 Mshowa
[(9)] .66699 .39931 0 0 Mshowa
[(7)] .89002 .45947 0 0 Mshowa
[(10)] .74946 .5032 0 0 Mshowa
[(1)] .27223 .44014 0 0 Mshowa
gsave
.56581 .10446 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60181 .1505 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6369 .19543 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7242 .34652 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75422 .38365 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81349 .4743 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37444 .31844 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.46145 .41199 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51033 .46469 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.6524 0 m
.95854 .45797 L
s
.95854 .45797 m
1 .79278 L
s
1 .79278 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.05179 .2399 m
0 .59246 L
s
0 .59246 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.6524 0 m
.05179 .2399 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 269.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00013A000`40O003h00O^Woo0P00I7oo002h
Ool200000goo0000001SOol00;Eoo`<000=oo`8006=oo`00/goo0P001Woo00<007oo0000HWoo002`
Ool30004Ool300001Goo001oogoo0000HGoo002^Ool20007Ool00`00Oomoo`020002Ool00`00Oomo
o`1OOol00:]oo`<000Uoo`03001oogoo008000=oo`03001oogoo05ioo`00Z7oo0`0027oo00@007oo
Oomoo`<00003Ool007oo00=oo`03001oogoo05eoo`00YWoo0P0037oo0P000Woo00@007ooOol000Ao
o`03001oogoo05eoo`00Xgoo0`0047oo1P001Goo00<007ooOol0G7oo002QOol2000COol20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1KOol009ioo`<001Aoo`03001oo`0000=oo`03001oogoo00Aoo`03
001oogoo05]oo`00W7oo0P005goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo05Yoo`00
VGoo0`0067oo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo05Uoo`00Ugoo0P006Woo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0FGoo002DOol3000KOol00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`1HOol0099oo`8001eoo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo05Moo`00Sgoo0`007goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0Egoo002<
Ool3000QOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`1FOol008Yoo`8002=oo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo05Eoo`00Qgoo0`0097oo00<007ooOol02goo00<007oo
Ool02Goo00<007ooOol0EGoo0025Ool2000VOol00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`1DOol0089oo`<002Qoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo05=oo`00P7oo0P00
:Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol0Dgoo001mOol3000[Ool00`00Oomoo`0>
Ool00`00Oomoo`0<Ool00`00Oomoo`1BOol007]oo`8002eoo`03001oogoo00moo`03001oogoo00eo
o`03001oogoo055oo`00N7oo0`00;Woo00<007ooOol047oo00<007ooOol03Goo00<007ooOol0DGoo
001fOol2000aOol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`1@Ool007=oo`<002Uoo`@0
00Eoo`03001oogoo015oo`03001oogoo00moo`03001oogoo04moo`00L7oo0`00;Goo00@007ooOol0
00=oo`03001oogoo019oo`03001oogoo00moo`03001oogoo04moo`00KWoo0P00<7oo00@007ooOol0
009oo`03001oogoo01=oo`03001oogoo011oo`03001oogoo04ioo`00Jgoo0`00<Woo0`000Woo00<0
07ooOol057oo00<007ooOol04Goo00<007ooOol0CGoo001YOol2000eOol00`00Oomoo`02Ool00`00
Oomoo`0DOol00`00Oomoo`0<Ool20003Ool00`00Oomoo`1=Ool006Ioo`<003Ioo`8000=oo`03001o
ogoo01Eoo`03001oogoo00Moo`05001oogooOol00002Ool01@00Oomoogoo0000CWoo001TOol2000m
Ool00`00Oomoo`0FOol00`00Oomoo`08Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`1;Ool0065o
o`<003ioo`03001oogoo01Moo`03001oogoo00Uoo`8000=oo`03001oogoo00=oo`03001oogoo04Yo
o`00Ggoo0P00@7oo00<007ooOol067oo00<007ooOol01goo0P0000=oo`0000000Woo00<007ooOol0
0goo00<007ooOol0BWoo001LOol30012Ool00`00Oomoo`0HOol00`00Oomoo`04Ool30003Ool01000
Ool000001goo00<007ooOol0BGoo001JOol20014Ool00`00Oomoo`0IOol01000Oomoogoo0`001goo
00<007ooOol027oo00<007ooOol0B7oo001GOol30015Ool00`00Oomoo`0JOol01000Ool000002Woo
00<007ooOol027oo00<007ooOol0B7oo001DOol30017Ool00`00Oomoo`0JOol3000HOol00`00Oomo
o`17Ool0059oo`8004Uoo`03001oogoo00]oo`<000Yoo`<0009oo`03001oogoo01Moo`03001oogoo
04Ioo`00Cgoo0`00Bgoo00<007ooOol02Woo00<007ooOol02Goo0P001Goo00<007ooOol05goo00<0
07ooOol0AWoo001=Ool2001=Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool30007Ool00`00Oomoo`0H
Ool00`00Oomoo`15Ool004Yoo`<004ioo`03001oogoo00eoo`<0009oo`<000Yoo`03001oogoo01Uo
o`03001oogoo04Aoo`00B7oo0P00D7oo00<007ooOol04Goo0P003Goo00<007ooOol06Goo00<007oo
Ool0A7oo0015Ool3001AOol00`00Oomoo`0?Ool3000?Ool00`00Oomoo`0JOol00`00Oomoo`13Ool0
04=oo`8005Aoo`03001oogoo00aoo`<0019oo`03001oogoo01]oo`03001oogoo049oo`00@7oo0`00
EGoo00<007ooOol02goo0P005Goo00<007ooOol06goo00<007ooOol0@Woo000nOol2001GOol00`00
Oomoo`09Ool3000GOol00`00Oomoo`0LOol00`00Oomoo`11Ool003]oo`<005Qoo`03001oogoo00Mo
o`<001Yoo`03001oogoo01eoo`03001oogoo041oo`00>7oo0`00FWoo00<007ooOol01Woo0P007Goo
00<007ooOol07Goo00<007ooOol0@7oo000fOol2001MOol00`00Oomoo`03Ool3000OOol00`00Oomo
o`0NOol00`00Oomoo`0oOol003=oo`<005ioo`04001oogooOol3000ROol00`00Oomoo`0OOol00`00
Oomoo`0nOol0035oo`80061oo`03001oogoo008001eoo`<000Eoo`03001oogoo01moo`03001oogoo
03ioo`00;Woo0`00GWoo100000=oo`0000007Woo00<007ooOol01Woo00<007ooOol087oo00<007oo
Ool0?Goo000/Ool2001QOol00`00Oomoo`0ROol40005Ool00`00Oomoo`0QOol00`00Oomoo`0lOol0
02Uoo`<006Aoo`03001oogoo009oo``001Aoo`8000Ioo`03001oogoo01Moo`03001oogoo00Moo`03
001oogoo03aoo`009goo0P00J7oo00<007ooOol03Goo5`001Goo00<007ooOol067oo00<007ooOol0
0goo0`0000=oo`00Ool0?7oo000TOol3001SOol20003Ool01000Oomoo`009Goo5`002Woo00<007oo
Ool00goo00D007ooOomoo`0003aoo`008Woo0P00J7oo0P000Woo0P00:goo00<007ooOol03goo3000
00=oo`0000000`000Woo00<007ooOol0>Woo000OOol3001ZOol2000_Ool00`00Oomoo`0JOol00`00
Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`0iOol001aoo`<006aoo`04001oogoo000^Ool00`00
Oomoo`0IOol01`00Oomoogoo001oo`0000Eoo`03001oogoo03Qoo`006Woo0P00KWoo00D007ooOomo
o`0002ioo`03001oogoo01Uoo`03001oogoo009oo`8000Eoo`03001oogoo03Qoo`005goo0`00Kgoo
00<007ooOol00goo00<007ooOol0:goo00<007ooOol09Woo00<007ooOol0=goo000EOol2001aOol0
0`00Oomoo`0bOol00`00Oomoo`0WOol00`00Oomoo`0fOol0019oo`<0079oo`03001oogoo03Aoo`03
001oogoo02Ioo`03001oogoo03Ioo`0047oo0P00M7oo00<007ooOol0=Goo00<007ooOol09goo00<0
07ooOol0=Goo000>Ool2001eOol00`00Oomoo`0fOol00`00Oomoo`0XOol00`00Oomoo`0dOol000io
o`8007Aoo`03001oogoo03Moo`03001oogoo02Qoo`03001oogoo03Aoo`003Woo00<007oo0000LWoo
00<007ooOol0>7oo00<007ooOol0:Goo00<007ooOol0<goo000>Ool01000Oomoo`00LGoo00<007oo
Ool0>7oo00<007ooOol0:Woo00<007ooOol0<Woo000=Ool00`00Oomoo`02Ool00`00Oomoo`1]Ool0
0`00Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0bOol000eoo`03001oogoo00=oo`03001oogoo
06]oo`03001oogoo03Yoo`03001oogoo02]oo`03001oogoo035oo`003Goo00<007ooOol017oo00<0
07ooOol0JGoo00<007ooOol0>goo00<007ooOol0;7oo00<007ooOol0<7oo000=Ool00`00Oomoo`05
Ool00`00Oomoo`1WOol00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0`Ool000eoo`03001o
ogoo00Ioo`03001oogoo06Eoo`03001oogoo03eoo`03001oogoo02eoo`03001oogoo02moo`003Goo
00<007ooOol01goo00<007ooOol0Hgoo00<007ooOol0?Woo00<007ooOol0;Woo00<007ooOol0;Woo
000=Ool00`00Oomoo`08Ool00`00Oomoo`1QOol00`00Oomoo`0oOol00`00Oomoo`0^Ool00`00Oomo
o`0^Ool000aoo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo041oo`03001oogoo02moo`03
001oogoo02eoo`0037oo00<007ooOol02goo00<007ooOol0GGoo00<007ooOol0@Goo00<007ooOol0
<7oo00<007ooOol0;7oo000<Ool00`00Oomoo`0<Ool00`00Oomoo`1KOol00`00Oomoo`12Ool00`00
Oomoo`0`Ool00`00Oomoo`0/Ool000aoo`03001oogoo00eoo`03001oogoo05Uoo`03001oogoo04=o
o`03001oogoo035oo`03001oogoo02]oo`0037oo00<007ooOol03Woo00<007ooOol0Egoo00<007oo
Ool0A7oo00<007ooOol0<Woo00<007ooOol0:Woo000<Ool00`00Oomoo`0?Ool00`00Oomoo`1EOol0
0`00Oomoo`15Ool00`00Oomoo`0bOol00`00Oomoo`0ZOol000aoo`03001oogoo011oo`03001oogoo
05=oo`03001oogoo04Ioo`03001oogoo03=oo`03001oogoo02Uoo`0037oo00<007ooOol04Goo00<0
07ooOol0DGoo00<007ooOol0Agoo00<007ooOol08goo0P003goo00<007ooOol0:7oo000;Ool00`00
Oomoo`0COol00`00Oomoo`1?Ool00`00Oomoo`18Ool00`00Oomoo`0ROol01000Oomoo`003Woo00<0
07ooOol0:7oo000;Ool00`00Oomoo`0DOol00`00Oomoo`1=Ool00`00Oomoo`19Ool00`00Oomoo`0N
Ool20005Ool00`00Oomoo`0=Ool00`00Oomoo`0WOol000]oo`03001oogoo01Eoo`03001oogoo04=o
o`D000=oo`03001oogoo04Yoo`03001oogoo021oo`D0015oo`03001oogoo02Ioo`002goo00<007oo
Ool05Woo00<007ooOol0@Woo10000goo00<007ooOol0Bgoo00<007ooOol087oo10004Woo00<007oo
Ool09Woo000;Ool00`00Oomoo`0GOol00`00Oomoo`14Ool01000Oomoo`00CWoo00<007ooOol07goo
00<007ooOol010004Goo00<007ooOol09Goo000;Ool00`00Oomoo`0HOol00`00Oomoo`11Ool30002
Ool00`00Oomoo`1=Ool00`00Oomoo`0MOol01@00Oomoogoo00005Goo00<007ooOol097oo000;Ool0
0`00Oomoo`0IOol00`00Oomoo`14Ool00`00Oomoo`1>Ool00`00Oomoo`0KOol2000JOol00`00Oomo
o`0TOol000Yoo`03001oogoo01]oo`03001oogoo049oo`03001oogoo04moo`03001oogoo01Yoo`03
001oogoo01]oo`03001oogoo02=oo`002Woo00<007ooOol077oo0P00@Goo00<007ooOol0D7oo00<0
07ooOol067oo0P007goo00<007ooOol08Woo000:Ool00`00Oomoo`0NOol00`00Oomoo`0mOol00`00
Oomoo`1AOol00`00Oomoo`0GOol00`00Oomoo`0OOol00`00Oomoo`0ROol000Yoo`03001oogoo01mo
o`03001oogoo03]oo`03001oogoo059oo`03001oogoo00aoo`<000Ioo`8002=oo`03001oogoo025o
o`002Woo00<007ooOol087oo00<007ooOol0>Goo00<007ooOol0Dgoo00<007ooOol02goo00<007oo
Ool01Woo00<007ooOol097oo00<007ooOol087oo000:Ool00`00Oomoo`0QOol00`00Oomoo`0gOol0
0`00Oomoo`1DOol00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0VOol00`00Oomoo`0OOol0
00Yoo`03001oogoo029oo`03001oogoo03Eoo`03001oogoo05Eoo`03001oogoo00aoo`<0009oo`80
02Uoo`03001oogoo01moo`002Goo00<007ooOol097oo00<007ooOol0<goo00<007ooOol0EWoo00<0
07ooOol047oo00<007ooOol0:Woo00<007ooOol07Woo0009Ool00`00Oomoo`0UOol00`00Oomoo`0a
Ool00`00Oomoo`1GOol00`00Oomoo`0>Ool2000^Ool00`00Oomoo`0MOol000Uoo`03001oogoo02Io
o`03001oogoo02moo`03001oogoo05Qoo`03001oogoo00eoo`03001oogoo02ioo`03001oogoo01eo
o`002Goo00<007ooOol09goo00<007ooOol0;Goo00<007ooOol0FGoo00<007ooOol037oo00<007oo
Ool0<7oo00<007ooOol077oo0009Ool00`00Oomoo`0XOol00`00Oomoo`0[Ool00`00Oomoo`1IOol2
000<Ool2000dOol00`00Oomoo`0KOol000Uoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo
05Moo`<0009oo`03001oogoo00Qoo`03001oogoo03Aoo`03001oogoo01]oo`002Goo00<007ooOol0
:Woo00<007ooOol09goo00<007ooOol0EGoo0`001Woo00<007ooOol01Goo0P00>7oo00<007ooOol0
6Woo0009Ool00`00Oomoo`0[Ool00`00Oomoo`0UOol00`00Oomoo`1COol30009Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool3000DOol00`00Oomoo`02Ool2000?Ool00`00Oomoo`0IOol000Qoo`03001o
ogoo02eoo`03001oogoo02=oo`03001oogoo055oo`<000eoo`04001oogooOol2000>Ool00`00Oomo
o`0FOol200001Goo001oogoo00003Woo00<007ooOol06Goo0008Ool00`00Oomoo`0^Ool00`00Oomo
o`0QOol00`00Oomoo`1?Ool3000AOol00`00Ool0000@Ool4000BOol70002Ool00`00Oomoo`0=Ool0
0`00Oomoo`0HOol000Qoo`03001oogoo02moo`03001oogoo01moo`03001oogoo04eoo`<001Eoo`03
001oogoo011oo`8000Moo``000Eoo`04001oo`00000AOol00`00Oomoo`0GOol000Qoo`03001oogoo
031oo`03001oogoo01eoo`03001oogoo04]oo`<0015oo`<0009oo`<000moo``0015oo`80009oo`03
001oogoo00ioo`03001oogoo01Moo`0027oo00<007ooOol0<Goo00<007ooOol077oo00<007ooOol0
BGoo0P003Goo00<007ooOol01Woo00<007oo00000goo00<007ooOol030007Goo00@007oo0000019o
o`03001oogoo01Ioo`0027oo00<007ooOol0<Woo00<007ooOol06Woo00<007ooOol0Agoo0`0047oo
0P001Goo0`0000=oo`0000001000@7oo00<007ooOol05Goo0008Ool00`00Oomoo`0cOol00`00Oomo
o`0HOol00`00Oomoo`15Ool3000;Ool5O0060003Ool01000Oomoo`001Woo00<007ooOol0?Woo00<0
07ooOol05Goo0007Ool00`00Oomoo`0eOol00`00Oomoo`0FOol00`00Oomoo`0XOol3000HOol30005
Ool9O0050005Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol0?Woo00<007ooOol0
57oo0007Ool00`00Oomoo`0fOol00`00Oomoo`0DOol00`00Oomoo`0XOol00`00Oomoo`0FOol30008
O004000?Ool00`00Oomoo`02Ool300000g`0Oomoo`04Ool00`00Oomoo`0oOol00`00Oomoo`0COol0
00Moo`03001oogoo03Moo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo00moo`Al00<0009l
00<0029oo`03O01oogoo00Aoo`03001oogoo03ioo`03001oogoo01=oo`001goo00<007ooOol0>7oo
00<007ooOol047oo00<007ooOol0:goo0`001Goo2G`01000:goo00=l07ooOol017oo00<007ooOol0
?Woo00<007ooOol04Woo0007Ool00`00Oomoo`0iOol00`00Oomoo`0>Ool00`00Oomoo`0ZOol00`00
O01l0007O0000`00Oomoo`04Ool3000^Ool00g`0Oomoo`05Ool00`00Oomoo`0nOol00`00Oomoo`0A
Ool000Moo`03001oogoo03Yoo`03001oogoo00aoo`03001oogoo025oo`8000Ul00eoo`<0039oo`03
O01oogoo00Aoo`03001oogoo03ioo`03001oogoo015oo`001goo00<007ooOol0>goo00<007ooOol0
2Woo00<007ooOol067oo0`002G`04goo0`00=Woo00=l07ooOol017oo00<007ooOol0?Woo00<007oo
Ool047oo0006Ool00`00Oomoo`0mOol00`00Oomoo`08Ool00`00Oomoo`0?Ool40009O00IOol3000j
Ool00g`0Oomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`0?Ool000Ioo`03001oogoo03ioo`03001o
ogoo009oo`D000Qoo`D000Ul01moo`<003ioo`03O01oogoo00Aoo`03001oogoo03eoo`03001oogoo
00moo`001Woo00<007ooOol0?goo00<007ooOol00goo00<007ooOol00Woo1P001G`09Goo0`00@Goo
00=l07ooOol01Goo00<007ooOol0?Goo00<007ooOol03Woo0006Ool00`00Oomoo`10Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool60n0POol30015Ool00g`0Oomoo`04Ool00`00Oomoo`0nOol00`00Oomo
o`0=Ool000Ioo`03001oogoo045oo`05001oogooOol00006Ool400000goo0n03h00<0n0EOol30019
Ool00g`0Oomoo`04Ool00`00Oomoo`0mOol00`00Oomoo`0=Ool000Ioo`03001oogoo049oo`04001o
ogoo000:Ool00`000n03h00D0n0:Ool3001=Ool00g`0Oomoo`04Ool00`00Oomoo`0mOol00`00Oomo
o`0<Ool000Ioo`03001oogoo04=oo`<000]ooah3h080051oo`03O01oogoo00Eoo`03001oogoo02Yo
o`03001oogoo011oo`03001oogoo00]oo`001Goo00<007ooOol0AGoo00<007ooOol02Woo6`?P0`00
20?PBgoo00=l07ooOol017oo00<007ooOol09Goo00<007ooOol00Woo00<007ooOol047oo00<007oo
Ool02goo0005Ool00`00Oomoo`16Ool00`00Oomoo`0?OolB0n03000B0n0:Ool4000gOol00g`0Oomo
o`04Ool00`00Oomoo`0UOol20002Ool00`00Oomoo`0@Ool2000<Ool000Eoo`03001oogoo04Moo`03
001oogoo01Ioo`L3h0<001d3h005Ool007ooOol0000iOol00g`0Oomoo`04Ool00`00Oomoo`0UOol2
0002Ool00`00Oomoo`0<Ool300000goo001oo`0;Ool000Eoo`03001oogoo04Qoo`03001oogoo01Uo
o`<00003Ool3h0?P01h3h0040003h0?P00030n0gOol00g`0Oomoo`04Ool00`00Oomoo`0QOol30000
1Goo001oogoo00002Woo100017oo00<007ooOol02Woo0005Ool00`00Oomoo`19Ool00`00Oomoo`0E
Ool3000<OolI0n03000;0n0_Ool00g`0Oomoo`05Ool00`00Oomoo`0?Ool3000:Ool40004Ool40007
Ool30008Ool00`00Oomoo`0:Ool000Eoo`03001oogoo04Yoo`03001oogoo015oo`<001Mooa<3h003
0003h0?P0103h2Uoo`03O01oogoo00Aoo`03001oogoo00ioo`03001oogoo00Qoo`<000Qoo`03001o
ogoo00Eoo`<000]oo`03001oogoo00Yoo`001Goo00<007ooOol0Bgoo00<007ooOol03Goo0`008Goo
2`?P0P006P?P8Woo00=l07ooOol017oo00<007ooOol03Goo00<007ooOol01Goo0`0047oo0`003goo
00<007ooOol02Goo0005Ool00`00Oomoo`1<Ool00`00Oomoo`09Ool3000/OolW0n0KOol00g`0Oomo
o`04Ool00`00Oomoo`0=Ool3000017oo000000003goo10004Woo00<007ooOol02Goo0004Ool00`00
Oomoo`1>Ool00`00Oomoo`05Ool3000gOolW0n0DOol00g`0Oomoo`04Ool00`00Oomoo`0<Ool4000?
Ool3000FOol00`00Oomoo`09Ool000Aoo`03001oogoo04moo`04001oogooOol30012OolW0n0<Ool0
0g`0Oomoo`04Ool00`00Oomoo`09Ool3000@Ool3000IOol00`00Oomoo`09Ool000Aoo`03001oogoo
051oo`<004aoobH3h0Moo`03O01oogoo00Aoo`03001oogoo00Eoo`<0011oo`<001aoo`03001oogoo
00Uoo`0017oo00<007ooOol0CGoo0`0000=oo`00Ool0E7oo7P?P00=oo`00Ool01Goo00=l07ooOol0
17oo00<007ooOol010003goo10007goo00<007ooOol02Goo0004Ool00`00Oomoo`1:Ool30005Ool0
0`00Oomoo`1JOol:0n000`000n03h0090n001000Ool000000Woo1@000Woo1@0047oo0`008goo00<0
07ooOol02Goo0004Ool00`00Oomoo`17Ool30009Ool00`00Oomoo`1NOol800090n000goo00000002
0003Ool01000Oomoogoo100000=oo`00Ool037oo0`009Woo00<007ooOol02Goo0004Ool00`00Oomo
o`14Ool3000=Ool00`00Oomoo`1BOolC0003Ool60n03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00<007oo00002Goo1000:Goo00<007ooOol02Goo0003Ool00`00Oomoo`12Ool3000AOol00`00
Oomoo`17OolN000;Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol000Eoo`<002io
o`03001oogoo00Qoo`000goo00<007ooOol0@7oo0P005Goo00<007ooOol0>goo:P003goo00D007oo
Oomoo`00009oo`06001oogooOol007oo0`00<Goo00<007ooOol027oo0003Ool00`00Oomoo`0mOol3
000HOol00`00Oomoo`0`Oold000>Ool20004Ool20003Ool3000dOol00`00Oomoo`08Ool000=oo`03
001oogoo03Yoo`<001aoo`03001oogoo02AoocD000Eoo`H001Aoo`@0009oo`03001oogoo039oo`03
001oogoo00Qoo`000goo00<007ooOol0=goo0`0087oo00<007ooOol067oo=@004Goo1P0047oo0`00
1goo00<007ooOol0<Goo00<007ooOol027oo0003Ool00`00Oomoo`0dOol3000TOol2000>Oole000K
Ool7000<Ool3000;Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool000=oo`03001oogoo035oo`<002Uo
o`03001oogoo03D002Moo`L000Qoo`<000moo`03001oogoo02moo`03001oogoo00Qoo`000Woo00<0
07ooOol0;goo0`009Goo=@00<Woo1`000goo10004goo00<007ooOol0;Woo00<007ooOol027oo0002
Ool00`00Oomoo`0/Ool3000MOole000nOol9000GOol00`00Oomoo`0_Ool00`00Oomoo`07Ool0009o
o`03001oogoo02Uoo`<001Qooc8004Yoo`H001Yoo`03001oogoo02ioo`03001oogoo00Moo`000Woo
00<007ooOol09Woo0`006goo:000Dgoo20006Woo00<007ooOol0;Goo00<007ooOol01goo0002Ool0
0`00Oomoo`0SOol3000NOolM0002Ool00`00Oomoo`1EOol40002Ool7000JOol00`00Oomoo`0/Ool0
0`00Oomoo`07Ool0009oo`03001oogoo021oo`<0025ooah0009oo`03001oogoo055oo`<000Moo`L0
01Uoo`03001oogoo02aoo`03001oogoo00Moo`000Woo00<007ooOol07Goo0`0097oo9P00Bgoo0`00
2goo1P006Woo00<007ooOol0:goo00<007ooOol01goo0002Ool00`00Oomoo`0JOol3000]OolX0010
Ool3000?Ool6000JOol00`00Oomoo`0ZOol00`00Oomoo`07Ool00003Ool007oo01Uoo`<003QoobL0
03Eoo`@001=oo`H001Yoo`03001oogoo02Uoo`03001oogoo00Moo`0000=oo`00Ool05Woo0`00@goo
9`00:Woo0`005goo1`006Woo00<007ooOol0:7oo00<007ooOol01goo00000goo001oo`0DOol2001>
OolW000OOol3000KOol7000IOol00`00Oomoo`0YOol00`00Oomoo`06Ool00003Ool007oo015oo`<0
05QoobL001Aoo`<001moo`L001Uoo`03001oogoo02Qoo`03001oogoo00Ioo`0000=oo`00Ool03Woo
0`00G7oo00<007ooOol017oo9`0027oo10008goo1P006Woo00<007ooOol09goo00<007ooOol01Woo
00000goo001oo`0;Ool3001POol00`00Oomoo`0:OolX000XOol6000JOol00`00Oomoo`0VOol00`00
Oomoo`06Ool00003Ool007oo00Qoo`<006Aoo`03001oogoo015oobL0029oo`H001Uoo`03001oogoo
02Ioo`03001oogoo00Ioo`0000<007ooOol01Goo0`00J7oo00<007ooOol067oo9`006Woo1`006Goo
00<007ooOol09Goo00<007ooOol01Woo00000`00Oomoo`02Ool3001/Ool00`00Oomoo`0OOolW000C
Ool7000IOol00`00Oomoo`0TOol00`00Oomoo`06Ool00003001oo`000080071oo`03001oogoo01io
o`<000EoobL000aoo`L001Uoo`03001oogoo02=oo`03001oogoo00Ioo`000P00M7oo00<007ooOol0
6Woo0`0047oo9`001Goo1P006Woo00<007ooOol08Woo00<007ooOol01Woo00000goo001oo`1dOol0
0`00Oomoo`0EOol4000JOol/000IOol00`00Oomoo`0SOol00`00Oomoo`05Ool0009oo`8007Aoo`03
001oogoo015oo`<002IoobH001Qoo`03001oogoo029oo`03001oogoo00Eoo`0017oo00<007ooOol0
LWoo00<007ooOol03Goo0`00<Goo7P006Goo00<007ooOol08Goo00<007ooOol01Goo0005Ool00`00
Oomoo`1bOol00`00Oomoo`09Ool3000lOolG000IOol00`00Oomoo`0POol00`00Oomoo`05Ool000Io
o`03001oogoo079oo`03001oogoo00Aoo`@004Moo`h001]oo`03001oogoo01moo`03001oogoo00Eo
o`001goo0P00Lgoo00<007ooOol00`00Dgoo1P006goo00<007ooOol07goo00<007ooOol01Goo0009
Ool00`00Oomoo`1aOol2001IOol00`00Oomoo`0LOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Yo
o`03001oogoo071oo`03001oogoo07Qoo`03001oogoo01eoo`03001oogoo00Eoo`002goo00<007oo
Ool0Kgoo00<007ooOol0NGoo00<007ooOol077oo00<007ooOol01Goo000<Ool2001_Ool00`00Oomo
o`1iOol00`00Oomoo`0MOol00`00Oomoo`04Ool000ioo`03001oogoo06aoo`03001oogoo07Yoo`03
001oogoo01aoo`03001oogoo00Aoo`003goo00<007ooOol0Jgoo00<007ooOol0Ngoo00<007ooOol0
6goo00<007ooOol017oo000@Ool00`00Oomoo`1ZOol00`00Oomoo`1lOol00`00Oomoo`0JOol00`00
Oomoo`04Ool0015oo`8006Yoo`03001oogoo07eoo`03001oogoo01Uoo`03001oogoo00Aoo`004goo
00<007ooOol0Igoo00<007ooOol0OGoo00<007ooOol06Goo00<007ooOol017oo000DOol00`00Oomo
o`1VOol00`00Oomoo`1nOol00`00Oomoo`0HOol00`00Oomoo`04Ool001Eoo`03001oogoo06Eoo`03
001oogoo07moo`03001oogoo01Moo`03001oogoo00Aoo`005Woo0P00IGoo00<007ooOol0P7oo00<0
07ooOol05goo00<007ooOol00goo000HOol00`00Oomoo`1ROol00`00Oomoo`20Ool00`00Oomoo`0G
Ool00`00Oomoo`03Ool001Uoo`03001oogoo065oo`03001oogoo085oo`03001oogoo01Ioo`03001o
ogoo00=oo`006Woo00<007ooOol0H7oo00<007ooOol0PWoo00<007ooOol05Goo00<007ooOol00goo
000KOol2001POol00`00Oomoo`23Ool00`00Oomoo`0DOol00`00Oomoo`03Ool001eoo`03001oogoo
05eoo`03001oogoo08Aoo`03001oogoo01=oo`03001oogoo00=oo`007Woo00<007ooOol0G7oo00<0
07ooOol0Q7oo00<007ooOol04goo00<007ooOol00goo000OOol2001LOol00`00Oomoo`25Ool00`00
Oomoo`0BOol00`00Oomoo`03Ool0025oo`03001oogoo05Uoo`03001oogoo08Ioo`03001oogoo015o
o`03001oogoo00=oo`008Woo00<007ooOol0F7oo00<007ooOol0Qgoo00<007ooOol04Goo00<007oo
Ool00Woo000SOol00`00Oomoo`1GOol00`00Oomoo`27Ool00`00Oomoo`0AOol00`00Oomoo`02Ool0
02Aoo`8005Moo`03001oogoo08Qoo`03001oogoo011oo`03001oogoo009oo`009Woo00<007ooOol0
Dgoo00<007ooOol0RWoo00<007ooOol03goo00<007ooOol00Woo000WOol00`00Oomoo`1BOol00`00
Oomoo`2;Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool002Qoo`03001oogoo055oo`03001oogoo08ao
o`03001oogoo00eoo`03001oogoo009oo`00:Goo0P00DGoo00<007ooOol0S7oo00<007ooOol03Goo
00<007ooOol00Woo000[Ool00`00Oomoo`1>Ool00`00Oomoo`2=Ool00`00Oomoo`0<Ool00`00Oomo
o`02Ool002aoo`03001oogoo04eoo`03001oogoo08ioo`03001oogoo00]oo`03001oogoo009oo`00
;Goo00<007ooOol0C7oo00<007ooOol0Sgoo00<007ooOol02goo00<007ooOol00Goo000^Ool2001<
Ool00`00Oomoo`2?Ool00`00Oomoo`0;Ool00`00Oomoo`01Ool0031oo`03001oogoo04Uoo`03001o
ogoo091oo`03001oogoo00Yoo`03001oogoo005oo`00<Goo00<007ooOol0B7oo00<007ooOol0TGoo
00<007ooOol02Goo00<007ooOol00Goo000bOol00`00Oomoo`17Ool00`00Oomoo`2BOol00`00Oomo
o`08Ool00`00Oomoo`01Ool003=oo`8004Moo`03001oogoo09=oo`03001oogoo00Moo`03001oogoo
005oo`00=Goo00<007ooOol0A7oo00<007ooOol0Tgoo00<007ooOol01goo00<007ooOol00Goo000f
Ool00`00Oomoo`13Ool00`00Oomoo`2DOol00`00Oomoo`06Ool00`00Oomoo`01Ool003Moo`03001o
ogoo049oo`03001oogoo09Eoo`03001oogoo00Ioo`40005oo`5oo`00>7oo0P00@Woo00<007ooOol0
UWoo00<007ooOol01Goo0@000Goo0Goo000jOol00`00Oomoo`0oOol00`00Oomoo`2FOol00`00Oomo
o`05Ool10001Ool1Ool003]oo`03001oogoo03ioo`03001oogoo09Moo`03001oogoo00Aoo`40005o
o`5oo`00?7oo00<007ooOol0?Goo00<007ooOol0V7oo00<007ooOol00goo0@000Goo0Goo000mOol2
000mOol00`00Oomoo`2IOol00`00Oomoo`02Ool10001Ool1Ool003moo`03001oogoo03Yoo`03001o
ogoo09Yoo`05001oogooOol00002Ool0041oo`03001oogoo03Uoo`03001oogoo09Yoo`05001oogoo
Ool00002Ool0045oo`03001oogoo03Qoo`03001oogoo09]oo`04001oogoo0002Ool0049oo`8003Qo
o`03001oogoo09aoo`04001oogoo0001Ool004Aoo`03001oogoo03Eoo`03001oogoo09eoo`03001o
o`00005oo`00AGoo00<007ooOol0=7oo00<007ooOol0WGoo00<007oo00000Goo0016Ool00`00Oomo
o`0cOol00`00Oomoo`2NOol20001Ool004Moo`8003=oo`03001oogoo09ioo`80005oo`00BGoo00<0
07ooOol0<7oo00<007ooOol0VWoo10000goo001:Ool00`00Oomoo`0_Ool00`00Oomoo`2FOol40007
Ool004]oo`03001oogoo02ioo`03001oogoo099oo`@000]oo`00C7oo0P00;Woo00<007ooOol0SWoo
10003goo001>Ool00`00Oomoo`0[Ool00`00Oomoo`2:Ool4000COol004moo`03001oogoo02Yoo`03
001oogoo08Ioo`@001Moo`00D7oo00<007ooOol0:Goo00<007ooOol0PWoo10006goo001AOol2000Y
Ool00`00Oomoo`1nOol4000OOol005=oo`03001oogoo02Ioo`03001oogoo07Yoo`@002=oo`00E7oo
00<007ooOol09Goo00<007ooOol0MWoo10009goo001EOol00`00Oomoo`0TOol00`00Oomoo`1bOol4
000[Ool005Ioo`8002Aoo`03001oogoo06ioo`@002moo`00F7oo00<007ooOol08Goo00<007ooOol0
JWoo1000<goo001IOol00`00Oomoo`0POol00`00Oomoo`1VOol4000gOol005Yoo`03001oogoo01mo
o`03001oogoo069oo`@003]oo`00Fgoo0P007goo00<007ooOol0GWoo1000?goo001MOol00`00Oomo
o`0LOol00`00Oomoo`1JOol40013Ool005ioo`03001oogoo01]oo`03001oogoo05Ioo`@004Moo`00
Ggoo0P006Woo00<007ooOol0Dgoo1000Bgoo001QOol00`00Oomoo`0GOol00`00Oomoo`1?Ool4001?
Ool0069oo`03001oogoo01Ioo`03001oogoo04]oo`@005=oo`00Hgoo00<007ooOol05Goo00<007oo
Ool0Agoo1000Egoo001TOol2000EOol00`00Oomoo`13Ool4001KOol006Ioo`03001oogoo019oo`03
001oogoo03moo`@005moo`00Igoo00<007ooOol04Goo00<007ooOol0>goo1000Hgoo001XOol00`00
Oomoo`0@Ool00`00Oomoo`0gOol4001WOol006Uoo`80011oo`03001oogoo03=oo`@006]oo`00Jgoo
00<007ooOol03Goo00<007ooOol0;goo1000Kgoo001/Ool00`00Oomoo`0<Ool00`00Oomoo`0[Ool4
001cOol006eoo`03001oogoo00]oo`03001oogoo02Moo`@007Moo`00KWoo0P002goo00<007ooOol0
8goo1000Ngoo001`Ool00`00Oomoo`08Ool00`00Oomoo`0OOol4001oOol0075oo`03001oogoo00Mo
o`03001oogoo01]oo`@008=oo`00LWoo00<007ooOol01Woo00<007ooOol05goo1000Qgoo001cOol2
0006Ool00`00Oomoo`0COol4002;Ool007Eoo`03001oogoo00=oo`03001oogoo00moo`@008moo`00
MWoo00<007ooOol00Woo00<007ooOol02goo1000Tgoo001gOol01@00Oomoogoo00002Goo1000Ugoo
001hOol200000goo001oo`04Ool4002KOol007Yoo`800003Ool00000008009moo`00Ngoo0P00Xgoo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {268.938, 0}} -> {-0.000204162, 0.0102969, \
0.00329395, 0.00329395}}],

Cell["\<\
We will show that any loop can be decomposed into a product of \"basic\"  \
loops.  
These loops are called \"Schreier generators\".
In fact we will decompose any randomly chosen path.\
\>", "Emphasis",
  CellTags->"emphasis"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Word Paths and basic loops", "Subsection"],

Cell[CellGroupData[{

Cell["an example", "Subsubsection"],

Cell["We can construct a random example.", "Text"],

Cell[CellGroupData[{

Cell["random constr", "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"gens", "=", 
      RowBox[{"theGpGens", "/.", 
        RowBox[{
          RowBox[{"LPerm", "[", 
            RowBox[{"a_", ",", "_"}], "]"}], "\[Rule]", "a"}]}]}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", 
        ",", "\<\"d\"\>", ",", "\<\"e\"\>"}], "}"}]], "Output",
  CellTags->"enfold"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"aword", "=", 
      RowBox[{"gens", "[", 
        RowBox[{"[", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{"Random", "[", 
                RowBox[{"Integer", ",", 
                  RowBox[{"{", 
                    RowBox[{"1", ",", 
                      RowBox[{"Length", "[", "gens", "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"{", "6", "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"a\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", 
        ",", "\<\"a\"\>", ",", "\<\"e\"\>", ",", "\<\"a\"\>"}], 
      "}"}]], "Output",
  CellTags->"enfold"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"aword", "=", 
        RowBox[{"{", 
          RowBox[{
          "\"\<d\>\"", ",", "\"\<d\>\"", ",", "\"\<b\>\"", ",", "\"\<d\>\"", 
            ",", "\"\<e\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", 
            "\"\<b\>\"", ",", "\"\<a\>\"", ",", "\"\<c\>\""}], "}"}]}], 
      ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell["construct path edges along the word:", "Text",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"pathedges", "=", 
      RowBox[{"Cases", "[", 
        RowBox[{
          RowBox[{"FoldList", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"Replace", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"#1", ",", "#2"}], "}"}], ",", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"i_", ",", "_"}], "}"}], ",", "a_"}], 
                        "}"}], "\[RuleDelayed]", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"Cases", "[", 
                            RowBox[{"theGpGens", ",", 
                              RowBox[{
                                RowBox[{"LPerm", "[", 
                                  RowBox[{"a", ",", "\[Sigma]_"}], "]"}], 
                                "\[RuleDelayed]", "\[IndentingNewLine]", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"(", 
                                      RowBox[{"i", "/.", "\[Sigma]"}], ")"}], 
                                    ",", 
                                    RowBox[{"TEdge", "[", 
                                      RowBox[{"i", ",", "a", ",", 
                                        RowBox[{"i", "/.", "\[Sigma]"}]}], 
                                      "]"}]}], "}"}]}]}], "]"}], "/.", 
                          RowBox[{"{", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"{", "}"}], "\[Rule]", 
                                RowBox[{"TEdge", "[", 
                                  RowBox[{"i", ",", "a", ",", "i"}], "]"}]}], 
                              ",", 
                              RowBox[{
                                RowBox[{"{", "e_", "}"}], "\[Rule]", "e"}]}], 
                            "}"}]}], ")"}]}]}], "]"}], "&"}], ",", 
              RowBox[{"{", 
                RowBox[{"1", ","}], "}"}], ",", "aword"}], "]"}], ",", 
          "_TEdge", ",", "Infinity"}], "]"}]}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"TEdge", "[", 
          RowBox[{"1", ",", "\<\"d\"\>", ",", "10"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"10", ",", "\<\"d\"\>", ",", "9"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"9", ",", "\<\"b\"\>", ",", "4"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"4", ",", "\<\"d\"\>", ",", "1"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"1", ",", "\<\"e\"\>", ",", "1"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"1", ",", "\<\"b\"\>", ",", "1"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"1", ",", "\<\"c\"\>", ",", "9"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"9", ",", "\<\"b\"\>", ",", "4"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"4", ",", "\<\"a\"\>", ",", "3"}], "]"}], ",", 
        RowBox[{"TEdge", "[", 
          RowBox[{"3", ",", "\<\"c\"\>", ",", "10"}], "]"}]}], 
      "}"}]], "Output",
  CellTags->"enfold"]
}, Closed]],

Cell["Construct the path arrows:", "Text",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"patharrows", "=", 
      RowBox[{"pathedges", "/.", "\[IndentingNewLine]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"TEdge", "[", 
                RowBox[{"i_", ",", "a_", ",", "i_"}], "]"}], "\[RuleDelayed]",
               
              RowBox[{"TNodeLoop", "[", 
                RowBox[{"i", ",", "a"}], "]"}]}], ",", 
            RowBox[{
              RowBox[{"TEdge", "[", 
                RowBox[{"i_", ",", "a_", ",", "j_"}], "]"}], ":>", 
              RowBox[{
                RowBox[{"Cases", "[", 
                  RowBox[{"arrs", ",", 
                    RowBox[{"_", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"i", ",", "j"}], "}"}], ",", "a"}], "]"}], 
                    ",", "Infinity"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}]}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "10"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",",
         
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"10", ",", "9"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",",
         
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",", 
        
        RowBox[{"TNodeLoop", "[", 
          RowBox[{"1", ",", "\<\"e\"\>"}], "]"}], ",", 
        RowBox[{"TNodeLoop", "[", 
          RowBox[{"1", ",", "\<\"b\"\>"}], "]"}], ",", 
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"4", ",", "3"}], "}"}], ",", "\<\"a\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"3", ",", "10"}], "}"}], ",", "\<\"c\"\>"}], "]"}]}], 
      "}"}]], "Output",
  CellTags->"enfold"]
}, Closed]],

Cell["construct the graphic elements for the arrows:", "Text",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"pathelements", "=", 
        RowBox[{"patharrows", "/.", "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
                    RowBox[{"RGBColor", "[", 
                      RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
                    RowBox[{"Line", "@", 
                      RowBox[{"ShrinkSeg", "[", 
                        RowBox[{
                          RowBox[{"ij", "/.", "ptrules"}], ",", ".8"}], 
                        "]"}]}]}], "}"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"ArrowJump", "[", 
                  RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                      RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
                    RowBox[{"Line", "@", 
                      RowBox[{"ShrinkSeg", "[", 
                        RowBox[{
                          RowBox[{"ij", "/.", "ptrules"}], ",", ".8"}], 
                        "]"}]}]}], "}"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"TNodeLoop", "[", 
                  RowBox[{"i_", ",", "a_"}], "]"}], ":>", 
                RowBox[{"Circle", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"i", "/.", "ptrules"}], ")"}], " ", "+", 
                      RowBox[{"{", 
                        RowBox[{".1", ",", "0"}], "}"}]}], ",", ".1"}], 
                  "]"}]}]}], "}"}]}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["print patharrows", "Subsubsection"],

Cell["Here are the arrows of our chosen path:", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[BoxData["patharrows"], "Input",
  Evaluatable->False,
  CellTags->"calc"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "10"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",",
         
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"10", ",", "9"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",",
         
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",", 
        
        RowBox[{"TNodeLoop", "[", 
          RowBox[{"1", ",", "\<\"e\"\>"}], "]"}], ",", 
        RowBox[{"TNodeLoop", "[", 
          RowBox[{"1", ",", "\<\"b\"\>"}], "]"}], ",", 
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"4", ",", "3"}], "}"}], ",", "\<\"a\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"3", ",", "10"}], "}"}], ",", "\<\"c\"\>"}], "]"}]}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["animation along path", "Subsubsection",
  AnimationDisplayTime->0.2197],

Cell[CellGroupData[{

Cell["constr", "SmallText",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"Show", "[", 
            RowBox[{
              RowBox[{"Graphics", "[", 
                RowBox[{"{", 
                  RowBox[{"nodes2D", ",", "treearrs2D", ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"Take", "[", 
                          RowBox[{"pathelements", ",", "i"}], "]"}], ",", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
                            RowBox[{
                              RowBox[{"pathelements", "[", 
                                RowBox[{"[", "i", "]"}], "]"}], "/.", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{
                                    RowBox[{"{", 
                                      RowBox[{"_", ",", 
                                        RowBox[{"Line", "[", 
                                        RowBox[{"{", 
                                        RowBox[{"_", ",", "p_"}], "}"}], 
                                        "]"}]}], "}"}], "|", 
                                    RowBox[{"Circle", "[", 
                                      RowBox[{"p_", ",", "_"}], "]"}]}], 
                                  "\[Rule]", 
                                  RowBox[{"Point", "[", "p", "]"}]}], 
                                "}"}]}]}], "}"}]}], "}"}]}], "}"}], "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"PlotRange", "\[Rule]", "treerange"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{"i", ",", 
              RowBox[{"Length", "[", "aword", "]"}]}], "}"}]}], "]"}], 
      ";"}]], "Input",
  Evaluatable->False,
  AnimationDisplayTime->0.482681,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell["This is an animated tour along the path:", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
.06214 .33763 m
.55928 .56653 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.371293,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000egoo00<007oo00003Goo000bOol3003LOol2000=Ool002io
o`@00>1oo`03001oogoo00]oo`00:goo0`00lWoo000WOol4003eOol002Aoo`<00?Uoo`0087oo1000
o7oo000MOol3003oOol1Ool001Uoo`@00?moo`Aoo`005Goo1000ogoo27oo000BOol3003oOol<Ool0
00ioo`@00?moo`moo`002goo0`00ogoo4goo00000`00Oomoo`06Ool2003oOolFOol00?moob5oo`00
ogoo8Goo003oOolQOol000Uoo`@00?mooaAoo`003Goo1@00ogoo3goo0009Ool20007Ool6003oOol9
Ool000]oo`8000]oo`D00?moo`Aoo`003Goo0P0000=oo`?P0n0010?P1goo1P00oGoo000?Ool00`00
0n03h0060n0;Ool5003hOol0011oo`X3h0ioo`H00?9oo`0047oo3@?P4Goo1@00kGoo000@Ool?0n0D
Ool6003WOol0019oo`l3h1Qoo`D001Uoo`<00<Ioo`0057oo3`?P6goo1P004Woo00D007ooOomoo`00
0<Eoo`005Woo3`?P7goo1@003Goo00<007ooOol0agoo000IOol>0n0ROol60007Ool01@00Oomoogoo
0000Wgoo0P0017oo0`007Goo000KOol>0n0VOol50003Ool3002ROol01000Oomoo`000goo00<007oo
Ool06Woo000MOol?0n0XOol6002SOol00`00Oomoo`03Ool00`00Oomoo`0JOol001moo`l3h2aoo`H0
09aoo`<000Aoo`03001oogoo01Yoo`008Goo3`?P<7oo1@00TWoo1@000Woo1@007Goo000SOol?0n0c
Ool60027Ool50006Ool00`00Ool0000POol002Eoo`l3h3Moo`D006Moo`<001=oo`D000Yoo`03001o
ogoo00D001aoo`00:7oo3P?P>Woo1P00H7oo00D007ooOomoo`0000eoo`D000ioo`03001oogoo029o
o`00:Woo3`?P?Goo1@00Fgoo00<007ooOol02goo1000>7oo000/Ool?0n10Ool6001EOol01@00Oomo
ogoo000017oo1@00?7oo000^Ool?0n14Ool5001AOol80011Ool0031oo`l3h4Moo`H004Uoo`D004Io
o`00<Woo3`?PBgoo1@00?goo1@00Bgoo000eOol>0n1>Ool6000?Ool00`00Oomoo`0SOol4001@Ool0
03Moo`h3h59oo`D000Yoo`03001oogoo01ioo`D005Aoo`00>Goo3`?PE7oo1P001Goo00<007ooOol0
67oo1@00FGoo000kOol?0n1HOol500000goo001oo`06Ool2000;Ool5001NOol003eoo`l3h5]oo`<0
00Qoo`03001oogoo00=oo`D006=oo`00?goo3`?PFWoo00<007ooOol027oo00<007ooOol00P00J7oo
0011Ool?0n1GOol00`00Oomoo`06Ool4001/Ool004Aoo`h3h5Aoo`03001oogoo00Ioo`05001oogoo
Ool00002Ool4001VOol004Ioo`h3h5]oo`05001oogooOol00006Ool5001QOol004Qoo`l3h003Ool0
0000008005Aoo`<000aoo`D001Aoo`<004Eoo`00BWoo3`?P00=oo`00Ool0J7oo1@003Woo00<007oo
Ool0AWoo001<Ool?0n1^Ool50009Ool50014Ool004ioo`l3h75oo`D000Aoo`05001oogooOol00014
Ool0051oo`l3h7Aoo`P004Eoo`00Dgoo3P?PMgoo1P00@Woo001EOol?0n1jOol5000mOol005Moo`l3
h7eoo`D003Qoo`00FGoo3`?PP7oo1@003Woo00<007ooOol08Woo001KOol?0n23Ool50009Ool00`00
Oomoo`0ROol005eoo`l3h8Ioo`D000Eoo`03001oogoo025oo`00H7oo3P?PRGoo1@0000Aoo`00Oomo
o`<001eoo`00HWoo3P?PS7oo10000goo00<007ooOol06Woo001TOol?0n29Ool01000Oomoo`000goo
00<007ooOol06Woo001VOol?0n26Ool00`00Oomoo`02Ool3000MOol006Qoo`l3h8=oo`03001oogoo
009oo`05001oogooOol0000LOol006Yoo`l3h8Ioo`05001oogooOol0000LOol006aoo`l3h8Eoo`<0
01eoo`00Kgoo3P?PXgoo001aOol?0n2POol007=oo`l3h9ioo`00MGoo3`?PW7oo001gOol?0n2JOol0
07Uoo`l3h9Qoo`00O7oo3P?PUWoo001nOol>0n2DOol0081oo`l3h95oo`00PWoo3`?PSgoo0024Ool?
0n2=Ool008Ioo`l3h8]oo`00R7oo3`?PRGoo002;Ool>0n27Ool008eoo`h3h8Eoo`00Sgoo3`?PPWoo
002AOol?0n20Ool009=oo`l3h7ioo`00UGoo3P?POGoo002GOol<0n04Ool00`00Oomoo`1fOol009Yo
o`T3h0Aoo`03001oogoo07Ioo`00W7oo1`?P0P000goo00<007ooOol0MGoo002NOol50n02Ool20000
0goo001oo`1fOol00:Moo`8002aoo`<004Qoo`00Z7oo0P00:Woo00D007ooOomoo`0001aoo`03001o
ogoo02Qoo`00YWoo0P001Goo0`0017oo0P007Woo00<007ooOol07Woo00<007ooOol00Woo00<007oo
Ool08goo002UOol00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`007Goo00D007ooOomoo`00
01eoo`05001oogooOol0000UOol00:ioo`03001oogoo009oo`04001oogoo000NOol3000OOol01@00
Oomoogoo000097oo002^Ool00`00Oomoo`02Ool00`00Ool000130002Ool00`00Oomoo`0ROol00:io
o`03001oogoo009oo`04001oogoo0010Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00:eoo`8000Ao
o`04001oogoo000oOol00`00Ool00003Ool00`00Oomoo`0QOol00:ioo`03001oogoo00=oo`8003mo
o`03001oogoo00D002=oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
0 g
.03 w
.62142 .44064 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000egoo00<007oo00003Goo000bOol3003LOol2000=Ool002io
o`@00>1oo`03001oogoo00]oo`00:goo0`00lWoo000WOol4003eOol002Aoo`<00?Uoo`0087oo1000
o7oo000MOol3003oOol1Ool001Uoo`@00?moo`Aoo`005Goo1000ogoo27oo000BOol3003oOol<Ool0
00ioo`@00?moo`moo`002goo0`00ogoo4goo00000`00Oomoo`06Ool2003oOolFOol00?moob5oo`00
ogoo8Goo003oOolQOol000Uoo`@00?mooaAoo`003Goo1@00ogoo3goo0009Ool20007Ool6003oOol9
Ool000]oo`8000]oo`D00?moo`Aoo`003Goo0P0000=oo`?P0n0010?P1goo1P00oGoo000?Ool00`00
0n03h0060n0;Ool5003hOol0011oo`X3h0ioo`H00?9oo`0047oo3@?P4Goo1@00kGoo000@Ool?0n0D
Ool6003WOol0019oo`l3h1Qoo`D001Uoo`<00<Ioo`0057oo3`?P6goo1P004Woo00D007ooOomoo`00
0<Eoo`005Woo3`?P7goo1@003Goo00<007ooOol0agoo000IOol>0n0ROol60007Ool01@00Oomoogoo
0000Wgoo0P0017oo0`007Goo000KOol>0n0VOol50003Ool3002ROol01000Oomoo`000goo00<007oo
Ool06Woo000MOol?0n0XOol6002SOol00`00Oomoo`03Ool00`00Oomoo`0JOol001moo`l3h2aoo`H0
09aoo`<000Aoo`03001oogoo01Yoo`008Goo3`?P<7oo1@00TWoo1@000Woo1@007Goo000SOol?0n0c
Ool60027Ool50006Ool00`00Ool0000POol002Eoo`l3h3Moo`D006Moo`<001=oo`D000Yoo`03001o
ogoo00D001aoo`00:7oo3P?P>Woo1P00H7oo00D007ooOomoo`0000eoo`D000ioo`03001oogoo029o
o`00:Woo3`?P?Goo1@00Fgoo00<007ooOol02goo1000>7oo000/Ool?0n10Ool6001EOol01@00Oomo
ogoo000017oo1@00?7oo000^Ool?0n14Ool5001AOol80011Ool0031oo`l3h4Moo`H004Uoo`D004Io
o`00<Woo3`?PBgoo1@00?goo1@00Bgoo000eOol>0n1>Ool6000?Ool00`00Oomoo`0SOol4001@Ool0
03Moo`h3h59oo`D000Yoo`03001oogoo01ioo`D005Aoo`00>Goo3`?PE7oo1P001Goo00<007ooOol0
67oo1@00FGoo000kOol?0n1HOol500000goo001oo`06Ool2000;Ool5001NOol003eoo`l3h5]oo`<0
00Qoo`03001oogoo00=oo`D006=oo`00?goo3`?PFWoo00<007ooOol027oo00<007ooOol00P00J7oo
0011Ool?0n1GOol00`00Oomoo`06Ool4001/Ool004Aoo`h3h5Aoo`03001oogoo00Ioo`D0009oo`@0
06Ioo`00AWoo3P?PFgoo1P001Goo1@00HGoo0018Ool?0n000goo00000002001BOol80009Ool5000D
Ool30015Ool004Yoo`l3h003Ool007oo059oo`P000ioo`D000ioo`03001oogoo04Ioo`00C7oo3`?P
Dgoo20004goo1@002Goo1@00A7oo001>Ool?0n1AOol8000HOol50004Ool01@00Oomoogoo0000A7oo
001@Ool?0n1@Ool6000NOol80015Ool005=oo`h3h4moo`@002Aoo`H0049oo`00EGoo3`?PCWoo00=l
07ooOol0:Goo1@00?Goo001GOol?0n1<Ool00g`0Oomoo`0^Ool5000hOol005Uoo`l3h4Yoo`03O01o
ogoo03=oo`D000ioo`03001oogoo029oo`00Fgoo3`?PB7oo00=l07ooOol0>7oo1@002Goo00<007oo
Ool08Woo001MOol?0n16Ool00g`0Oomoo`0mOol50005Ool00`00Oomoo`0QOol0061oo`h3h4Aoo`03
O01oogoo049oo`D00004Ool007ooOol3000MOol0069oo`h3h49oo`03O01oogoo04Moo`@000=oo`03
001oogoo01Yoo`00I7oo3`?P?goo00=l07ooOol0Agoo00@007ooOol000=oo`03001oogoo01Yoo`00
IWoo3`?P?Goo00=l07ooOol0AWoo00<007ooOol00Woo0`007Goo001XOol?0n0kOol00g`0Oomoo`15
Ool00`00Oomoo`02Ool01@00Oomoogoo000077oo001ZOol?0n0iOol00g`0Oomoo`1:Ool01@00Oomo
ogoo000077oo001/Ool?0n0gOol00g`0Oomoo`1;Ool3000MOol006moo`h3h3Eoo`03O01oogoo06]o
o`00LGoo3`?P<Woo00=l07ooOol0Jgoo001cOol?0n0`Ool00g`0Oomoo`1[Ool007Eoo`l3h2ioo`03
O01oogoo06]oo`00Mgoo3`?P;7oo00=l07ooOol0Jgoo001iOol?0n0ZOol00g`0Oomoo`1[Ool007ao
o`h3h2Qoo`03O01oogoo06]oo`00OWoo3P?P9Woo00=l07ooOol0Jgoo0020Ool?0n0SOol00g`0Oomo
o`1[Ool0089oo`l3h25oo`03O01oogoo06]oo`00Q7oo3`?P7goo00=l07ooOol0Jgoo0026Ool?0n0M
Ool00g`0Oomoo`1[Ool008Qoo`l3h1]oo`03O01oogoo06]oo`00Rgoo3P?P6Goo00=l07ooOol0Jgoo
002=Ool>0n0GOol00g`0Oomoo`1[Ool008moo`l3h1Aoo`03O01oogoo06]oo`00TGoo3`?P4Woo00=l
07ooOol0Jgoo002COol?0n0@Ool00g`0Oomoo`1[Ool009Eoo`h3h0moo`03O01oogoo06]oo`00Ugoo
30?P17oo00<007ooOol027oo00=l07ooOol0Jgoo002JOol90n04Ool00`00Oomoo`08Ool00g`0Oomo
o`1[Ool009aoo`L3h08000=oo`03001oogoo00Moo`03O01oogoo06]oo`00WWoo1@?P0Woo0P0000=o
o`00Ool027oo00=l07ooOol0Jgoo002WOol20009Ool00g`0Oomoo`0POol30018Ool00:Qoo`8002Yo
o`05001oogooOol0000LOol00`00Oomoo`0XOol00:Ioo`8000Eoo`<000Aoo`8001ioo`03001oogoo
01ioo`03001oogoo009oo`03001oogoo02=oo`00YGoo00<007ooOol01Woo00<007ooOol00Woo00@0
07ooOol001eoo`05001oogooOol0000MOol01@00Oomoogoo00009Goo002^Ool00`00Oomoo`02Ool0
1000Oomoo`007Woo0`007goo00D007ooOomoo`0002Aoo`00[Woo00<007ooOol00Woo00<007oo0000
@`000Woo00<007ooOol08Woo002^Ool00`00Oomoo`02Ool01000Oomoo`00@7oo00<007ooOol00Woo
00<007ooOol08Goo002]Ool20004Ool01000Oomoo`00?goo00<007oo00000goo00<007ooOol08Goo
002^Ool00`00Oomoo`03Ool2000oOol00`00Oomoo`05000SOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
0 g
.03 w
.92357 .26896 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000cWoo10001Goo00<007oo00003Goo000bOol3003AOol60005
Ool2000=Ool002ioo`@00==oo`P000Eoo`03001oogoo00]oo`00:goo0`00egoo20004goo000WOol4
003JOol8000COol002Aoo`<00=ioo`P001=oo`0087oo1000ggoo0W`000=oo`000000100057oo000M
Ool3003QOol2O004Ool4000EOol001Uoo`@00>9oo`9l01moo`005Goo1000i7oo0W`08Goo000BOol3
003VOol2O00SOol000ioo`@00>Moo`9l02Eoo`002goo0`00jGoo0W`09goo00000`00Oomoo`06Ool2
003ZOol2O00YOol00?=oo`9l02]oo`00lGoo0W`0;Goo003_Ool2O00_Ool000Uoo`@00>1oo`9l035o
o`003Goo1@00fGoo0W`0<goo0009Ool20007Ool6003AOol2O00eOol000]oo`8000]oo`D00<Yoo`9l
03Moo`003Goo0P0000=oo`?P0n0010?P1goo1P00`Woo0W`0>Goo000?Ool00`000n03h0060n0;Ool5
002kOol2O00kOol0011oo`X3h0ioo`H00;=oo`9l03eoo`0047oo3@?P4Goo1@00[Goo00=l07ooOol0
?Goo000@Ool?0n0DOol6002UOol2O010Ool0019oo`l3h1Qoo`D001Uoo`<0089oo`9l049oo`0057oo
3`?P6goo1P004Woo00D007ooOomoo`0007moo`9l04Aoo`005Woo3`?P7goo1@003Goo00<007ooOol0
Ogoo0W`0AWoo000IOol>0n0ROol60007Ool01@00Oomoogoo0000Ngoo0W`08Woo0P0017oo0`007Goo
000KOol>0n0VOol50003Ool3001jOol2O00VOol01000Oomoo`000goo00<007ooOol06Woo000MOol?
0n0XOol6001hOol2O00YOol00`00Oomoo`03Ool00`00Oomoo`0JOol001moo`l3h2aoo`H0071oo`9l
02Yoo`<000Aoo`03001oogoo01Yoo`008Goo3`?P<7oo1@00JGoo0W`09goo1@000Woo1@007Goo000S
Ool?0n0cOol6001QOol2O00TOol50006Ool00`00Ool0000POol002Eoo`l3h3Moo`D005Yoo`9l00]o
o`<001=oo`D000Yoo`03001oogoo00D001aoo`00:7oo3P?P>Woo1P00DWoo0W`037oo00D007ooOomo
o`0000eoo`D000ioo`03001oogoo029oo`00:Woo3`?P?Goo1@00Bgoo0W`03Woo00<007ooOol02goo
1000>7oo000/Ool?0n10Ool60013Ool2O00@Ool01@00Oomoogoo000017oo1@00?7oo000^Ool?0n14
Ool5000lOol2O00COol80011Ool0031oo`l3h4Moo`H003Aoo`9l01=oo`D004Ioo`00<Woo3`?PBgoo
1@00;Goo0W`047oo1@00Bgoo000eOol>0n1>Ool6000?Ool00`00Oomoo`0COol2O00>Ool4001@Ool0
03Moo`h3h59oo`D000Yoo`03001oogoo019oo`03O01oogoo00Uoo`D005Aoo`00>Goo3`?PE7oo1P00
1Goo00<007ooOol067oo1@00FGoo000kOol?0n1HOol500000goo001oo`06Ool2000;Ool5001NOol0
03eoo`l3h5]oo`<000Qoo`03001oogoo00=oo`D006=oo`00?goo3`?PFWoo00<007ooOol027oo00<0
07ooOol00P00J7oo0011Ool?0n1GOol00`00Oomoo`06Ool4001/Ool004Aoo`h3h5Aoo`03001oogoo
00Ioo`05001oogooOol00002Ool4001VOol004Ioo`h3h5]oo`05001oogooOol00006Ool5001QOol0
04Qoo`l3h003Ool00000008005Aoo`<000aoo`D001Aoo`<004Eoo`00BWoo3`?P00=oo`00Ool0J7oo
1@003Woo00<007ooOol0AWoo001<Ool?0n1GOol00g`0Oomoo`0DOol50009Ool50014Ool004ioo`l3
h5Eoo`03O01oogoo01Uoo`D000Aoo`05001oogooOol00014Ool0051oo`l3h5=oo`03O01oogoo01io
o`P004Eoo`00Dgoo3P?PDGoo00=l07ooOol08goo1P00@Woo001EOol?0n1>Ool00g`0Oomoo`0YOol5
000mOol005Moo`l3h4aoo`03O01oogoo02ioo`D003Qoo`00FGoo3`?PBWoo00=l07ooOol0<goo1@00
3Woo00<007ooOol08Woo001KOol?0n18Ool00g`0Oomoo`0hOol50009Ool00`00Oomoo`0ROol005eo
o`l3h4Ioo`03O01oogoo03eoo`D000Eoo`03001oogoo025oo`00H7oo3P?PA7oo00=l07ooOol0@Woo
1@0000Aoo`00Oomoo`<001eoo`00HWoo3P?P@Woo00=l07ooOol0Agoo10000goo00<007ooOol06Woo
001TOol?0n0oOol00g`0Oomoo`17Ool01000Oomoo`000goo00<007ooOol06Woo001VOol?0n0mOol0
0g`0Oomoo`16Ool00`00Oomoo`02Ool3000MOol006Qoo`l3h3]oo`03O01oogoo04Eoo`03001oogoo
009oo`05001oogooOol0000LOol006Yoo`l3h3Uoo`03O01oogoo04Yoo`05001oogooOol0000LOol0
06aoo`l3h3Moo`03O01oogoo04]oo`<001eoo`00Kgoo3P?P=Goo00=l07ooOol0Jgoo001aOol?0n0b
Ool00g`0Oomoo`1[Ool007=oo`l3h31oo`03O01oogoo06]oo`00MGoo3`?P;Woo00=l07ooOol0Jgoo
001gOol?0n0/Ool00g`0Oomoo`1[Ool007Uoo`l3h2Yoo`03O01oogoo06]oo`00O7oo3P?P:7oo00=l
07ooOol0Jgoo001nOol>0n0VOol00g`0Oomoo`1[Ool0081oo`l3h2=oo`03O01oogoo06]oo`00PWoo
3`?P8Goo00=l07ooOol0Jgoo0024Ool?0n0OOol00g`0Oomoo`1[Ool008Ioo`l3h1eoo`03O01oogoo
06]oo`00R7oo3`?P6goo00=l07ooOol0Jgoo002;Ool>0n0IOol00g`0Oomoo`1[Ool008eoo`h3h1Mo
o`03O01oogoo06]oo`00Sgoo3`?P57oo00=l07ooOol0Jgoo002AOol?0n0BOol00g`0Oomoo`1[Ool0
09=oo`l3h11oo`03O01oogoo06]oo`00UGoo3P?P3goo00=l07ooOol0Jgoo002GOol<0n04Ool00`00
Oomoo`08Ool00g`0Oomoo`1[Ool009Yoo`T3h0Aoo`03001oogoo00Qoo`03O01oogoo06]oo`00W7oo
1`?P0P000goo00<007ooOol01goo00=l07ooOol0Jgoo002NOol50n02Ool200000goo001oo`08Ool0
0g`0Oomoo`1[Ool00:Moo`8000Uoo`03O01oogoo021oo`<004Qoo`00Z7oo0P00:Woo00D007ooOomo
o`0001aoo`03001oogoo02Qoo`00YWoo0P001Goo0`0017oo0P007Woo00<007ooOol07Woo00<007oo
Ool00Woo00<007ooOol08goo002UOol00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`007Goo
00D007ooOomoo`0001eoo`05001oogooOol0000UOol00:ioo`03001oogoo009oo`04001oogoo000N
Ool3000OOol01@00Oomoogoo000097oo002^Ool00`00Oomoo`02Ool00`00Ool000130002Ool00`00
Oomoo`0ROol00:ioo`03001oogoo009oo`04001oogoo0010Ool00`00Oomoo`02Ool00`00Oomoo`0Q
Ool00:eoo`8000Aoo`04001oogoo000oOol00`00Ool00003Ool00`00Oomoo`0QOol00:ioo`03001o
ogoo00=oo`8003moo`03001oogoo00D002=oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
.03 w
.09571 .30329 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000]Goo2G`06Goo00<007oo00003Goo000bOol3002XOolAO00S
Ool2000=Ool002ioo`@009Yooa5l03Eoo`03001oogoo00]oo`00:goo0`00SGoo4G`0E7oo000WOol4
001oOolAO01<Ool2O00GOol002Aoo`<0079ooa5l05]oo`9l01Uoo`0087oo1000I7oo4G`0JWoo0W`0
6goo000MOol3001HOol@O01iOol2O00MOol001Uoo`@004Yooa5l08Moo`9l01moo`005Goo1000?Goo
4G`0UWoo0W`08Goo000BOol30005Ool4000WOolAO02UOol2O00SOol000ioo`@000Moo`H001Eooa5l
0;Aoo`9l02Eoo`002goo0`002Woo20000goo4G`0`goo0W`09goo00000`00Oomoo`06Ool2000=Ool8
0003O03BOol2O00YOol001Qoo`P00==oo`9l02]oo`0067oo2000dGoo0W`0;Goo000IOol6003@Ool2
O00_Ool000Uoo`@000eoo`@00<moo`9l035oo`003Goo1@00fGoo0W`0<goo0009Ool20007Ool6003A
Ool2O00eOol000]oo`8000]oo`D00<Yoo`9l03Moo`003Goo0P0000=oo`?P0n0010?P1goo1P00`Woo
0W`0>Goo000?Ool00`000n03h0060n0;Ool5002kOol2O00kOol0011oo`X3h0ioo`H00;=oo`9l03eo
o`0047oo3@?P4Goo1@00[Goo00=l07ooOol0?Goo000@Ool?0n0DOol6002UOol2O010Ool0019oo`l3
h1Qoo`D001Uoo`<0089oo`9l049oo`0057oo3`?P6goo1P004Woo00D007ooOomoo`0007moo`9l04Ao
o`005Woo3`?P7goo1@003Goo00<007ooOol0Ogoo0W`0AWoo000IOol>0n0ROol60007Ool01@00Oomo
ogoo0000Ngoo0W`08Woo0P0017oo0`007Goo000KOol>0n0VOol50003Ool3001jOol2O00VOol01000
Oomoo`000goo00<007ooOol06Woo000MOol?0n0XOol6001hOol2O00YOol00`00Oomoo`03Ool00`00
Oomoo`0JOol001moo`l3h2aoo`H0071oo`9l02Yoo`<000Aoo`03001oogoo01Yoo`008Goo3`?P<7oo
1@00JGoo0W`09goo1@000Woo1@007Goo000SOol?0n0cOol6001QOol2O00TOol50006Ool00`00Ool0
000POol002Eoo`l3h3Moo`D005Yoo`9l00]oo`<001=oo`D000Yoo`03001oogoo00D001aoo`00:7oo
3P?P>Woo1P00DWoo0W`037oo00D007ooOomoo`0000eoo`D000ioo`03001oogoo029oo`00:Woo3`?P
?Goo1@00Bgoo0W`03Woo00<007ooOol02goo1000>7oo000/Ool?0n10Ool60013Ool2O00@Ool01@00
Oomoogoo000017oo1@00?7oo000^Ool?0n14Ool5000lOol2O00COol80011Ool0031oo`l3h4Moo`H0
03Aoo`9l01=oo`D004Ioo`00<Woo3`?PBgoo1@00;Goo0W`047oo1@00Bgoo000eOol>0n1>Ool6000?
Ool00`00Oomoo`0COol2O00>Ool4001@Ool003Moo`h3h59oo`D000Yoo`03001oogoo019oo`03O01o
ogoo00Uoo`D005Aoo`00>Goo3`?PE7oo1P001Goo00<007ooOol067oo1@00FGoo000kOol?0n1HOol5
00000goo001oo`06Ool2000;Ool5001NOol003eoo`l3h5]oo`<000Qoo`03001oogoo00=oo`D006=o
o`00?goo3`?PFWoo00<007ooOol027oo00<007ooOol00P00J7oo0011Ool?0n1GOol00`00Oomoo`06
Ool4001/Ool004Aoo`h3h5Aoo`03001oogoo00Ioo`05001oogooOol00002Ool4001VOol004Ioo`h3
h5]oo`05001oogooOol00006Ool5001QOol004Qoo`l3h003Ool00000008005Aoo`<000aoo`D001Ao
o`<004Eoo`00BWoo3`?P00=oo`00Ool0J7oo1@003Woo00<007ooOol0AWoo001<Ool?0n1GOol00g`0
Oomoo`0DOol50009Ool50014Ool004ioo`l3h5Eoo`03O01oogoo01Uoo`D000Aoo`05001oogooOol0
0014Ool0051oo`l3h5=oo`03O01oogoo01ioo`P004Eoo`00Dgoo3P?PDGoo00=l07ooOol08goo1P00
@Woo001EOol?0n1>Ool00g`0Oomoo`0YOol5000mOol005Moo`l3h4aoo`03O01oogoo02ioo`D003Qo
o`00FGoo3`?PBWoo00=l07ooOol0<goo1@003Woo00<007ooOol08Woo001KOol?0n18Ool00g`0Oomo
o`0hOol50009Ool00`00Oomoo`0ROol005eoo`l3h4Ioo`03O01oogoo03eoo`D000Eoo`03001oogoo
025oo`00H7oo3P?PA7oo00=l07ooOol0@Woo1@0000Aoo`00Oomoo`<001eoo`00HWoo3P?P@Woo00=l
07ooOol0Agoo10000goo00<007ooOol06Woo001TOol?0n0oOol00g`0Oomoo`17Ool01000Oomoo`00
0goo00<007ooOol06Woo001VOol?0n0mOol00g`0Oomoo`16Ool00`00Oomoo`02Ool3000MOol006Qo
o`l3h3]oo`03O01oogoo04Eoo`03001oogoo009oo`05001oogooOol0000LOol006Yoo`l3h3Uoo`03
O01oogoo04Yoo`05001oogooOol0000LOol006aoo`l3h3Moo`03O01oogoo04]oo`<001eoo`00Kgoo
3P?P=Goo00=l07ooOol0Jgoo001aOol?0n0bOol00g`0Oomoo`1[Ool007=oo`l3h31oo`03O01oogoo
06]oo`00MGoo3`?P;Woo00=l07ooOol0Jgoo001gOol?0n0/Ool00g`0Oomoo`1[Ool007Uoo`l3h2Yo
o`03O01oogoo06]oo`00O7oo3P?P:7oo00=l07ooOol0Jgoo001nOol>0n0VOol00g`0Oomoo`1[Ool0
081oo`l3h2=oo`03O01oogoo06]oo`00PWoo3`?P8Goo00=l07ooOol0Jgoo0024Ool?0n0OOol00g`0
Oomoo`1[Ool008Ioo`l3h1eoo`03O01oogoo06]oo`00R7oo3`?P6goo00=l07ooOol0Jgoo002;Ool>
0n0IOol00g`0Oomoo`1[Ool008eoo`h3h1Moo`03O01oogoo06]oo`00Sgoo3`?P57oo00=l07ooOol0
Jgoo002AOol?0n0BOol00g`0Oomoo`1[Ool009=oo`l3h11oo`03O01oogoo06]oo`00UGoo3P?P3goo
00=l07ooOol0Jgoo002GOol<0n04Ool00`00Oomoo`08Ool00g`0Oomoo`1[Ool009Yoo`T3h0Aoo`03
001oogoo00Qoo`03O01oogoo06]oo`00W7oo1`?P0P000goo00<007ooOol01goo00=l07ooOol0Jgoo
002NOol50n02Ool200000goo001oo`08Ool00g`0Oomoo`1[Ool00:Moo`8000Uoo`03O01oogoo021o
o`<004Qoo`00Z7oo0P00:Woo00D007ooOomoo`0001aoo`03001oogoo02Qoo`00YWoo0P001Goo0`00
17oo0P007Woo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08goo002UOol00`00Oomoo`06
Ool00`00Oomoo`02Ool01000Oomoo`007Goo00D007ooOomoo`0001eoo`05001oogooOol0000UOol0
0:ioo`03001oogoo009oo`04001oogoo000NOol3000OOol01@00Oomoogoo000097oo002^Ool00`00
Oomoo`02Ool00`00Ool000130002Ool00`00Oomoo`0ROol00:ioo`03001oogoo009oo`04001oogoo
0010Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00:eoo`8000Aoo`04001oogoo000oOol00`00Ool0
0003Ool00`00Oomoo`0QOol00:ioo`03001oogoo00=oo`8003moo`03001oogoo00D002=oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
.03 w
.02143 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000]Goo2G`06Goo00<007oo00003Goo000bOol3002XOolAO00S
Ool2000=Ool002ioo`@009Yooa5l03Eoo`03001oogoo00]oo`00:goo0`00SGoo4G`0E7oo000WOol4
001oOolAO01<Ool2O00GOol002Aoo`<0079ooa5l05]oo`9l01Uoo`0087oo1000I7oo4G`0JWoo0W`0
6goo000MOol3001HOol@O01iOol2O00MOol001Uoo`@004Yooa5l08Moo`9l01moo`005Goo1000?Goo
4G`0UWoo0W`08Goo000BOol3000`OolAO02UOol2O00SOol000ioo`@0029ooa5l0;Aoo`9l02Eoo`00
0goo2`005Goo4G`0`goo0W`09goo00000`00Ool00009000?Ool8O03BOol2O00YOol00003Ool00000
00L00003Ool007oo0>Ioo`9l02]oo`0000<007oo00001`000Woo00<007ooOol0hWoo0W`0;Goo0000
0`00Ool0000700000goo001oo`3ROol2O00_Ool00003Ool0000000X00>1oo`9l035oo`000goo1P00
17oo1@00fGoo0W`0<goo0004Ool400000goo00000007Ool6003AOol2O00eOol000]oo`8000]oo`D0
0<Yoo`9l03Moo`003Goo0P0000=oo`?P0n0010?P1goo1P00`Woo0W`0>Goo000?Ool00`000n03h006
0n0;Ool5002kOol2O00kOol0011oo`X3h0ioo`H00;=oo`9l03eoo`0047oo3@?P4Goo1@00[Goo00=l
07ooOol0?Goo000@Ool?0n0DOol6002UOol2O010Ool0019oo`l3h1Qoo`D001Uoo`<0089oo`9l049o
o`0057oo3`?P6goo1P004Woo00D007ooOomoo`0007moo`9l04Aoo`005Woo3`?P7goo1@003Goo00<0
07ooOol0Ogoo0W`0AWoo000IOol>0n0ROol60007Ool01@00Oomoogoo0000Ngoo0W`08Woo0P0017oo
0`007Goo000KOol>0n0VOol50003Ool3001jOol2O00VOol01000Oomoo`000goo00<007ooOol06Woo
000MOol?0n0XOol6001hOol2O00YOol00`00Oomoo`03Ool00`00Oomoo`0JOol001moo`l3h2aoo`H0
071oo`9l02Yoo`<000Aoo`03001oogoo01Yoo`008Goo3`?P<7oo1@00JGoo0W`09goo1@000Woo1@00
7Goo000SOol?0n0cOol6001QOol2O00TOol50006Ool00`00Ool0000POol002Eoo`l3h3Moo`D005Yo
o`9l00]oo`<001=oo`D000Yoo`03001oogoo00D001aoo`00:7oo3P?P>Woo1P00DWoo0W`037oo00D0
07ooOomoo`0000eoo`D000ioo`03001oogoo029oo`00:Woo3`?P?Goo1@00Bgoo0W`03Woo00<007oo
Ool02goo1000>7oo000/Ool?0n10Ool60013Ool2O00@Ool01@00Oomoogoo000017oo1@00?7oo000^
Ool?0n14Ool5000lOol2O00COol80011Ool0031oo`l3h4Moo`H003Aoo`9l01=oo`D004Ioo`00<Woo
3`?PBgoo1@00;Goo0W`047oo1@00Bgoo000eOol>0n1>Ool6000?Ool00`00Oomoo`0COol2O00>Ool4
001@Ool003Moo`h3h59oo`D000Yoo`03001oogoo019oo`03O01oogoo00Uoo`D005Aoo`00>Goo3`?P
E7oo1P001Goo00<007ooOol067oo1@00FGoo000kOol?0n1HOol500000goo001oo`06Ool2000;Ool5
001NOol003eoo`l3h5]oo`<000Qoo`03001oogoo00=oo`D006=oo`00?goo3`?PFWoo00<007ooOol0
27oo00<007ooOol00P00J7oo0011Ool?0n1GOol00`00Oomoo`06Ool4001/Ool004Aoo`h3h5Aoo`03
001oogoo00Ioo`05001oogooOol00002Ool4001VOol004Ioo`h3h5]oo`05001oogooOol00006Ool5
001QOol004Qoo`l3h003Ool00000008005Aoo`<000aoo`D001Aoo`<004Eoo`00BWoo3`?P00=oo`00
Ool0J7oo1@003Woo00<007ooOol0AWoo001<Ool?0n1GOol00g`0Oomoo`0DOol50009Ool50014Ool0
04ioo`l3h5Eoo`03O01oogoo01Uoo`D000Aoo`05001oogooOol00014Ool0051oo`l3h5=oo`03O01o
ogoo01ioo`P004Eoo`00Dgoo3P?PDGoo00=l07ooOol08goo1P00@Woo001EOol?0n1>Ool00g`0Oomo
o`0YOol5000mOol005Moo`l3h4aoo`03O01oogoo02ioo`D003Qoo`00FGoo3`?PBWoo00=l07ooOol0
<goo1@003Woo00<007ooOol08Woo001KOol?0n18Ool00g`0Oomoo`0hOol50009Ool00`00Oomoo`0R
Ool005eoo`l3h4Ioo`03O01oogoo03eoo`D000Eoo`03001oogoo025oo`00H7oo3P?PA7oo00=l07oo
Ool0@Woo1@0000Aoo`00Oomoo`<001eoo`00HWoo3P?P@Woo00=l07ooOol0Agoo10000goo00<007oo
Ool06Woo001TOol?0n0oOol00g`0Oomoo`17Ool01000Oomoo`000goo00<007ooOol06Woo001VOol?
0n0mOol00g`0Oomoo`16Ool00`00Oomoo`02Ool3000MOol006Qoo`l3h3]oo`03O01oogoo04Eoo`03
001oogoo009oo`05001oogooOol0000LOol006Yoo`l3h3Uoo`03O01oogoo04Yoo`05001oogooOol0
000LOol006aoo`l3h3Moo`03O01oogoo04]oo`<001eoo`00Kgoo3P?P=Goo00=l07ooOol0Jgoo001a
Ool?0n0bOol00g`0Oomoo`1[Ool007=oo`l3h31oo`03O01oogoo06]oo`00MGoo3`?P;Woo00=l07oo
Ool0Jgoo001gOol?0n0/Ool00g`0Oomoo`1[Ool007Uoo`l3h2Yoo`03O01oogoo06]oo`00O7oo3P?P
:7oo00=l07ooOol0Jgoo001nOol>0n0VOol00g`0Oomoo`1[Ool0081oo`l3h2=oo`03O01oogoo06]o
o`00PWoo3`?P8Goo00=l07ooOol0Jgoo0024Ool?0n0OOol00g`0Oomoo`1[Ool008Ioo`l3h1eoo`03
O01oogoo06]oo`00R7oo3`?P6goo00=l07ooOol0Jgoo002;Ool>0n0IOol00g`0Oomoo`1[Ool008eo
o`h3h1Moo`03O01oogoo06]oo`00Sgoo3`?P57oo00=l07ooOol0Jgoo002AOol?0n0BOol00g`0Oomo
o`1[Ool009=oo`l3h11oo`03O01oogoo06]oo`00UGoo3P?P3goo00=l07ooOol0Jgoo002GOol<0n04
Ool00`00Oomoo`08Ool00g`0Oomoo`1[Ool009Yoo`T3h0Aoo`03001oogoo00Qoo`03O01oogoo06]o
o`00W7oo1`?P0P000goo00<007ooOol01goo00=l07ooOol0Jgoo002NOol50n02Ool200000goo001o
o`08Ool00g`0Oomoo`1[Ool00:Moo`8000Uoo`03O01oogoo021oo`<004Qoo`00Z7oo0P00:Woo00D0
07ooOomoo`0001aoo`03001oogoo02Qoo`00YWoo0P001Goo0`0017oo0P007Woo00<007ooOol07Woo
00<007ooOol00Woo00<007ooOol08goo002UOol00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomo
o`007Goo00D007ooOomoo`0001eoo`05001oogooOol0000UOol00:ioo`03001oogoo009oo`04001o
ogoo000NOol3000OOol01@00Oomoogoo000097oo002^Ool00`00Oomoo`02Ool00`00Ool000130002
Ool00`00Oomoo`0ROol00:ioo`03001oogoo009oo`04001oogoo0010Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol00:eoo`8000Aoo`04001oogoo000oOol00`00Ool00003Ool00`00Oomoo`0QOol00:io
o`03001oogoo00=oo`8003moo`03001oogoo00D002=oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
.03 w
.02143 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000]Goo2G`06Goo00<007oo00003Goo000bOol3002XOolAO00S
Ool2000=Ool002ioo`@009Yooa5l03Eoo`03001oogoo00]oo`00:goo0`00SGoo4G`0E7oo000WOol4
001oOolAO01<Ool2O00GOol002Aoo`<0079ooa5l05]oo`9l01Uoo`0087oo1000I7oo4G`0JWoo0W`0
6goo000MOol3001HOol@O01iOol2O00MOol001Uoo`@004Yooa5l08Moo`9l01moo`005Goo1000?Goo
4G`0UWoo0W`08Goo000BOol3000`OolAO02UOol2O00SOol000ioo`@0029ooa5l0;Aoo`9l02Eoo`00
0goo2`005Goo4G`0`goo0W`09goo00000`00Ool00009000?Ool8O03BOol2O00YOol00003Ool00000
00L00003Ool007oo0>Ioo`9l02]oo`0000<007oo00001`000Woo00<007ooOol0hWoo0W`0;Goo0000
0`00Ool0000700000goo001oo`3ROol2O00_Ool00003Ool0000000X00>1oo`9l035oo`000goo1P00
17oo1@00fGoo0W`0<goo0004Ool400000goo00000007Ool6003AOol2O00eOol000]oo`8000]oo`D0
0<Yoo`9l03Moo`003Goo0P0000=oo`?P0n0010?P1goo1P00`Woo0W`0>Goo000?Ool00`000n03h006
0n0;Ool5002kOol2O00kOol0011oo`X3h0ioo`H00;=oo`9l03eoo`0047oo3@?P4Goo1@00[Goo00=l
07ooOol0?Goo000@Ool?0n0DOol6002UOol2O010Ool0019oo`l3h1Qoo`D001Uoo`<0089oo`9l049o
o`0057oo3`?P6goo1P004Woo00D007ooOomoo`0007moo`9l04Aoo`005Woo3`?P7goo1@003Goo00<0
07ooOol0Ogoo0W`0AWoo000IOol>0n0ROol60007Ool01@00Oomoogoo0000Ngoo0W`08Woo0P0017oo
0`007Goo000KOol>0n0VOol50003Ool3001jOol2O00VOol01000Oomoo`000goo00<007ooOol06Woo
000MOol?0n0XOol6001hOol2O00YOol00`00Oomoo`03Ool00`00Oomoo`0JOol001moo`l3h2aoo`H0
071oo`9l02Yoo`<000Aoo`03001oogoo01Yoo`008Goo3`?P<7oo1@00JGoo0W`09goo1@000Woo1@00
7Goo000SOol?0n0cOol6001QOol2O00TOol50006Ool00`00Ool0000POol002Eoo`l3h3Moo`D005Yo
o`9l00]oo`<001=oo`D000Yoo`03001oogoo00D001aoo`00:7oo3P?P>Woo1P00DWoo0W`037oo00D0
07ooOomoo`0000eoo`D000ioo`03001oogoo029oo`00:Woo3`?P?Goo1@00Bgoo0W`03Woo00<007oo
Ool02goo1000>7oo000/Ool?0n10Ool60013Ool2O00@Ool01@00Oomoogoo000017oo1@00?7oo000^
Ool?0n14Ool5000lOol2O00COol80011Ool0031oo`l3h4Moo`H003Aoo`9l01=oo`D004Ioo`00<Woo
3`?PBgoo1@00;Goo0W`047oo1@00Bgoo000eOol>0n1>Ool6000?Ool00`00Oomoo`0COol2O00>Ool4
001@Ool003Moo`h3h59oo`D000Yoo`03001oogoo019oo`03O01oogoo00Uoo`D005Aoo`00>Goo3`?P
E7oo1P001Goo00<007ooOol067oo1@00FGoo000kOol?0n1HOol500000goo001oo`06Ool2000;Ool5
001NOol003eoo`l3h5]oo`<000Qoo`03001oogoo00=oo`D006=oo`00?goo3`?PFWoo00<007ooOol0
27oo00<007ooOol00P00J7oo0011Ool?0n1GOol00`00Oomoo`06Ool4001/Ool004Aoo`h3h5Aoo`03
001oogoo00Ioo`05001oogooOol00002Ool4001VOol004Ioo`h3h5]oo`05001oogooOol00006Ool5
001QOol004Qoo`l3h003Ool00000008005Aoo`<000aoo`D001Aoo`<004Eoo`00BWoo3`?P00=oo`00
Ool0J7oo1@003Woo00<007ooOol0AWoo001<Ool?0n1GOol00g`0Oomoo`0DOol50009Ool50014Ool0
04ioo`l3h5Eoo`03O01oogoo01Uoo`D000Aoo`05001oogooOol00014Ool0051oo`l3h5=oo`03O01o
ogoo01ioo`P004Eoo`00Dgoo3P?PDGoo00=l07ooOol08goo1P00@Woo001EOol?0n1>Ool00g`0Oomo
o`0YOol5000mOol005Moo`l3h4aoo`03O01oogoo02ioo`D003Qoo`00FGoo3`?PBWoo00=l07ooOol0
<goo1@003Woo00<007ooOol08Woo001KOol?0n18Ool00g`0Oomoo`0hOol50009Ool00`00Oomoo`0R
Ool005eoo`l3h4Ioo`03O01oogoo03eoo`D000Eoo`03001oogoo025oo`00H7oo3P?PA7oo00=l07oo
Ool0@Woo1@0000Aoo`00Oomoo`<001eoo`00HWoo3P?P@Woo00=l07ooOol0Agoo10000goo00<007oo
Ool06Woo001TOol?0n0oOol00g`0Oomoo`17Ool01000Oomoo`000goo00<007ooOol06Woo001VOol?
0n0mOol00g`0Oomoo`16Ool00`00Oomoo`02Ool3000MOol006Qoo`l3h3]oo`03O01oogoo04Eoo`03
001oogoo009oo`05001oogooOol0000LOol006Yoo`l3h3Uoo`03O01oogoo04Yoo`05001oogooOol0
000LOol006aoo`l3h3Moo`03O01oogoo04]oo`<001eoo`00Kgoo3P?P=Goo00=l07ooOol0Jgoo001a
Ool?0n0bOol00g`0Oomoo`1[Ool007=oo`l3h31oo`03O01oogoo06]oo`00MGoo3`?P;Woo00=l07oo
Ool0Jgoo001gOol?0n0/Ool00g`0Oomoo`1[Ool007Uoo`l3h2Yoo`03O01oogoo06]oo`00O7oo3P?P
:7oo00=l07ooOol0Jgoo001nOol>0n0VOol00g`0Oomoo`1[Ool0081oo`l3h2=oo`03O01oogoo06]o
o`00PWoo3`?P8Goo00=l07ooOol0Jgoo0024Ool?0n0OOol00g`0Oomoo`1[Ool008Ioo`l3h1eoo`03
O01oogoo06]oo`00R7oo3`?P6goo00=l07ooOol0Jgoo002;Ool>0n0IOol00g`0Oomoo`1[Ool008eo
o`h3h1Moo`03O01oogoo06]oo`00Sgoo3`?P57oo00=l07ooOol0Jgoo002AOol?0n0BOol00g`0Oomo
o`1[Ool009=oo`l3h11oo`03O01oogoo06]oo`00UGoo3P?P3goo00=l07ooOol0Jgoo002GOol<0n04
Ool00`00Oomoo`08Ool00g`0Oomoo`1[Ool009Yoo`T3h0Aoo`03001oogoo00Qoo`03O01oogoo06]o
o`00W7oo1`?P0P000goo00<007ooOol01goo00=l07ooOol0Jgoo002NOol50n02Ool200000goo001o
o`08Ool00g`0Oomoo`1[Ool00:Moo`8000Uoo`03O01oogoo021oo`<004Qoo`00Z7oo0P00:Woo00D0
07ooOomoo`0001aoo`03001oogoo02Qoo`00YWoo0P001Goo0`0017oo0P007Woo00<007ooOol07Woo
00<007ooOol00Woo00<007ooOol08goo002UOol00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomo
o`007Goo00D007ooOomoo`0001eoo`05001oogooOol0000UOol00:ioo`03001oogoo009oo`04001o
ogoo000NOol3000OOol01@00Oomoogoo000097oo002^Ool00`00Oomoo`02Ool00`00Ool000130002
Ool00`00Oomoo`0ROol00:ioo`03001oogoo009oo`04001oogoo0010Ool00`00Oomoo`02Ool00`00
Oomoo`0QOol00:eoo`8000Aoo`04001oogoo000oOol00`00Ool00003Ool00`00Oomoo`0QOol00:io
o`03001oogoo00=oo`8003moo`03001oogoo00D002=oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
0 1 0 r
.02 w
.06214 .32046 m
.55928 .41202 L
s
.06214 .32046 m
.55928 .41202 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000]Goo2G`06Goo00<007oo00003Goo000bOol3002XOolAO00S
Ool2000=Ool002ioo`@009Yooa5l03Eoo`03001oogoo00]oo`00:goo0`00SGoo4G`0E7oo000WOol4
001oOolAO01<Ool2O00GOol002Aoo`<0079ooa5l05]oo`9l01Uoo`0087oo1000I7oo4G`0JWoo0W`0
6goo000MOol3001HOol@O01iOol2O00MOol001Uoo`@004Yooa5l08Moo`9l01moo`005Goo1000?Goo
4G`0UWoo0W`08Goo000BOol3000`OolAO02UOol2O00SOol000ioo`@0029ooa5l0;Aoo`9l02Eoo`00
0goo2`005Goo4G`0`goo0W`09goo00000`00Ool00006Ool3000?Ool8O03BOol2O00YOol00003Ool0
07oo00Qoo`03001oogoo0>Eoo`9l02]oo`0000<007ooOol02Goo00<007ooOol0hWoo0W`0;Goo0000
0`00Oomoo`08Ool00`00Oomoo`02Ool80n3GOol2O00_Ool00003Ool0000000Ioo`@000=oo`d3h=1o
o`9l035oo`000goo1P0017oo0`004P?PbGoo0W`0<goo0009Ool20005OolG0n32Ool2O00eOol000]o
o`8000=ooad3h;Yoo`9l03Moo`003Goo0P0000=oo`?P0n0080?P/goo0W`0>Goo000?Ool00`000n03
h0060n000goo0n03h00L0n2/Ool2O00kOol0011oo`X3h0Aooah3h:Eoo`9l03eoo`0047oo3@?P1Woo
7`?PWWoo00=l07ooOol0?Goo000@Ool?0n0:OolN0n2GOol2O010Ool0019oo`l3h0eooah3h0]oo`<0
089oo`9l049oo`0057oo3`?P47oo7P?P1Goo00D007ooOomoo`0007moo`9l04Aoo`005Woo3`?P4goo
7`?PPGoo0W`0AWoo000IOol>0n0GOolN0n1jOol2O00ROol20004Ool3000MOol001]oo`h3h1Yooah3
h7=oo`9l02Ioo`04001oogoo0003Ool00`00Oomoo`0JOol001eoo`l3h1aooal3h6]oo`9l02Uoo`03
001oogoo00=oo`03001oogoo01Yoo`007goo3`?P7goo7`?PI7oo0W`0:Woo0`0017oo00<007ooOol0
6Woo000QOol?0n0SOolN0n1MOol2O00WOol50002Ool5000MOol002=oo`l3h2Iooah3h5Ioo`9l02Ao
o`D000Ioo`03001oo`00021oo`009Goo3`?P:Goo7`?PCWoo0W`02goo0`004goo1@002Woo00<007oo
Ool01@0077oo000XOol>0n0]OolN0n17Ool2O00<Ool01@00Oomoogoo00003Goo1@003Woo00<007oo
Ool08Woo000ZOol?0n0_OolN0n10Ool2O00>Ool00`00Oomoo`0;Ool4000hOol002aoo`l3h39ooah3
h3Uoo`9l011oo`05001oogooOol00004Ool5000lOol002ioo`l3h3Eooal3h35oo`9l01=oo`P0045o
o`00<7oo3`?P>Goo7P?P:Woo0W`04goo1@00AWoo000bOol?0n0lOolN0n0SOol2O00@Ool5001;Ool0
03Eoo`h3h3mooah3h0Ioo`03001oogoo01=oo`9l00ioo`@0051oo`00=goo3P?P@Woo70?P0goo00<0
07ooOol04Woo00=l07ooOol02Goo1@00E7oo000iOol?0n15OolF0n04Ool00`00Oomoo`0HOol5001I
Ool003]oo`l3h4Qooa43h0@00003Ool007oo00Ioo`8000]oo`D005ioo`00?Goo3`?PBgoo30?P17oo
0`0027oo00<007ooOol00goo1@00Hgoo000oOol?0n1>Ool70n05Ool00`00Oomoo`08Ool00`00Oomo
o`02001XOol0045oo`l3h5Moo`03001oogoo00Ioo`@006aoo`00A7oo3P?PE7oo00<007ooOol01Woo
00D007ooOomoo`00009oo`@006Ioo`00AWoo3P?PFgoo00D007ooOomoo`0000Ioo`D0065oo`00B7oo
3`?P00=oo`0000000P00E7oo0`0037oo1@0057oo0`00AGoo001:Ool?0n000goo001oo`1XOol5000>
Ool00`00Oomoo`16Ool004aoo`l3h5Moo`03O01oogoo01Aoo`D000Uoo`D004Aoo`00CWoo3`?PEGoo
00=l07ooOol06Goo1@0017oo00D007ooOomoo`0004Aoo`00D7oo3`?PDgoo00=l07ooOol07Woo2000
AGoo001COol>0n1AOol00g`0Oomoo`0SOol60012Ool005Eoo`l3h4ioo`03O01oogoo02Uoo`D003eo
o`00Egoo3`?PC7oo00=l07ooOol0;Woo1@00>7oo001IOol?0n1:Ool00g`0Oomoo`0cOol5000>Ool0
0`00Oomoo`0ROol005]oo`l3h4Qoo`03O01oogoo03Qoo`D000Uoo`03001oogoo029oo`00GGoo3`?P
AWoo00=l07ooOol0?Goo1@001Goo00<007ooOol08Goo001POol>0n14Ool00g`0Oomoo`12Ool50000
17oo001oogoo0`007Goo001ROol>0n12Ool00g`0Oomoo`17Ool40003Ool00`00Oomoo`0JOol006Ao
o`l3h3moo`03O01oogoo04Moo`04001oogoo0003Ool00`00Oomoo`0JOol006Ioo`l3h3eoo`03O01o
ogoo04Ioo`03001oogoo009oo`<001eoo`00J7oo3`?P>goo00=l07ooOol0AGoo00<007ooOol00Woo
00D007ooOomoo`0001aoo`00JWoo3`?P>Goo00=l07ooOol0BWoo00D007ooOomoo`0001aoo`00K7oo
3`?P=goo00=l07ooOol0Bgoo0`007Goo001_Ool>0n0eOol00g`0Oomoo`1[Ool0075oo`l3h39oo`03
O01oogoo06]oo`00Lgoo3`?P<7oo00=l07ooOol0Jgoo001eOol?0n0^Ool00g`0Oomoo`1[Ool007Mo
o`l3h2aoo`03O01oogoo06]oo`00NGoo3`?P:Woo00=l07ooOol0Jgoo001lOol>0n0XOol00g`0Oomo
o`1[Ool007ioo`h3h2Ioo`03O01oogoo06]oo`00P7oo3`?P8goo00=l07ooOol0Jgoo0022Ool?0n0Q
Ool00g`0Oomoo`1[Ool008Aoo`l3h1moo`03O01oogoo06]oo`00QWoo3`?P7Goo00=l07ooOol0Jgoo
0028Ool?0n0KOol00g`0Oomoo`1[Ool008]oo`h3h1Uoo`03O01oogoo06]oo`00SGoo3P?P5goo00=l
07ooOol0Jgoo002?Ool?0n0DOol00g`0Oomoo`1[Ool0095oo`l3h19oo`03O01oogoo06]oo`00Tgoo
3`?P47oo00=l07ooOol0Jgoo002EOol>0n0?Ool00g`0Oomoo`1[Ool009Moo``3h0Aoo`03001oogoo
00Qoo`03O01oogoo06]oo`00VWoo2@?P17oo00<007ooOol027oo00=l07ooOol0Jgoo002LOol70n02
0003Ool00`00Oomoo`07Ool00g`0Oomoo`1[Ool009ioo`D3h09oo`800003Ool007oo00Qoo`03O01o
ogoo06]oo`00Ygoo0P002Goo00=l07ooOol087oo0`00B7oo002XOol2000ZOol01@00Oomoogoo0000
77oo00<007ooOol0:7oo002VOol20005Ool30004Ool2000NOol00`00Oomoo`0NOol00`00Oomoo`02
Ool00`00Oomoo`0SOol00:Eoo`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000MOol01@00
Oomoogoo00007Goo00D007ooOomoo`0002Eoo`00[Woo00<007ooOol00Woo00@007ooOol001ioo`<0
01moo`05001oogooOol0000TOol00:ioo`03001oogoo009oo`03001oo`0004<0009oo`03001oogoo
029oo`00[Woo00<007ooOol00Woo00@007ooOol0041oo`03001oogoo009oo`03001oogoo025oo`00
[Goo0P0017oo00@007ooOol003moo`03001oo`0000=oo`03001oogoo025oo`00[Woo00<007ooOol0
0goo0P00?goo00<007ooOol01@008goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
0 1 0 r
.02 w
.06214 .32046 m
.55928 .41202 L
s
1 0 0 r
.5 Mabswid
.65499 .4063 m
.92357 .26896 L
s
0 g
.03 w
.92357 .26896 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`<000eo
o`00X7oo100017oo00<007ooOol04Goo0`00HGoo002MOol30008Ool00`00Oomoo`0DOol3001NOol0
09Uoo`@000]oo`03001oogoo01Moo`<005]oo`00UGoo10003Woo00<007ooOol06goo0`00F7oo002B
Ool3000cOol3001EOol008ioo`@003Uoo`<0059oo`00Rgoo0`00@7oo0`00Cgoo0027Ool40016Ool3
000=Ool3000lOol008Aoo`<004eoo`<000Uoo`03001oogoo03eoo`00P7oo1000Dgoo0`001Woo1@00
>goo001mOol3001JOol30003Ool01@00Oomoogoo0000>goo001iOol4001POol3000017oo00000000
?7oo001eOol4001WOol3000mOol0079oo`<006ioo`<003Yoo`00KWoo1000M7oo0`00=goo001FOol4
000AOol3001kOol3000dOol005Eoo`04001oogoo000>Ool40021Ool3000aOol005Ioo`<000]oo`<0
08Qoo`<002ioo`00EGoo00@007ooOol000Moo`@008ioo`<002]oo`00EWoo0P001Goo0`00UGoo0`00
:7oo001IOol4002KOol3000UOol005Eoo`@00:9oo`<0029oo`00DWoo0`00ZGoo0`007goo001>Ool4
002_Ool30007Ool00`00Oomoo`0BOol004]oo`<00;Ioo`<000Aoo`03001oogoo019oo`00Agoo1000
_7oo0`000Woo00<007ooOol04Goo0014Ool30033Ool30004Ool3000<Ool0041oo`@00<Qoo`8000Ao
o`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D000aoo`00>Goo1000cGoo00<007ooOol0
0Woo00@007ooOol000eoo`00=Goo1000]Goo2G`047oo10001Goo00<007oo00003Goo000bOol3002X
OolAO00HOol60005Ool2000=Ool002ioo`@009Yooa5l02Qoo`P000Eoo`03001oogoo00]oo`00:goo
0`00SGoo4G`0>Goo20004goo000WOol4001oOolAO01:Ool8000COol002Aoo`<0079ooa5l05]oo`P0
01=oo`0087oo1000I7oo4G`0JWoo0W`000=oo`000000100057oo000MOol3001HOol@O01iOol2O004
Ool4000EOol001Uoo`@004Yooa5l08Moo`9l01moo`005Goo1000?Goo4G`0UWoo0W`08Goo000BOol3
000`OolAO02UOol2O00SOol000ioo`@0029ooa5l0;Aoo`9l02Eoo`000goo2`005Goo4G`0`goo0W`0
9goo00000`00Ool00006Ool3000?Ool8O03BOol2O00YOol00003Ool007oo00Qoo`03001oogoo0>Eo
o`9l02]oo`0000<007ooOol02Goo00<007ooOol0hWoo0W`0;Goo00000`00Oomoo`08Ool00`00Oomo
o`02Ool80n3GOol2O00_Ool00003Ool0000000Ioo`@000=oo`d3h=1oo`9l035oo`000goo1P0017oo
0`004P?PbGoo0W`0<goo0009Ool20005OolG0n32Ool2O00eOol000]oo`8000=ooad3h;Yoo`9l03Mo
o`003Goo0P0000=oo`?P0n0080?P/goo0W`0>Goo000?Ool00`000n03h0060n000goo0n03h00L0n2/
Ool2O00kOol0011oo`X3h0Aooah3h:Eoo`9l03eoo`0047oo3@?P1Woo7`?PWWoo00=l07ooOol0?Goo
000@Ool?0n0:OolN0n2GOol2O010Ool0019oo`l3h0eooah3h0]oo`<0089oo`9l049oo`0057oo3`?P
47oo7P?P1Goo00D007ooOomoo`0007moo`9l04Aoo`005Woo3`?P4goo7`?PPGoo0W`0AWoo000IOol>
0n0GOolN0n1jOol2O00ROol20004Ool3000MOol001]oo`h3h1Yooah3h7=oo`9l02Ioo`04001oogoo
0003Ool00`00Oomoo`0JOol001eoo`l3h1aooal3h6]oo`9l02Uoo`03001oogoo00=oo`03001oogoo
01Yoo`007goo3`?P7goo7`?PI7oo0W`0:Woo0`0017oo00<007ooOol06Woo000QOol?0n0SOolN0n1M
Ool2O00WOol50002Ool5000MOol002=oo`l3h2Iooah3h5Ioo`9l02Aoo`D000Ioo`03001oo`00021o
o`009Goo3`?P:Goo7`?PCWoo0W`02goo0`004goo1@002Woo00<007ooOol01@0077oo000XOol>0n0]
OolN0n17Ool2O00<Ool01@00Oomoogoo00003Goo1@003Woo00<007ooOol08Woo000ZOol?0n0_OolN
0n10Ool2O00>Ool00`00Oomoo`0;Ool4000hOol002aoo`l3h39ooah3h3Uoo`9l011oo`05001oogoo
Ool00004Ool5000lOol002ioo`l3h3Eooal3h35oo`9l01=oo`P0045oo`00<7oo3`?P>Goo7P?P:Woo
0W`04goo1@00AWoo000bOol?0n0lOolN0n0SOol2O00@Ool5001;Ool003Eoo`h3h3mooah3h0Ioo`03
001oogoo01=oo`9l00ioo`@0051oo`00=goo3P?P@Woo70?P0goo00<007ooOol04Woo00=l07ooOol0
2Goo1@00E7oo000iOol?0n15OolF0n04Ool00`00Oomoo`0HOol5001IOol003]oo`l3h4Qooa43h0@0
0003Ool007oo00Ioo`8000]oo`D005ioo`00?Goo3`?PBgoo30?P17oo0`0027oo00<007ooOol00goo
1@00Hgoo000oOol?0n1>Ool70n05Ool00`00Oomoo`08Ool00`00Oomoo`02001XOol0045oo`l3h5Mo
o`03001oogoo00Ioo`@006aoo`00A7oo3P?PE7oo00<007ooOol01Woo00D007ooOomoo`00009oo`@0
06Ioo`00AWoo3P?PFgoo00D007ooOomoo`0000Ioo`D0065oo`00B7oo3`?P00=oo`0000000P00E7oo
0`0037oo1@0057oo0`00AGoo001:Ool?0n000goo001oo`1XOol5000>Ool00`00Oomoo`16Ool004ao
o`l3h5Moo`03O01oogoo01Aoo`D000Uoo`D004Aoo`00CWoo3`?PEGoo00=l07ooOol06Goo1@0017oo
00D007ooOomoo`0004Aoo`00D7oo3`?PDgoo00=l07ooOol07Woo2000AGoo001COol>0n1AOol00g`0
Oomoo`0SOol60012Ool005Eoo`l3h4ioo`03O01oogoo02Uoo`D003eoo`00Egoo3`?PC7oo00=l07oo
Ool0;Woo1@00>7oo001IOol?0n1:Ool00g`0Oomoo`0cOol5000>Ool00`00Oomoo`0ROol005]oo`l3
h4Qoo`03O01oogoo03Qoo`D000Uoo`03001oogoo029oo`00GGoo3`?PAWoo00=l07ooOol0?Goo1@00
1Goo00<007ooOol08Goo001POol>0n14Ool00g`0Oomoo`12Ool5000017oo001oogoo0`007Goo001R
Ool>0n12Ool00g`0Oomoo`17Ool40003Ool00`00Oomoo`0JOol006Aoo`l3h3moo`03O01oogoo04Mo
o`04001oogoo0003Ool00`00Oomoo`0JOol006Ioo`l3h3eoo`03O01oogoo04Ioo`03001oogoo009o
o`<001eoo`00J7oo3`?P>goo00=l07ooOol0AGoo00<007ooOol00Woo00D007ooOomoo`0001aoo`00
JWoo3`?P>Goo00=l07ooOol0BWoo00D007ooOomoo`0001aoo`00K7oo3`?P=goo00=l07ooOol0Bgoo
0`007Goo001_Ool>0n0eOol00g`0Oomoo`1[Ool0075oo`l3h39oo`03O01oogoo06]oo`00Lgoo3`?P
<7oo00=l07ooOol0Jgoo001eOol?0n0^Ool00g`0Oomoo`1[Ool007Moo`l3h2aoo`03O01oogoo06]o
o`00NGoo3`?P:Woo00=l07ooOol0Jgoo001lOol>0n0XOol00g`0Oomoo`1[Ool007ioo`h3h2Ioo`03
O01oogoo06]oo`00P7oo3`?P8goo00=l07ooOol0Jgoo0022Ool?0n0QOol00g`0Oomoo`1[Ool008Ao
o`l3h1moo`03O01oogoo06]oo`00QWoo3`?P7Goo00=l07ooOol0Jgoo0028Ool?0n0KOol00g`0Oomo
o`1[Ool008]oo`h3h1Uoo`03O01oogoo06]oo`00SGoo3P?P5goo00=l07ooOol0Jgoo002?Ool?0n0D
Ool00g`0Oomoo`1[Ool0095oo`l3h19oo`03O01oogoo06]oo`00Tgoo3`?P47oo00=l07ooOol0Jgoo
002EOol>0n0?Ool00g`0Oomoo`1[Ool009Moo``3h0Aoo`03001oogoo00Qoo`03O01oogoo06]oo`00
VWoo2@?P17oo00<007ooOol027oo00=l07ooOol0Jgoo002LOol70n020003Ool00`00Oomoo`07Ool0
0g`0Oomoo`1[Ool009ioo`D3h09oo`800003Ool007oo00Qoo`03O01oogoo06]oo`00Ygoo0P002Goo
00=l07ooOol087oo0`00B7oo002XOol2000ZOol01@00Oomoogoo000077oo00<007ooOol0:7oo002V
Ool20005Ool30004Ool2000NOol00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`0SOol00:Eo
o`03001oogoo00Ioo`03001oogoo009oo`04001oogoo000MOol01@00Oomoogoo00007Goo00D007oo
Oomoo`0002Eoo`00[Woo00<007ooOol00Woo00@007ooOol001ioo`<001moo`05001oogooOol0000T
Ool00:ioo`03001oogoo009oo`03001oo`0004<0009oo`03001oogoo029oo`00[Woo00<007ooOol0
0Woo00@007ooOol0041oo`03001oogoo009oo`03001oogoo025oo`00[Goo0P0017oo00@007ooOol0
03moo`03001oo`0000=oo`03001oogoo025oo`00[Woo00<007ooOol00goo0P00?goo00<007ooOol0
1@008goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
0 1 0 r
.02 w
.06214 .32046 m
.55928 .41202 L
s
1 0 0 r
.5 Mabswid
.65499 .4063 m
.92357 .26896 L
s
.95714 .24035 m
.95714 .14879 L
s
0 g
.03 w
.95714 .14879 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL0009oo`@000aoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00H000]oo`00
Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`03001oogoo00P000Yoo`00Y7oo0`000Woo00<0
07ooOol017oo0`001Woo0`00CWoo00@007ooOomoo`P000Yoo`00X7oo100017oo00<007ooOol04Goo
0`00Cgoo20002Woo002MOol30008Ool00`00Oomoo`0DOol3001<Ool8000:Ool009Uoo`@000]oo`03
001oogoo01Moo`<004Yoo`H000]oo`00UGoo10003Woo00<007ooOol06goo0`00B7oo100037oo002B
Ool3000cOol30017Ool00g`0Oomoo`0;Ool008ioo`@003Uoo`<004Aoo`03O01oogoo00]oo`00Rgoo
0`00@7oo0`00@Goo00=l07ooOol02goo0027Ool40016Ool3000=Ool3000^Ool00g`0Oomoo`0;Ool0
08Aoo`<004eoo`<000Uoo`03001oogoo02moo`03O01oogoo00]oo`00P7oo1000Dgoo0`001Woo1@00
;Goo00=l07ooOol02goo001mOol3001JOol30003Ool01@00Oomoogoo0000;Goo00=l07ooOol02goo
001iOol4001POol3000017oo00000000;Woo00=l07ooOol02goo001eOol4001WOol3000_Ool00g`0
Oomoo`0;Ool0079oo`<006ioo`<002aoo`03O01oogoo00]oo`00KWoo1000M7oo0`00:Goo00=l07oo
Ool02goo001FOol4000AOol3001kOol3000VOol00g`0Oomoo`0;Ool005Eoo`04001oogoo000>Ool4
0021Ool3000SOol00g`0Oomoo`0;Ool005Ioo`<000]oo`<008Qoo`<0021oo`03O01oogoo00]oo`00
EGoo00@007ooOol000Moo`@008ioo`<001eoo`03O01oogoo00]oo`00EWoo0P001Goo0`00UGoo0`00
6Woo00=l07ooOol02goo001IOol4002KOol3000GOol00g`0Oomoo`0;Ool005Eoo`@00:9oo`<001Ao
o`03O01oogoo00]oo`00DWoo0`00ZGoo0`004Goo00=l07ooOol02goo001>Ool4002_Ool30007Ool0
0`00Oomoo`04Ool00g`0Oomoo`0;Ool004]oo`<00;Ioo`<000Aoo`03001oogoo00Aoo`03O01oogoo
00]oo`00Agoo1000_7oo0`000Woo00<007ooOol00goo00=l07ooOol02goo0014Ool30033Ool30004
Ool3000<Ool0041oo`@00<Qoo`8000Aoo`03001oogoo00]oo`00?Goo0`00bgoo00@007ooOomoo`D0
00aoo`00>Goo1000cGoo00<007ooOol00Woo00@007ooOol000eoo`00=Goo1000]Goo2G`06Goo00<0
07oo00003Goo000bOol3002XOolAO00SOol2000=Ool002ioo`@009Yooa5l03Eoo`03001oogoo00]o
o`00:goo0`00SGoo4G`0E7oo000WOol4001oOolAO01<Ool2O00GOol002Aoo`<0079ooa5l05]oo`9l
01Uoo`0087oo1000I7oo4G`0JWoo0W`06goo000MOol3001HOol@O01iOol2O00MOol001Uoo`@004Yo
oa5l08Moo`9l01moo`005Goo1000?Goo4G`0UWoo0W`08Goo000BOol3000`OolAO02UOol2O00SOol0
00ioo`@0029ooa5l0;Aoo`9l02Eoo`000goo2`005Goo4G`0`goo0W`09goo00000`00Ool00006Ool3
000?Ool8O03BOol2O00YOol00003Ool007oo00Qoo`03001oogoo0>Eoo`9l02]oo`0000<007ooOol0
2Goo00<007ooOol0hWoo0W`0;Goo00000`00Oomoo`08Ool00`00Oomoo`02Ool80n3GOol2O00_Ool0
0003Ool0000000Ioo`@000=oo`d3h=1oo`9l035oo`000goo1P0017oo0`004P?PbGoo0W`0<goo0009
Ool20005OolG0n32Ool2O00eOol000]oo`8000=ooad3h;Yoo`9l03Moo`003Goo0P0000=oo`?P0n00
80?P/goo0W`0>Goo000?Ool00`000n03h0060n000goo0n03h00L0n2/Ool2O00kOol0011oo`X3h0Ao
oah3h:Eoo`9l03eoo`0047oo3@?P1Woo7`?PWWoo00=l07ooOol0?Goo000@Ool?0n0:OolN0n2GOol2
O010Ool0019oo`l3h0eooah3h0]oo`<0089oo`9l049oo`0057oo3`?P47oo7P?P1Goo00D007ooOomo
o`0007moo`9l04Aoo`005Woo3`?P4goo7`?PPGoo0W`0AWoo000IOol>0n0GOolN0n1jOol2O00ROol2
0004Ool3000MOol001]oo`h3h1Yooah3h7=oo`9l02Ioo`04001oogoo0003Ool00`00Oomoo`0JOol0
01eoo`l3h1aooal3h6]oo`9l02Uoo`03001oogoo00=oo`03001oogoo01Yoo`007goo3`?P7goo7`?P
I7oo0W`0:Woo0`0017oo00<007ooOol06Woo000QOol?0n0SOolN0n1MOol2O00WOol50002Ool5000M
Ool002=oo`l3h2Iooah3h5Ioo`9l02Aoo`D000Ioo`03001oo`00021oo`009Goo3`?P:Goo7`?PCWoo
0W`02goo0`004goo1@002Woo00<007ooOol01@0077oo000XOol>0n0]OolN0n17Ool2O00<Ool01@00
Oomoogoo00003Goo1@003Woo00<007ooOol08Woo000ZOol?0n0_OolN0n10Ool2O00>Ool00`00Oomo
o`0;Ool4000hOol002aoo`l3h39ooah3h3Uoo`9l011oo`05001oogooOol00004Ool5000lOol002io
o`l3h3Eooal3h35oo`9l01=oo`P0045oo`00<7oo3`?P>Goo7P?P:Woo0W`04goo1@00AWoo000bOol?
0n0lOolN0n0SOol2O00@Ool5001;Ool003Eoo`h3h3mooah3h0Ioo`03001oogoo01=oo`9l00ioo`@0
051oo`00=goo3P?P@Woo70?P0goo00<007ooOol04Woo00=l07ooOol02Goo1@00E7oo000iOol?0n15
OolF0n04Ool00`00Oomoo`0HOol5001IOol003]oo`l3h4Qooa43h0@00003Ool007oo00Ioo`8000]o
o`D005ioo`00?Goo3`?PBgoo30?P17oo0`0027oo00<007ooOol00goo1@00Hgoo000oOol?0n1>Ool7
0n05Ool00`00Oomoo`08Ool00`00Oomoo`02001XOol0045oo`l3h5Moo`03001oogoo00Ioo`@006ao
o`00A7oo3P?PE7oo00<007ooOol01Woo00D007ooOomoo`00009oo`@006Ioo`00AWoo3P?PFgoo00D0
07ooOomoo`0000Ioo`D0065oo`00B7oo3`?P00=oo`0000000P00E7oo0`0037oo1@0057oo0`00AGoo
001:Ool?0n000goo001oo`1XOol5000>Ool00`00Oomoo`16Ool004aoo`l3h5Moo`03O01oogoo01Ao
o`D000Uoo`D004Aoo`00CWoo3`?PEGoo00=l07ooOol06Goo1@0017oo00D007ooOomoo`0004Aoo`00
D7oo3`?PDgoo00=l07ooOol07Woo2000AGoo001COol>0n1AOol00g`0Oomoo`0SOol60012Ool005Eo
o`l3h4ioo`03O01oogoo02Uoo`D003eoo`00Egoo3`?PC7oo00=l07ooOol0;Woo1@00>7oo001IOol?
0n1:Ool00g`0Oomoo`0cOol5000>Ool00`00Oomoo`0ROol005]oo`l3h4Qoo`03O01oogoo03Qoo`D0
00Uoo`03001oogoo029oo`00GGoo3`?PAWoo00=l07ooOol0?Goo1@001Goo00<007ooOol08Goo001P
Ool>0n14Ool00g`0Oomoo`12Ool5000017oo001oogoo0`007Goo001ROol>0n12Ool00g`0Oomoo`17
Ool40003Ool00`00Oomoo`0JOol006Aoo`l3h3moo`03O01oogoo04Moo`04001oogoo0003Ool00`00
Oomoo`0JOol006Ioo`l3h3eoo`03O01oogoo04Ioo`03001oogoo009oo`<001eoo`00J7oo3`?P>goo
00=l07ooOol0AGoo00<007ooOol00Woo00D007ooOomoo`0001aoo`00JWoo3`?P>Goo00=l07ooOol0
BWoo00D007ooOomoo`0001aoo`00K7oo3`?P=goo00=l07ooOol0Bgoo0`007Goo001_Ool>0n0eOol0
0g`0Oomoo`1[Ool0075oo`l3h39oo`03O01oogoo06]oo`00Lgoo3`?P<7oo00=l07ooOol0Jgoo001e
Ool?0n0^Ool00g`0Oomoo`1[Ool007Moo`l3h2aoo`03O01oogoo06]oo`00NGoo3`?P:Woo00=l07oo
Ool0Jgoo001lOol>0n0XOol00g`0Oomoo`1[Ool007ioo`h3h2Ioo`03O01oogoo06]oo`00P7oo3`?P
8goo00=l07ooOol0Jgoo0022Ool?0n0QOol00g`0Oomoo`1[Ool008Aoo`l3h1moo`03O01oogoo06]o
o`00QWoo3`?P7Goo00=l07ooOol0Jgoo0028Ool?0n0KOol00g`0Oomoo`1[Ool008]oo`h3h1Uoo`03
O01oogoo06]oo`00SGoo3P?P5goo00=l07ooOol0Jgoo002?Ool?0n0DOol00g`0Oomoo`1[Ool0095o
o`l3h19oo`03O01oogoo06]oo`00Tgoo3`?P47oo00=l07ooOol0Jgoo002EOol>0n0?Ool00g`0Oomo
o`1[Ool009Moo``3h0Aoo`03001oogoo00Qoo`03O01oogoo06]oo`00VWoo2@?P17oo00<007ooOol0
27oo00=l07ooOol0Jgoo002LOol70n020003Ool00`00Oomoo`07Ool00g`0Oomoo`1[Ool009ioo`D3
h09oo`800003Ool007oo00Qoo`03O01oogoo06]oo`00Ygoo0P002Goo00=l07ooOol087oo0`00B7oo
002XOol2000ZOol01@00Oomoogoo000077oo00<007ooOol0:7oo002VOol20005Ool30004Ool2000N
Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`0SOol00:Eoo`03001oogoo00Ioo`03001o
ogoo009oo`04001oogoo000MOol01@00Oomoogoo00007Goo00D007ooOomoo`0002Eoo`00[Woo00<0
07ooOol00Woo00@007ooOol001ioo`<001moo`05001oogooOol0000TOol00:ioo`03001oogoo009o
o`03001oo`0004<0009oo`03001oogoo029oo`00[Woo00<007ooOol00Woo00@007ooOol0041oo`03
001oogoo009oo`03001oogoo025oo`00[Goo0P0017oo00@007ooOol003moo`03001oo`0000=oo`03
001oogoo025oo`00[Woo00<007ooOol00goo0P00?goo00<007ooOol01@008goo003oOolQOol00?mo
ob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.20924e-017 0.214315 0.309017 0.114451 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
[(6)] .95714 .02289 0 0 Mshowa
[(3)] .95714 .13734 0 0 Mshowa
[(4)] .95714 .25179 0 0 Mshowa
[(2)] .62142 .13734 0 0 Mshowa
[(5)] .90003 .36624 0 0 Mshowa
[(8)] .90003 .48069 0 0 Mshowa
[(9)] .62142 .42347 0 0 Mshowa
[(7)] .87894 .59514 0 0 Mshowa
[(10)] .62142 .59514 0 0 Mshowa
[(1)] 0 .30902 0 0 Mshowa
.5 Mabswid
[ ] 0 setdash
.6382 .13162 m
.94035 .02861 L
s
.93337 .04381 m
.94035 .02861 L
.92805 .01998 L
s
gsave
.78662 .0682 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .13734 m
.94035 .13734 L
s
.93035 .1497 m
.94035 .13734 L
.93035 .12498 L
s
gsave
.78928 .12498 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6382 .14306 m
.94035 .24607 L
s
.92805 .2547 m
.94035 .24607 L
.93337 .23087 L
s
gsave
.79194 .18265 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42061 m
.8861 .3691 L
s
.87787 .38332 m
.8861 .3691 L
.87459 .35894 L
s
gsave
.75908 .38266 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63535 .42633 m
.8861 .47783 L
s
.87459 .488 m
.8861 .47783 L
.87787 .46361 L
s
gsave
.76236 .43989 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.63429 .59514 m
.86606 .59514 L
s
.85606 .6075 m
.86606 .59514 L
.85606 .58278 L
s
gsave
.75018 .58278 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .30043 m
.59035 .14592 L
s
.58277 .16068 m
.59035 .14592 L
.57841 .13656 L
s
gsave
.30853 .21112 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .31474 m
.59035 .41775 L
s
.57898 .42815 m
.59035 .41775 L
.58193 .4037 L
s
gsave
.31218 .35402 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03107 .32332 m
.59035 .58084 L
s
.57749 .58811 m
.59035 .58084 L
.58447 .56494 L
s
gsave
.3142 .4405 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 0 r
.02 w
.06214 .33763 m
.55928 .56653 L
s
1 0 0 r
.5 Mabswid
.62142 .57798 m
.62142 .44064 L
s
.65499 .4063 m
.92357 .26896 L
s
.86142 .25751 m
.09571 .30329 L
s
0 g
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
newpath
matrix currentmatrix
0.0214315 0.0114451 scale
.99993 27.0003 1 0 365.73 arc
setmatrix s
0 1 0 r
.02 w
.06214 .32046 m
.55928 .41202 L
s
1 0 0 r
.5 Mabswid
.65499 .4063 m
.92357 .26896 L
s
.95714 .24035 m
.95714 .14879 L
s
.92357 .18312 m
.65499 .54936 L
s
0 g
.03 w
.65499 .54936 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolAOol3000=Ool00?moo`]oo`03001oogoo009oo`05001oogoo
Ool0000<Ool00?moo`aoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00?moo`eoo`03001oogoo
00@000eoo`00ogoo3Goo0P0000=oo`00Ool03goo003oOol:Ool300001Goo001oogoo00003goo003o
Ool7Ool30003Ool00`00Oomoo`02Ool2000=Ool00?moo`Aoo`<000Ioo`03001oogoo015oo`00ogoo
0Goo0`0027oo00<007ooOol04Woo003mOol3000POol00?Yoo`<002=oo`00mgoo0`009Woo003dOol3
000YOol00?5oo`<002aoo`00gWoo100037oo0`00;goo003OOol01000Oomoo`0027oo0`00<Woo003O
Ool01000Oomoo`001Goo0`00=Goo003OOol01000Oomoo`000Woo0`00>7oo003OOol6000kOol00=mo
o`<003ioo`00g7oo1000@7oo003IOol30014Ool00=Ioo`<004Moo`00dgoo0`00BWoo003@Ool3001=
Ool00<eoo`<0051oo`00bWoo0`00Dgoo0037Ool3001FOol00<Aoo`<005Uoo`00`Goo0`00G7oo002n
Ool3000OOol3000mOol00;]oo`<0025oo`05001oogooOol0000VOol00`00Oomoo`0COol00:moo`D0
00Aoo`<002Aoo`03001oogoo02Qoo`03001oogoo00=oo`<000eoo`00/7oo00@007ooOol000=oo`03
001oogoo02Eoo`05001oogooOol0000WOol01@00Oomoogoo00000goo00<007ooOol02Woo002aOol0
0`00Oomoo`0/Ool3000YOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00:Eoo`8000]oo`03001oogoo
009ooeL000=oo`8000eoo`00Ygoo0P001Woo00D007ooOomoo`0005Qoo`03001oogoo00Aoo`03001o
ogoo00Yoo`00Ygoo0`001Goo00D007ooOomoo`0000=oo`80059oo`05001oogooOol00003Ool00`00
Oomoo`0:Ool00:Aoo`<0009oo`03001oogoo00Aoo`<000Ioo`<004ioo`03001oogoo00=oo`800003
O01oogoo00]oo`00X7oo100017oo00<007ooOol04Goo0`00Dgoo00=l07ooOol02goo002MOol30008
Ool00`00Oomoo`0DOol3001@Ool00g`0Oomoo`0;Ool009Uoo`@000]oo`03001oogoo01Moo`<004eo
o`03O01oogoo00]oo`00UGoo10003Woo00<007ooOol06goo0`00BWoo00=l07ooOol02goo002BOol3
000cOol30017Ool00g`0Oomoo`0;Ool008ioo`@003Uoo`<004Aoo`03O01oogoo00]oo`00Rgoo0`00
@7oo0`00@Goo00=l07ooOol02goo0027Ool40016Ool3000=Ool3000^Ool00g`0Oomoo`0;Ool008Ao
o`<004eoo`<000Uoo`03001oogoo02moo`03O01oogoo00]oo`00P7oo1000Dgoo0`001Woo1@008goo
00=l07ooOol01goo00=l07ooOol02goo001mOol3001JOol30003Ool01@00Oomoogoo00008goo00=l
07ooOol01goo00=l07ooOol02goo001iOol4001POol3000017oo000000008goo00=l07ooOol027oo
00=l07ooOol02goo001eOol4001WOol3000SOol00g`0Oomoo`09Ool00g`0Oomoo`0;Ool0079oo`<0
06ioo`<001moo`03O01oogoo00Yoo`03O01oogoo00]oo`00KWoo1000M7oo0`0077oo00=l07ooOol0
2Woo00=l07ooOol02goo001FOol4000AOol3001kOol3000HOol00g`0Oomoo`0;Ool00g`0Oomoo`0;
Ool005Eoo`04001oogoo000>Ool40021Ool3000DOol00g`0Oomoo`0<Ool00g`0Oomoo`0;Ool005Io
o`<000]oo`<008Qoo`<0011oo`03O01oogoo00eoo`03O01oogoo00]oo`00EGoo00@007ooOol000Mo
o`@008ioo`<000eoo`03O01oogoo00eoo`03O01oogoo00]oo`00EWoo0P001Goo0`00UGoo0`002Goo
00=l07ooOol03Woo00=l07ooOol02goo001IOol4002KOol30005Ool00g`0Oomoo`0?Ool00g`0Oomo
o`0;Ool005Eoo`@00:9oo`<0009oo`03O01oogoo00moo`03O01oogoo00]oo`00DWoo0`00ZGoo00<0
07`000004Goo00=l07ooOol02goo001>Ool4002/Ool00g`0Oomoo`030007Ool00`00Oomoo`04Ool0
0g`0Oomoo`0;Ool004]oo`<00:moo`03O01oogoo00Aoo`<000Aoo`03001oogoo00Aoo`03O01oogoo
00]oo`00Agoo1000/Woo00=l07ooOol01goo0`000Woo00<007ooOol00goo00=l07ooOol02goo0014
Ool3002eOol00g`0Oomoo`0;Ool30004Ool3000<Ool0041oo`@00;Moo`03O01oogoo00ioo`8000Ao
o`03001oogoo00]oo`00?Goo0`00^Woo00=l07ooOol03Woo00@007ooOomoo`D000aoo`00>Goo1000
_Goo00=l07ooOol03Goo00<007ooOol00Woo00@007ooOol000eoo`00=Goo1000]Goo2G`00Woo00=l
07ooOol057oo00<007oo00003Goo000bOol3002XOolAO00:Ool00g`0Oomoo`0FOol2000=Ool002io
o`@009Yooa5l01Yoo`03O01oogoo01Qoo`03001oogoo00]oo`00:goo0`00SGoo4G`0:goo00=l07oo
Ool09Woo000WOol4001oOolAO00kOol00g`0Oomoo`0>Ool2O00GOol002Aoo`<0079ooa5l04]oo`03
O01oogoo00eoo`9l01Uoo`0087oo1000I7oo4G`0G7oo00=l07ooOol02goo0W`06goo000MOol3001H
Ool@O01/Ool00g`0Oomoo`0:Ool2O00MOol001Uoo`@004Yooa5l07]oo`03O01oogoo00Uoo`9l01mo
o`005Goo1000?Goo4G`0Rgoo00=l07ooOol027oo0W`08Goo000BOol3000`OolAO02LOol00g`0Oomo
o`06Ool2O00SOol000ioo`@0029ooa5l0:aoo`03O01oogoo00Eoo`9l02Eoo`000goo2`005Goo4G`0
_7oo00=l07ooOol017oo0W`09goo00000`00Ool00006Ool3000?Ool8O03<Ool00g`0Oomoo`03Ool2
O00YOol00003Ool007oo00Qoo`03001oogoo0>5oo`04O01oogooOol2O00[Ool00003001oogoo00Uo
o`03001oogoo0=moo`03O01oogoo009l02eoo`0000<007ooOol027oo00<007ooOol00Woo20?PeGoo
00Al07ooO01l02moo`0000=oo`0000001Woo10000goo3@?Pcgoo0g`0<Goo0003Ool60004Ool3000B
0n39Ool2O00cOol000Uoo`8000EooaL3h<9oo`=l03Aoo`002goo0P000goo7@?P^Woo0W`000=oog`0
Ool0=7oo000=Ool200000goo0n03h00P0n2cOol2O003Ool00g`0Oomoo`0cOol000moo`030003h0?P
00H3h003Ool3h0?P01`3h:aoo`9l00Aoo`03O01oogoo03Aoo`0047oo2P?P17oo7P?PYGoo0W`01Goo
00=l07ooOol0=Goo000@Ool=0n06OolO0n2NOol00g`0Oomoo`04Ool00g`0Oomoo`0fOol0011oo`l3
h0Yooah3h9Moo`9l00Moo`03O01oogoo03Ioo`004Woo3`?P3Goo7P?P2goo0`00PWoo0W`027oo00=l
07ooOol0=goo000DOol?0n0@OolN0n05Ool01@00Oomoogoo0000Ogoo0W`02Goo00=l07ooOol0>7oo
000FOol?0n0COolO0n21Ool2O00:Ool00g`0Oomoo`0iOol001Uoo`h3h1Mooah3h7Yoo`9l00aoo`03
O01oogoo01=oo`8000Aoo`<001eoo`006goo3P?P6Woo7P?PLgoo0W`03Goo00=l07ooOol05Woo00@0
07ooOol000=oo`03001oogoo01Yoo`007Goo3`?P77oo7`?PJgoo0W`03Woo00=l07ooOol067oo00<0
07ooOol00goo00<007ooOol06Woo000OOol?0n0OOolO0n1TOol2O00?Ool00g`0Oomoo`0HOol30004
Ool00`00Oomoo`0JOol0025oo`l3h2=ooah3h5eoo`9l015oo`03O01oogoo01=oo`D0009oo`D001eo
o`008goo3`?P9Woo7P?PEWoo0W`04Woo00=l07ooOol03goo1@001Woo00<007oo000087oo000UOol?
0n0YOolO0n1>Ool2O00;Ool30005Ool00g`0Oomoo`0;Ool5000:Ool00`00Oomoo`05000LOol002Qo
o`h3h2eooah3h4Moo`9l00aoo`05001oogooOol00004Ool00g`0Oomoo`06Ool5000>Ool00`00Oomo
o`0ROol002Yoo`l3h2mooah3h41oo`9l00ioo`03001oogoo00Eoo`03O01oogoo00=oo`@003Qoo`00
;7oo3`?P<Woo7P?P>Goo0W`047oo00D007ooOomoo`00009oo`03O01oo`0000@003aoo`00;Woo3`?P
=Goo7`?P<Goo0W`04goo1@0000=l00000000@Goo000`Ool?0n0iOolN0n0ZOol2O00COol50002Ool0
0g`0Oomoo`11Ool0039oo`l3h3aooah3h2=oo`9l011oo`D000Ioo`03O01oogoo049oo`00=Goo3P?P
?goo7P?P1Woo00<007ooOol04goo0W`03Woo10002Woo00=l07ooOol0@goo000gOol>0n12OolL0n03
Ool00`00Oomoo`0BOol00g`0Oomoo`09Ool5000=Ool00g`0Oomoo`14Ool003Uoo`l3h4EooaH3h0Ao
o`03001oogoo01Qoo`D0019oo`03O01oogoo04Aoo`00>goo3`?PB7oo4@?P100000=oo`00Ool01Woo
0P002goo1@005Woo00=l07ooOol0AGoo000mOol?0n1;Ool<0n04Ool30008Ool00`00Oomoo`03Ool5
000JOol00g`0Oomoo`16Ool003moo`l3h4ioo`L3h0Eoo`03001oogoo00Qoo`03001oogoo008001io
o`03O01oogoo04Moo`00@Goo3`?PEgoo00<007ooOol01Woo10008Woo00=l07ooOol0Agoo0014Ool>
0n1DOol00`00Oomoo`06Ool01@00Oomoogoo00000Woo10006goo00=l07ooOol0B7oo0016Ool>0n1K
Ool01@00Oomoogoo00001Woo1@005Goo00=l07ooOol0BGoo0018Ool?0n000goo00000002001DOol3
000<Ool5000@Ool017`0Oomoogoo0`00AGoo001:Ool?0n000goo001oo`1XOol5000:Ool01G`0Oomo
ogoo0000B7oo001<Ool?0n1GOol00g`0Oomoo`0DOol50004Ool00g`0Oomoo`02Ool50014Ool004io
o`l3h5Eoo`03O01oogoo01Uoo`<00003O00007oo00=oo`05001oogooOol00014Ool0051oo`l3h5=o
o`03O01oogoo01aoo`03O01oo`0000L004Eoo`00Dgoo3P?PDGoo00=l07ooOol06goo00=l07ooOol0
1Goo1P00@Woo001EOol?0n1>Ool00g`0Oomoo`0JOol00g`0Oomoo`0<Ool5000mOol005Moo`l3h4ao
o`03O01oogoo01Uoo`03O01oogoo019oo`D003Qoo`00FGoo3`?PBWoo00=l07ooOol06Goo00=l07oo
Ool05goo1@003Woo00<007ooOol08Woo001KOol?0n18Ool00g`0Oomoo`0HOol00g`0Oomoo`0MOol5
0009Ool00`00Oomoo`0ROol005eoo`l3h4Ioo`03O01oogoo01Moo`03O01oogoo02=oo`D000Eoo`03
001oogoo025oo`00H7oo3P?PA7oo00=l07ooOol05Woo00=l07ooOol0:Goo1@0000Aoo`00Oomoo`<0
01eoo`00HWoo3P?P@Woo00=l07ooOol05Woo00=l07ooOol0;Woo10000goo00<007ooOol06Woo001T
Ool?0n0oOol00g`0Oomoo`0EOol00g`0Oomoo`0_Ool01000Oomoo`000goo00<007ooOol06Woo001V
Ool?0n0mOol00g`0Oomoo`0DOol00g`0Oomoo`0_Ool00`00Oomoo`02Ool3000MOol006Qoo`l3h3]o
o`03O01oogoo01Aoo`03O01oogoo02ioo`03001oogoo009oo`05001oogooOol0000LOol006Yoo`l3
h3Uoo`03O01oogoo01=oo`03O01oogoo03Aoo`05001oogooOol0000LOol006aoo`l3h3Moo`03O01o
ogoo019oo`03O01oogoo03Ioo`<001eoo`00Kgoo3P?P=Goo00=l07ooOol04Goo00=l07ooOol0Egoo
001aOol?0n0bOol00g`0Oomoo`0AOol00g`0Oomoo`1GOol007=oo`l3h31oo`03O01oogoo011oo`03
O01oogoo05Qoo`00MGoo3`?P;Woo00=l07ooOol03goo00=l07ooOol0FGoo001gOol?0n0/Ool00g`0
Oomoo`0>Ool00g`0Oomoo`1JOol007Uoo`l3h2Yoo`03O01oogoo00ioo`03O01oogoo05Yoo`00O7oo
3P?P:7oo00=l07ooOol03Goo00=l07ooOol0Fgoo001nOol>0n0VOol00g`0Oomoo`0<Ool00g`0Oomo
o`1LOol0081oo`l3h2=oo`03O01oogoo00]oo`03O01oogoo05eoo`00PWoo3`?P8Goo00=l07ooOol0
2goo00=l07ooOol0GGoo0024Ool?0n0OOol00g`0Oomoo`0:Ool00g`0Oomoo`1NOol008Ioo`l3h1eo
o`03O01oogoo00Uoo`03O01oogoo05moo`00R7oo3`?P6goo00=l07ooOol01Goo100000=l07ooOol0
Ggoo002;Ool>0n0IOol00g`0Oomoo`04Ool6001QOol008eoo`h3h1Moo`03O01oogoo00=oo`P0061o
o`00Sgoo3`?P57oo00=l07ooOol00goo2000H7oo002AOol?0n0BOol00g`0Oomoo`03Ool8001POol0
09=oo`l3h11oo`03O01oogoo00=oo`P0061oo`00UGoo3P?P3goo00=l07ooOol017oo1P00HGoo002G
Ool<0n04Ool00`00Oomoo`08Ool00g`0Oomoo`05Ool4001ROol009Yoo`T3h0Aoo`03001oogoo00Qo
o`03O01oogoo06]oo`00W7oo1`?P0P000goo00<007ooOol01goo00=l07ooOol0Jgoo002NOol50n02
Ool200000goo001oo`08Ool00g`0Oomoo`1[Ool00:Moo`8000Uoo`03O01oogoo021oo`<004Qoo`00
Z7oo0P00:Woo00D007ooOomoo`0001aoo`03001oogoo02Qoo`00YWoo0P001Goo0`0017oo0P007Woo
00<007ooOol07Woo00<007ooOol00Woo00<007ooOol08goo002UOol00`00Oomoo`06Ool00`00Oomo
o`02Ool01000Oomoo`007Goo00D007ooOomoo`0001eoo`05001oogooOol0000UOol00:ioo`03001o
ogoo009oo`04001oogoo000NOol3000OOol01@00Oomoogoo000097oo002^Ool00`00Oomoo`02Ool0
0`00Ool000130002Ool00`00Oomoo`0ROol00:ioo`03001oogoo009oo`04001oogoo0010Ool00`00
Oomoo`02Ool00`00Oomoo`0QOol00:eoo`8000Aoo`04001oogoo000oOol00`00Ool00003Ool00`00
Oomoo`0QOol00:ioo`03001oogoo00=oo`8003moo`03001oogoo00D002=oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00578691, -2.70002, \
0.0162983, 0.0305193}},
  CellTags->"enfold"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["construction of factorization and graphics for first  loop", "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell["loopfactorrules", "Subsubsection",
  CellTags->"enfold"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ArrowPathBack", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"ArrowPathBack", "[", 
          RowBox[{"arrs_", ",", "j_"}], "]"}], ":=", 
        RowBox[{
          RowBox[{"Cases", "[", 
            RowBox[{"arrs", ",", 
              RowBox[{"ArrowIndex", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"i_", ",", "j"}], "}"}], ",", "a_"}], "]"}], ",", 
              "Infinity"}], "]"}], "/.", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{"{", "}"}], "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"{", "}"}], ",", 
                    RowBox[{"{", "}"}]}], "}"}]}], ",", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"r", ":", 
                    RowBox[{"ArrowIndex", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"i_", ",", "j"}], "}"}], ",", "a_"}], 
                      "]"}]}], "}"}], "\[Rule]", 
                RowBox[{"{", 
                  RowBox[{"i", ",", "r"}], "}"}]}]}], "}"}]}]}], 
      ";"}]}], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ArrowPathTo", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"ArrowPathTo", "[", 
          RowBox[{"arrs_", ",", "j_"}], "]"}], ":=", 
        RowBox[{"Reverse", "@", 
          RowBox[{"Cases", "[", 
            RowBox[{
              RowBox[{"FixedPointList", "[", 
                RowBox[{
                  RowBox[{
                    RowBox[{"ArrowPathBack", "[", 
                      RowBox[{"arrs", ",", 
                        RowBox[{"#", "[", 
                          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",",
                   
                  RowBox[{"{", 
                    RowBox[{"j", ","}], "}"}]}], "]"}], ",", "_ArrowIndex", 
              ",", "Infinity"}], "]"}]}]}], ";"}]}], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"loopfactorrules", "=", 
        RowBox[{
          RowBox[{"Tpath", "[", 
            RowBox[{"l___TLoop", ",", "ps___ArrowIndex", ",", 
              RowBox[{"r", ":", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"ArrowJump", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"i_", ",", "j_"}], "}"}], ",", "a_"}], 
                      "]"}], "|", 
                    RowBox[{"TNodeLoop", "[", 
                      RowBox[{"j_", ",", "a_"}], "]"}]}], ")"}]}], ",", 
              "qs___"}], "]"}], "\[RuleDelayed]", "\[IndentingNewLine]", 
          RowBox[{"With", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"rs", "=", 
                  RowBox[{"ArrowPathTo", "[", 
                    RowBox[{"arrs", ",", "j"}], "]"}]}], "}"}], ",", 
              RowBox[{"Tpath", "[", 
                RowBox[{"l", ",", 
                  RowBox[{"TLoop", "[", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{"ps", ",", "r", ",", 
                          RowBox[{"Inv", "[", "rs", "]"}]}], "}"}], ",", 
                      RowBox[{
                        RowBox[{"Length", "[", 
                          RowBox[{"{", "l", "}"}], "]"}], "+", "1"}]}], "]"}],
                   ",", 
                  RowBox[{"Sequence", "@@", "rs"}], ",", "qs"}], "]"}]}], 
            "]"}]}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{

Cell["first loop", "Subsubsection",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"patharrows2", "=", 
      RowBox[{"List", "@@", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"Tpath", "@@", "patharrows"}], "/.", "loopfactorrules"}], 
          ")"}]}]}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "10"}], "}"}], ",", "\<\"d\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"10", ",", "9"}], "}"}], ",", "\<\"d\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", 
                    RowBox[{"ArrowIndex", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], 
                      "]"}], "}"}], "]"}]}], "}"}], ",", "1"}], "]"}], ",", 
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"4", ",", "1"}], "}"}], ",", "\<\"d\"\>"}], "]"}], ",", 
        
        RowBox[{"TNodeLoop", "[", 
          RowBox[{"1", ",", "\<\"e\"\>"}], "]"}], ",", 
        RowBox[{"TNodeLoop", "[", 
          RowBox[{"1", ",", "\<\"b\"\>"}], "]"}], ",", 
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"4", ",", "3"}], "}"}], ",", "\<\"a\"\>"}], "]"}], ",", 
        
        RowBox[{"ArrowJump", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"3", ",", "10"}], "}"}], ",", "\<\"c\"\>"}], "]"}]}], 
      "}"}]], "Output",
  CellTags->"enfold"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3D loop element rules:path3Delementsof[patharrows_]", "Subsubsection",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"pathelementrules", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"ArrowIndex", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
                  RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
                  RowBox[{"Line", "@", 
                    RowBox[{"ShrinkSeg", "[", 
                      RowBox[{
                        RowBox[{"ij", "/.", "ptrules"}], ",", ".8"}], 
                      "]"}]}]}], "}"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"ArrowJump", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
                  RowBox[{"Line", "@", 
                    RowBox[{"ShrinkSeg", "[", 
                      RowBox[{
                        RowBox[{"ij", "/.", "ptrules"}], ",", ".8"}], 
                      "]"}]}]}], "}"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"TNodeLoop", "[", 
                RowBox[{"i_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"Circle", "[", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"i", "/.", "ptrules"}], ")"}], " ", ",", ".1"}], 
                "]"}]}]}], "}"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"loopelementrules", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"ArrowIndex", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
                  RowBox[{"Line", "[", 
                    RowBox[{"ij", "/.", "ptrules"}], "]"}]}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"ArrowJump", "[", 
                RowBox[{"ij_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
                  RowBox[{"Line", "[", 
                    RowBox[{"ij", "/.", "ptrules"}], "]"}]}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"TNodeLoop", "[", 
                RowBox[{"i_", ",", "a_"}], "]"}], "\[RuleDelayed]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
                  RowBox[{"Circle", "[", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"i", "/.", "ptrules"}], ")"}], " ", ",", 
                      ".1"}], "]"}]}], "}"}]}]}], "}"}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"circle3Drule", "=", 
        RowBox[{
          RowBox[{"Circle", "[", 
            RowBox[{"p_", ",", "r_"}], "]"}], ":>", "\[IndentingNewLine]", 
          RowBox[{"Line", "[", 
            RowBox[{"Table", "[", 
              RowBox[{
                RowBox[{"p", "+", 
                  RowBox[{".2", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"0", ",", "0", ",", "1"}], "}"}], "+", 
                        RowBox[{
                          RowBox[{"Cos", "[", "t", "]"}], 
                          RowBox[{"{", 
                            RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "+", 
                        RowBox[{
                          RowBox[{"Sin", "[", "t", "]"}], 
                          RowBox[{"{", 
                            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], 
                      ")"}]}]}], ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", 
                    RowBox[{"2", "Pi"}], ",", 
                    RowBox[{"2", 
                      RowBox[{"Pi", "/", "12"}]}]}], "}"}]}], "]"}], 
            "]"}]}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"thickcircle3Drule", "=", 
        RowBox[{
          RowBox[{"Circle", "[", 
            RowBox[{"p_", ",", "r_"}], "]"}], ":>", "\[IndentingNewLine]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
              RowBox[{"Line", "[", 
                RowBox[{"Table", "[", 
                  RowBox[{
                    RowBox[{"p", "+", 
                      RowBox[{".2", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{"{", 
                              RowBox[{"0", ",", "0", ",", "1"}], "}"}], "+", 
                            RowBox[{
                              RowBox[{"Cos", "[", "t", "]"}], 
                              RowBox[{"{", 
                                RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
                            "+", 
                            RowBox[{
                              RowBox[{"Sin", "[", "t", "]"}], 
                              RowBox[{"{", 
                                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], 
                          ")"}]}]}], ",", 
                    RowBox[{"{", 
                      RowBox[{"t", ",", "0", ",", 
                        RowBox[{"2", "Pi"}], ",", 
                        RowBox[{"2", 
                          RowBox[{"Pi", "/", "12"}]}]}], "}"}]}], "]"}], 
                "]"}]}], "}"}]}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"TLoop3Drule", "=", 
        RowBox[{
          RowBox[{"TLoop", "[", 
            RowBox[{"path_", ",", "h_"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"path", "/.", 
                    RowBox[{
                      RowBox[{"Inv", "[", "p_", "]"}], "\[Rule]", "p"}]}], "/.",
                   "loopelementrules"}], "/.", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"x_", "?", "NumberQ"}], ",", 
                      RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
                  RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "h"}], "}"}]}]}], "/.", 
              "circle3Drule"}], ")"}]}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "path3Delementsof", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"path3Delementsof", "[", "patharrows_", "]"}], ":=", 
        RowBox[{
          RowBox[{"Cases", "[", 
            RowBox[{"patharrows", ",", 
              RowBox[{"l_TLoop", "\[RuleDelayed]", 
                RowBox[{"(", 
                  RowBox[{"l", "/.", "TLoop3Drule"}], ")"}]}]}], "]"}], "~", 
          "Join", "~", "\[IndentingNewLine]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"DeleteCases", "[", 
                    RowBox[{"patharrows", ",", "l_TLoop"}], "]"}], "/.", 
                  "pathelementrules"}], "/.", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"x_", "?", "NumberQ"}], ",", 
                      RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
                  RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "0"}], "}"}]}]}], "/.", 
              "circle3Drule"}], ")"}]}]}], ";"}]}], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{

Cell["graphics elements", "Subsubsection",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{"pathelements2", "=", 
        RowBox[{"path3Delementsof", "[", "patharrows2", "]"}]}], 
      ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"pathelements2", "=", 
        RowBox[{
          RowBox[{"Cases", "[", 
            RowBox[{"patharrows2", ",", 
              RowBox[{"l_TLoop", "\[RuleDelayed]", 
                RowBox[{"(", 
                  RowBox[{"l", "/.", "TLoop3Drule"}], ")"}]}]}], "]"}], "~", 
          "Join", "~", "\[IndentingNewLine]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"DeleteCases", "[", 
                    RowBox[{"patharrows2", ",", "l_TLoop"}], "]"}], "/.", 
                  "pathelementrules"}], "/.", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"x_", "?", "NumberQ"}], ",", 
                      RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
                  RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "0"}], "}"}]}]}], "/.", 
              "circle3Drule"}], ")"}]}]}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["display first loop", "Subsection"],

Cell["\<\
Here we see the first basic loop split off and floating above the remainder \
of the path:\
\>", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"Graphics3D", "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"nodes2D", ",", "treearrs2D"}], "}"}], "/.", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"x_", "?", "NumberQ"}], ",", 
                        RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
                    RowBox[{"{", 
                      RowBox[{"x", ",", "y", ",", "0"}], "}"}]}]}], ",", 
                "pathelements2"}], "}"}], "]"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}], ";"}]], "Input",
  Evaluatable->False,
  CellTags->"calc"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93746 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.14996e-017 1.05825 -0.0109014 1.05825 [
[ 0 0 0 0 ]
[ 1 .93746 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05179 .2399 m
0 .59246 L
s
0 .59246 m
.42939 .93746 L
s
.42939 .93746 m
.43745 .61846 L
s
.43745 .61846 m
.05179 .2399 L
s
.6524 0 m
.95854 .45797 L
s
.95854 .45797 m
1 .79278 L
s
1 .79278 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.05179 .2399 m
0 .59246 L
s
0 .59246 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.6524 0 m
.05179 .2399 L
s
.43745 .61846 m
.95854 .45797 L
s
.95854 .45797 m
1 .79278 L
s
1 .79278 m
.42939 .93746 L
s
.42939 .93746 m
.43745 .61846 L
s
0 0 m
1 0 L
1 .93746 L
0 .93746 L
closepath
clip
newpath
.5 Mabswid
.72285 .50645 m
.72632 .50015 L
s
.75633 .50106 m
.88284 .46171 L
s
.72632 .50015 m
.71578 .49194 L
s
.29684 .44339 m
.72632 .50015 L
s
1 0 0 r
.7183 .16594 m
.74646 .47081 L
s
0 g
.88252 .4708 m
.88284 .46171 L
s
.88284 .46171 m
.87199 .45602 L
s
.02 w
.75596 .60689 m
.67128 .50558 L
s
.26439 .54543 m
.75596 .60689 L
s
.5 Mabswid
.2837 .46242 m
.28486 .47455 L
s
.27909 .44986 m
.2837 .46242 L
s
.27223 .44014 m
.27909 .44986 L
s
.28486 .47455 m
.28225 .48305 L
s
.26492 .43585 m
.27223 .44014 L
s
.29159 .43814 m
.64686 .40139 L
s
0 1 0 r
.02 w
.31099 .43613 m
.62678 .40347 L
s
0 g
.5 Mabswid
.28225 .48305 m
.27651 .48562 L
s
.25909 .4382 m
.26492 .43585 L
s
.28278 .42932 m
.49447 .21201 L
s
.27651 .48562 m
.26915 .4815 L
s
.25634 .44664 m
.25909 .4382 L
s
1 0 0 r
.72012 .23701 m
.31783 .41946 L
s
0 g
.26915 .4815 m
.26216 .47172 L
s
.25746 .45893 m
.25634 .44664 L
s
.26216 .47172 m
.25746 .45893 L
s
.64592 .41007 m
.64686 .40139 L
s
.64686 .40139 m
.63497 .39397 L
s
.67617 .39857 m
.84268 .38505 L
s
.67328 .39491 m
.79155 .31215 L
s
.84069 .39374 m
.84268 .38505 L
s
.84268 .38505 m
.83145 .37736 L
s
1 0 0 r
.67701 .38201 m
.76388 .23213 L
s
0 g
.02 w
.26439 .54543 m
.67128 .50558 L
s
.5 Mabswid
.7936 .32362 m
.79155 .31215 L
s
.79155 .31215 m
.77976 .30739 L
s
.49903 .22485 m
.49447 .21201 L
s
.75925 .22043 m
.76232 .21117 L
s
.49447 .21201 m
.48166 .20749 L
s
.76232 .21117 m
.75004 .20106 L
s
.52108 .1992 m
.76232 .21117 L
s
1 0 0 r
.76972 .20307 m
.72052 .13038 L
s
0 g
.5176 .19477 m
.70348 .12497 L
s
.5141 .19033 m
.63983 .03174 L
s
.70408 .13746 m
.70348 .12497 L
s
.70348 .12497 m
.69013 .11714 L
s
.6445 .04701 m
.63983 .03174 L
s
.63983 .03174 m
.62651 .0272 L
s
[(6)] .64735 .02226 0 0 Mshowa
[(3)] .71415 .12096 0 0 Mshowa
[(4)] .77565 .21183 0 0 Mshowa
[(2)] .5076 .19853 0 0 Mshowa
[(5)] .7984 .30736 0 0 Mshowa
[(8)] .852 .38429 0 0 Mshowa
[(9)] .66699 .39931 0 0 Mshowa
[(7)] .89002 .45947 0 0 Mshowa
[(10)] .74946 .5032 0 0 Mshowa
[(1)] .27223 .44014 0 0 Mshowa
gsave
.56581 .10446 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60181 .1505 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6369 .19543 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7242 .34652 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75422 .38365 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81349 .4743 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37444 .31844 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.46145 .41199 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51033 .46469 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.6524 0 m
.95854 .45797 L
s
.95854 .45797 m
1 .79278 L
s
1 .79278 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.05179 .2399 m
0 .59246 L
s
0 .59246 m
.66744 .36699 L
s
.66744 .36699 m
.6524 0 L
s
.6524 0 m
.05179 .2399 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 269.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00013A000`40O003h00O^Woo0P00I7oo002h
Ool200000goo0000001SOol00;Eoo`<000=oo`8006=oo`00/goo0P001Woo00<007oo0000HWoo002`
Ool30004Ool300001Goo001oogoo0000HGoo002^Ool20007Ool00`00Oomoo`020002Ool00`00Oomo
o`1OOol00:]oo`<000Uoo`03001oogoo008000=oo`03001oogoo05ioo`00Z7oo0`0027oo00@007oo
Oomoo`<00003Ool007oo00=oo`03001oogoo05eoo`00YWoo0P0037oo0P000Woo00@007ooOol000Ao
o`03001oogoo05eoo`00Xgoo0`0047oo1P001Goo00<007ooOol0G7oo002QOol2000COol20003Ool0
0`00Oomoo`04Ool00`00Oomoo`1KOol009ioo`<001Aoo`03001oo`0000=oo`03001oogoo00Aoo`03
001oogoo05]oo`00W7oo0P005goo00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo05Yoo`00
VGoo0`0067oo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo05Uoo`00Ugoo0P006Woo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0FGoo002DOol3000KOol00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`1HOol0099oo`8001eoo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo05Moo`00Sgoo0`007goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0Egoo002<
Ool3000QOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`1FOol008Yoo`8002=oo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo05Eoo`00Qgoo0`0097oo00<007ooOol02goo00<007oo
Ool02Goo00<007ooOol0EGoo0025Ool2000VOol00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`1DOol0089oo`<002Qoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo05=oo`00P7oo0P00
:Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol0Dgoo001mOol3000[Ool00`00Oomoo`0>
Ool00`00Oomoo`0<Ool00`00Oomoo`1BOol007]oo`8002eoo`03001oogoo00moo`03001oogoo00eo
o`03001oogoo055oo`00N7oo0`00;Woo00<007ooOol047oo00<007ooOol03Goo00<007ooOol0DGoo
001fOol2000aOol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`1@Ool007=oo`<002Uoo`@0
00Eoo`03001oogoo015oo`03001oogoo00moo`03001oogoo04moo`00L7oo0`00;Goo00@007ooOol0
00=oo`03001oogoo019oo`03001oogoo00moo`03001oogoo04moo`00KWoo0P00<7oo00@007ooOol0
009oo`03001oogoo01=oo`03001oogoo011oo`03001oogoo04ioo`00Jgoo0`00<Woo0`000Woo00<0
07ooOol057oo00<007ooOol04Goo00<007ooOol0CGoo001YOol2000eOol00`00Oomoo`02Ool00`00
Oomoo`0DOol00`00Oomoo`0<Ool20003Ool00`00Oomoo`1=Ool006Ioo`<003Ioo`8000=oo`03001o
ogoo01Eoo`03001oogoo00Moo`05001oogooOol00002Ool01@00Oomoogoo0000CWoo001TOol2000m
Ool00`00Oomoo`0FOol00`00Oomoo`08Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`1;Ool0065o
o`<003ioo`03001oogoo01Moo`03001oogoo00Uoo`8000=oo`03001oogoo00=oo`03001oogoo04Yo
o`00Ggoo0P00@7oo00<007ooOol067oo00<007ooOol01goo0P0000=oo`0000000Woo00<007ooOol0
0goo00<007ooOol0BWoo001LOol30012Ool00`00Oomoo`0HOol00`00Oomoo`04Ool30003Ool01P00
Ool00000Ooml00Eoo`03001oogoo04Uoo`00FWoo0P00A7oo00<007ooOol06Goo00@007ooOomoo`<0
00Moo`03001oogoo009oo`03O01oogoo00=oo`03001oogoo04Qoo`00Egoo0`00AGoo00<007ooOol0
6Woo00@007oo000000Yoo`03001oogoo009oo`03O01oogoo00=oo`03001oogoo04Qoo`00E7oo0`00
Agoo00<007ooOol06Woo0`004Woo00=l07ooOol00goo00<007ooOol0Agoo001BOol20019Ool00`00
Oomoo`0;Ool3000:Ool30002Ool00`00Oomoo`0AOol00g`0Oomoo`03Ool00`00Oomoo`16Ool004mo
o`<004]oo`03001oogoo00Yoo`03001oogoo00Uoo`8000Eoo`03001oogoo015oo`03O01oogoo00=o
o`03001oogoo04Ioo`00CGoo0P00CGoo00<007ooOol02goo00<007ooOol01Woo0`001goo00<007oo
Ool04Woo00=l07ooOol00goo00<007ooOol0AGoo001:Ool3001>Ool00`00Oomoo`0=Ool30002Ool3
000:Ool00`00Oomoo`0COol00g`0Oomoo`03Ool00`00Oomoo`14Ool004Qoo`80051oo`03001oogoo
015oo`8000eoo`03001oogoo01=oo`03O01oogoo00=oo`03001oogoo04Aoo`00AGoo0`00DGoo00<0
07ooOol03goo0`003goo00<007ooOol057oo00=l07ooOol00goo00<007ooOol0@goo0013Ool2001D
Ool00`00Oomoo`0<Ool3000BOol00`00Oomoo`0>Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00`00
Oomoo`12Ool0041oo`<005Eoo`03001oogoo00]oo`8001Eoo`03001oogoo00ioo`03O01oogoo00Ao
o`03O01oogoo00=oo`03001oogoo049oo`00?Woo0P00Egoo00<007ooOol02Goo0`005goo00<007oo
Ool03Woo00=l07ooOol01Goo00=l07ooOol00goo00<007ooOol0@Goo000kOol3001HOol00`00Oomo
o`07Ool3000JOol00`00Oomoo`0>Ool00g`0Oomoo`06Ool00g`0Oomoo`03Ool00`00Oomoo`10Ool0
03Qoo`<005Yoo`03001oogoo00Ioo`8001eoo`03001oogoo00ioo`03O01oogoo00Ioo`03O01oogoo
00=oo`03001oogoo041oo`00=Woo0P00GGoo00<007ooOol00goo0`007goo00<007ooOol03Woo00=l
07ooOol01goo00=l07ooOol00goo00<007ooOol0?goo000cOol3001NOol01000Oomoogoo0`008Woo
00<007ooOol03goo00=l07ooOol01goo00=l07ooOol00goo00<007ooOol0?Woo000aOol2001POol0
0`00Oomoo`02000MOol30005Ool00`00Oomoo`0?Ool00g`0Oomoo`07Ool00g`0Oomoo`03Ool00`00
Oomoo`0nOol002ioo`<005ioo`@00003Ool0000001ioo`03001oogoo00Ioo`03001oogoo00moo`03
O01oogoo00Qoo`03O01oogoo00=oo`03001oogoo03eoo`00;7oo0P00HGoo00<007ooOol08Woo1000
1Goo00<007ooOol03goo00=l07ooOol02Goo00=l07ooOol00goo00<007ooOol0?7oo000YOol3001T
Ool00`00Oomoo`02Ool<000DOol20006Ool00`00Oomoo`0?Ool00g`0Oomoo`05Ool01@00Oomoogoo
O0001Goo00<007ooOol0?7oo000WOol2001XOol00`00Oomoo`0=OolG0005Ool00`00Oomoo`0?Ool0
0g`0Oomoo`06Ool01P00OomoogooO01oo`<00003Ool007oo03aoo`0097oo0`00Hgoo0P000goo00@0
07ooOol002EooaL00003O01oogoo00Moo`03001oogoo00=oo`05001oogooOol0000lOol0029oo`80
06Qoo`80009oo`8002]oo`03001oogoo00moo``00003Ool0000000<0009oo`03001oogoo03Yoo`00
7goo0`00JWoo0P00;goo00<007ooOol03goo00=l07ooOol027oo00<007oo00000Woo00<007ooOol0
0Woo00<007ooOol0>Goo000LOol3001/Ool01000Oomoo`00;Woo00<007ooOol03goo00=l07ooOol0
1goo00L007ooOomoo`00Ool00005Ool00`00Oomoo`0hOol001Yoo`8006ioo`05001oogooOol0000^
Ool00`00Oomoo`0?Ool00g`0Oomoo`07Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`0hOol001Mo
o`<006moo`03001oogoo00=oo`03001oogoo02]oo`03001oogoo011oo`03O01oogoo01=oo`03001o
ogoo03Moo`005Goo0P00LGoo00<007ooOol0<Woo00<007ooOol047oo00=l07ooOol057oo00<007oo
Ool0=Woo000BOol3001bOol00`00Oomoo`0dOol00`00Oomoo`0?Ool00g`0Oomoo`08Ool00g`0Oomo
o`09Ool00`00Oomoo`0fOol0011oo`8007Aoo`03001oogoo03Eoo`03001oogoo00moo`03O01oogoo
00Moo`03O01oogoo00]oo`03001oogoo03Eoo`003Woo0P00MGoo00<007ooOol0=Woo00<007ooOol0
37oo0W`000=oog`0Ool027oo00=l07ooOol037oo00<007ooOol0=7oo000>Ool2001dOol00`00Oomo
o`0gOol00`00Oomoo`0:Ool2O003Ool00g`0Oomoo`06Ool00g`0Oomoo`0=Ool00`00Oomoo`0dOol0
00ioo`03001oo`00079oo`03001oogoo03Qoo`03001oogoo00Qoo`9l00Eoo`03O01oogoo00Ioo`03
O01oogoo00ioo`03001oogoo03=oo`003Woo00@007ooOol0075oo`03001oogoo03Qoo`03001oogoo
00Ioo`9l00Moo`03O01oogoo00Eoo`03O01oogoo011oo`03001oogoo039oo`003Goo00<007ooOol0
0Woo00<007ooOol0KGoo00<007ooOol0>Goo00<007ooOol017oo0W`02Goo00=l07ooOol01Goo00=l
07ooOol047oo00<007ooOol0<Woo000=Ool00`00Oomoo`03Ool00`00Oomoo`1[Ool00`00Oomoo`0j
Ool01000Oomoogoo0g`02goo00=l07ooOol017oo00=l07ooOol04Woo00<007ooOol0<Goo000=Ool0
0`00Oomoo`04Ool00`00Oomoo`1YOol00`00Oomoo`0kOol01000Ooml07`03Woo00=l07ooOol00goo
00=l07ooOol057oo00<007ooOol0<7oo000=Ool00`00Oomoo`05Ool00`00Oomoo`1WOol00`00Oomo
o`0lOol00`00O01oo`0@Ool00g`0Oomoo`02Ool00g`0Oomoo`0DOol00`00Oomoo`0`Ool000eoo`03
001oogoo00Ioo`03001oogoo06Eoo`03001oogoo03]oo`9l0003001oogoo011oo`05O01oogooOoml
000HOol00`00Oomoo`0_Ool000eoo`03001oogoo00Moo`03001oogoo06=oo`03001oogoo03Uoo`=l
009oo`03001oogoo011oo`05O01oogooOoml000IOol00`00Oomoo`0^Ool000eoo`03001oogoo00Qo
o`03001oogoo065oo`03001oogoo03Qoo`9l00Eoo`03001oogoo011oo`04O01oogooO00JOol00`00
Oomoo`0^Ool000aoo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo03Moo`9l00Moo`03001o
ogoo011oo`03O01oog`001aoo`03001oogoo02eoo`0037oo00<007ooOol02goo00<007ooOol0GGoo
00<007ooOol0=Woo0W`02Goo00<007ooOol047oo00=l07ooO0007Goo00<007ooOol0;7oo000<Ool0
0`00Oomoo`0<Ool00`00Oomoo`1KOol00`00Oomoo`0eOol2O00;Ool00`00Oomoo`0@Ool2O00NOol0
0`00Oomoo`0/Ool000aoo`03001oogoo00eoo`03001oogoo05Uoo`03001oogoo03=oo`=l00eoo`03
001oogoo011oo`9l01moo`03001oogoo02]oo`0037oo00<007ooOol03Woo00<007ooOol0Egoo00<0
07ooOol0<Woo0W`047oo00<007ooOol047oo00=l07ooOol07goo00<007ooOol0:Woo000<Ool00`00
Oomoo`0?Ool00`00Oomoo`1EOol00`00Oomoo`0aOol2O00BOol00`00Oomoo`0@Ool00g`0Oomoo`0O
Ool00`00Oomoo`0ZOol000aoo`03001oogoo011oo`03001oogoo05=oo`03001oogoo031oo`9l01Ao
o`03001oogoo00moo`9l029oo`03001oogoo02Uoo`0037oo00<007ooOol04Goo00<007ooOol0DGoo
00<007ooOol0;goo0W`05Woo00<007ooOol03Woo00Al07ooOoml015oo`8000moo`03001oogoo02Qo
o`002goo00<007ooOol04goo00<007ooOol0Cgoo00<007ooOol0;Goo0g`067oo00<007ooOol03Woo
00Al07ooOoml011oo`04001oogoo000>Ool00`00Oomoo`0XOol000]oo`03001oogoo01Aoo`03001o
ogoo04eoo`03001oogoo02aoo`9l01]oo`03001oogoo00eoo`05O01oogooOoml000<Ool20005Ool0
0`00Oomoo`0=Ool00`00Oomoo`0WOol000]oo`03001oogoo01Eoo`03001oogoo04=oo`D000=oo`03
001oogoo02]oo`9l01eoo`03001oogoo00eoo`05O01oogooOoml000>Ool5000AOol00`00Oomoo`0V
Ool000]oo`03001oogoo01Ioo`03001oogoo049oo`@000=oo`03001oogoo02Yoo`9l01moo`03001o
ogoo00aoo`03O01oogoo009oo`03O01oogoo00aoo`@0019oo`03001oogoo02Ioo`002goo00<007oo
Ool05goo00<007ooOol0A7oo00@007ooOol002]oo`9l025oo`03001oogoo00]oo`03O01oogoo00=o
o`03O01oogoo00]oo`03001oogoo00@0015oo`03001oogoo02Eoo`002goo00<007ooOol067oo00<0
07ooOol0@Goo0`000Woo00<007ooOol09Woo0g`097oo00<007ooOol02Woo00=l07ooOol00goo00=l
07ooOol02Woo00D007ooOomoo`0001Eoo`03001oogoo02Aoo`002goo00<007ooOol06Goo00<007oo
Ool0A7oo00<007ooOol09Goo0W`09goo00<007ooOol02Goo00=l07ooOol017oo00=l07ooOol027oo
0P006Woo00<007ooOol097oo000:Ool00`00Oomoo`0KOol00`00Oomoo`12Ool00`00Oomoo`0TOol2
O00YOol00`00Oomoo`09Ool00g`0Oomoo`04Ool00g`0Oomoo`07Ool00`00Oomoo`0KOol00`00Oomo
o`0SOol000Yoo`03001oogoo01aoo`80045oo`03001oogoo02=oo`9l02]oo`03001oogoo00Qoo`03
O01oogoo00Eoo`03O01oogoo00Eoo`8001moo`03001oogoo029oo`002Woo00<007ooOol07Woo00<0
07ooOol0?Goo00<007ooOol08Goo0g`0;Goo00<007ooOol027oo00=l07ooOol01Goo00=l07ooOol0
17oo00<007ooOol07goo00<007ooOol08Woo000:Ool00`00Oomoo`0OOol00`00Oomoo`0kOol00`00
Oomoo`0POol2O00`Ool00`00Oomoo`07Ool00g`0Oomoo`02Ool30002Ool017`0Oomoogoo0P008goo
00<007ooOol08Goo000:Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00Oomoo`0OOol2O00bOol0
0`00Oomoo`06Ool00g`0Oomoo`02Ool00`00Oomoo`03Ool017`0Oomoo`009Woo00<007ooOol087oo
000:Ool00`00Oomoo`0QOol00`00Oomoo`0gOol00`00Oomoo`0NOol2O00dOol00`00Oomoo`06Ool0
0g`0Oomoo`02Ool00`00Oomoo`03Ool00g`0Ool0000XOol00`00Oomoo`0OOol000Yoo`03001oogoo
029oo`03001oogoo03Eoo`03001oogoo01eoo`9l03Ioo`03001oogoo00Eoo`03O01oogoo00Aoo`<0
009oo`8002Uoo`03001oogoo01moo`002Goo00<007ooOol097oo00<007ooOol0<goo00<007ooOol0
6goo0g`0>7oo00<007ooOol01Goo00=l07ooOol027oo00<007`0Ool0:Woo00<007ooOol07Woo0009
Ool00`00Oomoo`0UOol00`00Oomoo`0aOol00`00Oomoo`0JOol2O00kOol00`00Oomoo`04Ool00g`0
Oomoo`07Ool200000gooO01oo`0[Ool00`00Oomoo`0MOol000Uoo`03001oogoo02Ioo`03001oogoo
02moo`03001oogoo01Uoo`9l03eoo`03001oogoo00=oo`03O01oogoo00Moo`05001oogooOoml000/
Ool00`00Oomoo`0MOol000Uoo`03001oogoo02Moo`03001oogoo02eoo`03001oogoo01Qoo`9l03mo
o`03001oogoo00=oo`03O01oogoo00Ioo`03001oogoo009oo`03O01oogoo02]oo`03001oogoo01ao
o`002Goo00<007ooOol0:7oo00<007ooOol0:goo00<007ooOol05goo0W`0@7oo0P0017oo00=l07oo
Ool01Goo0P001Goo00=l07ooOol0;7oo00<007ooOol06goo0009Ool00`00Oomoo`0YOol00`00Oomo
o`0YOol00`00Oomoo`0EOol3O00oOol30002Ool01@00OomoogooO0001Woo00<007ooOol01Goo00=l
07ooOol0;7oo00<007ooOol06goo0009Ool00`00Oomoo`0ZOol00`00Oomoo`0WOol00`00Oomoo`0D
Ool2O00oOol30006Ool00`00Ooml0005Ool20008Ool00g`0Oomoo`0]Ool00`00Oomoo`0JOol000Uo
o`03001oogoo02]oo`03001oogoo02Eoo`03001oogoo01=oo`9l03ioo`<000Uoo`03001oog`000Ao
o`03001oogoo00Uoo`03O01oogoo00<001Aoo`03001oogoo009oo`8000moo`03001oogoo01Uoo`00
27oo00<007ooOol0;Goo00<007ooOol08goo00<007ooOol04Woo0W`0?Goo0`003Goo00@007ooOomo
o`8000aoo`03O01oo`0001Qoo`800005Ool007ooOol0000>Ool00`00Oomoo`0IOol000Qoo`03001o
ogoo02ioo`03001oogoo025oo`03001oogoo015oo`9l03aoo`<0015oo`03001oo`0000ioo`03O01o
o`0000<0019oo`L0009oo`03001oogoo00eoo`03001oogoo01Qoo`0027oo00<007ooOol0;goo00<0
07ooOol07goo00<007ooOol03goo0g`0>goo0`005Goo00<007ooOol03Goo00=l07ooOol00P001goo
30001Goo00@007oo0000015oo`03001oogoo01Moo`0027oo00<007ooOol0<7oo00<007ooOol07Goo
00<007ooOol03Woo0W`0>goo0`004Goo0`000Woo0`003goo30004Goo0P000Woo00<007ooOol03Woo
00<007ooOol05goo0008Ool00`00Oomoo`0aOol00`00Oomoo`0LOol00`00Oomoo`0<Ool2O00kOol2
0006Ool70n000`00Oomoo`06Ool00`00Ool00003Ool00`00Oomoo`0<00000g`0Oomoo`0JOol01000
Ool000004Woo00<007ooOol05Woo0008Ool00`00Oomoo`0bOol00`00Oomoo`0JOol00`00Oomoo`0;
Ool2O00jOol3000?0n000goo00000005Ool300000goo00000004000<Ool00g`0Oomoo`0aOol00`00
Oomoo`0EOol000Qoo`03001oogoo03=oo`03001oogoo01Qoo`03001oogoo00Uoo`=l03Eoo`@3h0<0
0183h0@000=oo`04001oogoo0006Ool00`00Oomoo`0:Ool00g`0Oomoo`0aOol00`00Oomoo`0EOol0
00Moo`03001oogoo03Eoo`03001oogoo01Ioo`03001oogoo00Qoo`9l01ioo`<000ioo`X3h0<001D3
h0=oo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00g`0Oomoo`0bOol00`00
Oomoo`0DOol000Moo`03001oogoo03Ioo`03001oogoo01Aoo`03001oogoo00Moo`9l01moo`03001o
ogoo00Iooa03h0<001P3h0=oo`03001oogoo009oo`<000Moo`03001oogoo00Uoo`03O01oogoo03=o
o`03001oogoo01=oo`001goo00<007ooOol0=goo00<007ooOol04Woo00<007ooOol01Woo0W`08Goo
00<000?P0n004`?P0`0050?P6Woo00<007ooOol027oo00=l07ooOol0<goo00<007ooOol04goo0007
Ool00`00Oomoo`0hOol00`00Oomoo`0@Ool00`00Oomoo`05Ool2O00JOol:0n03000?0n03000>0n0T
Ool00`00Oomoo`08Ool00g`0Oomoo`0cOol00`00Oomoo`0BOol000Moo`03001oogoo03Uoo`03001o
ogoo00ioo`03001oogoo00Aoo`9l01=oob83h0<000P3h2ioo`03001oogoo00Moo`03O01oogoo03Ao
o`03001oogoo015oo`001goo00<007ooOol0>Woo00<007ooOol037oo00<007ooOol04Goo:0?P0`00
0P?P=goo00<007ooOol01goo00=l07ooOol0=7oo00<007ooOol04Goo0007Ool00`00Oomoo`0kOol0
0`00Oomoo`0:Ool00`00Oomoo`09Ool]0n0017oo00000000?Goo00<007ooOol01Woo00=l07ooOol0
=Goo00<007ooOol047oo0006Ool00`00Oomoo`0mOol00`00Oomoo`08Ool00`00Oomoo`03Ool[0n07
Ool30011Ool00`00Oomoo`05Ool00g`0Oomoo`0fOol00`00Oomoo`0?Ool000Ioo`03001oogoo03io
o`03001oogoo009oo`D000Ioob83h0eoo`<004Eoo`03001oogoo00Aoo`03O01oogoo03Ioo`03001o
ogoo00moo`001Woo00<007ooOol0?goo00<007oo00000P0000=oo`00Ool00goo10006@?P4goo0`00
BGoo00<007ooOol00goo00=l07ooOol0=goo00<007ooOol03Woo0006Ool00`00Oomoo`10Ool20002
Ool20008Ool@0n0IOol3001<Ool00`00Oomoo`03Ool00g`0Oomoo`0hOol00`00Oomoo`0=Ool000Io
o`03001oogoo041oo`8000=oo`8000Eoo`8000L3h1moo`<0051oo`03001oogoo009oo`03O01oogoo
03Qoo`03001oogoo00eoo`001Woo00<007ooOol0@7oo00<007oo00000Woo0P002Goo20006Goo0`00
E7oo00D007ooOomoog`003]oo`03001oogoo00aoo`001Woo00<007ooOol0@7oo00<007ooOol00`00
00=oo`00Ool03goo20003goo0P00F7oo00@007ooOoml02Uoo`03001oogoo011oo`03001oogoo00]o
o`001Goo00<007ooOol0@Goo00D007ooOomoo`00009oo`03001oogoo01Ioo`L000Eoo`<005Yoo`05
001oogooOoml000SOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool000Eoo`03001o
ogoo045oo`03001oogoo009oo`04001oogoo000NOol8000IOol4000nOol01000Oomoog`097oo0P00
0Woo00<007ooOol047oo0P0037oo0005Ool00`00Oomoo`11Ool00`00Oomoo`03Ool00`00Ool0000M
Ool30006Ool8000@Ool01000Oomoo`00@7oo00<007ooO0009Goo0P000Woo00<007ooOol037oo0`00
00=oo`00Ool02goo0005Ool00`00Oomoo`12Ool00`00Oomoo`03Ool2000JOol3000AOol70009Ool0
1000Oomoo`00@Goo00<007`0Ool08Goo0`0000Eoo`00Oomoo`0000Yoo`@000Aoo`03001oogoo00Yo
o`001Goo00<007ooOol0@Woo00<007ooOol017oo00<007ooOol05Goo0`006goo20000Woo0`00@Woo
00<007ooOol03goo0`002Woo100017oo10001goo0`0027oo00<007ooOol02Woo0005Ool00`00Oomo
o`13Ool00`00Oomoo`03Ool2000COol3000VOol8000oOol00`00Oomoo`0>Ool00`00Oomoo`08Ool3
0008Ool00`00Oomoo`05Ool3000;Ool00`00Oomoo`0:Ool000Eoo`03001oogoo04Aoo`03001oogoo
009oo`03001oo`0000moo`<002aoo`8000=oo`P003Qoo`03001oogoo00eoo`03001oogoo00Eoo`<0
011oo`<000moo`03001oogoo00Uoo`001Goo00<007ooOol0A7oo00<007ooOol00Woo00@007ooOol0
00]oo`<003aoo`L0039oo`03001oogoo00eoo`<00004Ool00000000?Ool4000BOol00`00Oomoo`09
Ool000Aoo`03001oogoo04Ioo`05001oogooOol00003Ool00`00Oomoo`05Ool30016Ool8000[Ool0
0`00Oomoo`0<Ool4000?Ool3000FOol00`00Oomoo`09Ool000Aoo`03001oogoo04Moo`<000Eoo`04
001oogooOol3001AOol8000SOol00`00Oomoo`09Ool3000@Ool3000IOol00`00Oomoo`09Ool000Ao
o`03001oogoo051oo`<005aoo`L001eoo`03001oogoo00Eoo`<0011oo`<001aoo`03001oogoo00Uo
o`0017oo00<007ooOol0CGoo0`0000=oo`00Ool0Hgoo200027oo00<007ooOol02goo00<007ooOol0
10003goo10007goo00<007ooOol02Goo0004Ool00`00Oomoo`1:Ool30005Ool00`00Oomoo`1TOol0
0`00Oomoo`02Ool800000goo00000002Ool50002Ool5000@Ool3000SOol00`00Oomoo`09Ool000Ao
o`03001oogoo04Moo`<000Uoo`03001oogoo05ioo`P000Yoo`@000=oo`04001oogooOol400000goo
001oo`0<Ool3000VOol00`00Oomoo`09Ool000Aoo`03001oogoo04Aoo`<000eoo`03001oogoo059o
oa<000aoo`03001oogoo009oo`05001oogooOol00002Ool00`00Ool00009Ool4000YOol00`00Oomo
o`09Ool000=oo`03001oogoo049oo`<0015oo`03001oogoo04Mooah000]oo`03001oogoo009oo`05
001oogooOol00002Ool01000Oomoo`001Goo0`00;Woo00<007ooOol027oo0003Ool00`00Oomoo`10
Ool2000EOol00`00Oomoo`0kOolZ000?Ool01@00Oomoogoo00000Woo00H007ooOomoo`00Ool3000a
Ool00`00Oomoo`08Ool000=oo`03001oogoo03eoo`<001Qoo`03001oogoo031ooc@000ioo`8000Ao
o`8000=oo`<003Aoo`03001oogoo00Qoo`000goo00<007ooOol0>Woo0`0077oo00<007ooOol097oo
=@001Goo1P0057oo10000Woo00<007ooOol0<Woo00<007ooOol027oo0003Ool00`00Oomoo`0gOol3
000POol00`00Oomoo`0HOole000AOol6000@Ool30007Ool00`00Oomoo`0aOol00`00Oomoo`08Ool0
00=oo`03001oogoo03Aoo`<002Aoo`8000ioocD001]oo`L000aoo`<000]oo`03001oogoo031oo`03
001oogoo00Qoo`000goo00<007ooOol0<Goo0`00:Goo00<007ooOol0=@009goo1`0027oo0`003goo
00<007ooOol0;goo00<007ooOol027oo0002Ool00`00Oomoo`0_Ool3000UOole000bOol70003Ool4
000COol00`00Oomoo`0^Ool00`00Oomoo`08Ool0009oo`03001oogoo02aoo`<001eoocD003ioo`T0
01Moo`03001oogoo02moo`03001oogoo00Moo`000Woo00<007ooOol0:Goo0`0067oo<P00BWoo1P00
6Woo00<007ooOol0;Woo00<007ooOol01goo0002Ool00`00Oomoo`0VOol3000KOolX001COol8000J
Ool00`00Oomoo`0]Ool00`00Oomoo`07Ool0009oo`03001oogoo02=oo`<001iooad0009oo`03001o
ogoo05Eoo`@0009oo`L001Yoo`03001oogoo02aoo`03001oogoo00Moo`000Woo00<007ooOol087oo
0`008Goo7P000Woo00<007ooOol0DGoo0`001goo1`006Goo00<007ooOol0;7oo00<007ooOol01goo
0002Ool00`00Oomoo`0MOol3000TOolV001;Ool3000;Ool6000JOol00`00Oomoo`0[Ool00`00Oomo
o`07Ool0009oo`03001oogoo01Yoo`<002eoobP0041oo`<000moo`H001Yoo`03001oogoo02Yoo`03
001oogoo00Moo`0000=oo`00Ool06Goo0`00>7oo9`00=Goo10004goo1P006Woo00<007ooOol0:Goo
00<007ooOol01goo00000goo001oo`0FOol30013OolW000ZOol3000GOol7000JOol00`00Oomoo`0X
Ool00`00Oomoo`07Ool00003Ool007oo01Aoo`8004ioobL001moo`<001]oo`L001Uoo`03001oogoo
02Uoo`03001oogoo00Ioo`0000=oo`00Ool04Goo0`00F7oo9`0057oo0`007goo1`006Goo00<007oo
Ool0:7oo00<007ooOol01Woo00000goo001oo`0>Ool3001LOol00`00Oomoo`04OolW0008Ool4000S
Ool6000JOol00`00Oomoo`0WOol00`00Oomoo`06Ool00003Ool007oo00]oo`<0061oo`03001oogoo
00YoobP002Qoo`H001Yoo`03001oogoo02Ioo`03001oogoo00Ioo`0000=oo`00Ool027oo0`00I7oo
00<007ooOol04Goo9`008Woo1P006Goo00<007ooOol09Woo00<007ooOol01Woo00000`00Oomoo`05
Ool3001XOol00`00Oomoo`0HOolW000JOol7000IOol00`00Oomoo`0UOol00`00Oomoo`06Ool00003
001oogoo009oo`<006aoo`03001oogoo01moobL001=oo`L001Uoo`03001oogoo02Aoo`03001oogoo
00Ioo`0000<007oo00000P00L7oo00<007ooOol07Woo0`001Goo9`0037oo1`006Goo00<007ooOol0
8goo00<007ooOol01Woo0002001dOol00`00Oomoo`0JOol3000@OolW0005Ool6000JOol00`00Oomo
o`0ROol00`00Oomoo`06Ool00003Ool007oo07Aoo`03001oogoo01Eoo`@001Yoob`001Uoo`03001o
ogoo02=oo`03001oogoo00Eoo`000Woo0P00M7oo00<007ooOol04Goo0`009Woo9P0067oo00<007oo
Ool08Woo00<007ooOol01Goo0004Ool00`00Oomoo`1bOol00`00Oomoo`0=Ool3000aOolN000IOol0
0`00Oomoo`0QOol00`00Oomoo`05Ool000Eoo`03001oogoo079oo`03001oogoo00Uoo`<003aooaL0
01Uoo`03001oogoo021oo`03001oogoo00Eoo`001Woo00<007ooOol0LWoo00<007ooOol017oo1000
Agoo3P006goo00<007ooOol07goo00<007ooOol01Goo0007Ool2001cOol00`00Oomoo`03001COol6
000KOol00`00Oomoo`0OOol00`00Oomoo`05Ool000Uoo`03001oogoo075oo`8005Uoo`03001oogoo
01aoo`03001oogoo01ioo`03001oogoo00Eoo`002Woo00<007ooOol0L7oo00<007ooOol0N7oo00<0
07ooOol07Goo00<007ooOol01Goo000;Ool00`00Oomoo`1_Ool00`00Oomoo`1iOol00`00Oomoo`0L
Ool00`00Oomoo`05Ool000aoo`8006moo`03001oogoo07Uoo`03001oogoo01eoo`03001oogoo00Ao
o`003Woo00<007ooOol0K7oo00<007ooOol0NWoo00<007ooOol077oo00<007ooOol017oo000?Ool0
0`00Oomoo`1[Ool00`00Oomoo`1kOol00`00Oomoo`0KOol00`00Oomoo`04Ool0011oo`03001oogoo
06Yoo`03001oogoo07aoo`03001oogoo01Yoo`03001oogoo00Aoo`004Goo0P00JWoo00<007ooOol0
OGoo00<007ooOol06Goo00<007ooOol017oo000COol00`00Oomoo`1WOol00`00Oomoo`1mOol00`00
Oomoo`0IOol00`00Oomoo`04Ool001Aoo`03001oogoo06Ioo`03001oogoo07ioo`03001oogoo01Qo
o`03001oogoo00Aoo`005Goo00<007ooOol0IGoo00<007ooOol0Ogoo00<007ooOol05goo00<007oo
Ool017oo000FOol2001UOol00`00Oomoo`20Ool00`00Oomoo`0GOol00`00Oomoo`03Ool001Qoo`03
001oogoo069oo`03001oogoo081oo`03001oogoo01Moo`03001oogoo00=oo`006Goo00<007ooOol0
HGoo00<007ooOol0PGoo00<007ooOol05Woo00<007ooOol00goo000JOol00`00Oomoo`1POol00`00
Oomoo`22Ool00`00Oomoo`0EOol00`00Oomoo`03Ool001]oo`80061oo`03001oogoo08=oo`03001o
ogoo01Aoo`03001oogoo00=oo`007Goo00<007ooOol0GGoo00<007ooOol0Q7oo00<007ooOol04goo
00<007ooOol00goo000NOol00`00Oomoo`1LOol00`00Oomoo`24Ool00`00Oomoo`0COol00`00Oomo
o`03Ool001moo`8005aoo`03001oogoo08Eoo`03001oogoo019oo`03001oogoo00=oo`008Goo00<0
07ooOol0FGoo00<007ooOol0QWoo00<007ooOol04Goo00<007ooOol00goo000ROol00`00Oomoo`1H
Ool00`00Oomoo`27Ool00`00Oomoo`0AOol00`00Oomoo`02Ool002=oo`03001oogoo05Moo`03001o
ogoo08Moo`03001oogoo015oo`03001oogoo009oo`0097oo0P00Egoo00<007ooOol0R7oo00<007oo
Ool047oo00<007ooOol00Woo000VOol00`00Oomoo`1COol00`00Oomoo`2:Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool002Moo`03001oogoo059oo`03001oogoo08]oo`03001oogoo00ioo`03001oogoo
009oo`00:7oo00<007ooOol0DGoo00<007ooOol0S7oo00<007ooOol03Goo00<007ooOol00Woo000Y
Ool2001AOol00`00Oomoo`2<Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool002]oo`03001oogoo04io
o`03001oogoo08eoo`03001oogoo00aoo`03001oogoo009oo`00;7oo00<007ooOol0CGoo00<007oo
Ool0SWoo00<007ooOol02goo00<007ooOol00Woo000]Ool00`00Oomoo`1<Ool00`00Oomoo`2?Ool0
0`00Oomoo`0;Ool00`00Oomoo`01Ool002ioo`8004aoo`03001oogoo08moo`03001oogoo00]oo`03
001oogoo005oo`00<7oo00<007ooOol0BGoo00<007ooOol0T7oo00<007ooOol02Woo00<007ooOol0
0Goo000aOol00`00Oomoo`18Ool00`00Oomoo`2AOol00`00Oomoo`09Ool00`00Oomoo`01Ool0039o
o`03001oogoo04Moo`03001oogoo099oo`03001oogoo00Qoo`03001oogoo005oo`00<goo0P00Agoo
00<007ooOol0Tgoo00<007ooOol01goo00<007ooOol00Goo000eOol00`00Oomoo`14Ool00`00Oomo
o`2COol00`00Oomoo`07Ool00`00Oomoo`01Ool003Ioo`03001oogoo04=oo`03001oogoo09Aoo`03
001oogoo00Ioo`03001oogoo005oo`00=goo00<007ooOol0@Woo00<007ooOol0UGoo00<007ooOol0
1Woo0@000Goo0Goo000hOol20012Ool00`00Oomoo`2FOol00`00Oomoo`05Ool10001Ool1Ool003Yo
o`03001oogoo03moo`03001oogoo09Ioo`03001oogoo00Eoo`40005oo`5oo`00>goo00<007ooOol0
?Woo00<007ooOol0Ugoo00<007ooOol017oo0@000Goo0Goo000lOol00`00Oomoo`0mOol00`00Oomo
o`2HOol00`00Oomoo`03Ool10001Ool1Ool003eoo`8003eoo`03001oogoo09Uoo`03001oogoo009o
o`40005oo`5oo`00?goo00<007ooOol0>Woo00<007ooOol0VWoo00D007ooOomoo`00009oo`00@7oo
00<007ooOol0>Goo00<007ooOol0VWoo00D007ooOomoo`00009oo`00@Goo00<007ooOol0>7oo00<0
07ooOol0Vgoo00@007ooOol0009oo`00@Woo0P00>7oo00<007ooOol0W7oo00@007ooOol0005oo`00
A7oo00<007ooOol0=Goo00<007ooOol0WGoo00<007oo00000Goo0015Ool00`00Oomoo`0dOol00`00
Oomoo`2MOol00`00Ool00001Ool004Ioo`03001oogoo03=oo`03001oogoo09ioo`80005oo`00Agoo
0P00<goo00<007ooOol0WWoo0P000Goo0019Ool00`00Oomoo`0`Ool00`00Oomoo`2JOol40003Ool0
04Yoo`03001oogoo02moo`03001oogoo09Ioo`@000Moo`00Bgoo00<007ooOol0;Woo00<007ooOol0
TWoo10002goo001<Ool2000^Ool00`00Oomoo`2>Ool4000?Ool004ioo`03001oogoo02]oo`03001o
ogoo08Yoo`@001=oo`00Cgoo00<007ooOol0:Woo00<007ooOol0QWoo10005goo001@Ool00`00Oomo
o`0YOol00`00Oomoo`22Ool4000KOol0055oo`8002Uoo`03001oogoo07ioo`@001moo`00Dgoo00<0
07ooOol09Woo00<007ooOol0NWoo10008goo001DOol00`00Oomoo`0UOol00`00Oomoo`1fOol4000W
Ool005Eoo`03001oogoo02Aoo`03001oogoo079oo`@002]oo`00EWoo0P0097oo00<007ooOol0KWoo
1000;goo001HOol00`00Oomoo`0QOol00`00Oomoo`1ZOol4000cOol005Uoo`03001oogoo021oo`03
001oogoo06Ioo`@003Moo`00FWoo00<007ooOol07goo00<007ooOol0HWoo1000>goo001KOol2000O
Ool00`00Oomoo`1NOol4000oOol005eoo`03001oogoo01aoo`03001oogoo05Yoo`@004=oo`00GWoo
00<007ooOol06goo00<007ooOol0EWoo1000Agoo001OOol2000JOol00`00Oomoo`1COol4001;Ool0
065oo`03001oogoo01Moo`03001oogoo04moo`@004moo`00HWoo00<007ooOol05Woo00<007ooOol0
Bgoo1000Dgoo001SOol00`00Oomoo`0EOol00`00Oomoo`17Ool4001GOol006Aoo`8001Eoo`03001o
ogoo04=oo`@005]oo`00IWoo00<007ooOol04Woo00<007ooOol0?goo1000Ggoo001WOol00`00Oomo
o`0AOol00`00Oomoo`0kOol4001SOol006Qoo`03001oogoo011oo`03001oogoo03Moo`@006Moo`00
JGoo0P0047oo00<007ooOol0<goo1000Jgoo001[Ool00`00Oomoo`0=Ool00`00Oomoo`0_Ool4001_
Ool006aoo`03001oogoo00aoo`03001oogoo02]oo`@007=oo`00KGoo00<007ooOol02goo00<007oo
Ool09goo1000Mgoo001^Ool2000;Ool00`00Oomoo`0SOol4001kOol0071oo`03001oogoo00Qoo`03
001oogoo01moo`@007moo`00LGoo00<007ooOol01goo00<007ooOol06goo1000Pgoo001bOol00`00
Oomoo`06Ool00`00Oomoo`0GOol40027Ool007=oo`8000Ioo`03001oogoo01=oo`@008]oo`00MGoo
00<007ooOol00goo00<007ooOol03goo1000Sgoo001fOol00`00Oomoo`02Ool00`00Oomoo`0;Ool4
002COol007Moo`05001oogooOol00009Ool4002GOol007Qoo`800003Ool007oo00Aoo`@009]oo`00
NWoo0P0000=oo`0000000P00Wgoo001kOol2002SOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {268.938, 0}} -> {-0.000204162, 0.0102969, \
0.00329395, 0.00329395}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construction of all loops and their graphics", "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell["all loops", "Subsubsection",
  CellTags->"enfold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"patharrowsend", "=", 
      RowBox[{"List", "@@", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"Tpath", "@@", "patharrows"}], "//.", "loopfactorrules"}],
           ")"}]}]}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "10"}], "}"}], ",", "\<\"d\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"10", ",", "9"}], "}"}], ",", "\<\"d\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", 
                    RowBox[{"ArrowIndex", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], 
                      "]"}], "}"}], "]"}]}], "}"}], ",", "1"}], "]"}], ",", 
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"ArrowIndex", "[", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"1", ",", "2"}], "}"}], 
                          ",", "\<\"a\"\>"}], "]"}], ",", 
                      RowBox[{"ArrowIndex", "[", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"2", ",", "4"}], "}"}], 
                          ",", "\<\"e\"\>"}], "]"}]}], "}"}], "]"}]}], "}"}], 
            ",", "2"}], "]"}], ",", 
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "2"}], "}"}], ",", "\<\"a\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"2", ",", "4"}], "}"}], ",", "\<\"e\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"4", ",", "1"}], "}"}], ",", "\<\"d\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", "}"}], "]"}]}], "}"}], ",", "3"}], "]"}], ",", 
        
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"TNodeLoop", "[", 
                  RowBox[{"1", ",", "\<\"e\"\>"}], "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", "}"}], "]"}]}], "}"}], ",", "4"}], "]"}], ",", 
        
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"TNodeLoop", "[", 
                  RowBox[{"1", ",", "\<\"b\"\>"}], "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", "}"}], "]"}]}], "}"}], ",", "5"}], "]"}], ",", 
        
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "9"}], "}"}], ",", "\<\"c\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"9", ",", "4"}], "}"}], ",", "\<\"b\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"ArrowIndex", "[", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"1", ",", "2"}], "}"}], 
                          ",", "\<\"a\"\>"}], "]"}], ",", 
                      RowBox[{"ArrowIndex", "[", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"2", ",", "4"}], "}"}], 
                          ",", "\<\"e\"\>"}], "]"}]}], "}"}], "]"}]}], "}"}], 
            ",", "6"}], "]"}], ",", 
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "2"}], "}"}], ",", "\<\"a\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"2", ",", "4"}], "}"}], ",", "\<\"e\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"4", ",", "3"}], "}"}], ",", "\<\"a\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"ArrowIndex", "[", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"1", ",", "2"}], "}"}], 
                          ",", "\<\"a\"\>"}], "]"}], ",", 
                      RowBox[{"ArrowIndex", "[", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"2", ",", "3"}], "}"}], 
                          ",", "\<\"c\"\>"}], "]"}]}], "}"}], "]"}]}], "}"}], 
            ",", "7"}], "]"}], ",", 
        RowBox[{"TLoop", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"1", ",", "2"}], "}"}], ",", "\<\"a\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowIndex", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"2", ",", "3"}], "}"}], ",", "\<\"c\"\>"}], 
                  "]"}], ",", 
                RowBox[{"ArrowJump", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"3", ",", "10"}], "}"}], ",", "\<\"c\"\>"}], 
                  "]"}], ",", 
                RowBox[{"Inv", "[", 
                  RowBox[{"{", 
                    RowBox[{"ArrowIndex", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"1", ",", "10"}], "}"}], ",", "\<\"d\"\>"}],
                       "]"}], "}"}], "]"}]}], "}"}], ",", "8"}], "]"}], ",", 
        RowBox[{"ArrowIndex", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"1", ",", "10"}], "}"}], ",", "\<\"d\"\>"}], "]"}]}], 
      "}"}]], "Output",
  CellTags->"enfold"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["graphics for all loops", "Subsubsection",
  CellTags->"enfold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"pathelementsend", "=", 
          RowBox[{
            RowBox[{"Cases", "[", 
              RowBox[{"patharrowsend", ",", 
                RowBox[{"l_TLoop", "\[RuleDelayed]", 
                  RowBox[{"(", 
                    RowBox[{"l", "/.", "TLoop3Drule"}], ")"}]}]}], "]"}], "~",
             "Join", "~", "\[IndentingNewLine]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"DeleteCases", "[", 
                      RowBox[{"patharrowsend", ",", "l_TLoop"}], "]"}], "/.", 
                    "pathelementrules"}], "/.", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"x_", "?", "NumberQ"}], ",", 
                        RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
                    RowBox[{"{", 
                      RowBox[{"x", ",", "y", ",", "0"}], "}"}]}]}], "/.", 
                "circle3Drule"}], ")"}]}]}], ";"}], 
      "\[IndentingNewLine]"}]], "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["display all loops", "Subsection"],

Cell["\<\
If we continue factoring off basic loops, the path gets shorter.
Eventually, if it is originally a loop, there will be nothing left.
       ( For a general path there will may be a residue consisting of one \
extended branch of the spanning tree).\
\>", "Emphasis",
  CellTags->"emphasis"],

Cell["\<\
Here we see the basic loops stacked up (and the residue on the spanning \
tree).
The original path is the product of these loops.\
\>", "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"Graphics3D", "[", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"nodes2D", ",", "treearrs2D"}], "}"}], "/.", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"x_", "?", "NumberQ"}], ",", 
                        RowBox[{"y_", "?", "NumberQ"}]}], "}"}], "\[Rule]", 
                    RowBox[{"{", 
                      RowBox[{"x", ",", "y", ",", "0"}], "}"}]}]}], ",", 
                "pathelementsend"}], "}"}], "]"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"Length", "[", "pathelementsend", "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"BoxRatios", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{"2", ",", "2", ",", "2"}], "}"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 5.12828e-017 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.69763 .46827 m
.70145 .46229 L
s
.70145 .46229 m
.69209 .455 L
s
.30031 .42424 m
.70145 .46229 L
s
.72998 .46213 m
.85418 .42108 L
s
0 1 0 r
.02 w
.32304 .4264 m
.67961 .46021 L
s
0 g
.72658 .51479 m
.65559 .42197 L
s
.27321 .473 m
.72658 .51479 L
s
.5 Mabswid
.85312 .42959 m
.85418 .42108 L
s
.85418 .42108 m
.84425 .41615 L
s
.29582 .41957 m
.63403 .37315 L
s
.28829 .41173 m
.50536 .20303 L
s
.02 w
.27321 .473 m
.65559 .42197 L
s
.5 Mabswid
.63242 .38126 m
.63403 .37315 L
s
.63403 .37315 m
.62335 .36668 L
s
.66212 .36949 m
.82206 .35095 L
s
.65968 .36618 m
.77921 .28485 L
s
.81944 .35913 m
.82206 .35095 L
s
.02 w
.26875 .52572 m
.51858 .29811 L
s
.26875 .52572 m
.65794 .4753 L
s
.5 Mabswid
.82206 .35095 m
.81196 .34418 L
s
.02 w
.78733 .35735 m
.26413 .58033 L
s
.26413 .58033 m
.51842 .35544 L
s
.65794 .4753 m
.78213 .30003 L
s
.27017 .65284 m
.27144 .66017 L
s
.26575 .64435 m
.27017 .65284 L
s
.27144 .66017 m
.26923 .66441 L
s
.5 Mabswid
.78022 .29545 m
.77921 .28485 L
s
.02 w
.25934 .63693 m
.26575 .64435 L
s
.26923 .66441 m
.2641 .66443 L
s
.25262 .63256 m
.25934 .63693 L
s
.5 Mabswid
.77921 .28485 m
.76835 .28085 L
s
.02 w
.2641 .66443 m
.25737 .66016 L
s
.24739 .63244 m
.25262 .63256 L
s
.25737 .66016 m
.25087 .65271 L
s
.24508 .63666 m
.24739 .63244 L
s
.25087 .65271 m
.24635 .64409 L
s
.24635 .64409 m
.24508 .63666 L
s
.26542 .71157 m
.26672 .71909 L
s
.26092 .70301 m
.26542 .71157 L
s
.26672 .71909 m
.26445 .72358 L
s
.25437 .69564 m
.26092 .70301 L
s
.26445 .72358 m
.2592 .72384 L
s
.2475 .69144 m
.25437 .69564 L
s
.2592 .72384 m
.25233 .71974 L
s
.24215 .69156 m
.2475 .69144 L
s
.25233 .71974 m
.24568 .71235 L
s
.23979 .69603 m
.24215 .69156 L
s
.24568 .71235 m
.24108 .70365 L
s
.24108 .70365 m
.23979 .69603 L
s
.5 Mabswid
.5086 .21476 m
.50536 .20303 L
s
.02 w
.24921 .75658 m
.5179 .54238 L
s
.24921 .75658 m
.66824 .70951 L
s
.5 Mabswid
.50536 .20303 m
.49363 .19934 L
s
.75596 .20063 m
.75966 .19189 L
s
.75966 .19189 m
.74878 .18296 L
s
.53156 .19013 m
.75966 .19189 L
s
.02 w
.23829 .88566 m
.75347 .92204 L
s
.75818 .6085 m
.75347 .92204 L
s
.5 Mabswid
.52863 .18617 m
.7107 .11401 L
s
.52569 .18219 m
.6579 .03 L
s
.02 w
.24386 .81987 m
.51772 .61022 L
s
.66824 .70951 m
.8043 .54421 L
s
.23829 .88566 m
.51752 .68113 L
s
.5 Mabswid
.71025 .12561 m
.7107 .11401 L
s
.7107 .11401 m
.69865 .10727 L
s
.02 w
.51858 .29811 m
.78213 .30003 L
s
.51842 .35544 m
.78733 .35735 L
s
.5 Mabswid
.66107 .04398 m
.6579 .03 L
s
.6579 .03 m
.64563 .02635 L
s
.02 w
.5179 .54238 m
.8043 .54421 L
s
.81045 .61201 m
.75281 .53606 L
s
.51772 .61022 m
.81045 .61201 L
s
.51772 .61022 m
.75281 .53606 L
s
.51752 .68113 m
.75818 .6085 L
s
[(6)] .66582 .02088 0 0 Mshowa
[(3)] .72119 .10985 0 0 Mshowa
[(4)] .77232 .19199 0 0 Mshowa
[(2)] .51887 .19003 0 0 Mshowa
[(5)] .78615 .28012 0 0 Mshowa
[(8)] .83104 .34991 0 0 Mshowa
[(9)] .65333 .37051 0 0 Mshowa
[(7)] .86124 .41875 0 0 Mshowa
[(10)] .72325 .46435 0 0 Mshowa
[(1)] .27752 .42208 0 0 Mshowa
gsave
.5817 .10052 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61201 .1418 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.64159 .18213 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71213 .31933 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73767 .35282 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78676 .43523 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38347 .30604 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45768 .38951 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49947 .43667 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 312.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001>1000`40O003h00O_goo0P00Ggoo002m
Ool200000goo0000001NOol00;]oo`8000=oo`8005ioo`00^7oo0`001Goo00<007oo0000GGoo002f
Ool20005Ool400000goo001oo`1LOol00;=oo`<000Moo`04001oogoo0002Ool00`00Oomoo`1JOol0
0;5oo`8000Yoo`04001oogoo0003Ool00`00Oomoo`1IOol00:moo`8000aoo`@000=oo`03001oogoo
05Uoo`00[7oo0`002Woo0P000goo00<007oo000017oo00<007ooOol0F7oo002ZOol2000?Ool20000
0goo000000020004Ool00`00Oomoo`1GOol00:Moo`<0015oo`8000Aoo`03001oogoo009oo`03001o
ogoo05Moo`00YGoo0P004goo00<007oo000017oo00<007ooOol00goo00<007ooOol0EWoo002SOol2
000DOol01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol0EWoo002POol3000EOol00`00
Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol0EGoo002NOol2000HOol00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`1DOol009aoo`8001Uoo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo05Aoo`00VGoo0`006Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0Dgoo002G
Ool2000LOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`1BOol009Aoo`<001eoo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo059oo`00TWoo0P007goo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol0DGoo002@Ool2000POol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomo
o`1AOol008eoo`<0025oo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo051oo`00Rgoo0P00
97oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol0Cgoo0028Ool3000UOol00`00Oomoo`0>
Ool00`00Oomoo`0:Ool00`00Oomoo`1?Ool008Ioo`8002Moo`03001oogoo00moo`03001oogoo00]o
o`03001oogoo04ioo`00Q7oo0P00:7oo00<007ooOol047oo00<007ooOol037oo00<007ooOol0CGoo
0021Ool3000YOol00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomoo`1=Ool007moo`80029oo`@0
00Eoo`03001oogoo01=oo`03001oogoo00aoo`03001oogoo04aoo`00OGoo0P009Goo00@007ooOol0
00=oo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo04aoo`00NWoo0`009goo00@007ooOol0
009oo`03001oogoo01Eoo`03001oogoo00Qoo`8000=oo`03001oogoo04]oo`00N7oo0P00:Woo0`00
0Woo00<007ooOol05Woo00<007ooOol01goo00@007ooOol000=oo`03001oogoo04Yoo`00MGoo0`00
;7oo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol0BWoo001cOol2000^Ool20003Ool00`00Oomoo`0GOol00`00Oomoo`04Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`19Ool0075oo`8003Aoo`03001oogoo01Qoo`03001oogoo00Eo
o`<0009oo`03001oogoo00=oo`03001oogoo04Qoo`00KWoo0`00=Goo00<007ooOol06Goo00<007oo
Ool00goo0P0000=oo`00Ool00P001Woo00<007ooOol0B7oo001/Ool2000gOol00`00Oomoo`0JOol0
0`00Oomoo`030003Ool00`00Oomoo`08Ool00`00Oomoo`17Ool006Uoo`<003Qoo`03001oogoo01]o
o`<000Ioo`03001oogoo00Qoo`03001oogoo04Moo`00Igoo0P00>Woo00<007ooOol06Woo0`0057oo
00<007ooOol0AWoo001UOol2000kOol00`00Oomoo`0HOol30002Ool00`00Oomoo`0COol00`00Oomo
o`15Ool0069oo`<003aoo`03001oogoo00Yoo`<000Yoo`8000Eoo`03001oogoo01=oo`03001oogoo
04Eoo`00H7oo0P00?goo00<007ooOol02Goo00<007ooOol027oo0`001goo00<007ooOol057oo00<0
07ooOol0A7oo001MOol30010Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool3000:Ool00`00Oomoo`0D
Ool00`00Oomoo`14Ool005]oo`80049oo`03001oogoo00aoo`<0009oo`8000eoo`03001oogoo01Eo
o`03001oogoo04=oo`00FGoo0P00@goo00<007ooOol03goo0`0047oo00<007ooOol05Goo00<007oo
Ool0@Woo001FOol30014Ool00`00Oomoo`0>Ool2000COol00`00Oomoo`0EOol00`00Oomoo`12Ool0
05Aoo`8004Ioo`03001oogoo00aoo`<001Eoo`03001oogoo01Ioo`03001oogoo045oo`00DWoo0P00
Agoo00<007ooOol02Woo0`0067oo00<007ooOol05goo00<007ooOol0@7oo001?Ool30018Ool00`00
Oomoo`09Ool2000KOol00`00Oomoo`0GOol00`00Oomoo`10Ool004eoo`8004]oo`03001oogoo00Io
o`<001eoo`03001oogoo01Qoo`03001oogoo03moo`00BWoo0`00C7oo00<007ooOol01Goo0P0087oo
00<007ooOol067oo00<007ooOol0?goo0018Ool2001>Ool00`00Oomoo`03Ool3000ROol00`00Oomo
o`0IOol00`00Oomoo`0nOol004Ioo`8004moo`04001oogooOol3000IOol30009Ool00`00Oomoo`0J
Ool00`00Oomoo`0mOol004=oo`<004aoo`D0009oo`8001]oo`03001oogoo00Yoo`03001oogoo011o
o`03001oogoo00Moo`03001oogoo03eoo`00@Goo0P00Cgoo00<007ooOol00Woo0P007Goo10002Goo
00<007ooOol04Goo00<007ooOol00goo0`0000=oo`00Ool0?Goo000nOol3001BOol00`00Oomoo`0Q
Ool2000:Ool00`00Oomoo`0BOol20004Ool01@00Oomoogoo0000?Goo000lOol2001FOol01000Oomo
ogooB0000Woo00<007ooOol0>goo000jOol2001FOol01000Oomoo`00;Goo00<007ooOol04goo00<0
07oo00000Woo00<007ooOol00Woo00<007ooOol0>Woo000gOol3001COol20004Ool2000^Ool00`00
Oomoo`0COol01P00Oomoo`00Ool000Aoo`03001oogoo03Yoo`00=Goo0P00F7oo0`00<Goo00<007oo
Ool04Woo00<007ooOol00Woo0P001Goo00<007ooOol0>Goo000cOol2001KOol2000bOol00`00Oomo
o`0NOol00`00Oomoo`0hOol0031oo`<005aoo`03001oo`00039oo`03001oogoo01ioo`03001oogoo
03Qoo`00;Woo0P00GWoo00@007ooOol0039oo`03001oogoo01moo`03001oogoo03Moo`00:goo0`00
Ggoo00D007ooOomoo`00039oo`03001oogoo021oo`03001oogoo03Ioo`00:Goo0P00HGoo00<007oo
Ool0=Goo00<007ooOol087oo00<007ooOol0=Woo000WOol2001ROol00`00Oomoo`0fOol00`00Oomo
o`0QOol00`00Oomoo`0eOol002Aoo`<006=oo`03001oogoo03Moo`03001oogoo025oo`03001oogoo
03Eoo`008Woo0P00IGoo00<007ooOol0>7oo00<007ooOol08Woo00<007ooOol0=7oo000OOol3001V
Ool00`00Oomoo`0iOol00`00Oomoo`0SOol00`00Oomoo`0cOol001eoo`8006Moo`8003aoo`03001o
ogoo02=oo`03001oogoo03=oo`006goo0P00J7oo00<007ooOol0?7oo00<007ooOol097oo00<007oo
Ool0<Woo000IOol2001YOol00`00Oomoo`0mOol00`00Oomoo`0UOol00`00Oomoo`0aOol001Uoo`80
06Qoo`03001oogoo03ioo`03001oogoo02Eoo`03001oogoo035oo`006Goo00<007oo0000IWoo00<0
07ooOol0?goo00<007ooOol09Woo00<007ooOol0<7oo000IOol01000Oomoo`00I7oo00<007ooOol0
@7oo00<007ooOol09Woo00<007ooOol0<7oo000HOol00`00Oomoo`02Ool00`00Oomoo`1POol00`00
Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0_Ool001Qoo`03001oogoo00=oo`03001oogoo05io
o`03001oogoo049oo`03001oogoo02Qoo`03001oogoo02ioo`0067oo00<007ooOol017oo00<007oo
Ool0G7oo00<007ooOol0A7oo00<007ooOol09goo00<007ooOol0;Woo000HOol00`00Oomoo`05Ool0
0`00Oomoo`1JOol00`00Oomoo`15Ool00`00Oomoo`0XOol00`00Oomoo`0]Ool001Qoo`03001oogoo
00Ioo`03001oogoo05Qoo`03001oogoo04Ioo`03001oogoo01Qoo`8000moo`03001oogoo02aoo`00
67oo00<007ooOol01goo00<007ooOol0EWoo00<007ooOol0Agoo00<007ooOol05goo00@007ooOol0
00ioo`03001oogoo02aoo`005goo00<007ooOol02Goo00<007ooOol0E7oo00<007ooOol0B7oo00<0
07ooOol06Woo00<007ooOol03Goo00<007ooOol0:goo000GOol00`00Oomoo`0:Ool00`00Oomoo`1B
Ool00`00Oomoo`19Ool00`00Oomoo`0DOol20002Ool2000@Ool00`00Oomoo`0[Ool001Moo`03001o
ogoo00]oo`03001oogoo051oo`03001oogoo04Yoo`03001oogoo01Ioo`<0019oo`03001oogoo02Yo
o`005goo00<007ooOol037oo00<007ooOol0CWoo00<007ooOol06Woo00<007ooOol0;Woo00<007oo
Ool05Goo1P004Goo00<007ooOol0:Goo000GOol00`00Oomoo`0=Ool00`00Oomoo`1<Ool00`00Oomo
o`0IOomA000AOol00`00Oomoo`0YOol001Moo`03001oogoo00ioo`03001oogoo04Yoo`03001oogoo
01Yooe40019oo`03001oogoo02Qoo`005goo00<007ooOol03goo00<007ooOol0@7oo1@000goo00<0
07ooOol06WooD`004Goo00<007ooOol0:7oo000FOol00`00Oomoo`0@Ool00`00Oomoo`10Ool40003
Ool00`00Oomoo`0JOomC000COol00`00Oomoo`0WOol001Ioo`03001oogoo015oo`03001oogoo049o
o`04001oo`00000LOomD000DOol00`00Oomoo`0VOol001Ioo`03001oogoo019oo`03001oogoo03mo
o`@001eoo`L0031oo`03001oogoo00aoo`8000Eoo`H001Ioo`03001oogoo02Ioo`005Woo00<007oo
Ool04goo00<007ooOol0@7oo00<007ooOol06Woo2000<Goo00<007ooOol00goo0`001Goo00<007oo
Ool01Goo1P005goo00<007ooOol09Goo000FOol00`00Oomoo`0DOol00`00Oomoo`0nOol00`00Oomo
o`0JOol8000bOol00`00Oomoo`02Ool00`00Oomoo`04Ool20007Ool6000IOol00`00Oomoo`0TOol0
01Ioo`03001oogoo01Eoo`03001oogoo03aoo`03001oogoo01Yoo`P003=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Ioo`H001Yoo`03001oogoo02Aoo`005Goo00<007ooOol05goo00<0
07ooOol0>Woo00<007ooOol06Woo2000=Goo00<007ooOol00Woo0`0000=oo`00Ool01goo1`006goo
00<007ooOol08goo000EOol00`00Oomoo`0HOol00`00Oomoo`0hOol00`00Oomoo`0JOol7000gOol0
0`00Oomoo`04Ool20009Ool6000LOol00`00Oomoo`0SOol001Eoo`03001oogoo01Uoo`03001oogoo
03Ioo`03001oogoo01Yoo`L003Qoo`03001oogoo00=oo`03001oogoo00Qoo`H001ioo`03001oogoo
029oo`005Goo00<007ooOol06Woo00<007ooOol0=7oo00<007ooOol06Woo1`00>Goo00@007ooOomo
o`8000Yoo`H0021oo`03001oogoo025oo`005Goo00<007ooOol06goo00<007ooOol0<Woo00<007oo
Ool06Woo1`00>Woo00@007ooOol000]oo`L0021oo`03001oogoo025oo`005Goo00<007ooOol077oo
00<007ooOol0<7oo00<007ooOol06Woo1`00>goo0`0037oo1P004Woo0P003Woo00<007ooOol087oo
000DOol00`00Oomoo`0NOol00`00Oomoo`0^Ool00`00Oomoo`0JOol7000:Ool00`00Oomoo`0_Ool0
0`00Oomoo`0;Ool6000?Ool01000Oomoo`000Woo00<007ooOol037oo00<007ooOol07goo000DOol0
0`00Oomoo`0OOol00`00Oomoo`0/Ool00`00Oomoo`0JOol70009OolY0009Ool3000;Ool70009Ool0
0`00Oomoo`05Ool00`00Ool00002Ool00`00Oomoo`0<Ool00`00Oomoo`0OOol001Aoo`03001oogoo
021oo`03001oogoo02Yoo`03001oogoo01Uoo`P000Yooe8000=oo`D00003Ool00000011oo`03001o
ogoo01ioo`0057oo00<007ooOol08Goo00<007ooOol0:7oo00<007ooOol06Goo20002WooEP0017oo
0P000Woo00<007ooOol03Goo00<007ooOol07Woo000DOol00`00Oomoo`0ROol00`00Oomoo`0VOol0
0`00Oomoo`0IOol8000:OomD0007Ool01000Ool000004Goo00<007ooOol07Goo000DOol00`00Oomo
o`0SOol00`00Oomoo`0TOol00`00Oomoo`0IOol80009OomG000LOol00`00Oomoo`0LOol001Aoo`03
001oogoo02Aoo`03001oogoo029oo`03001oogoo01Uoo`L000Yoo`P001eoo`03001oogoo00IoobT0
01eoo`03001oogoo01aoo`004goo00<007ooOol09Woo00<007ooOol087oo00<007ooOol06Goo1`00
2Woo20007goo0P001Goo0`0000=oo`0000000`000goo00<007ooOol01Woo4P008Goo00<007ooOol0
6goo000COol00`00Oomoo`0WOol00`00Oomoo`0NOol00`00Oomoo`0IOol7000:Ool8000OOol40003
Ool01000Oomoo`002Goo00<007ooOol01Goo4@0097oo00<007ooOol06Woo000COol00`00Oomoo`0X
Ool00`00Oomoo`0KOol2000KOol7000:Ool7000IOol80003Ool01@00Oomoogoo00000Woo00<007oo
Ool01goo00<007ooOol01Goo3`009Woo00<007ooOol06Woo000COol00`00Oomoo`0YOol00`00Oomo
o`0IOol00`00Oomoo`0JOol7000:Ool7000COol7000;Ool00`00Oomoo`02Ool30009Ool00`00Oomo
o`04Ool=000ZOol00`00Oomoo`0IOol001=oo`03001oogoo02Yoo`03001oogoo01Moo`03001oogoo
01Yoo`L000Aoo`<000=oo`L000aoo`P002Aoo`03001oogoo00h002aoo`03001oogoo01Uoo`004goo
00<007ooOol0:goo00<007ooOol05Goo00<007ooOol06Woo1`0017oo00<007ooOol00goo1`001Woo
1`00;7oo3`00;goo00<007ooOol067oo000BOol00`00Oomoo`0]Ool00`00Oomoo`0COol00`00Oomo
o`0IOol80005Ool00`00Oomoo`02Ool>000bOol=000cOol00`00Oomoo`0GOol0019oo`03001oogoo
02ioo`03001oogoo015oo`03001oogoo01Uoo`P000Moo`X003Moo`h003Eoo`03001oogoo01Moo`00
4Woo00<007ooOol0;goo00<007ooOol03goo00<007ooOol06Goo200017oo3@00=Woo3P00>7oo00<0
07ooOol05Woo000BOol00`00Oomoo`0`Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol=0004Ool8000d
OolA000iOol00`00Oomoo`0EOol0019oo`03001oogoo035oo`03001oogoo00]oo`03001oogoo01Qo
o`P000Yoo`P003=ooa8003Yoo`03001oogoo01Eoo`004Woo00<007ooOol0<Woo00<007ooOol02Goo
00<007ooOol04Goo3`002Woo1`00<goo4`00?7oo00<007ooOol057oo000BOol00`00Oomoo`0cOol0
0`00Oomoo`07Ool00`00Oomoo`0;Ool70007Ool7000:Ool7000aOol>00000goo00000005000ZOol0
0`00Oomoo`0?Ool00`00Oomoo`0DOol0015oo`03001oogoo03Aoo`03001oogoo009oo`D000Ioo`P0
00eoo`L000Yoo`L0031oo`h000=oo`H002Ioo`03001oogoo009oo`03001oogoo00moo`8001Eoo`00
4Goo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol00Woo10000Woo20?P2Woo1`002Woo1`00
;Woo3P001Goo1P00:7oo0P000Woo00<007ooOol037oo0`0000=oo`00Ool057oo000AOol00`00Oomo
o`0fOol00`00Oomoo`02Ool00`00Oomoo`08OolA0n070009Ool8000WOolF0004Ool6000ZOol20002
Ool00`00Oomoo`08Ool30004Ool00`00Oomoo`0COol0015oo`03001oogoo03Moo`05001oogooOol0
0006Ool4000?0n0800050n04Ool8000QOolM0004Ool6000WOol50002Ool00`00Oomoo`05Ool30007
Ool00`00Oomoo`0COol0015oo`03001oogoo03Qoo`04001oogoo000:Ool>0n0800090n08000KOolU
0002Ool6000GOol3000;Ool30003Ool50004Ool3000;Ool00`00Oomoo`0BOol0015oo`03001oogoo
03Uoo`<000Yoo`d3h0P000T3h0P000/3h0=oo`@0009oobD000=oo``001Moo`03001oogoo00Uoo`<0
00aoo`<000ioo`03001oogoo019oo`0047oo00<007ooOol0>goo00<007ooOol04Goo10?P20002@?P
1`003`?P:0001goo30005goo00<007ooOol01Woo0`0037oo0`004Goo00<007ooOol04Woo000@Ool0
0`00Oomoo`0lOol00`00Oomoo`0COol7000:0n0700080n0]000;Ool;000HOol30002Ool3000<Ool3
000DOol00`00Oomoo`0BOol0011oo`03001oogoo03eoo`03001oogoo015oo`L000Yoo`L00083h380
00ioo`P0009oo`03001oogoo01Moo`<000]oo`@001Moo`03001oogoo019oo`0047oo00<007ooOol0
?Woo00<007ooOol03goo1`002Woo:00010?P3P001P?P2goo1P000goo00<007ooOol057oo0`002goo
0`006goo00<007ooOol04Woo000@Ool00`00Oomoo`0oOol00`00Oomoo`0=Ool70006OolU000:0n0=
000C0n080002Ool00`00Oomoo`0AOol3000;Ool3000NOol00`00Oomoo`0BOol0011oo`03001oogoo
041oo`03001oogoo00]oob`000Qoo`H3h0h001D3h0P0009oo`03001oogoo00ioo`<000]oo`<0029o
o`03001oogoo015oo`0047oo00<007ooOol0@Goo00<007ooOol02Goo9@0057oo3P005P?P2P0000=o
o`00Ool01@000Woo0P000goo0`002goo0`009Goo00<007ooOol04Goo000?Ool00`00Oomoo`13Ool0
1000Oomoogoo9@006Goo3@001Woo4P?P3@000goo00D007ooOomoo`00009oo`<000]oo`<002Qoo`03
001oogoo015oo`003goo00<007ooOol0@7oo9@007Goo3P004Woo20?P3P000Woo00@007ooOomoo`@0
00Yoo`<002]oo`03001oogoo015oo`003goo00<007ooOol0>Woo:0007Woo3P006Goo20000P?P1P00
0goo00D007ooOomoo`00009oo`03001oogoo00Eoo`<002ioo`03001oogoo015oo`003goo00<007oo
Ool0>Woo700017oo1`007Goo3@005Goo3P0017oo1P000Woo00D007ooOomoo`00009oo`03001oogoo
009oo`<0035oo`03001oogoo015oo`003goo00<007ooOol0>Woo7P0000=oo`0000001@006goo3P00
3goo5P0017oo2@0017oo0P000Woo0`00=7oo00<007ooOol04Goo000?Ool00`00Oomoo`0jOolX000G
Ool>000:OolL0006Ool60007Ool3000gOol00`00Oomoo`0AOol000ioo`03001oogoo03]ooc<000Yo
o`d000Eoob@000Moo`H000=oo`<003]oo`03001oogoo011oo`003Woo00<007ooOol0@gooI@000goo
00<007ooOol027oo2000?Woo00<007ooOol047oo000>Ool00`00Oomoo`15Ool800000goo0000001A
000EOol7000oOol00`00Oomoo`0@Ool000ioo`03001oogoo04Aoo`L0009oo`03001oogoo00AoodD0
01aoo`P003moo`03001oogoo011oo`003Woo00<007ooOol0@goo1`0017oo00<007ooOol00Woo1`00
2Goo=P006Goo0`000Woo1`00?Woo00<007ooOol047oo000>Ool00`00Oomoo`12Ool70006Ool00`00
Oomoo`07000<Oolo000:Ool40006Ool7000mOol00`00Oomoo`0@Ool000ioo`03001oogoo041oo`P0
00Qoo`P000Iooe4000Uoo`P003aoo`03001oogoo011oo`003Goo00<007ooOol0@7oo200027oo;000
2Goo?000?Goo00<007ooOol03goo000=Ool00`00Oomoo`0oOol80008OolV000KOolc000kOol00`00
Oomoo`0?Ool000eoo`03001oogoo03ioo`P0009oobT002UoobT003]oo`03001oogoo00moo`003Goo
00<007ooOol0?Goo<P00<Goo0`000Woo7`00>Woo00<007ooOol03goo000=Ool00`00Oomoo`0kOolb
000`Ool3000@OolC000kOol00`00Oomoo`0?Ool000eoo`03001oogoo03]ooad000Eoo`d0031oo`<0
01aoo`03001oo`0000L003]oo`03001oogoo00moo`0037oo00<007ooOol0>goo5`001Woo00<007oo
Ool03P00;goo0`007goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0<goo00<007ooOol0
3goo000<Ool00`00Oomoo`0lOol=00000goo000000050008Ool>000^Ool3000ROol00`00Oomoo`0:
Ool5000dOol00`00Oomoo`0>Ool000aoo`03001oogoo03aoo`H000Ioo`P000Ioo`h0025oo`03001o
ogoo00Yoo`<002Eoo`03001oogoo00Moo`P000]oo`03001oogoo02Ioo`03001oogoo00ioo`0037oo
00<007ooOol0?Woo00<007ooOol01Woo20001Goo3P008GooE`009Woo00<007ooOol03Woo000<Ool0
0`00Oomoo`16Ool80004Ool>000SOomG000VOol00`00Oomoo`0>Ool000aoo`03001oogoo04Eoo`P0
009oo`l002=ooeX002Eoo`03001oogoo00ioo`002goo00<007ooOol0AGoo1`000Woo3P000goo00<0
07ooOol07gooFP009Woo00<007ooOol03Woo000;Ool00`00Oomoo`14Ool700000goo0000000;0007
Ool00`00Oomoo`0MOomK000VOol00`00Oomoo`0>Ool000]oo`03001oogoo04=ooa@000Yoo`03001o
ogoo01]oo`P002]ooa4000Qoo`H0009oo`H002Qoo`03001oogoo00ioo`002goo00<007ooOol0@Woo
4`003Goo00<007ooOol067oo2000:Goo4P0037oo3000:Woo00<007ooOol03Goo000;Ool00`00Oomo
o`11OolA000AOol00`00Oomoo`0DOol:000WOolB000?Ool<000ZOol00`00Oomoo`0=Ool000]oo`03
001oogoo03mooa4001Aoo`03001oogoo011oo`<00003Ool0000000H002Eooa4000=oo`03001oogoo
00ioo`X002]oo`03001oogoo00eoo`002goo00<007ooOol0?Woo40005goo00<007ooOol037oo0`00
0goo20008goo4@001Woo00<007ooOol03goo2000;7oo00<007ooOol03Goo000:Ool00`00Oomoo`0n
Ool>000KOol00`00Oomoo`08Ool30004Ool8000ROolA0009Ool00`00Oomoo`0@Ool6000]Ool00`00
Oomoo`0=Ool000Yoo`03001oogoo03aoo`h001ioo`03001oogoo00Aoo`<000Ioo`P001mooa4000eo
o`03001oogoo00moo`P002aoo`03001oogoo00eoo`002Woo00<007ooOol0>goo3@008Goo00<007oo
Ool00`0027oo20007Goo4@0047oo00<007ooOol03Woo2@00;7oo00<007ooOol03Goo000:Ool00`00
Oomoo`0kOol:000UOol2000:Ool8000KOolA000COol00`00Oomoo`0=Ool;000/Ool00`00Oomoo`0<
Ool000Yoo`03001oogoo03aoo`L002Moo`03001oogoo00Moo`P001Yooa4001Eoo`8000moo``002]o
o`03001oogoo00aoo`002Woo00<007ooOol0?Goo1000:Goo00<007ooOol01Woo20005goo4P005Goo
0`000Woo00<007ooOol02goo1P0000=oo`0000001@00:Woo00<007ooOol037oo0009Ool00`00Oomo
o`0nOol2000[Ool00`00Oomoo`05Ool8000EOolA000EOol40006Ool00`00Oomoo`09Ool60003Ool6
000ZOol00`00Oomoo`0<Ool000Uoo`03001oogoo06]oo`03001oogoo00Aoo`P001=ooa4001Eoo`<0
00Yoo`03001oogoo00Qoo`L000Aoo`H002Uoo`03001oogoo00aoo`002Goo00<007ooOol0Jgoo00<0
07ooOol00Woo200047oo00<007oo000040005Goo0`003Woo00<007ooOol01Woo1`001Woo1P00:7oo
00<007ooOol037oo0009Ool00`00Oomoo`1[Ool01000Oomoogoo20003goo;00047oo00<007ooOol0
17oo1`001goo1P00:7oo00<007ooOol037oo0009Ool00`00Oomoo`1[Ool00`00Oomoo`08000@OomI
000WOol00`00Oomoo`0;Ool000Uoo`03001oogoo06]oo`X000mooe/002Moo`03001oogoo00]oo`00
2Goo00<007ooOol0Jgoo200047ooG@009Woo00<007ooOol02goo0008Ool00`00Oomoo`1[Ool8000@
OomM000WOol00`00Oomoo`0;Ool000Qoo`03001oogoo03]oo`03001oo`0002aoo`P000moo`T001Ao
o`<0019oobd002Moo`03001oogoo00]oo`0027oo00<007ooOol0>Woo1P00:7oo200047oo20004goo
0`006Woo6@0037oo00<007ooOol09goo00<007ooOol02goo0008Ool00`00Oomoo`0jOol6000WOol8
000@Ool8000@Ool4000IOolG00000goo00000003000fOol00`00Oomoo`0;Ool000Qoo`03001oogoo
03Uoo`P002Eoo`P000moo`T000ioo`<001Yooa800003Ool0000000D00003Ool0000000<003Moo`03
001oogoo00Yoo`0027oo00<007ooOol0>Goo2@008goo20003goo20003Goo0`006Goo4P0017oo2000
00=oo`0000000`00=goo00<007ooOol02Woo0007Ool00`00Oomoo`0jOol:000POol9000?Ool8000;
Ool3000IOolB0006Ool70002Ool6000gOol00`00Oomoo`0:Ool000Moo`03001oogoo03Uoo``001io
o`P00003Ool007oo00eoo`P000Uoo`<001Qooa<000Uoo`H000Aoo`D003Moo`03001oogoo00Yoo`00
1goo00<007ooOol0>Goo3@0077oo20000Woo00<007ooOol02Woo20001goo100067oo4P0037oo1P00
1Goo1@00=goo00<007ooOol02Woo0007Ool00`00Oomoo`0jOol<000KOol80003Ool00`00Oomoo`09
Ool80005Ool3000HOolC000>Ool60006Ool5000gOol00`00Oomoo`0:Ool000Moo`03001oogoo03Yo
o``001Uoo`P000Eoo`03001oogoo00Qoo`P000=oo`<001Qooa80015oo`L000Ioo`D003Moo`03001o
ogoo00Yoo`001goo00<007ooOol0?7oo2P0067oo20001Woo00<007ooOol01Woo2@0000Aoo`000000
01Qooa8001=oo`L000Moo`D003Moo`03001oogoo00Yoo`001goo00<007ooOol0?7oo2P005goo2000
1goo00<007ooOol01Goo2`005goo4P005Woo1`0027oo1@00>7oo00<007ooOol02Goo0006Ool00`00
Oomoo`0nOol9000FOol80008Ool00`00Oomoo`04Ool9000GOolB000IOol60009Ool6000gOol00`00
Oomoo`09Ool000Ioo`03001oogoo03moo`P001Aoo`P000Yoo`03001oogoo009oo`T001Eooa8001ao
o`H000Yoo`D00003Ool007oo03Eoo`03001oogoo00Uoo`001Woo00<007ooOol0?goo20004goo2000
2goo00@007ooOomoo`P0019oo`03001oo`00014001ioo`H000]oo`D0009oo`03001oogoo03=oo`03
001oogoo00Uoo`001Woo00<007ooOol0@7oo1`004Woo200037oo00<007ooOol020004Goo4`0087oo
1`002goo1@000Woo00<007ooOol0<goo00<007ooOol02Goo0006Ool00`00Oomoo`12Ool00`00Oomo
o`0COol8000=Ool:000BOol?000SOol7000<Ool50003Ool00`00Oomoo`0bOol00`00Oomoo`09Ool0
00Ioo`03001oogoo03]oo`04001oogoo000GOol8000;Ool<000BOol>000VOol6000=Ool50004Ool0
0`00Oomoo`0aOol00`00Oomoo`09Ool000Eoo`03001oogoo03]oo`L001Aoo`P000Uoo`<000=oo`P0
019oo`/002Uoo`H000ioo`D000Eoo`03001oogoo035oo`03001oogoo00Qoo`001Goo00<007ooOol0
>goo1`004goo20001goo0`0017oo2@004Woo2@00:goo1P003goo1@001Woo00<007ooOol0<7oo00<0
07ooOol027oo0005Ool00`00Oomoo`0kOol8000@Ool90005Ool30006Ool8000BOol9000/Ool7000?
Ool50007Ool00`00Oomoo`0_Ool00`00Oomoo`08Ool000Eoo`03001oogoo03Uoo`/000ioo`P000Ao
o`<000Qoo`P0019oo`P002eoo`L0011oo`D000Moo`03001oogoo02moo`03001oogoo00Qoo`001Goo
00<007ooOol0>Woo2`0037oo200000=oo`0000000P002Goo2@004Goo2@00;Woo1P004Goo1@0027oo
00<007ooOol0;Woo00<007ooOol027oo0005Ool00`00Oomoo`0iOol<000;Ool:000<Ool9000AOol9
000^Ool6000BOol50009Ool00`00Oomoo`0]Ool00`00Oomoo`08Ool000Eoo`03001oogoo03]oo``0
00Moo`T000ioo`P00003Ool007oo00moo`P002aoo`T001=oo`D000Yoo`03001oogoo02aoo`03001o
ogoo00Qoo`0017oo00<007ooOol0?7oo30001Woo20003Woo2@000Woo00<007ooOol037oo2@0097oo
4P004goo1@002goo00<007ooOol0;7oo00<007ooOol01goo0004Ool00`00Oomoo`0lOol=0004Ool8
000>Ool80004Ool00`00Oomoo`0;Ool8000MOolJ000DOol5000;Ool00`00Oomoo`0/Ool00`00Oomo
o`07Ool000Aoo`03001oogoo03eoo`/000=oo`T000ioo`P000Eoo`03001oogoo00Yoo`P001Aoob<0
01Eoo`D000aoo`03001oogoo02]oo`03001oogoo00Moo`0017oo00<007ooOol0?Woo50003goo2000
1Woo00<007ooOol027oo2@0037oo;0005Goo1@003Goo00<007ooOol0:Woo00<007ooOol01goo0004
Ool00`00Oomoo`0nOol:00000goo00000006000>Ool80008Ool00`00Oomoo`07Ool80005Ool^0004
Ool00`00Oomoo`0EOol5000>Ool00`00Oomoo`0YOol00`00Oomoo`07Ool000Aoo`03001oogoo03io
oa8000ioo`P000Uoo`03001oogoo00Iooc<002Eoo`D000moo`03001oogoo02Qoo`03001oogoo00Mo
o`000goo00<007ooOol0?goo4@003Woo20002Woo00@007ooOomoobl002ioo`D0011oo`03001oogoo
02Moo`03001oogoo00Moo`000goo00<007ooOol0?7oo0`000Woo3@003Woo2@001Woo;P00>7oo1@00
47oo00<007ooOol09goo00<007ooOol01goo0003Ool00`00Oomoo`0iOol30008Ool9000>Oole0011
Ool5000AOol00`00Oomoo`0WOol00`00Oomoo`06Ool000=oo`03001oogoo03Ioo`<000]oo`P000ao
obl004Yoo`D0019oo`03001oogoo02Ioo`03001oogoo00Ioo`000goo00<007ooOol0<goo0`003Goo
200017oo;P00E7oo1@004goo00<007ooOol09Goo00<007ooOol01Woo0003Ool00`00Oomoo`0_Ool4
000>Oolh001HOol5000DOol00`00Oomoo`0TOol00`00Oomoo`06Ool0009oo`03001oogoo02eoo`<0
011oob`000Aoo`T005Uoo`D001Aoo`03001oogoo02Aoo`03001oogoo00Ioo`000Woo00<007ooOol0
:Woo0`004goo8`0037oo2000Fgoo1@005Goo00<007ooOol08goo00<007ooOol01Woo0002Ool00`00
Oomoo`0WOol3000EOolM000AOol9001LOol5000FOol00`00Oomoo`0ROol00`00Oomoo`06Ool0009o
o`03001oogoo02Aoo`<001Uooa0000=oo`P0015oo`T005eoo`D001Moo`03001oogoo029oo`03001o
ogoo00Eoo`000Woo00<007ooOol087oo100077oo1`002Woo2@004Goo2000Ggoo1@0067oo00<007oo
Ool08Goo00<007ooOol01Goo0002Ool00`00Oomoo`0MOol3000ROol00`00Oomoo`0;Ool8000AOol9
001OOol5000IOol00`00Oomoo`0QOol00`00Oomoo`05Ool0009oo`03001oogoo01Yoo`<0039oo`P0
015oo`T0061oo`D001Yoo`03001oogoo021oo`03001oogoo00Eoo`0000=oo`00Ool06Goo0`00<goo
2@004Goo200000=oo`00Ool0Ggoo1@006goo00<007ooOol07goo00<007ooOol01Goo00000goo001o
o`0FOol3000eOol8000AOol90002Ool00`00Oomoo`1NOol5000LOol00`00Oomoo`0NOol00`00Oomo
o`05Ool00003Ool007oo019oo`@003Moo`P0015oo`P000Aoo`03001oogoo05ioo`D001eoo`03001o
ogoo01eoo`03001oogoo00Eoo`0000=oo`00Ool03goo0`00>Woo20004Goo20001Goo00<007ooOol0
GWoo1@007Woo00<007ooOol07Goo00<007ooOol017oo00000goo001oo`0<Ool3000kOol8000AOol9
0006Ool00`00Oomoo`1NOol5000NOol00`00Oomoo`0MOol00`00Oomoo`04Ool00003Ool007oo00Uo
o`<003eoo`P0015oo`P000Qoo`03001oogoo05ioo`D001moo`03001oogoo01aoo`03001oogoo00Ao
o`0000<007ooOol01Woo0`00?goo20004Goo20002Goo00<007ooOol0GWoo1@0087oo00<007ooOol0
6goo00<007ooOol017oo00000`00Oomoo`02Ool40010Ool9000@Ool9000:Ool00`00Oomoo`1NOol5
000QOol00`00Oomoo`0JOol00`00Oomoo`04Ool00003001oo`00008004=oo`P0015oo`P000aoo`03
001oogoo05ioo`D0029oo`03001oogoo01Uoo`03001oogoo00Aoo`000P00AGoo200047oo2@003Goo
00<007ooOol0GWoo1@008Woo00<007ooOol06Goo00<007ooOol017oo00000goo00000012Ool9000@
Ool9000>Ool00`00Oomoo`1NOol5000SOol00`00Oomoo`0IOol00`00Oomoo`03Ool000=oo`03001o
ogoo03ioo`P0015oo`P0011oo`03001oogoo05ioo`D002Aoo`03001oogoo01Qoo`03001oogoo00=o
o`0017oo00<007ooOol0?7oo200047oo2@004Goo00<007ooOol0GWoo1@009Goo00<007ooOol05goo
00<007ooOol00goo0005Ool2000kOol8000@Ool8000COol00`00Oomoo`1NOol5000VOol00`00Oomo
o`0FOol00`00Oomoo`03Ool000Moo`03001oogoo03Uoo`D0015oo`P001Aoo`03001oogoo05ioo`D0
02Moo`03001oogoo01Eoo`03001oogoo00=oo`0027oo0P00>Woo0`0047oo2@005Goo00<007ooOol0
GWoo1@009goo00<007ooOol05Goo00<007ooOol00goo000:Ool00`00Oomoo`0hOol00`00Oomoo`0>
Ool8000GOol00`00Oomoo`1NOol5000XOol00`00Oomoo`0DOol00`00Oomoo`03Ool000]oo`8004Qo
o`P001Moo`03001oogoo05moo`D002Uoo`03001oogoo01=oo`03001oogoo00=oo`003Goo00<007oo
Ool0@goo2@0067oo00<007ooOol0Ggoo1@00:Woo00<007ooOol04goo00<007ooOol00Woo000>Ool0
0`00Oomoo`11Ool8000JOol00`00Oomoo`1OOol5000[Ool00`00Oomoo`0BOol00`00Oomoo`02Ool0
00moo`80041oo`P001]oo`03001oogoo05moo`D002]oo`03001oogoo019oo`03001oogoo009oo`00
4Goo00<007ooOol0>goo2@0077oo00<007ooOol0Ggoo1@00;7oo00<007ooOol04Goo00<007ooOol0
0Woo000BOol2000jOol8000NOol00`00Oomoo`1OOol5000]Ool00`00Oomoo`0@Ool00`00Oomoo`02
Ool001Aoo`03001oogoo03Ioo`P001moo`03001oogoo05moo`D002ioo`03001oogoo00moo`03001o
ogoo009oo`005Goo0P00=7oo2@0087oo00<007ooOol0Ggoo1@00;goo00<007ooOol03Woo00<007oo
Ool00Woo000GOol00`00Oomoo`0`Ool8000ROol00`00Oomoo`1OOol5000`Ool00`00Oomoo`0>Ool0
0`00Oomoo`01Ool001Qoo`03001oogoo02eoo`T002=oo`03001oogoo05moo`D0031oo`03001oogoo
00ioo`03001oogoo005oo`006Goo0P00;7oo2@0097oo00<007ooOol0Ggoo1@00<Goo00<007ooOol0
3Goo00<007ooOol00Goo000KOol00`00Oomoo`0XOol8000VOol00`00Oomoo`1OOol5000bOol00`00
Oomoo`0<Ool00`00Oomoo`01Ool001aoo`8002Ioo`T002Moo`03001oogoo05moo`D003=oo`03001o
ogoo00]oo`03001oogoo005oo`007Woo00<007ooOol08Goo2@00:Goo00<007ooOol0Ggoo1@00=7oo
00<007ooOol02Woo00<007ooOol00Goo000OOol2000QOolG000KOol00`00Oomoo`1OOol5000dOol0
0`00Oomoo`0:Ool00`00Oomoo`01Ool0025oo`03001oogoo01eoobD000ioo`03001oogoo05moo`D0
03Eoo`03001oogoo00Yoo`40005oo`5oo`008Woo00<007ooOol07Goo<`00HGoo1@00=Woo00<007oo
Ool02Goo0@000Goo0Goo000SOol2000MOolo001EOol5000gOol00`00Oomoo`08Ool10001Ool1Ool0
02Eoo`03001oogoo01aoo`03001oogoo00Aood<004Qoo`D003Qoo`03001oogoo00Moo`40005oo`5o
o`009Woo0P00<Goo@`00>Woo1@00>Goo00<007ooOol01Woo0@000Goo0Goo000XOol00`00Oomoo`0k
Oom3000]Ool5000iOol00`00Oomoo`06Ool10001Ool1Ool002Uoo`8004Uood<001moo`D003Yoo`03
001oogoo00Eoo`40005oo`5oo`00:goo00<007ooOol0AWoo00<007ooOol02Woo@`004Woo1@00>goo
00<007ooOol017oo0@000Goo0Goo000/Ool00`00Oomoo`15Ool00`00Oomoo`0GOom40004Ool5000l
Ool00`00Oomoo`04Ool10001Ool002eoo`8004Eoo`03001oogoo02Eoocl003eoo`03001oogoo00=o
o`40005oo`00;goo00<007ooOol0@Woo00<007ooOol0<Woo<P00?Goo00<007ooOol00goo0@000Goo
000`Ool20012Ool00`00Oomoo`10OolT000nOol00`00Oomoo`02Ool10001Ool0039oo`03001oogoo
03moo`03001oogoo04eooaL003moo`05001oogooOol00001Ool003=oo`8003moo`03001oogoo05]o
o`T0041oo`04001oogoo0001Ool003Eoo`03001oogoo03]oo`03001oogoo0:Ioo`03001oo`00005o
o`00=Woo00<007ooOol0>Woo00<007ooOol0Ygoo0@000Goo0@00000gOol2000jOol00`00Oomoo`2W
Ool10001Ool1000003Uoo`03001oogoo03Moo`03001oogoo0:Qoo`800000>Woo0P00=goo00<007oo
Ool0Ygoo0`00000lOol00`00Oomoo`0dOol00`00Oomoo`2SOol40003Ool003eoo`03001oogoo03=o
o`03001oogoo09ioo`D000Moo`00?Woo0P00<goo00<007ooOol0VWoo100037oo0010Ool00`00Oomo
o`0`Ool00`00Oomoo`2FOol4000@Ool0045oo`80031oo`03001oogoo095oo`D001Aoo`00@goo00<0
07ooOol0;Goo00<007ooOol0SGoo10006Goo0014Ool2000]Ool00`00Oomoo`28Ool5000MOol004Io
o`03001oogoo02Yoo`03001oogoo08Aoo`@0029oo`00Agoo00<007ooOol0:Goo00<007ooOol0Ogoo
1@009Woo0018Ool2000YOol00`00Oomoo`1kOol4000[Ool004Yoo`03001oogoo02Ioo`03001oogoo
07Ioo`D002moo`00Bgoo0P009Woo00<007ooOol0LWoo1000=7oo001=Ool00`00Oomoo`0SOol00`00
Oomoo`1^Ool4000hOol004ioo`8002=oo`03001oogoo06Uoo`D003aoo`00D7oo00<007ooOol087oo
00<007ooOol0IGoo1000@Goo001AOol00`00Oomoo`0OOol00`00Oomoo`1POol50015Ool0059oo`80
01moo`03001oogoo05aoo`@004Yoo`00E7oo00<007ooOol077oo00<007ooOol0Egoo1@00CWoo001E
Ool2000LOol00`00Oomoo`1COol4001COol005Moo`03001oogoo01Uoo`03001oogoo04moo`@005Mo
o`00F7oo0P006Goo00<007ooOol0BWoo1@00Fgoo001JOol00`00Oomoo`0FOol00`00Oomoo`16Ool4
001POol005]oo`03001oogoo01Eoo`03001oogoo045oo`D006Aoo`00G7oo0P005Goo00<007ooOol0
?Goo1000JGoo001NOol00`00Oomoo`0AOol00`00Oomoo`0iOol5001]Ool005moo`80015oo`03001o
ogoo03Eoo`@0079oo`00HGoo00<007ooOol03Woo00<007ooOol0<Goo1000MWoo001ROol2000>Ool0
0`00Oomoo`0/Ool5001jOol006Aoo`03001oogoo00]oo`03001oogoo02Qoo`@007moo`00IGoo00<0
07ooOol02Woo00<007ooOol08goo1@00Pgoo001VOol2000:Ool00`00Oomoo`0OOol40028Ool006Qo
o`03001oogoo00Moo`03001oogoo01Yoo`D008aoo`00JGoo0P001goo00<007ooOol05Woo1000TGoo
001[Ool00`00Oomoo`04Ool00`00Oomoo`0AOol5002EOol006aoo`8000Aoo`03001oogoo00eoo`@0
09Yoo`00KWoo00D007ooOomoo`0000]oo`@009ioo`00Kgoo00@007ooOol000Ioo`D00:9oo`00L7oo
0`000Woo1000Ygoo001bOol3002[Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {311.563, 0}} -> {0.0486402, -4.05116*^-05, \
0.00298809, 0.00298809}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Presentation",
InitializationCellEvaluation->True,
CellGrouping->Manual,
WindowSize->{749, 488},
WindowMargins->{{18, Automatic}, {14, Automatic}},
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[], "StylesFolder"}, \
"Talk Style.nb", CharacterEncoding -> "MacintoshRoman"],
MacintoshSystemPageSetup->"\<\
0080001804P000000_82@?okonh34`9B;@<5:0?l00;m009H0UP0000068dB`0B`
02d5X5k/02H80@4101P00BL?00400@00000000000000P0010000034D00000000
0000000000000000000@04T400002000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "start"->{
    Cell[1717, 49, 68, 1, 60, "Title",
      CellTags->"start"]},
  "enfold"->{
    Cell[2005, 64, 52, 1, 26, "Commentary",
      CellTags->"enfold"],
    Cell[2082, 69, 56, 1, 22, "Commentary",
      CellTags->"enfold"],
    Cell[2141, 72, 116, 3, 35, "SmallText",
      CellTags->"enfold"],
    Cell[2306, 81, 76, 1, 26, "Commentary",
      CellTags->"enfold"],
    Cell[2385, 84, 197, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[10112, 283, 69, 1, 62, "Subsubsection",
      CellTags->"enfold"],
    Cell[10184, 286, 212, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "init", "calc"}],
    Cell[16414, 455, 57, 1, 62, "Subsubsection",
      CellTags->"enfold"],
    Cell[16474, 458, 102, 2, 70, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[34630, 836, 85, 1, 35, "SmallText",
      CellTags->"enfold"],
    Cell[34740, 841, 59, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[34802, 844, 136, 4, 51, "SmallText",
      CellTags->"enfold"],
    Cell[34941, 850, 349, 10, 70, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[35327, 865, 66, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[35418, 870, 215, 5, 76, "SmallText",
      CellTags->"enfold"],
    Cell[35636, 877, 625, 18, 130, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[36298, 900, 63, 1, 51, "SmallText",
      CellTags->"enfold"],
    Cell[36364, 903, 783, 19, 110, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[37150, 924, 480, 12, 90, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[37633, 938, 691, 17, 90, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[58551, 1602, 71, 1, 65, "Subsection",
      CellTags->"enfold"],
    Cell[58647, 1607, 57, 1, 35, "SmallText",
      CellTags->"enfold"],
    Cell[58707, 1610, 690, 17, 74, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[90102, 2506, 103, 1, 22, "Emphasis",
      CellTags->{"emphasis", "enfold"}],
    Cell[263778, 7738, 56, 1, 35, "SmallText",
      CellTags->"enfold"],
    Cell[263859, 7743, 254, 7, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[264116, 7752, 181, 4, 67, "Output",
      CellTags->"enfold"],
    Cell[264334, 7761, 521, 14, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[264858, 7777, 206, 5, 67, "Output",
      CellTags->"enfold"],
    Cell[265079, 7785, 396, 10, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[265478, 7797, 74, 1, 54, "Text",
      CellTags->"enfold"],
    Cell[265577, 7802, 2295, 48, 230, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[267875, 7852, 1062, 24, 107, "Output",
      CellTags->"enfold"],
    Cell[268952, 7879, 64, 1, 54, "Text",
      CellTags->"enfold"],
    Cell[269041, 7884, 986, 24, 110, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[270030, 7910, 1611, 47, 127, "Output",
      CellTags->"enfold"],
    Cell[271656, 7960, 84, 1, 54, "Text",
      CellTags->"enfold"],
    Cell[271743, 7963, 1948, 43, 170, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[275713, 8080, 49, 1, 35, "SmallText",
      CellTags->"enfold"],
    Cell[275765, 8083, 1984, 42, 210, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[277873, 8133, 16800, 588, 194, 10692, 507, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[294676, 8723, 17446, 601, 202, 10740, 512, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[312125, 9326, 17867, 608, 202, 10773, 515, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[329995, 9936, 18019, 613, 202, 10807, 518, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[348017, 10551, 18169, 619, 202, 10904, 523, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[366189, 11172, 18266, 624, 202, 11001, 528, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[384458, 11798, 18310, 629, 202, 11058, 534, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[402771, 12429, 18414, 635, 202, 11105, 539, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[421188, 13066, 18748, 642, 202, 11139, 542, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[439939, 13710, 20479, 666, 202, 11173, 545, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"enfold"],
    Cell[460479, 14383, 101, 1, 35, "SmallText",
      CellTags->"enfold"],
    Cell[460605, 14388, 62, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[460670, 14391, 1322, 36, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[461995, 14429, 881, 23, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[462879, 14454, 1579, 37, 170, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[464495, 14496, 57, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[464577, 14501, 280, 8, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[464860, 14511, 2305, 63, 167, "Output",
      CellTags->"enfold"],
    Cell[467214, 14580, 98, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[467315, 14583, 1698, 39, 190, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[469016, 14624, 1474, 35, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[470493, 14661, 1302, 31, 110, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[471798, 14694, 1547, 35, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[473348, 14731, 911, 23, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[474262, 14756, 1217, 30, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[475516, 14791, 64, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[475583, 14794, 206, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[475792, 14802, 1063, 26, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[514193, 15840, 87, 1, 35, "SmallText",
      CellTags->"enfold"],
    Cell[514305, 15845, 56, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[514386, 15850, 283, 8, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[514672, 15860, 7401, 184, 367, "Output",
      CellTags->"enfold"],
    Cell[522122, 16050, 69, 1, 71, "Subsubsection",
      CellTags->"enfold"],
    Cell[522194, 16053, 1162, 28, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}]},
  "calc"->{
    Cell[2385, 84, 197, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[3138, 112, 4585, 91, 294, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[7807, 209, 318, 9, 56, "Input",
      Evaluatable->False,
      CellTags->"calc"],
    Cell[10184, 286, 212, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "init", "calc"}],
    Cell[10632, 304, 795, 19, 76, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[11452, 327, 86, 2, 56, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[15411, 423, 276, 7, 76, "Input",
      CellTags->{"pathinit", "calc"}],
    Cell[15760, 434, 617, 16, 96, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[16474, 458, 102, 2, 70, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[25083, 627, 176, 5, 56, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[34941, 850, 349, 10, 70, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[35636, 877, 625, 18, 130, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[36364, 903, 783, 19, 110, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[37150, 924, 480, 12, 90, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[37633, 938, 691, 17, 90, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[38536, 969, 251, 8, 56, "Input",
      Evaluatable->False,
      CellTags->"calc"],
    Cell[58707, 1610, 690, 17, 74, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[59520, 1635, 302, 9, 56, "Input",
      Evaluatable->False,
      CellTags->"calc"],
    Cell[90565, 2525, 215, 6, 56, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[90805, 2535, 311, 8, 76, "Input",
      Evaluatable->False,
      CellTags->"calc"],
    Cell[263859, 7743, 254, 7, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[264334, 7761, 521, 14, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[265079, 7785, 396, 10, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[265577, 7802, 2295, 48, 230, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[269041, 7884, 986, 24, 110, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[271743, 7963, 1948, 43, 170, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[273892, 8019, 78, 2, 56, "Input",
      Evaluatable->False,
      CellTags->"calc"],
    Cell[275765, 8083, 1984, 42, 210, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[460670, 14391, 1322, 36, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[461995, 14429, 881, 23, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[462879, 14454, 1579, 37, 170, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[464577, 14501, 280, 8, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[467315, 14583, 1698, 39, 190, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[469016, 14624, 1474, 35, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[470493, 14661, 1302, 31, 110, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[471798, 14694, 1547, 35, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[473348, 14731, 911, 23, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[474262, 14756, 1217, 30, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[475583, 14794, 206, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[475792, 14802, 1063, 26, 130, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[477114, 14844, 868, 22, 136, "Input",
      Evaluatable->False,
      CellTags->"calc"],
    Cell[514386, 15850, 283, 8, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}],
    Cell[522194, 16053, 1162, 28, 150, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "calc"}]},
  "emphasis"->{
    Cell[2659, 97, 385, 8, 167, "Emphasis",
      CellTags->"emphasis"],
    Cell[9728, 271, 347, 7, 64, "Emphasis",
      CellTags->"emphasis"],
    Cell[15318, 420, 90, 1, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[24976, 622, 82, 1, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[38442, 964, 69, 1, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[59412, 1630, 83, 1, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[90102, 2506, 103, 1, 22, "Emphasis",
      CellTags->{"emphasis", "enfold"}],
    Cell[90401, 2519, 161, 4, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[229036, 6798, 269, 7, 50, "Emphasis",
      CellTags->"emphasis"],
    Cell[263319, 7717, 236, 6, 50, "Emphasis",
      CellTags->"emphasis"],
    Cell[273784, 8014, 83, 1, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[277764, 8128, 84, 1, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[476947, 14836, 142, 4, 22, "Emphasis",
      CellTags->"emphasis"],
    Cell[523447, 16089, 299, 6, 50, "Emphasis",
      CellTags->"emphasis"],
    Cell[523749, 16097, 181, 5, 36, "Emphasis",
      CellTags->"emphasis"]},
  "pathinit"->{
    Cell[3138, 112, 4585, 91, 294, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[10632, 304, 795, 19, 76, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[11452, 327, 86, 2, 56, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[15411, 423, 276, 7, 76, "Input",
      CellTags->{"pathinit", "calc"}],
    Cell[15760, 434, 617, 16, 96, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[16474, 458, 102, 2, 70, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[25083, 627, 176, 5, 56, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}],
    Cell[34941, 850, 349, 10, 70, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[35636, 877, 625, 18, 130, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[36364, 903, 783, 19, 110, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[37150, 924, 480, 12, 90, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[37633, 938, 691, 17, 90, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[58707, 1610, 690, 17, 74, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "enfold", "calc"}],
    Cell[90565, 2525, 215, 6, 56, "Input",
      Evaluatable->False,
      CellTags->{"pathinit", "calc"}]},
  "init"->{
    Cell[10184, 286, 212, 6, 70, "Input",
      Evaluatable->False,
      CellTags->{"enfold", "init", "calc"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"start", 565809, 17250},
  {"enfold", 565889, 17253},
  {"calc", 573056, 17442},
  {"emphasis", 577714, 17571},
  {"pathinit", 578865, 17602},
  {"init", 580433, 17644}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 68, 1, 60, "Title",
  CellTags->"start"],

Cell[CellGroupData[{
Cell[1810, 54, 30, 0, 26, "Commentary"],
Cell[1843, 56, 125, 3, 22, "Commentary"]
}, Closed]],

Cell[CellGroupData[{
Cell[2005, 64, 52, 1, 26, "Commentary",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[2082, 69, 56, 1, 22, "Commentary",
  CellTags->"enfold"],
Cell[2141, 72, 116, 3, 35, "SmallText",
  CellTags->"enfold"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2306, 81, 76, 1, 26, "Commentary",
  CellTags->"enfold"],
Cell[2385, 84, 197, 6, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{
Cell[2619, 95, 37, 0, 33, "Subsubsection"],
Cell[2659, 97, 385, 8, 167, "Emphasis",
  CellTags->"emphasis"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3081, 110, 54, 0, 55, "Subsubsection"],
Cell[3138, 112, 4585, 91, 294, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],
Cell[7726, 205, 56, 0, 42, "Text"],

Cell[CellGroupData[{
Cell[7807, 209, 318, 9, 56, "Input",
  Evaluatable->False,
  CellTags->"calc"],
Cell[8128, 220, 1460, 41, 96, "Output"]
}, Open  ]]
}, Open  ]],
Cell[9615, 265, 32, 0, 75, "Section"],

Cell[CellGroupData[{
Cell[9672, 269, 53, 0, 62, "Subsubsection"],
Cell[9728, 271, 347, 7, 64, "Emphasis",
  CellTags->"emphasis"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10112, 283, 69, 1, 62, "Subsubsection",
  CellTags->"enfold"],
Cell[10184, 286, 212, 6, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "init", "calc"}]
}, Closed]],

Cell[CellGroupData[{
Cell[10433, 297, 45, 0, 40, "Subsubsection"],
Cell[10481, 299, 148, 3, 76, "Text"],
Cell[10632, 304, 795, 19, 76, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell[CellGroupData[{
Cell[11452, 327, 86, 2, 56, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],
Cell[11541, 331, 3762, 86, 196, "Output"]
}, Open  ]],
Cell[15318, 420, 90, 1, 22, "Emphasis",
  CellTags->"emphasis"],
Cell[15411, 423, 276, 7, 76, "Input",
  CellTags->{"pathinit", "calc"}],
Cell[15690, 432, 67, 0, 35, "SmallText"],
Cell[15760, 434, 617, 16, 96, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[16414, 455, 57, 1, 62, "Subsubsection",
  CellTags->"enfold"],
Cell[16474, 458, 102, 2, 70, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}],
Cell[16579, 462, 8316, 153, 271, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[24932, 620, 41, 0, 40, "Subsubsection"],
Cell[24976, 622, 82, 1, 22, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[25083, 627, 176, 5, 56, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],
Cell[25262, 634, 9256, 192, 194, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34567, 832, 38, 0, 75, "Section"],

Cell[CellGroupData[{
Cell[34630, 836, 85, 1, 35, "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[34740, 841, 59, 1, 71, "Subsubsection",
  CellTags->"enfold"],
Cell[34802, 844, 136, 4, 51, "SmallText",
  CellTags->"enfold"],
Cell[34941, 850, 349, 10, 70, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{
Cell[35327, 865, 66, 1, 71, "Subsubsection",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[35418, 870, 215, 5, 76, "SmallText",
  CellTags->"enfold"],
Cell[35636, 877, 625, 18, 130, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{
Cell[36298, 900, 63, 1, 51, "SmallText",
  CellTags->"enfold"],
Cell[36364, 903, 783, 19, 110, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}],
Cell[37150, 924, 480, 12, 90, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}],
Cell[37633, 938, 691, 17, 90, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38385, 962, 54, 0, 37, "Subsection"],
Cell[38442, 964, 69, 1, 22, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[38536, 969, 251, 8, 56, "Input",
  Evaluatable->False,
  CellTags->"calc"],
Cell[38790, 979, 19712, 617, 296, 10524, 499, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58551, 1602, 71, 1, 65, "Subsection",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[58647, 1607, 57, 1, 35, "SmallText",
  CellTags->"enfold"],
Cell[58707, 1610, 690, 17, 74, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "enfold", "calc"}]
}, Closed]],
Cell[59412, 1630, 83, 1, 22, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[59520, 1635, 302, 9, 56, "Input",
  Evaluatable->False,
  CellTags->"calc"],
Cell[59825, 1646, 30262, 857, 194, 12062, 628, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[90102, 2506, 103, 1, 22, "Emphasis",
  CellTags->{"emphasis", "enfold"}],
Cell[90208, 2509, 103, 2, 35, "SmallText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90360, 2517, 38, 0, 75, "Section"],
Cell[90401, 2519, 161, 4, 22, "Emphasis",
  CellTags->"emphasis"],
Cell[90565, 2525, 215, 6, 56, "Input",
  Evaluatable->False,
  CellTags->{"pathinit", "calc"}],

Cell[CellGroupData[{
Cell[90805, 2535, 311, 8, 76, "Input",
  Evaluatable->False,
  CellTags->"calc"],
Cell[91119, 2545, 137721, 4241, 644, 57802, 3250, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[228855, 6789, 63, 0, 42, "Text"]
}, Open  ]],
Cell[228933, 6792, 24, 0, 75, "Section"],

Cell[CellGroupData[{
Cell[228982, 6796, 51, 0, 62, "Subsubsection"],
Cell[229036, 6798, 269, 7, 50, "Emphasis",
  CellTags->"emphasis"],
Cell[229308, 6807, 332, 11, 76, "Text"],
Cell[229643, 6820, 33673, 895, 286, 11793, 620, "GraphicsData", "PostScript", \
"Graphics"],
Cell[263319, 7717, 236, 6, 50, "Emphasis",
  CellTags->"emphasis"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263592, 7728, 48, 0, 65, "Subsection"],

Cell[CellGroupData[{
Cell[263665, 7732, 35, 0, 62, "Subsubsection"],
Cell[263703, 7734, 50, 0, 42, "Text"],

Cell[CellGroupData[{
Cell[263778, 7738, 56, 1, 35, "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[263859, 7743, 254, 7, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[264116, 7752, 181, 4, 67, "Output",
  CellTags->"enfold"]
}, Closed]],

Cell[CellGroupData[{
Cell[264334, 7761, 521, 14, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[264858, 7777, 206, 5, 67, "Output",
  CellTags->"enfold"]
}, Closed]],
Cell[265079, 7785, 396, 10, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[265478, 7797, 74, 1, 54, "Text",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[265577, 7802, 2295, 48, 230, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[267875, 7852, 1062, 24, 107, "Output",
  CellTags->"enfold"]
}, Closed]],
Cell[268952, 7879, 64, 1, 54, "Text",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[269041, 7884, 986, 24, 110, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[270030, 7910, 1611, 47, 127, "Output",
  CellTags->"enfold"]
}, Closed]],
Cell[271656, 7960, 84, 1, 54, "Text",
  CellTags->"enfold"],
Cell[271743, 7963, 1948, 43, 170, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[273740, 8012, 41, 0, 62, "Subsubsection"],
Cell[273784, 8014, 83, 1, 22, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[273892, 8019, 78, 2, 56, "Input",
  Evaluatable->False,
  CellTags->"calc"],
Cell[273973, 8023, 1589, 46, 136, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[275611, 8075, 77, 1, 62, "Subsubsection"],

Cell[CellGroupData[{
Cell[275713, 8080, 49, 1, 35, "SmallText",
  CellTags->"enfold"],
Cell[275765, 8083, 1984, 42, 210, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],
Cell[277764, 8128, 84, 1, 22, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[277873, 8133, 16800, 588, 194, 10692, 507, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"enfold"],
Cell[294676, 8723, 17446, 601, 202, 10740, 512, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"enfold"],
Cell[312125, 9326, 17867, 608, 202, 10773, 515, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"enfold"],
Cell[329995, 9936, 18019, 613, 202, 10807, 518, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"enfold"],
Cell[348017, 10551, 18169, 619, 202, 10904, 523, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"enfold"],
Cell[366189, 11172, 18266, 624, 202, 11001, 528, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"enfold"],
Cell[384458, 11798, 18310, 629, 202, 11058, 534, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"enfold"],
Cell[402771, 12429, 18414, 635, 202, 11105, 539, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"enfold"],
Cell[421188, 13066, 18748, 642, 202, 11139, 542, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"enfold"],
Cell[439939, 13710, 20479, 666, 202, 11173, 545, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"enfold"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[460479, 14383, 101, 1, 35, "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[460605, 14388, 62, 1, 71, "Subsubsection",
  CellTags->"enfold"],
Cell[460670, 14391, 1322, 36, 130, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[461995, 14429, 881, 23, 150, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[462879, 14454, 1579, 37, 170, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{
Cell[464495, 14496, 57, 1, 71, "Subsubsection",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[464577, 14501, 280, 8, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[464860, 14511, 2305, 63, 167, "Output",
  CellTags->"enfold"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[467214, 14580, 98, 1, 71, "Subsubsection",
  CellTags->"enfold"],
Cell[467315, 14583, 1698, 39, 190, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[469016, 14624, 1474, 35, 150, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[470493, 14661, 1302, 31, 110, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[471798, 14694, 1547, 35, 130, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[473348, 14731, 911, 23, 130, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[474262, 14756, 1217, 30, 150, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]],

Cell[CellGroupData[{
Cell[475516, 14791, 64, 1, 71, "Subsubsection",
  CellTags->"enfold"],
Cell[475583, 14794, 206, 6, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[475792, 14802, 1063, 26, 130, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[476904, 14834, 40, 0, 37, "Subsection"],
Cell[476947, 14836, 142, 4, 22, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[477114, 14844, 868, 22, 136, "Input",
  Evaluatable->False,
  CellTags->"calc"],
Cell[477985, 14868, 36159, 966, 286, 12291, 667, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[514193, 15840, 87, 1, 35, "SmallText",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[514305, 15845, 56, 1, 71, "Subsubsection",
  CellTags->"enfold"],

Cell[CellGroupData[{
Cell[514386, 15850, 283, 8, 70, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}],
Cell[514672, 15860, 7401, 184, 367, "Output",
  CellTags->"enfold"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[522122, 16050, 69, 1, 71, "Subsubsection",
  CellTags->"enfold"],
Cell[522194, 16053, 1162, 28, 150, "Input",
  Evaluatable->False,
  CellTags->{"enfold", "calc"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[523405, 16087, 39, 0, 37, "Subsection"],
Cell[523447, 16089, 299, 6, 50, "Emphasis",
  CellTags->"emphasis"],
Cell[523749, 16097, 181, 5, 36, "Emphasis",
  CellTags->"emphasis"],

Cell[CellGroupData[{
Cell[523955, 16106, 1040, 26, 156, "Input"],
Cell[524998, 16134, 39733, 1086, 329, 13284, 755, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

