(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    239495,       6586]*)
(*NotebookOutlinePosition[    240512,       6616]*)
(*  CellTagsIndexPosition[    240468,       6612]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik Basis", "Title"],

Cell[CellGroupData[{

Cell["A Basis", "Section"],

Cell["\<\
We can use our basis algorithm to find a basis of Rubik's \
Cube.\
\>", "Text"],

Cell["\<\
Just using the generators ( as permutations) that we made in the \
planar Rubik document, we apply the basis algorithm mechanically and get a \
basis.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Basis Data Structure", "Subsubsection"],

Cell[TextData[{
  "Here is a  simplified version of the basis data returned by the algorithm. \
The data structure is , for each basis point ",
  Cell[BoxData[
      FormBox["x", TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"TBasisData", "[", 
          RowBox[{"x", ",", 
            StyleBox["generators",
              FontSlant->"Italic"], 
            StyleBox[",",
              FontSlant->"Italic"], 
            StyleBox[
              RowBox[{"orbit", " ", "of", " ", "x"}],
              FontSlant->"Italic"]}], 
          StyleBox["]",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " where the generators may include some at lower levels:"
}], "Text"],

Cell[BoxData[
    RowBox[{"TStrongBasis", "[", 
      RowBox[{
        RowBox[{"TBasisData", "[", 
          RowBox[{"6", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "3"], ",", 
                SubscriptBox["g", "4"], ",", 
                SubscriptBox["g", "5"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "6", ",", "40", ",", "19", ",", "3", ",", "36", ",", "52", ",", 
                "7", ",", "54", ",", "14", ",", "34", ",", "16", ",", "48", 
                ",", "39", ",", "49", ",", "20", ",", "21", ",", "2", ",", 
                "47", ",", "1", ",", "41", ",", "15", ",", "53", ",", "8", 
                ",", "35"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"14", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "2"], ",", 
                SubscriptBox["g", "6"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "14", ",", "21", ",", "48", ",", "52", ",", "54", ",", "15", 
                ",", "34", ",", "39", ",", "49", ",", "40", ",", "47", ",", 
                "20", ",", "2", ",", "53", ",", "36", ",", "16", ",", "35", 
                ",", "41", ",", "3", ",", "19", ",", "1"}], "}"}]}], "]"}], 
        ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"19", ",", 
            RowBox[{"{", 
              SubscriptBox["g", "30"], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "19", ",", "40", ",", "36", ",", "53", ",", "48", ",", "41", 
                ",", "54", ",", "35", ",", "21", ",", "49", ",", "52", ",", 
                "39", ",", "20", ",", "34", ",", "47", ",", "3", ",", "1", 
                ",", "2"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"34", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "1"], ",", 
                SubscriptBox["g", "45"], ",", 
                SubscriptBox["g", "74"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "34", ",", "47", ",", "52", ",", "39", ",", "41", ",", "35", 
                ",", "53", ",", "54", ",", "40", ",", "49", ",", "48", ",", 
                "36", ",", "2", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"39", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "54"], ",", 
                SubscriptBox["g", "78"], ",", 
                SubscriptBox["g", "127"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "39", ",", "41", ",", "40", ",", "2", ",", "1", ",", "3", ",", 
                "52", ",", "53", ",", "54", ",", "48", ",", "47", ",", "49"}],
               "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"47", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "59"], ",", 
                SubscriptBox["g", "141"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "47", ",", "49", ",", "48", ",", "3", ",", "2", ",", "1", ",", 
                "52", ",", "53", ",", "54"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"32", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "57"], ",", 
                SubscriptBox["g", "62"], ",", 
                SubscriptBox["g", "166"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "32", ",", "46", ",", "51", ",", "38", ",", "43", ",", "42", 
                ",", "10", ",", "37", ",", "22", ",", "9", ",", "23", ",", 
                "50", ",", "45", ",", "33", ",", "29", ",", "30", ",", "18", 
                ",", "17", ",", "5", ",", "4", ",", "12", ",", "13", ",", 
                "25", ",", "26"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"37", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "66"], ",", 
                SubscriptBox["g", "68"], ",", 
                SubscriptBox["g", "82"], ",", 
                SubscriptBox["g", "256"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "37", ",", "50", ",", "45", ",", "42", ",", "9", ",", "43", ",",
                 "38", ",", "23", ",", "10", ",", "22", ",", "51", ",", "46", 
                ",", "30", ",", "29", ",", "17", ",", "18", ",", "4", ",", 
                "5", ",", "13", ",", "12", ",", "26", ",", "25"}], "}"}]}], 
          "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"42", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "71"], ",", 
                SubscriptBox["g", "91"], ",", 
                SubscriptBox["g", "148"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "42", ",", "45", ",", "50", ",", "9", ",", "43", ",", "46", ",",
                 "23", ",", "10", ",", "22", ",", "51", ",", "30", ",", "29", 
                ",", "17", ",", "18", ",", "4", ",", "5", ",", "13", ",", 
                "12", ",", "26", ",", "25"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"1", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "99"], ",", 
                SubscriptBox["g", "137"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "1", ",", "2", ",", "3", ",", "53", ",", "52", ",", "54"}], 
              "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"9", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "102"], ",", 
                SubscriptBox["g", "210"], ",", 
                SubscriptBox["g", "232"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "9", ",", "51", ",", "10", ",", "50", ",", "23", ",", "22", ",",
                 "46", ",", "45", ",", "29", ",", "30", ",", "18", ",", "17", 
                ",", "4", ",", "5", ",", "13", ",", "12", ",", "25", ",", 
                "26"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"22", ",", 
            RowBox[{"{", 
              SubscriptBox["g", "106"], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "22", ",", "45", ",", "50", ",", "46", ",", "51", ",", "23", 
                ",", "30", ",", "29", ",", "17", ",", "18", ",", "4", ",", 
                "5", ",", "13", ",", "12", ",", "26", ",", "25"}], "}"}]}], 
          "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"45", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "113"], ",", 
                SubscriptBox["g", "151"], ",", 
                SubscriptBox["g", "169"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "45", ",", "46", ",", "50", ",", "51", ",", "30", ",", "29", 
                ",", "17", ",", "18", ",", "4", ",", "5", ",", "13", ",", 
                "12", ",", "26", ",", "25"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"29", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "156"], ",", 
                SubscriptBox["g", "172"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "29", ",", "30", ",", "18", ",", "17", ",", "51", ",", "50", 
                ",", "5", ",", "4", ",", "12", ",", "13", ",", "25", ",", 
                "26"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"17", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "177"], ",", 
                SubscriptBox["g", "213"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "17", ",", "18", ",", "51", ",", "50", ",", "5", ",", "4", ",", 
                "12", ",", "13", ",", "25", ",", "26"}], "}"}]}], "]"}], ",", 
        
        RowBox[{"TBasisData", "[", 
          RowBox[{"4", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "218"], ",", 
                SubscriptBox["g", "235"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "4", ",", "5", ",", "51", ",", "50", ",", "12", ",", "13", ",", 
                "25", ",", "26"}], "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"12", ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["g", "240"], ",", 
                SubscriptBox["g", "259"]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
              "12", ",", "13", ",", "51", ",", "50", ",", "25", ",", "26"}], 
              "}"}]}], "]"}], ",", 
        RowBox[{"TBasisData", "[", 
          RowBox[{"25", ",", 
            RowBox[{"{", 
              SubscriptBox["g", "264"], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"25", ",", "26"}], "}"}]}], "]"}]}], "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["basis points", "Subsubsection"],

Cell["\<\
Here are the basis points (chosen \"randomly\" by the algorithm):\
\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
        "6", ",", "14", ",", "19", ",", "34", ",", "39", ",", "47", ",", "32",
           ",", "37", ",", "42", ",", "1", ",", "9", ",", "22", ",", "45", 
          ",", "29", ",", "17", ",", "4", ",", "12", ",", "25"}], "}"}], 
      TraditionalForm]]]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["basis generator labels", "Subsubsection"],

Cell["\<\
Here are the labels for the basis operations (the generators for \
any basis point include all those of ensuing points):\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "3"], ",", 
              SubscriptBox["g", "4"], ",", 
              SubscriptBox["g", "5"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "2"], ",", 
              SubscriptBox["g", "6"]}], "}"}], ",", 
          RowBox[{"{", 
            SubscriptBox["g", "30"], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "1"], ",", 
              SubscriptBox["g", "45"], ",", 
              SubscriptBox["g", "74"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "54"], ",", 
              SubscriptBox["g", "78"], ",", 
              SubscriptBox["g", "127"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "59"], ",", 
              SubscriptBox["g", "141"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "57"], ",", 
              SubscriptBox["g", "62"], ",", 
              SubscriptBox["g", "166"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "66"], ",", 
              SubscriptBox["g", "68"], ",", 
              SubscriptBox["g", "82"], ",", 
              SubscriptBox["g", "256"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "71"], ",", 
              SubscriptBox["g", "91"], ",", 
              SubscriptBox["g", "148"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "99"], ",", 
              SubscriptBox["g", "137"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "102"], ",", 
              SubscriptBox["g", "210"], ",", 
              SubscriptBox["g", "232"]}], "}"}], ",", 
          RowBox[{"{", 
            SubscriptBox["g", "106"], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "113"], ",", 
              SubscriptBox["g", "151"], ",", 
              SubscriptBox["g", "169"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "156"], ",", 
              SubscriptBox["g", "172"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "177"], ",", 
              SubscriptBox["g", "213"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "218"], ",", 
              SubscriptBox["g", "235"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["g", "240"], ",", 
              SubscriptBox["g", "259"]}], "}"}], ",", 
          RowBox[{"{", 
            SubscriptBox["g", "264"], "}"}]}], "}"}], 
      TraditionalForm]]]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basis Permutations", "Subsubsection"],

Cell["\<\
Here are the labelled permutations for the moves in the \
basis:\
\>", "Text"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "3"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"19", "\[Rule]", "7"}], ",", 
                    RowBox[{"20", "\[Rule]", "6"}], ",", 
                    RowBox[{"21", "\[Rule]", "8"}], ",", 
                    RowBox[{"32", "\[Rule]", "12"}], ",", 
                    RowBox[{"33", "\[Rule]", "13"}], ",", 
                    RowBox[{"52", "\[Rule]", "20"}], ",", 
                    RowBox[{"53", "\[Rule]", "19"}], ",", 
                    RowBox[{"54", "\[Rule]", "21"}], ",", 
                    RowBox[{"12", "\[Rule]", "25"}], ",", 
                    RowBox[{"13", "\[Rule]", "26"}], ",", 
                    RowBox[{"45", "\[Rule]", "32"}], ",", 
                    RowBox[{"46", "\[Rule]", "33"}], ",", 
                    RowBox[{"6", "\[Rule]", "40"}], ",", 
                    RowBox[{"7", "\[Rule]", "39"}], ",", 
                    RowBox[{"8", "\[Rule]", "41"}], ",", 
                    RowBox[{"25", "\[Rule]", "45"}], ",", 
                    RowBox[{"26", "\[Rule]", "46"}], ",", 
                    RowBox[{"39", "\[Rule]", "53"}], ",", 
                    RowBox[{"40", "\[Rule]", "52"}], ",", 
                    RowBox[{"41", "\[Rule]", "54"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "4"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"14", "\[Rule]", "1"}], ",", 
                    RowBox[{"15", "\[Rule]", "3"}], ",", 
                    RowBox[{"16", "\[Rule]", "2"}], ",", 
                    RowBox[{"9", "\[Rule]", "4"}], ",", 
                    RowBox[{"10", "\[Rule]", "5"}], ",", 
                    RowBox[{"1", "\[Rule]", "6"}], ",", 
                    RowBox[{"2", "\[Rule]", "8"}], ",", 
                    RowBox[{"3", "\[Rule]", "7"}], ",", 
                    RowBox[{"17", "\[Rule]", "9"}], ",", 
                    RowBox[{"18", "\[Rule]", "10"}], ",", 
                    RowBox[{"4", "\[Rule]", "12"}], ",", 
                    RowBox[{"5", "\[Rule]", "13"}], ",", 
                    RowBox[{"19", "\[Rule]", "14"}], ",", 
                    RowBox[{"20", "\[Rule]", "16"}], ",", 
                    RowBox[{"21", "\[Rule]", "15"}], ",", 
                    RowBox[{"12", "\[Rule]", "17"}], ",", 
                    RowBox[{"13", "\[Rule]", "18"}], ",", 
                    RowBox[{"6", "\[Rule]", "19"}], ",", 
                    RowBox[{"7", "\[Rule]", "21"}], ",", 
                    RowBox[{"8", "\[Rule]", "20"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "5"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"6", "\[Rule]", "3"}], ",", 
                    RowBox[{"7", "\[Rule]", "2"}], ",", 
                    RowBox[{"8", "\[Rule]", "1"}], ",", 
                    RowBox[{"25", "\[Rule]", "5"}], ",", 
                    RowBox[{"26", "\[Rule]", "4"}], ",", 
                    RowBox[{"39", "\[Rule]", "8"}], ",", 
                    RowBox[{"40", "\[Rule]", "7"}], ",", 
                    RowBox[{"41", "\[Rule]", "6"}], ",", 
                    RowBox[{"4", "\[Rule]", "23"}], ",", 
                    RowBox[{"5", "\[Rule]", "22"}], ",", 
                    RowBox[{"37", "\[Rule]", "26"}], ",", 
                    RowBox[{"38", "\[Rule]", "25"}], ",", 
                    RowBox[{"1", "\[Rule]", "36"}], ",", 
                    RowBox[{"2", "\[Rule]", "35"}], ",", 
                    RowBox[{"3", "\[Rule]", "34"}], ",", 
                    RowBox[{"22", "\[Rule]", "38"}], ",", 
                    RowBox[{"23", "\[Rule]", "37"}], ",", 
                    RowBox[{"34", "\[Rule]", "41"}], ",", 
                    RowBox[{"35", "\[Rule]", "40"}], ",", 
                    RowBox[{"36", "\[Rule]", "39"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "2"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"47", "\[Rule]", "16"}], ",", 
                    RowBox[{"48", "\[Rule]", "15"}], ",", 
                    RowBox[{"49", "\[Rule]", "14"}], ",", 
                    RowBox[{"29", "\[Rule]", "18"}], ",", 
                    RowBox[{"30", "\[Rule]", "17"}], ",", 
                    RowBox[{"14", "\[Rule]", "21"}], ",", 
                    RowBox[{"15", "\[Rule]", "20"}], ",", 
                    RowBox[{"16", "\[Rule]", "19"}], ",", 
                    RowBox[{"50", "\[Rule]", "30"}], ",", 
                    RowBox[{"51", "\[Rule]", "29"}], ",", 
                    RowBox[{"17", "\[Rule]", "33"}], ",", 
                    RowBox[{"18", "\[Rule]", "32"}], ",", 
                    RowBox[{"52", "\[Rule]", "49"}], ",", 
                    RowBox[{"53", "\[Rule]", "48"}], ",", 
                    RowBox[{"54", "\[Rule]", "47"}], ",", 
                    RowBox[{"32", "\[Rule]", "51"}], ",", 
                    RowBox[{"33", "\[Rule]", "50"}], ",", 
                    RowBox[{"19", "\[Rule]", "54"}], ",", 
                    RowBox[{"20", "\[Rule]", "53"}], ",", 
                    RowBox[{"21", "\[Rule]", "52"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "6"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"34", "\[Rule]", "2"}], ",", 
                    RowBox[{"35", "\[Rule]", "1"}], ",", 
                    RowBox[{"36", "\[Rule]", "3"}], ",", 
                    RowBox[{"22", "\[Rule]", "9"}], ",", 
                    RowBox[{"23", "\[Rule]", "10"}], ",", 
                    RowBox[{"1", "\[Rule]", "15"}], ",", 
                    RowBox[{"2", "\[Rule]", "14"}], ",", 
                    RowBox[{"3", "\[Rule]", "16"}], ",", 
                    RowBox[{"42", "\[Rule]", "22"}], ",", 
                    RowBox[{"43", "\[Rule]", "23"}], ",", 
                    RowBox[{"9", "\[Rule]", "29"}], ",", 
                    RowBox[{"10", "\[Rule]", "30"}], ",", 
                    RowBox[{"47", "\[Rule]", "35"}], ",", 
                    RowBox[{"48", "\[Rule]", "34"}], ",", 
                    RowBox[{"49", "\[Rule]", "36"}], ",", 
                    RowBox[{"29", "\[Rule]", "42"}], ",", 
                    RowBox[{"30", "\[Rule]", "43"}], ",", 
                    RowBox[{"14", "\[Rule]", "48"}], ",", 
                    RowBox[{"15", "\[Rule]", "47"}], ",", 
                    RowBox[{"16", "\[Rule]", "49"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"LPerm", "[", 
            RowBox[{
              SubscriptBox["g", "30"], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"19", "\[Rule]", "40"}], ",", 
                  RowBox[{"20", "\[Rule]", "41"}], ",", 
                  RowBox[{"21", "\[Rule]", "39"}], ",", 
                  RowBox[{"32", "\[Rule]", "46"}], ",", 
                  RowBox[{"33", "\[Rule]", "45"}], ",", 
                  RowBox[{"34", "\[Rule]", "54"}], ",", 
                  RowBox[{"35", "\[Rule]", "52"}], ",", 
                  RowBox[{"36", "\[Rule]", "53"}], ",", 
                  RowBox[{"37", "\[Rule]", "42"}], ",", 
                  RowBox[{"38", "\[Rule]", "43"}], ",", 
                  RowBox[{"39", "\[Rule]", "34"}], ",", 
                  RowBox[{"40", "\[Rule]", "36"}], ",", 
                  RowBox[{"41", "\[Rule]", "35"}], ",", 
                  RowBox[{"42", "\[Rule]", "33"}], ",", 
                  RowBox[{"43", "\[Rule]", "32"}], ",", 
                  RowBox[{"45", "\[Rule]", "37"}], ",", 
                  RowBox[{"46", "\[Rule]", "38"}], ",", 
                  RowBox[{"52", "\[Rule]", "20"}], ",", 
                  RowBox[{"53", "\[Rule]", "19"}], ",", 
                  RowBox[{"54", "\[Rule]", "21"}]}], "}"}]}], "]"}], "}"}], 
        ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "1"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"39", "\[Rule]", "34"}], ",", 
                    RowBox[{"40", "\[Rule]", "36"}], ",", 
                    RowBox[{"41", "\[Rule]", "35"}], ",", 
                    RowBox[{"45", "\[Rule]", "37"}], ",", 
                    RowBox[{"46", "\[Rule]", "38"}], ",", 
                    RowBox[{"52", "\[Rule]", "39"}], ",", 
                    RowBox[{"53", "\[Rule]", "41"}], ",", 
                    RowBox[{"54", "\[Rule]", "40"}], ",", 
                    RowBox[{"37", "\[Rule]", "42"}], ",", 
                    RowBox[{"38", "\[Rule]", "43"}], ",", 
                    RowBox[{"50", "\[Rule]", "45"}], ",", 
                    RowBox[{"51", "\[Rule]", "46"}], ",", 
                    RowBox[{"34", "\[Rule]", "47"}], ",", 
                    RowBox[{"35", "\[Rule]", "49"}], ",", 
                    RowBox[{"36", "\[Rule]", "48"}], ",", 
                    RowBox[{"42", "\[Rule]", "50"}], ",", 
                    RowBox[{"43", "\[Rule]", "51"}], ",", 
                    RowBox[{"47", "\[Rule]", "52"}], ",", 
                    RowBox[{"48", "\[Rule]", "54"}], ",", 
                    RowBox[{"49", "\[Rule]", "53"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "45"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"32", "\[Rule]", "38"}], ",", 
                    RowBox[{"33", "\[Rule]", "37"}], ",", 
                    RowBox[{"34", "\[Rule]", "41"}], ",", 
                    RowBox[{"35", "\[Rule]", "40"}], ",", 
                    RowBox[{"36", "\[Rule]", "39"}], ",", 
                    RowBox[{"37", "\[Rule]", "50"}], ",", 
                    RowBox[{"38", "\[Rule]", "51"}], ",", 
                    RowBox[{"39", "\[Rule]", "53"}], ",", 
                    RowBox[{"40", "\[Rule]", "52"}], ",", 
                    RowBox[{"41", "\[Rule]", "54"}], ",", 
                    RowBox[{"42", "\[Rule]", "33"}], ",", 
                    RowBox[{"43", "\[Rule]", "32"}], ",", 
                    RowBox[{"47", "\[Rule]", "35"}], ",", 
                    RowBox[{"48", "\[Rule]", "34"}], ",", 
                    RowBox[{"49", "\[Rule]", "36"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}], ",", 
                    RowBox[{"52", "\[Rule]", "47"}], ",", 
                    RowBox[{"53", "\[Rule]", "49"}], ",", 
                    RowBox[{"54", "\[Rule]", "48"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "74"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "48"}], ",", 
                    RowBox[{"2", "\[Rule]", "49"}], ",", 
                    RowBox[{"3", "\[Rule]", "47"}], ",", 
                    RowBox[{"9", "\[Rule]", "51"}], ",", 
                    RowBox[{"10", "\[Rule]", "50"}], ",", 
                    RowBox[{"22", "\[Rule]", "9"}], ",", 
                    RowBox[{"23", "\[Rule]", "10"}], ",", 
                    RowBox[{"34", "\[Rule]", "2"}], ",", 
                    RowBox[{"35", "\[Rule]", "1"}], ",", 
                    RowBox[{"36", "\[Rule]", "3"}], ",", 
                    RowBox[{"42", "\[Rule]", "22"}], ",", 
                    RowBox[{"43", "\[Rule]", "23"}], ",", 
                    RowBox[{"47", "\[Rule]", "52"}], ",", 
                    RowBox[{"48", "\[Rule]", "54"}], ",", 
                    RowBox[{"49", "\[Rule]", "53"}], ",", 
                    RowBox[{"50", "\[Rule]", "43"}], ",", 
                    RowBox[{"51", "\[Rule]", "42"}], ",", 
                    RowBox[{"52", "\[Rule]", "36"}], ",", 
                    RowBox[{"53", "\[Rule]", "34"}], ",", 
                    RowBox[{"54", "\[Rule]", "35"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "54"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"32", "\[Rule]", "46"}], ",", 
                    RowBox[{"33", "\[Rule]", "45"}], ",", 
                    RowBox[{"39", "\[Rule]", "41"}], ",", 
                    RowBox[{"40", "\[Rule]", "39"}], ",", 
                    RowBox[{"41", "\[Rule]", "40"}], ",", 
                    RowBox[{"42", "\[Rule]", "50"}], ",", 
                    RowBox[{"43", "\[Rule]", "51"}], ",", 
                    RowBox[{"45", "\[Rule]", "33"}], ",", 
                    RowBox[{"46", "\[Rule]", "32"}], ",", 
                    RowBox[{"47", "\[Rule]", "49"}], ",", 
                    RowBox[{"48", "\[Rule]", "47"}], ",", 
                    RowBox[{"49", "\[Rule]", "48"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}], ",", 
                    RowBox[{"52", "\[Rule]", "53"}], ",", 
                    RowBox[{"53", "\[Rule]", "54"}], ",", 
                    RowBox[{"54", "\[Rule]", "52"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "78"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "40"}], ",", 
                    RowBox[{"2", "\[Rule]", "41"}], ",", 
                    RowBox[{"3", "\[Rule]", "39"}], ",", 
                    RowBox[{"9", "\[Rule]", "38"}], ",", 
                    RowBox[{"10", "\[Rule]", "37"}], ",", 
                    RowBox[{"22", "\[Rule]", "9"}], ",", 
                    RowBox[{"23", "\[Rule]", "10"}], ",", 
                    RowBox[{"37", "\[Rule]", "22"}], ",", 
                    RowBox[{"38", "\[Rule]", "23"}], ",", 
                    RowBox[{"39", "\[Rule]", "2"}], ",", 
                    RowBox[{"40", "\[Rule]", "3"}], ",", 
                    RowBox[{"41", "\[Rule]", "1"}], ",", 
                    RowBox[{"42", "\[Rule]", "46"}], ",", 
                    RowBox[{"43", "\[Rule]", "45"}], ",", 
                    RowBox[{"45", "\[Rule]", "50"}], ",", 
                    RowBox[{"46", "\[Rule]", "51"}], ",", 
                    RowBox[{"47", "\[Rule]", "54"}], ",", 
                    RowBox[{"48", "\[Rule]", "53"}], ",", 
                    RowBox[{"49", "\[Rule]", "52"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}], ",", 
                    RowBox[{"52", "\[Rule]", "47"}], ",", 
                    RowBox[{"53", "\[Rule]", "49"}], ",", 
                    RowBox[{"54", "\[Rule]", "48"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "127"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "47"}], ",", 
                    RowBox[{"2", "\[Rule]", "48"}], ",", 
                    RowBox[{"3", "\[Rule]", "49"}], ",", 
                    RowBox[{"9", "\[Rule]", "51"}], ",", 
                    RowBox[{"10", "\[Rule]", "50"}], ",", 
                    RowBox[{"22", "\[Rule]", "9"}], ",", 
                    RowBox[{"23", "\[Rule]", "10"}], ",", 
                    RowBox[{"32", "\[Rule]", "43"}], ",", 
                    RowBox[{"33", "\[Rule]", "42"}], ",", 
                    RowBox[{"37", "\[Rule]", "32"}], ",", 
                    RowBox[{"38", "\[Rule]", "33"}], ",", 
                    RowBox[{"39", "\[Rule]", "52"}], ",", 
                    RowBox[{"40", "\[Rule]", "54"}], ",", 
                    RowBox[{"41", "\[Rule]", "53"}], ",", 
                    RowBox[{"42", "\[Rule]", "37"}], ",", 
                    RowBox[{"43", "\[Rule]", "38"}], ",", 
                    RowBox[{"45", "\[Rule]", "22"}], ",", 
                    RowBox[{"46", "\[Rule]", "23"}], ",", 
                    RowBox[{"47", "\[Rule]", "41"}], ",", 
                    RowBox[{"48", "\[Rule]", "39"}], ",", 
                    RowBox[{"49", "\[Rule]", "40"}], ",", 
                    RowBox[{"50", "\[Rule]", "45"}], ",", 
                    RowBox[{"51", "\[Rule]", "46"}], ",", 
                    RowBox[{"52", "\[Rule]", "2"}], ",", 
                    RowBox[{"53", "\[Rule]", "1"}], ",", 
                    RowBox[{"54", "\[Rule]", "3"}]}], "}"}]}], "]"}]}], "}"}],
         ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "59"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"32", "\[Rule]", "43"}], ",", 
                    RowBox[{"33", "\[Rule]", "42"}], ",", 
                    RowBox[{"37", "\[Rule]", "50"}], ",", 
                    RowBox[{"38", "\[Rule]", "51"}], ",", 
                    RowBox[{"42", "\[Rule]", "37"}], ",", 
                    RowBox[{"43", "\[Rule]", "38"}], ",", 
                    RowBox[{"45", "\[Rule]", "33"}], ",", 
                    RowBox[{"46", "\[Rule]", "32"}], ",", 
                    RowBox[{"47", "\[Rule]", "49"}], ",", 
                    RowBox[{"48", "\[Rule]", "47"}], ",", 
                    RowBox[{"49", "\[Rule]", "48"}], ",", 
                    RowBox[{"50", "\[Rule]", "45"}], ",", 
                    RowBox[{"51", "\[Rule]", "46"}], ",", 
                    RowBox[{"52", "\[Rule]", "54"}], ",", 
                    RowBox[{"53", "\[Rule]", "52"}], ",", 
                    RowBox[{"54", "\[Rule]", "53"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "141"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "54"}], ",", 
                    RowBox[{"2", "\[Rule]", "53"}], ",", 
                    RowBox[{"3", "\[Rule]", "52"}], ",", 
                    RowBox[{"9", "\[Rule]", "22"}], ",", 
                    RowBox[{"10", "\[Rule]", "23"}], ",", 
                    RowBox[{"22", "\[Rule]", "45"}], ",", 
                    RowBox[{"23", "\[Rule]", "46"}], ",", 
                    RowBox[{"29", "\[Rule]", "10"}], ",", 
                    RowBox[{"30", "\[Rule]", "9"}], ",", 
                    RowBox[{"32", "\[Rule]", "37"}], ",", 
                    RowBox[{"33", "\[Rule]", "38"}], ",", 
                    RowBox[{"37", "\[Rule]", "29"}], ",", 
                    RowBox[{"38", "\[Rule]", "30"}], ",", 
                    RowBox[{"42", "\[Rule]", "33"}], ",", 
                    RowBox[{"43", "\[Rule]", "32"}], ",", 
                    RowBox[{"45", "\[Rule]", "42"}], ",", 
                    RowBox[{"46", "\[Rule]", "43"}], ",", 
                    RowBox[{"47", "\[Rule]", "3"}], ",", 
                    RowBox[{"48", "\[Rule]", "1"}], ",", 
                    RowBox[{"49", "\[Rule]", "2"}], ",", 
                    RowBox[{"52", "\[Rule]", "47"}], ",", 
                    RowBox[{"53", "\[Rule]", "49"}], ",", 
                    RowBox[{"54", "\[Rule]", "48"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "57"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"32", "\[Rule]", "46"}], ",", 
                    RowBox[{"33", "\[Rule]", "45"}], ",", 
                    RowBox[{"42", "\[Rule]", "50"}], ",", 
                    RowBox[{"43", "\[Rule]", "51"}], ",", 
                    RowBox[{"45", "\[Rule]", "33"}], ",", 
                    RowBox[{"46", "\[Rule]", "32"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "62"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"32", "\[Rule]", "51"}], ",", 
                    RowBox[{"33", "\[Rule]", "50"}], ",", 
                    RowBox[{"37", "\[Rule]", "33"}], ",", 
                    RowBox[{"38", "\[Rule]", "32"}], ",", 
                    RowBox[{"42", "\[Rule]", "45"}], ",", 
                    RowBox[{"43", "\[Rule]", "46"}], ",", 
                    RowBox[{"45", "\[Rule]", "37"}], ",", 
                    RowBox[{"46", "\[Rule]", "38"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "166"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "52"}], ",", 
                    RowBox[{"2", "\[Rule]", "54"}], ",", 
                    RowBox[{"3", "\[Rule]", "53"}], ",", 
                    RowBox[{"9", "\[Rule]", "37"}], ",", 
                    RowBox[{"10", "\[Rule]", "38"}], ",", 
                    RowBox[{"17", "\[Rule]", "33"}], ",", 
                    RowBox[{"18", "\[Rule]", "32"}], ",", 
                    RowBox[{"22", "\[Rule]", "50"}], ",", 
                    RowBox[{"23", "\[Rule]", "51"}], ",", 
                    RowBox[{"29", "\[Rule]", "46"}], ",", 
                    RowBox[{"30", "\[Rule]", "45"}], ",", 
                    RowBox[{"32", "\[Rule]", "18"}], ",", 
                    RowBox[{"33", "\[Rule]", "17"}], ",", 
                    RowBox[{"37", "\[Rule]", "9"}], ",", 
                    RowBox[{"38", "\[Rule]", "10"}], ",", 
                    RowBox[{"42", "\[Rule]", "22"}], ",", 
                    RowBox[{"43", "\[Rule]", "23"}], ",", 
                    RowBox[{"45", "\[Rule]", "30"}], ",", 
                    RowBox[{"46", "\[Rule]", "29"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}], ",", 
                    RowBox[{"52", "\[Rule]", "1"}], ",", 
                    RowBox[{"53", "\[Rule]", "3"}], ",", 
                    RowBox[{"54", "\[Rule]", "2"}]}], "}"}]}], "]"}]}], "}"}],
         ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "66"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"37", "\[Rule]", "50"}], ",", 
                    RowBox[{"38", "\[Rule]", "51"}], ",", 
                    RowBox[{"42", "\[Rule]", "45"}], ",", 
                    RowBox[{"43", "\[Rule]", "46"}], ",", 
                    RowBox[{"45", "\[Rule]", "42"}], ",", 
                    RowBox[{"46", "\[Rule]", "43"}], ",", 
                    RowBox[{"50", "\[Rule]", "37"}], ",", 
                    RowBox[{"51", "\[Rule]", "38"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "68"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"37", "\[Rule]", "45"}], ",", 
                    RowBox[{"38", "\[Rule]", "46"}], ",", 
                    RowBox[{"42", "\[Rule]", "37"}], ",", 
                    RowBox[{"43", "\[Rule]", "38"}], ",", 
                    RowBox[{"45", "\[Rule]", "42"}], ",", 
                    RowBox[{"46", "\[Rule]", "43"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "82"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "3"}], ",", 
                    RowBox[{"2", "\[Rule]", "1"}], ",", 
                    RowBox[{"3", "\[Rule]", "2"}], ",", 
                    RowBox[{"9", "\[Rule]", "23"}], ",", 
                    RowBox[{"10", "\[Rule]", "22"}], ",", 
                    RowBox[{"22", "\[Rule]", "51"}], ",", 
                    RowBox[{"23", "\[Rule]", "50"}], ",", 
                    RowBox[{"37", "\[Rule]", "9"}], ",", 
                    RowBox[{"38", "\[Rule]", "10"}], ",", 
                    RowBox[{"42", "\[Rule]", "38"}], ",", 
                    RowBox[{"43", "\[Rule]", "37"}], ",", 
                    RowBox[{"50", "\[Rule]", "43"}], ",", 
                    RowBox[{"51", "\[Rule]", "42"}], ",", 
                    RowBox[{"52", "\[Rule]", "54"}], ",", 
                    RowBox[{"53", "\[Rule]", "52"}], ",", 
                    RowBox[{"54", "\[Rule]", "53"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "256"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "54"}], ",", 
                    RowBox[{"2", "\[Rule]", "53"}], ",", 
                    RowBox[{"3", "\[Rule]", "52"}], ",", 
                    RowBox[{"9", "\[Rule]", "38"}], ",", 
                    RowBox[{"10", "\[Rule]", "37"}], ",", 
                    RowBox[{"17", "\[Rule]", "10"}], ",", 
                    RowBox[{"18", "\[Rule]", "9"}], ",", 
                    RowBox[{"22", "\[Rule]", "45"}], ",", 
                    RowBox[{"23", "\[Rule]", "46"}], ",", 
                    RowBox[{"25", "\[Rule]", "43"}], ",", 
                    RowBox[{"26", "\[Rule]", "42"}], ",", 
                    RowBox[{"29", "\[Rule]", "22"}], ",", 
                    RowBox[{"30", "\[Rule]", "23"}], ",", 
                    RowBox[{"37", "\[Rule]", "26"}], ",", 
                    RowBox[{"38", "\[Rule]", "25"}], ",", 
                    RowBox[{"42", "\[Rule]", "18"}], ",", 
                    RowBox[{"43", "\[Rule]", "17"}], ",", 
                    RowBox[{"45", "\[Rule]", "50"}], ",", 
                    RowBox[{"46", "\[Rule]", "51"}], ",", 
                    RowBox[{"50", "\[Rule]", "30"}], ",", 
                    RowBox[{"51", "\[Rule]", "29"}], ",", 
                    RowBox[{"52", "\[Rule]", "3"}], ",", 
                    RowBox[{"53", "\[Rule]", "2"}], ",", 
                    RowBox[{"54", "\[Rule]", "1"}]}], "}"}]}], "]"}]}], "}"}],
         ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "71"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"42", "\[Rule]", "45"}], ",", 
                    RowBox[{"43", "\[Rule]", "46"}], ",", 
                    RowBox[{"45", "\[Rule]", "50"}], ",", 
                    RowBox[{"46", "\[Rule]", "51"}], ",", 
                    RowBox[{"50", "\[Rule]", "42"}], ",", 
                    RowBox[{"51", "\[Rule]", "43"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "91"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "3"}], ",", 
                    RowBox[{"2", "\[Rule]", "1"}], ",", 
                    RowBox[{"3", "\[Rule]", "2"}], ",", 
                    RowBox[{"9", "\[Rule]", "23"}], ",", 
                    RowBox[{"10", "\[Rule]", "22"}], ",", 
                    RowBox[{"22", "\[Rule]", "51"}], ",", 
                    RowBox[{"23", "\[Rule]", "50"}], ",", 
                    RowBox[{"42", "\[Rule]", "9"}], ",", 
                    RowBox[{"43", "\[Rule]", "10"}], ",", 
                    RowBox[{"45", "\[Rule]", "43"}], ",", 
                    RowBox[{"46", "\[Rule]", "42"}], ",", 
                    RowBox[{"50", "\[Rule]", "46"}], ",", 
                    RowBox[{"51", "\[Rule]", "45"}], ",", 
                    RowBox[{"52", "\[Rule]", "54"}], ",", 
                    RowBox[{"53", "\[Rule]", "52"}], ",", 
                    RowBox[{"54", "\[Rule]", "53"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "148"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "3"}], ",", 
                    RowBox[{"2", "\[Rule]", "1"}], ",", 
                    RowBox[{"3", "\[Rule]", "2"}], ",", 
                    RowBox[{"9", "\[Rule]", "46"}], ",", 
                    RowBox[{"10", "\[Rule]", "45"}], ",", 
                    RowBox[{"22", "\[Rule]", "43"}], ",", 
                    RowBox[{"23", "\[Rule]", "42"}], ",", 
                    RowBox[{"29", "\[Rule]", "22"}], ",", 
                    RowBox[{"30", "\[Rule]", "23"}], ",", 
                    RowBox[{"42", "\[Rule]", "30"}], ",", 
                    RowBox[{"43", "\[Rule]", "29"}], ",", 
                    RowBox[{"45", "\[Rule]", "51"}], ",", 
                    RowBox[{"46", "\[Rule]", "50"}], ",", 
                    RowBox[{"50", "\[Rule]", "9"}], ",", 
                    RowBox[{"51", "\[Rule]", "10"}], ",", 
                    RowBox[{"52", "\[Rule]", "54"}], ",", 
                    RowBox[{"53", "\[Rule]", "52"}], ",", 
                    RowBox[{"54", "\[Rule]", "53"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "99"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "2"}], ",", 
                    RowBox[{"2", "\[Rule]", "3"}], ",", 
                    RowBox[{"3", "\[Rule]", "1"}], ",", 
                    RowBox[{"9", "\[Rule]", "50"}], ",", 
                    RowBox[{"10", "\[Rule]", "51"}], ",", 
                    RowBox[{"22", "\[Rule]", "45"}], ",", 
                    RowBox[{"23", "\[Rule]", "46"}], ",", 
                    RowBox[{"45", "\[Rule]", "23"}], ",", 
                    RowBox[{"46", "\[Rule]", "22"}], ",", 
                    RowBox[{"50", "\[Rule]", "10"}], ",", 
                    RowBox[{"51", "\[Rule]", "9"}], ",", 
                    RowBox[{"52", "\[Rule]", "53"}], ",", 
                    RowBox[{"53", "\[Rule]", "54"}], ",", 
                    RowBox[{"54", "\[Rule]", "52"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "137"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"1", "\[Rule]", "53"}], ",", 
                    RowBox[{"2", "\[Rule]", "52"}], ",", 
                    RowBox[{"3", "\[Rule]", "54"}], ",", 
                    RowBox[{"9", "\[Rule]", "50"}], ",", 
                    RowBox[{"10", "\[Rule]", "51"}], ",", 
                    RowBox[{"22", "\[Rule]", "23"}], ",", 
                    RowBox[{"23", "\[Rule]", "22"}], ",", 
                    RowBox[{"50", "\[Rule]", "10"}], ",", 
                    RowBox[{"51", "\[Rule]", "9"}], ",", 
                    RowBox[{"52", "\[Rule]", "2"}], ",", 
                    RowBox[{"53", "\[Rule]", "1"}], ",", 
                    RowBox[{"54", "\[Rule]", "3"}]}], "}"}]}], "]"}]}], "}"}],
         ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "102"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"9", "\[Rule]", "51"}], ",", 
                    RowBox[{"10", "\[Rule]", "50"}], ",", 
                    RowBox[{"22", "\[Rule]", "46"}], ",", 
                    RowBox[{"23", "\[Rule]", "45"}], ",", 
                    RowBox[{"45", "\[Rule]", "22"}], ",", 
                    RowBox[{"46", "\[Rule]", "23"}], ",", 
                    RowBox[{"50", "\[Rule]", "9"}], ",", 
                    RowBox[{"51", "\[Rule]", "10"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "210"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"4", "\[Rule]", "18"}], ",", 
                    RowBox[{"5", "\[Rule]", "17"}], ",", 
                    RowBox[{"9", "\[Rule]", "4"}], ",", 
                    RowBox[{"10", "\[Rule]", "5"}], ",", 
                    RowBox[{"17", "\[Rule]", "23"}], ",", 
                    RowBox[{"18", "\[Rule]", "22"}], ",", 
                    RowBox[{"22", "\[Rule]", "50"}], ",", 
                    RowBox[{"23", "\[Rule]", "51"}], ",", 
                    RowBox[{"45", "\[Rule]", "46"}], ",", 
                    RowBox[{"46", "\[Rule]", "45"}], ",", 
                    RowBox[{"50", "\[Rule]", "10"}], ",", 
                    RowBox[{"51", "\[Rule]", "9"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "232"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"4", "\[Rule]", "10"}], ",", 
                    RowBox[{"5", "\[Rule]", "9"}], ",", 
                    RowBox[{"9", "\[Rule]", "13"}], ",", 
                    RowBox[{"10", "\[Rule]", "12"}], ",", 
                    RowBox[{"12", "\[Rule]", "29"}], ",", 
                    RowBox[{"13", "\[Rule]", "30"}], ",", 
                    RowBox[{"17", "\[Rule]", "51"}], ",", 
                    RowBox[{"18", "\[Rule]", "50"}], ",", 
                    RowBox[{"22", "\[Rule]", "5"}], ",", 
                    RowBox[{"23", "\[Rule]", "4"}], ",", 
                    RowBox[{"29", "\[Rule]", "18"}], ",", 
                    RowBox[{"30", "\[Rule]", "17"}], ",", 
                    RowBox[{"50", "\[Rule]", "23"}], ",", 
                    RowBox[{"51", "\[Rule]", "22"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"LPerm", "[", 
            RowBox[{
              SubscriptBox["g", "106"], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"22", "\[Rule]", "45"}], ",", 
                  RowBox[{"23", "\[Rule]", "46"}], ",", 
                  RowBox[{"45", "\[Rule]", "50"}], ",", 
                  RowBox[{"46", "\[Rule]", "51"}], ",", 
                  RowBox[{"50", "\[Rule]", "22"}], ",", 
                  RowBox[{"51", "\[Rule]", "23"}]}], "}"}]}], "]"}], "}"}], 
        ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "113"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"45", "\[Rule]", "46"}], ",", 
                    RowBox[{"46", "\[Rule]", "45"}], ",", 
                    RowBox[{"50", "\[Rule]", "51"}], ",", 
                    RowBox[{"51", "\[Rule]", "50"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "151"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"29", "\[Rule]", "46"}], ",", 
                    RowBox[{"30", "\[Rule]", "45"}], ",", 
                    RowBox[{"45", "\[Rule]", "50"}], ",", 
                    RowBox[{"46", "\[Rule]", "51"}], ",", 
                    RowBox[{"50", "\[Rule]", "30"}], ",", 
                    RowBox[{"51", "\[Rule]", "29"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "169"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"17", "\[Rule]", "46"}], ",", 
                    RowBox[{"18", "\[Rule]", "45"}], ",", 
                    RowBox[{"29", "\[Rule]", "51"}], ",", 
                    RowBox[{"30", "\[Rule]", "50"}], ",", 
                    RowBox[{"45", "\[Rule]", "17"}], ",", 
                    RowBox[{"46", "\[Rule]", "18"}], ",", 
                    RowBox[{"50", "\[Rule]", "29"}], ",", 
                    RowBox[{"51", "\[Rule]", "30"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "156"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"29", "\[Rule]", "30"}], ",", 
                    RowBox[{"30", "\[Rule]", "29"}], ",", 
                    RowBox[{"50", "\[Rule]", "51"}], ",", 
                    RowBox[{"51", "\[Rule]", "50"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "172"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"17", "\[Rule]", "50"}], ",", 
                    RowBox[{"18", "\[Rule]", "51"}], ",", 
                    RowBox[{"29", "\[Rule]", "18"}], ",", 
                    RowBox[{"30", "\[Rule]", "17"}], ",", 
                    RowBox[{"50", "\[Rule]", "30"}], ",", 
                    RowBox[{"51", "\[Rule]", "29"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "177"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"17", "\[Rule]", "18"}], ",", 
                    RowBox[{"18", "\[Rule]", "17"}], ",", 
                    RowBox[{"50", "\[Rule]", "51"}], ",", 
                    RowBox[{"51", "\[Rule]", "50"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "213"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"4", "\[Rule]", "18"}], ",", 
                    RowBox[{"5", "\[Rule]", "17"}], ",", 
                    RowBox[{"17", "\[Rule]", "51"}], ",", 
                    RowBox[{"18", "\[Rule]", "50"}], ",", 
                    RowBox[{"50", "\[Rule]", "4"}], ",", 
                    RowBox[{"51", "\[Rule]", "5"}]}], "}"}]}], "]"}]}], "}"}],
         ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "218"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"4", "\[Rule]", "5"}], ",", 
                    RowBox[{"5", "\[Rule]", "4"}], ",", 
                    RowBox[{"50", "\[Rule]", "51"}], ",", 
                    RowBox[{"51", "\[Rule]", "50"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "235"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"4", "\[Rule]", "51"}], ",", 
                    RowBox[{"5", "\[Rule]", "50"}], ",", 
                    RowBox[{"12", "\[Rule]", "4"}], ",", 
                    RowBox[{"13", "\[Rule]", "5"}], ",", 
                    RowBox[{"50", "\[Rule]", "13"}], ",", 
                    RowBox[{"51", "\[Rule]", "12"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "240"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"12", "\[Rule]", "13"}], ",", 
                    RowBox[{"13", "\[Rule]", "12"}], ",", 
                    RowBox[{"50", "\[Rule]", "51"}], ",", 
                    RowBox[{"51", "\[Rule]", "50"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "259"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"12", "\[Rule]", "51"}], ",", 
                    RowBox[{"13", "\[Rule]", "50"}], ",", 
                    RowBox[{"25", "\[Rule]", "12"}], ",", 
                    RowBox[{"26", "\[Rule]", "13"}], ",", 
                    RowBox[{"50", "\[Rule]", "26"}], ",", 
                    RowBox[{"51", "\[Rule]", "25"}]}], "}"}]}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"LPerm", "[", 
            RowBox[{
              SubscriptBox["g", "264"], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"25", "\[Rule]", "26"}], ",", 
                  RowBox[{"26", "\[Rule]", "25"}], ",", 
                  RowBox[{"50", "\[Rule]", "51"}], ",", 
                  RowBox[{"51", "\[Rule]", "50"}]}], "}"}]}], "]"}], "}"}]}], 
      "}"}]], "Output"],

Cell["Note how many simple actions have been found.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basis Formulae", "Subsubsection"],

Cell["Below are the formulae for the generators:", "Text"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              SubscriptBox["g", "0"], "\[Rule]", 
              RowBox[{"{", "}"}]}]},
          {
            RowBox[{
              SubscriptBox["g", "1"], "\[Rule]", "\<\"x\"\>"}]},
          {
            RowBox[{
              SubscriptBox["g", "2"], "\[Rule]", "\<\"y\"\>"}]},
          {
            RowBox[{
              SubscriptBox["g", "3"], "\[Rule]", "\<\"z\"\>"}]},
          {
            RowBox[{
              SubscriptBox["g", "4"], "\[Rule]", "\<\"x\"\>"}]},
          {
            RowBox[{
              SubscriptBox["g", "5"], "\[Rule]", "\<\"y\"\>"}]},
          {
            RowBox[{
              SubscriptBox["g", "6"], "\[Rule]", "\<\"z\"\>"}]},
          {
            RowBox[{
              SubscriptBox["g", "7"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "8"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "7"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "9"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "8"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "10"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "11"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "12"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "10"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "13"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "11"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "14"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "11"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "15"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "11"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "16"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "12"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "17"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "12"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "18"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "13"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "19"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "13"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "20"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "14"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "21"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "15"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "22"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "17"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "23"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "17"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "24"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "19"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "25"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "19"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "26"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "22"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "27"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "23"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "28"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "24"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "29"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "25"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "30"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "10"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "10"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "31"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "32"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "31"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "33"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "32"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "34"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "32"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "35"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "33"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "36"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "34"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "37"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "35"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "38"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "36"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "39"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "37"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "40"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "37"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "41"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "38"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "42"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "40"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "43"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "41"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "44"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "43"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "45"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "34"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "34"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "46"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "47"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "7"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "48"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "9"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "49"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "46"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "50"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "47"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "51"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "48"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "52"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "49"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "53"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "51"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "54"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "8"], "\[InvisibleSpace]", 
                SubscriptBox["g", "45"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "7"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "55"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "54"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "56"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "55"], "\[InvisibleSpace]", 
                SubscriptBox["g", "54"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "57"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "56"], "\[InvisibleSpace]", 
                SubscriptBox["g", "54"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "58"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "57"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "59"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "46"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "47"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "60"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "59"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "61"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "60"], "\[InvisibleSpace]", 
                SubscriptBox["g", "59"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "62"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "61"], "\[InvisibleSpace]", 
                SubscriptBox["g", "59"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "63"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "62"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "64"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "58"], "\[InvisibleSpace]", 
                SubscriptBox["g", "62"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "65"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "63"], "\[InvisibleSpace]", 
                SubscriptBox["g", "62"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "66"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "64"], "\[InvisibleSpace]", 
                SubscriptBox["g", "62"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "67"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "66"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "68"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "35"], "\[InvisibleSpace]", 
                SubscriptBox["g", "30"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "37"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "48"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "58"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "69"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "68"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "70"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "69"], "\[InvisibleSpace]", 
                SubscriptBox["g", "68"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "71"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "67"], "\[InvisibleSpace]", 
                SubscriptBox["g", "68"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "67"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "72"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "71"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "73"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "72"], "\[InvisibleSpace]", 
                SubscriptBox["g", "71"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "74"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "10"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "10"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "75"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "76"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "47"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "77"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "53"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "78"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "7"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "8"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "79"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "78"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "80"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "55"], "\[InvisibleSpace]", 
                SubscriptBox["g", "78"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "81"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "56"], "\[InvisibleSpace]", 
                SubscriptBox["g", "78"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "82"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "79"], "\[InvisibleSpace]", 
                SubscriptBox["g", "78"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "55"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "60"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "63"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "83"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "84"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "67"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "85"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "70"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "86"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "83"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "87"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "85"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "88"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "87"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "89"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "88"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "90"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "84"], "\[InvisibleSpace]", 
                SubscriptBox["g", "66"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "91"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "69"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "69"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "92"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "93"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "72"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "94"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "73"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "95"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "92"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "96"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "93"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "97"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "96"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "98"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "97"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "99"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "94"], "\[InvisibleSpace]", 
                SubscriptBox["g", "91"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "100"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "99"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "101"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "100"], "\[InvisibleSpace]", 
                SubscriptBox["g", "99"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "102"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "101"], "\[InvisibleSpace]", 
                SubscriptBox["g", "99"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "103"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "102"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "104"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "103"], "\[InvisibleSpace]", 
                SubscriptBox["g", "102"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "105"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "104"], "\[InvisibleSpace]", 
                SubscriptBox["g", "102"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "106"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "92"], "\[InvisibleSpace]", 
                SubscriptBox["g", "71"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "92"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "107"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "108"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "107"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "109"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "103"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "110"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "105"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "111"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "109"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "112"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "110"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "113"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "94"], "\[InvisibleSpace]", 
                SubscriptBox["g", "71"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "98"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "112"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "108"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "114"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "113"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "115"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "107"], "\[InvisibleSpace]", 
                SubscriptBox["g", "113"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "116"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "108"], "\[InvisibleSpace]", 
                SubscriptBox["g", "113"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "117"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "116"], "\[InvisibleSpace]", 
                SubscriptBox["g", "106"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "118"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "63"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "119"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "64"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "120"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "65"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "121"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "119"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "122"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "120"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "123"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "122"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "124"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "123"], "\[InvisibleSpace]", 
                SubscriptBox["g", "82"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "125"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "118"], "\[InvisibleSpace]", 
                SubscriptBox["g", "62"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "126"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "120"], "\[InvisibleSpace]", 
                SubscriptBox["g", "62"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "127"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "8"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "53"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "128"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "127"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "129"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "55"], "\[InvisibleSpace]", 
                SubscriptBox["g", "127"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "130"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "56"], "\[InvisibleSpace]", 
                SubscriptBox["g", "127"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "131"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "79"], "\[InvisibleSpace]", 
                SubscriptBox["g", "127"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "132"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "80"], "\[InvisibleSpace]", 
                SubscriptBox["g", "127"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "133"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "81"], "\[InvisibleSpace]", 
                SubscriptBox["g", "127"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "134"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "32"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "135"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "37"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "136"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "43"], "\[InvisibleSpace]", 
                SubscriptBox["g", "74"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "137"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "12"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "12"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "37"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "75"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "81"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "119"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "83"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "92"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "138"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "137"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "139"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "100"], "\[InvisibleSpace]", 
                SubscriptBox["g", "137"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "140"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "101"], "\[InvisibleSpace]", 
                SubscriptBox["g", "137"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "141"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "14"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "14"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "31"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "9"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "130"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "142"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "143"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "60"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "144"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "61"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "145"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "142"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "146"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "143"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "147"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "144"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "148"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "145"], "\[InvisibleSpace]", 
                SubscriptBox["g", "141"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "119"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "83"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "149"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "150"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "93"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "151"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "72"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "98"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "105"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "108"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "152"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "153"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "114"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "154"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "152"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "155"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "153"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "156"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "152"], "\[InvisibleSpace]", 
                SubscriptBox["g", "113"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "153"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "157"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "156"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "158"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "108"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "159"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "116"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "160"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "103"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "161"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "105"], "\[InvisibleSpace]", 
                SubscriptBox["g", "151"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "162"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "70"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "163"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "84"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "164"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "65"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "165"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "118"], "\[InvisibleSpace]", 
                SubscriptBox["g", "148"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "166"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "15"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "19"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "134"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "77"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "132"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "147"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "167"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "166"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "168"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "126"], "\[InvisibleSpace]", 
                SubscriptBox["g", "166"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "169"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "58"], "\[InvisibleSpace]", 
                SubscriptBox["g", "166"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "164"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "95"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "139"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "103"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "108"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "170"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "171"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "114"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "172"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "152"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "155"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "173"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "172"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "174"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "157"], "\[InvisibleSpace]", 
                SubscriptBox["g", "172"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "175"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "173"], "\[InvisibleSpace]", 
                SubscriptBox["g", "172"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "176"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "174"], "\[InvisibleSpace]", 
                SubscriptBox["g", "172"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "177"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "173"], "\[InvisibleSpace]", 
                SubscriptBox["g", "156"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "173"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "178"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "177"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "179"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "107"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "180"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "115"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "181"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "111"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "182"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "112"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "183"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "72"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "184"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "94"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "185"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "69"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "186"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "90"], "\[InvisibleSpace]", 
                SubscriptBox["g", "169"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "187"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "3"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "188"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "4"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "189"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "190"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "187"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "191"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "187"], "\[InvisibleSpace]", 
                SubscriptBox["g", "3"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "192"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "187"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "193"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "188"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "194"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "188"], "\[InvisibleSpace]", 
                SubscriptBox["g", "4"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "195"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "189"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "196"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "189"], "\[InvisibleSpace]", 
                SubscriptBox["g", "6"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "197"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "190"], "\[InvisibleSpace]", 
                SubscriptBox["g", "1"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "198"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "190"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "199"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "191"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "200"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "191"], "\[InvisibleSpace]", 
                SubscriptBox["g", "3"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "201"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "192"], "\[InvisibleSpace]", 
                SubscriptBox["g", "4"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "202"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "192"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "203"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "193"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "204"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "194"], "\[InvisibleSpace]", 
                SubscriptBox["g", "4"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "205"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "195"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "206"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "197"], "\[InvisibleSpace]", 
                SubscriptBox["g", "2"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "207"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "198"], "\[InvisibleSpace]", 
                SubscriptBox["g", "3"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "208"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "198"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "209"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "202"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "210"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "187"], "\[InvisibleSpace]", 
                SubscriptBox["g", "4"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "187"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "29"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "7"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "132"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "147"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "125"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "163"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "150"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "211"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "212"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "104"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "213"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "103"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "0"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "107"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "214"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "215"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "178"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "216"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "214"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "217"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "215"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "218"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "214"], "\[InvisibleSpace]", 
                SubscriptBox["g", "177"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "215"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "219"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "218"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "220"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "175"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "221"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "176"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "222"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "152"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "223"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "153"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "224"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "108"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "225"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "116"], "\[InvisibleSpace]", 
                SubscriptBox["g", "213"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "226"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "92"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "227"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "96"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "228"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "83"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "229"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "87"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "230"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "119"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "231"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "122"], "\[InvisibleSpace]", 
                SubscriptBox["g", "210"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "232"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "188"], "\[InvisibleSpace]", 
                SubscriptBox["g", "3"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "192"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "10"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "39"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "77"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "132"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "142"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "167"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "90"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "183"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "100"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "233"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "234"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "104"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "235"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "103"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "110"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "107"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "223"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "221"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "216"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "236"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "237"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "219"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "238"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "236"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "239"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "237"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "240"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "236"], "\[InvisibleSpace]", 
                SubscriptBox["g", "218"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "237"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "241"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "240"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "242"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "214"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "243"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "215"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "244"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "175"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "245"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "176"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "246"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "152"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "247"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "153"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "248"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "108"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "249"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "116"], "\[InvisibleSpace]", 
                SubscriptBox["g", "235"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "250"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "92"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "251"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "96"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "252"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "83"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "253"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "87"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "254"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "119"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "255"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "122"], "\[InvisibleSpace]", 
                SubscriptBox["g", "232"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "256"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "188"], "\[InvisibleSpace]", 
                SubscriptBox["g", "5"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "188"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "23"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "36"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "51"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "130"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "63"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "257"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "256"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "258"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "85"], "\[InvisibleSpace]", 
                SubscriptBox["g", "256"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "259"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "67"], "\[InvisibleSpace]", 
                SubscriptBox["g", "256"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "162"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "93"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "138"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "112"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "108"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "171"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "175"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "215"], ")"}], 
                  RowBox[{"-", "1"}]], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "236"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "260"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "261"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "241"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "262"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "260"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "263"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "261"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "264"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "260"], "\[InvisibleSpace]", 
                SubscriptBox["g", "240"], "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", 
                    SubscriptBox["g", "261"], ")"}], 
                  RowBox[{"-", "1"}]]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "265"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "0"], "\[InvisibleSpace]", 
                SubscriptBox["g", "264"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "266"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "236"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "267"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "237"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "268"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "214"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "269"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "215"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "270"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "175"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "271"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "176"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "272"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "152"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "273"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "153"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "274"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "108"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "275"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "116"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "276"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "103"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "277"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "105"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "278"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "73"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "279"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "98"], "\[InvisibleSpace]", 
                SubscriptBox["g", "259"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "280"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "64"], "\[InvisibleSpace]", 
                SubscriptBox["g", "256"]}]}]},
          {
            RowBox[{
              SubscriptBox["g", "281"], "\[Rule]", 
              RowBox[{
                SubscriptBox["g", "120"], "\[InvisibleSpace]", 
                SubscriptBox["g", "256"]}]}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {Subscript[ g, 0] -> {}, Subscript[ g, 1] -> "x", Subscript[
         g, 2] -> "y", Subscript[ g, 3] -> "z", Subscript[ g, 4] -> "x", 
        Subscript[ g, 5] -> "y", Subscript[ g, 6] -> "z", Subscript[ g, 7] -> 
        SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 1]], Subscript[ g, 8] -> SequenceForm[ 
          Subscript[ g, 7], 
          Subscript[ g, 1]], Subscript[ g, 9] -> SequenceForm[ 
          Subscript[ g, 8], 
          Subscript[ g, 1]], Subscript[ g, 10] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 2]], Subscript[ g, 11] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 6]], Subscript[ g, 12] -> SequenceForm[ 
          Subscript[ g, 10], 
          Subscript[ g, 2]], Subscript[ g, 13] -> SequenceForm[ 
          Subscript[ g, 11], 
          Subscript[ g, 1]], Subscript[ g, 14] -> SequenceForm[ 
          Subscript[ g, 11], 
          Subscript[ g, 2]], Subscript[ g, 15] -> SequenceForm[ 
          Subscript[ g, 11], 
          Subscript[ g, 6]], Subscript[ g, 16] -> SequenceForm[ 
          Subscript[ g, 12], 
          Subscript[ g, 1]], Subscript[ g, 17] -> SequenceForm[ 
          Subscript[ g, 12], 
          Subscript[ g, 2]], Subscript[ g, 18] -> SequenceForm[ 
          Subscript[ g, 13], 
          Subscript[ g, 1]], Subscript[ g, 19] -> SequenceForm[ 
          Subscript[ g, 13], 
          Subscript[ g, 2]], Subscript[ g, 20] -> SequenceForm[ 
          Subscript[ g, 14], 
          Subscript[ g, 2]], Subscript[ g, 21] -> SequenceForm[ 
          Subscript[ g, 15], 
          Subscript[ g, 6]], Subscript[ g, 22] -> SequenceForm[ 
          Subscript[ g, 17], 
          Subscript[ g, 1]], Subscript[ g, 23] -> SequenceForm[ 
          Subscript[ g, 17], 
          Subscript[ g, 6]], Subscript[ g, 24] -> SequenceForm[ 
          Subscript[ g, 19], 
          Subscript[ g, 2]], Subscript[ g, 25] -> SequenceForm[ 
          Subscript[ g, 19], 
          Subscript[ g, 6]], Subscript[ g, 26] -> SequenceForm[ 
          Subscript[ g, 22], 
          Subscript[ g, 1]], Subscript[ g, 27] -> SequenceForm[ 
          Subscript[ g, 23], 
          Subscript[ g, 6]], Subscript[ g, 28] -> SequenceForm[ 
          Subscript[ g, 24], 
          Subscript[ g, 2]], Subscript[ g, 29] -> SequenceForm[ 
          Subscript[ g, 25], 
          Subscript[ g, 6]], Subscript[ g, 30] -> SequenceForm[ 
          Subscript[ g, 10], 
          Subscript[ g, 1], 
          Superscript[ 
            Subscript[ g, 10], -1]], Subscript[ g, 31] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 30]], Subscript[ g, 32] -> SequenceForm[ 
          Subscript[ g, 31], 
          Subscript[ g, 30]], Subscript[ g, 33] -> SequenceForm[ 
          Subscript[ g, 32], 
          Subscript[ g, 30]], Subscript[ g, 34] -> SequenceForm[ 
          Subscript[ g, 32], 
          Subscript[ g, 1]], Subscript[ g, 35] -> SequenceForm[ 
          Subscript[ g, 33], 
          Subscript[ g, 1]], Subscript[ g, 36] -> SequenceForm[ 
          Subscript[ g, 34], 
          Subscript[ g, 1]], Subscript[ g, 37] -> SequenceForm[ 
          Subscript[ g, 35], 
          Subscript[ g, 1]], Subscript[ g, 38] -> SequenceForm[ 
          Subscript[ g, 36], 
          Subscript[ g, 30]], Subscript[ g, 39] -> SequenceForm[ 
          Subscript[ g, 37], 
          Subscript[ g, 1]], Subscript[ g, 40] -> SequenceForm[ 
          Subscript[ g, 37], 
          Subscript[ g, 30]], Subscript[ g, 41] -> SequenceForm[ 
          Subscript[ g, 38], 
          Subscript[ g, 30]], Subscript[ g, 42] -> SequenceForm[ 
          Subscript[ g, 40], 
          Subscript[ g, 30]], Subscript[ g, 43] -> SequenceForm[ 
          Subscript[ g, 41], 
          Subscript[ g, 1]], Subscript[ g, 44] -> SequenceForm[ 
          Subscript[ g, 43], 
          Subscript[ g, 1]], Subscript[ g, 45] -> SequenceForm[ 
          Subscript[ g, 34], 
          Subscript[ g, 30], 
          Superscript[ 
            Subscript[ g, 34], -1]], Subscript[ g, 46] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 45]], Subscript[ g, 47] -> SequenceForm[ 
          Subscript[ g, 7], 
          Subscript[ g, 45]], Subscript[ g, 48] -> SequenceForm[ 
          Subscript[ g, 9], 
          Subscript[ g, 45]], Subscript[ g, 49] -> SequenceForm[ 
          Subscript[ g, 46], 
          Subscript[ g, 45]], Subscript[ g, 50] -> SequenceForm[ 
          Subscript[ g, 47], 
          Subscript[ g, 45]], Subscript[ g, 51] -> SequenceForm[ 
          Subscript[ g, 48], 
          Subscript[ g, 45]], Subscript[ g, 52] -> SequenceForm[ 
          Subscript[ g, 49], 
          Subscript[ g, 45]], Subscript[ g, 53] -> SequenceForm[ 
          Subscript[ g, 51], 
          Subscript[ g, 45]], Subscript[ g, 54] -> SequenceForm[ 
          Subscript[ g, 8], 
          Subscript[ g, 45], 
          Superscript[ 
            Subscript[ g, 7], -1]], Subscript[ g, 55] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 54]], Subscript[ g, 56] -> SequenceForm[ 
          Subscript[ g, 55], 
          Subscript[ g, 54]], Subscript[ g, 57] -> SequenceForm[ 
          Subscript[ g, 56], 
          Subscript[ g, 54], 
          Superscript[ 
            Subscript[ g, 0], -1]], Subscript[ g, 58] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 57]], Subscript[ g, 59] -> SequenceForm[ 
          Subscript[ g, 46], 
          Subscript[ g, 1], 
          Superscript[ 
            Subscript[ g, 47], -1]], Subscript[ g, 60] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 59]], Subscript[ g, 61] -> SequenceForm[ 
          Subscript[ g, 60], 
          Subscript[ g, 59]], Subscript[ g, 62] -> SequenceForm[ 
          Subscript[ g, 61], 
          Subscript[ g, 59], 
          Superscript[ 
            Subscript[ g, 0], -1]], Subscript[ g, 63] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 62]], Subscript[ g, 64] -> SequenceForm[ 
          Subscript[ g, 58], 
          Subscript[ g, 62]], Subscript[ g, 65] -> SequenceForm[ 
          Subscript[ g, 63], 
          Subscript[ g, 62]], Subscript[ g, 66] -> SequenceForm[ 
          Subscript[ g, 64], 
          Subscript[ g, 62], 
          Superscript[ 
            Subscript[ g, 0], -1]], Subscript[ g, 67] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 66]], Subscript[ g, 68] -> SequenceForm[ 
          Subscript[ g, 35], 
          Subscript[ g, 30], 
          Superscript[ 
            Subscript[ g, 37], -1], 
          Superscript[ 
            Subscript[ g, 48], -1], 
          Superscript[ 
            Subscript[ g, 58], -1]], Subscript[ g, 69] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 68]], Subscript[ g, 70] -> SequenceForm[ 
          Subscript[ g, 69], 
          Subscript[ g, 68]], Subscript[ g, 71] -> SequenceForm[ 
          Subscript[ g, 67], 
          Subscript[ g, 68], 
          Superscript[ 
            Subscript[ g, 67], -1]], Subscript[ g, 72] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 71]], Subscript[ g, 73] -> SequenceForm[ 
          Subscript[ g, 72], 
          Subscript[ g, 71]], Subscript[ g, 74] -> SequenceForm[ 
          Subscript[ g, 10], 
          Subscript[ g, 6], 
          Superscript[ 
            Subscript[ g, 10], -1]], Subscript[ g, 75] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 74]], Subscript[ g, 76] -> SequenceForm[ 
          Subscript[ g, 47], 
          Subscript[ g, 74]], Subscript[ g, 77] -> SequenceForm[ 
          Subscript[ g, 53], 
          Subscript[ g, 74]], Subscript[ g, 78] -> SequenceForm[ 
          Subscript[ g, 7], 
          Subscript[ g, 74], 
          Superscript[ 
            Subscript[ g, 8], -1]], Subscript[ g, 79] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 78]], Subscript[ g, 80] -> SequenceForm[ 
          Subscript[ g, 55], 
          Subscript[ g, 78]], Subscript[ g, 81] -> SequenceForm[ 
          Subscript[ g, 56], 
          Subscript[ g, 78]], Subscript[ g, 82] -> SequenceForm[ 
          Subscript[ g, 79], 
          Subscript[ g, 78], 
          Superscript[ 
            Subscript[ g, 55], -1], 
          Superscript[ 
            Subscript[ g, 60], -1], 
          Superscript[ 
            Subscript[ g, 63], -1]], Subscript[ g, 83] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 82]], Subscript[ g, 84] -> SequenceForm[ 
          Subscript[ g, 67], 
          Subscript[ g, 82]], Subscript[ g, 85] -> SequenceForm[ 
          Subscript[ g, 70], 
          Subscript[ g, 82]], Subscript[ g, 86] -> SequenceForm[ 
          Subscript[ g, 83], 
          Subscript[ g, 82]], Subscript[ g, 87] -> SequenceForm[ 
          Subscript[ g, 85], 
          Subscript[ g, 82]], Subscript[ g, 88] -> SequenceForm[ 
          Subscript[ g, 87], 
          Subscript[ g, 82]], Subscript[ g, 89] -> SequenceForm[ 
          Subscript[ g, 88], 
          Subscript[ g, 82]], Subscript[ g, 90] -> SequenceForm[ 
          Subscript[ g, 84], 
          Subscript[ g, 66]], Subscript[ g, 91] -> SequenceForm[ 
          Subscript[ g, 69], 
          Subscript[ g, 82], 
          Superscript[ 
            Subscript[ g, 69], -1]], Subscript[ g, 92] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 91]], Subscript[ g, 93] -> SequenceForm[ 
          Subscript[ g, 72], 
          Subscript[ g, 91]], Subscript[ g, 94] -> SequenceForm[ 
          Subscript[ g, 73], 
          Subscript[ g, 91]], Subscript[ g, 95] -> SequenceForm[ 
          Subscript[ g, 92], 
          Subscript[ g, 91]], Subscript[ g, 96] -> SequenceForm[ 
          Subscript[ g, 93], 
          Subscript[ g, 91]], Subscript[ g, 97] -> SequenceForm[ 
          Subscript[ g, 96], 
          Subscript[ g, 91]], Subscript[ g, 98] -> SequenceForm[ 
          Subscript[ g, 97], 
          Subscript[ g, 91]], Subscript[ g, 99] -> SequenceForm[ 
          Subscript[ g, 94], 
          Subscript[ g, 91], 
          Superscript[ 
            Subscript[ g, 0], -1]], Subscript[ g, 100] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 99]], Subscript[ g, 101] -> SequenceForm[ 
          Subscript[ g, 100], 
          Subscript[ g, 99]], Subscript[ g, 102] -> SequenceForm[ 
          Subscript[ g, 101], 
          Subscript[ g, 99], 
          Superscript[ 
            Subscript[ g, 0], -1]], Subscript[ g, 103] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 102]], Subscript[ g, 104] -> SequenceForm[ 
          Subscript[ g, 103], 
          Subscript[ g, 102]], Subscript[ g, 105] -> SequenceForm[ 
          Subscript[ g, 104], 
          Subscript[ g, 102]], Subscript[ g, 106] -> SequenceForm[ 
          Subscript[ g, 92], 
          Subscript[ g, 71], 
          Superscript[ 
            Subscript[ g, 92], -1]], Subscript[ g, 107] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 106]], Subscript[ g, 108] -> SequenceForm[ 
          Subscript[ g, 107], 
          Subscript[ g, 106]], Subscript[ g, 109] -> SequenceForm[ 
          Subscript[ g, 103], 
          Subscript[ g, 106]], Subscript[ g, 110] -> SequenceForm[ 
          Subscript[ g, 105], 
          Subscript[ g, 106]], Subscript[ g, 111] -> SequenceForm[ 
          Subscript[ g, 109], 
          Subscript[ g, 106]], Subscript[ g, 112] -> SequenceForm[ 
          Subscript[ g, 110], 
          Subscript[ g, 106]], Subscript[ g, 113] -> SequenceForm[ 
          Subscript[ g, 94], 
          Subscript[ g, 71], 
          Superscript[ 
            Subscript[ g, 98], -1], 
          Superscript[ 
            Subscript[ g, 112], -1], 
          Superscript[ 
            Subscript[ g, 108], -1]], Subscript[ g, 114] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 113]], Subscript[ g, 115] -> SequenceForm[ 
          Subscript[ g, 107], 
          Subscript[ g, 113]], Subscript[ g, 116] -> SequenceForm[ 
          Subscript[ g, 108], 
          Subscript[ g, 113]], Subscript[ g, 117] -> SequenceForm[ 
          Subscript[ g, 116], 
          Subscript[ g, 106]], Subscript[ g, 118] -> SequenceForm[ 
          Subscript[ g, 63], 
          Subscript[ g, 82]], Subscript[ g, 119] -> SequenceForm[ 
          Subscript[ g, 64], 
          Subscript[ g, 82]], Subscript[ g, 120] -> SequenceForm[ 
          Subscript[ g, 65], 
          Subscript[ g, 82]], Subscript[ g, 121] -> SequenceForm[ 
          Subscript[ g, 119], 
          Subscript[ g, 82]], Subscript[ g, 122] -> SequenceForm[ 
          Subscript[ g, 120], 
          Subscript[ g, 82]], Subscript[ g, 123] -> SequenceForm[ 
          Subscript[ g, 122], 
          Subscript[ g, 82]], Subscript[ g, 124] -> SequenceForm[ 
          Subscript[ g, 123], 
          Subscript[ g, 82]], Subscript[ g, 125] -> SequenceForm[ 
          Subscript[ g, 118], 
          Subscript[ g, 62]], Subscript[ g, 126] -> SequenceForm[ 
          Subscript[ g, 120], 
          Subscript[ g, 62]], Subscript[ g, 127] -> SequenceForm[ 
          Subscript[ g, 8], 
          Subscript[ g, 74], 
          Superscript[ 
            Subscript[ g, 53], -1]], Subscript[ g, 128] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 127]], Subscript[ g, 129] -> SequenceForm[ 
          Subscript[ g, 55], 
          Subscript[ g, 127]], Subscript[ g, 130] -> SequenceForm[ 
          Subscript[ g, 56], 
          Subscript[ g, 127]], Subscript[ g, 131] -> SequenceForm[ 
          Subscript[ g, 79], 
          Subscript[ g, 127]], Subscript[ g, 132] -> SequenceForm[ 
          Subscript[ g, 80], 
          Subscript[ g, 127]], Subscript[ g, 133] -> SequenceForm[ 
          Subscript[ g, 81], 
          Subscript[ g, 127]], Subscript[ g, 134] -> SequenceForm[ 
          Subscript[ g, 32], 
          Subscript[ g, 74]], Subscript[ g, 135] -> SequenceForm[ 
          Subscript[ g, 37], 
          Subscript[ g, 74]], Subscript[ g, 136] -> SequenceForm[ 
          Subscript[ g, 43], 
          Subscript[ g, 74]], Subscript[ g, 137] -> SequenceForm[ 
          Subscript[ g, 12], 
          Subscript[ g, 6], 
          Superscript[ 
            Subscript[ g, 12], -1], 
          Superscript[ 
            Subscript[ g, 37], -1], 
          Superscript[ 
            Subscript[ g, 75], -1], 
          Superscript[ 
            Subscript[ g, 81], -1], 
          Superscript[ 
            Subscript[ g, 119], -1], 
          Superscript[ 
            Subscript[ g, 83], -1], 
          Superscript[ 
            Subscript[ g, 92], -1]], Subscript[ g, 138] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 137]], Subscript[ g, 139] -> SequenceForm[ 
          Subscript[ g, 100], 
          Subscript[ g, 137]], Subscript[ g, 140] -> SequenceForm[ 
          Subscript[ g, 101], 
          Subscript[ g, 137]], Subscript[ g, 141] -> SequenceForm[ 
          Subscript[ g, 14], 
          Subscript[ g, 1], 
          Superscript[ 
            Subscript[ g, 14], -1], 
          Superscript[ 
            Subscript[ g, 31], -1], 
          Superscript[ 
            Subscript[ g, 9], -1], 
          Superscript[ 
            Subscript[ g, 130], -1]], Subscript[ g, 142] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 141]], Subscript[ g, 143] -> SequenceForm[ 
          Subscript[ g, 60], 
          Subscript[ g, 141]], Subscript[ g, 144] -> SequenceForm[ 
          Subscript[ g, 61], 
          Subscript[ g, 141]], Subscript[ g, 145] -> SequenceForm[ 
          Subscript[ g, 142], 
          Subscript[ g, 141]], Subscript[ g, 146] -> SequenceForm[ 
          Subscript[ g, 143], 
          Subscript[ g, 141]], Subscript[ g, 147] -> SequenceForm[ 
          Subscript[ g, 144], 
          Subscript[ g, 141]], Subscript[ g, 148] -> SequenceForm[ 
          Subscript[ g, 145], 
          Subscript[ g, 141], 
          Superscript[ 
            Subscript[ g, 0], -1], 
          Superscript[ 
            Subscript[ g, 119], -1], 
          Superscript[ 
            Subscript[ g, 83], -1]], Subscript[ g, 149] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 148]], Subscript[ g, 150] -> SequenceForm[ 
          Subscript[ g, 93], 
          Subscript[ g, 148]], Subscript[ g, 151] -> SequenceForm[ 
          Subscript[ g, 72], 
          Subscript[ g, 148], 
          Superscript[ 
            Subscript[ g, 98], -1], 
          Superscript[ 
            Subscript[ g, 105], -1], 
          Superscript[ 
            Subscript[ g, 108], -1]], Subscript[ g, 152] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 151]], Subscript[ g, 153] -> SequenceForm[ 
          Subscript[ g, 114], 
          Subscript[ g, 151]], Subscript[ g, 154] -> SequenceForm[ 
          Subscript[ g, 152], 
          Subscript[ g, 151]], Subscript[ g, 155] -> SequenceForm[ 
          Subscript[ g, 153], 
          Subscript[ g, 151]], Subscript[ g, 156] -> SequenceForm[ 
          Subscript[ g, 152], 
          Subscript[ g, 113], 
          Superscript[ 
            Subscript[ g, 153], -1]], Subscript[ g, 157] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 156]], Subscript[ g, 158] -> SequenceForm[ 
          Subscript[ g, 108], 
          Subscript[ g, 151]], Subscript[ g, 159] -> SequenceForm[ 
          Subscript[ g, 116], 
          Subscript[ g, 151]], Subscript[ g, 160] -> SequenceForm[ 
          Subscript[ g, 103], 
          Subscript[ g, 151]], Subscript[ g, 161] -> SequenceForm[ 
          Subscript[ g, 105], 
          Subscript[ g, 151]], Subscript[ g, 162] -> SequenceForm[ 
          Subscript[ g, 70], 
          Subscript[ g, 148]], Subscript[ g, 163] -> SequenceForm[ 
          Subscript[ g, 84], 
          Subscript[ g, 148]], Subscript[ g, 164] -> SequenceForm[ 
          Subscript[ g, 65], 
          Subscript[ g, 148]], Subscript[ g, 165] -> SequenceForm[ 
          Subscript[ g, 118], 
          Subscript[ g, 148]], Subscript[ g, 166] -> SequenceForm[ 
          Subscript[ g, 15], 
          Subscript[ g, 1], 
          Superscript[ 
            Subscript[ g, 19], -1], 
          Superscript[ 
            Subscript[ g, 134], -1], 
          Superscript[ 
            Subscript[ g, 77], -1], 
          Superscript[ 
            Subscript[ g, 132], -1], 
          Superscript[ 
            Subscript[ g, 147], -1]], Subscript[ g, 167] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 166]], Subscript[ g, 168] -> SequenceForm[ 
          Subscript[ g, 126], 
          Subscript[ g, 166]], Subscript[ g, 169] -> SequenceForm[ 
          Subscript[ g, 58], 
          Subscript[ g, 166], 
          Superscript[ 
            Subscript[ g, 164], -1], 
          Superscript[ 
            Subscript[ g, 95], -1], 
          Superscript[ 
            Subscript[ g, 139], -1], 
          Superscript[ 
            Subscript[ g, 103], -1], 
          Superscript[ 
            Subscript[ g, 108], -1]], Subscript[ g, 170] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 169]], Subscript[ g, 171] -> SequenceForm[ 
          Subscript[ g, 114], 
          Subscript[ g, 169]], Subscript[ g, 172] -> SequenceForm[ 
          Subscript[ g, 152], 
          Subscript[ g, 169], 
          Superscript[ 
            Subscript[ g, 155], -1]], Subscript[ g, 173] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 172]], Subscript[ g, 174] -> SequenceForm[ 
          Subscript[ g, 157], 
          Subscript[ g, 172]], Subscript[ g, 175] -> SequenceForm[ 
          Subscript[ g, 173], 
          Subscript[ g, 172]], Subscript[ g, 176] -> SequenceForm[ 
          Subscript[ g, 174], 
          Subscript[ g, 172]], Subscript[ g, 177] -> SequenceForm[ 
          Subscript[ g, 173], 
          Subscript[ g, 156], 
          Superscript[ 
            Subscript[ g, 173], -1]], Subscript[ g, 178] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 177]], Subscript[ g, 179] -> SequenceForm[ 
          Subscript[ g, 107], 
          Subscript[ g, 169]], Subscript[ g, 180] -> SequenceForm[ 
          Subscript[ g, 115], 
          Subscript[ g, 169]], Subscript[ g, 181] -> SequenceForm[ 
          Subscript[ g, 111], 
          Subscript[ g, 169]], Subscript[ g, 182] -> SequenceForm[ 
          Subscript[ g, 112], 
          Subscript[ g, 169]], Subscript[ g, 183] -> SequenceForm[ 
          Subscript[ g, 72], 
          Subscript[ g, 169]], Subscript[ g, 184] -> SequenceForm[ 
          Subscript[ g, 94], 
          Subscript[ g, 169]], Subscript[ g, 185] -> SequenceForm[ 
          Subscript[ g, 69], 
          Subscript[ g, 169]], Subscript[ g, 186] -> SequenceForm[ 
          Subscript[ g, 90], 
          Subscript[ g, 169]], Subscript[ g, 187] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 3]], Subscript[ g, 188] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 4]], Subscript[ g, 189] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 5]], Subscript[ g, 190] -> SequenceForm[ 
          Subscript[ g, 187], 
          Subscript[ g, 1]], Subscript[ g, 191] -> SequenceForm[ 
          Subscript[ g, 187], 
          Subscript[ g, 3]], Subscript[ g, 192] -> SequenceForm[ 
          Subscript[ g, 187], 
          Subscript[ g, 5]], Subscript[ g, 193] -> SequenceForm[ 
          Subscript[ g, 188], 
          Subscript[ g, 2]], Subscript[ g, 194] -> SequenceForm[ 
          Subscript[ g, 188], 
          Subscript[ g, 4]], Subscript[ g, 195] -> SequenceForm[ 
          Subscript[ g, 189], 
          Subscript[ g, 5]], Subscript[ g, 196] -> SequenceForm[ 
          Subscript[ g, 189], 
          Subscript[ g, 6]], Subscript[ g, 197] -> SequenceForm[ 
          Subscript[ g, 190], 
          Subscript[ g, 1]], Subscript[ g, 198] -> SequenceForm[ 
          Subscript[ g, 190], 
          Subscript[ g, 5]], Subscript[ g, 199] -> SequenceForm[ 
          Subscript[ g, 191], 
          Subscript[ g, 2]], Subscript[ g, 200] -> SequenceForm[ 
          Subscript[ g, 191], 
          Subscript[ g, 3]], Subscript[ g, 201] -> SequenceForm[ 
          Subscript[ g, 192], 
          Subscript[ g, 4]], Subscript[ g, 202] -> SequenceForm[ 
          Subscript[ g, 192], 
          Subscript[ g, 5]], Subscript[ g, 203] -> SequenceForm[ 
          Subscript[ g, 193], 
          Subscript[ g, 2]], Subscript[ g, 204] -> SequenceForm[ 
          Subscript[ g, 194], 
          Subscript[ g, 4]], Subscript[ g, 205] -> SequenceForm[ 
          Subscript[ g, 195], 
          Subscript[ g, 5]], Subscript[ g, 206] -> SequenceForm[ 
          Subscript[ g, 197], 
          Subscript[ g, 2]], Subscript[ g, 207] -> SequenceForm[ 
          Subscript[ g, 198], 
          Subscript[ g, 3]], Subscript[ g, 208] -> SequenceForm[ 
          Subscript[ g, 198], 
          Subscript[ g, 5]], Subscript[ g, 209] -> SequenceForm[ 
          Subscript[ g, 202], 
          Subscript[ g, 5]], Subscript[ g, 210] -> SequenceForm[ 
          Subscript[ g, 187], 
          Subscript[ g, 4], 
          Superscript[ 
            Subscript[ g, 187], -1], 
          Superscript[ 
            Subscript[ g, 29], -1], 
          Superscript[ 
            Subscript[ g, 7], -1], 
          Superscript[ 
            Subscript[ g, 132], -1], 
          Superscript[ 
            Subscript[ g, 147], -1], 
          Superscript[ 
            Subscript[ g, 125], -1], 
          Superscript[ 
            Subscript[ g, 163], -1], 
          Superscript[ 
            Subscript[ g, 150], -1]], Subscript[ g, 211] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 210]], Subscript[ g, 212] -> SequenceForm[ 
          Subscript[ g, 104], 
          Subscript[ g, 210]], Subscript[ g, 213] -> SequenceForm[ 
          Subscript[ g, 103], 
          Subscript[ g, 210], 
          Superscript[ 
            Subscript[ g, 0], -1], 
          Superscript[ 
            Subscript[ g, 107], -1]], Subscript[ g, 214] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 213]], Subscript[ g, 215] -> SequenceForm[ 
          Subscript[ g, 178], 
          Subscript[ g, 213]], Subscript[ g, 216] -> SequenceForm[ 
          Subscript[ g, 214], 
          Subscript[ g, 213]], Subscript[ g, 217] -> SequenceForm[ 
          Subscript[ g, 215], 
          Subscript[ g, 213]], Subscript[ g, 218] -> SequenceForm[ 
          Subscript[ g, 214], 
          Subscript[ g, 177], 
          Superscript[ 
            Subscript[ g, 215], -1]], Subscript[ g, 219] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 218]], Subscript[ g, 220] -> SequenceForm[ 
          Subscript[ g, 175], 
          Subscript[ g, 213]], Subscript[ g, 221] -> SequenceForm[ 
          Subscript[ g, 176], 
          Subscript[ g, 213]], Subscript[ g, 222] -> SequenceForm[ 
          Subscript[ g, 152], 
          Subscript[ g, 213]], Subscript[ g, 223] -> SequenceForm[ 
          Subscript[ g, 153], 
          Subscript[ g, 213]], Subscript[ g, 224] -> SequenceForm[ 
          Subscript[ g, 108], 
          Subscript[ g, 213]], Subscript[ g, 225] -> SequenceForm[ 
          Subscript[ g, 116], 
          Subscript[ g, 213]], Subscript[ g, 226] -> SequenceForm[ 
          Subscript[ g, 92], 
          Subscript[ g, 210]], Subscript[ g, 227] -> SequenceForm[ 
          Subscript[ g, 96], 
          Subscript[ g, 210]], Subscript[ g, 228] -> SequenceForm[ 
          Subscript[ g, 83], 
          Subscript[ g, 210]], Subscript[ g, 229] -> SequenceForm[ 
          Subscript[ g, 87], 
          Subscript[ g, 210]], Subscript[ g, 230] -> SequenceForm[ 
          Subscript[ g, 119], 
          Subscript[ g, 210]], Subscript[ g, 231] -> SequenceForm[ 
          Subscript[ g, 122], 
          Subscript[ g, 210]], Subscript[ g, 232] -> SequenceForm[ 
          Subscript[ g, 188], 
          Subscript[ g, 3], 
          Superscript[ 
            Subscript[ g, 192], -1], 
          Superscript[ 
            Subscript[ g, 10], -1], 
          Superscript[ 
            Subscript[ g, 39], -1], 
          Superscript[ 
            Subscript[ g, 77], -1], 
          Superscript[ 
            Subscript[ g, 132], -1], 
          Superscript[ 
            Subscript[ g, 142], -1], 
          Superscript[ 
            Subscript[ g, 167], -1], 
          Superscript[ 
            Subscript[ g, 90], -1], 
          Superscript[ 
            Subscript[ g, 183], -1], 
          Superscript[ 
            Subscript[ g, 100], -1]], Subscript[ g, 233] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 232]], Subscript[ g, 234] -> SequenceForm[ 
          Subscript[ g, 104], 
          Subscript[ g, 232]], Subscript[ g, 235] -> SequenceForm[ 
          Subscript[ g, 103], 
          Subscript[ g, 232], 
          Superscript[ 
            Subscript[ g, 110], -1], 
          Superscript[ 
            Subscript[ g, 107], -1], 
          Superscript[ 
            Subscript[ g, 223], -1], 
          Superscript[ 
            Subscript[ g, 221], -1], 
          Superscript[ 
            Subscript[ g, 216], -1]], Subscript[ g, 236] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 235]], Subscript[ g, 237] -> SequenceForm[ 
          Subscript[ g, 219], 
          Subscript[ g, 235]], Subscript[ g, 238] -> SequenceForm[ 
          Subscript[ g, 236], 
          Subscript[ g, 235]], Subscript[ g, 239] -> SequenceForm[ 
          Subscript[ g, 237], 
          Subscript[ g, 235]], Subscript[ g, 240] -> SequenceForm[ 
          Subscript[ g, 236], 
          Subscript[ g, 218], 
          Superscript[ 
            Subscript[ g, 237], -1]], Subscript[ g, 241] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 240]], Subscript[ g, 242] -> SequenceForm[ 
          Subscript[ g, 214], 
          Subscript[ g, 235]], Subscript[ g, 243] -> SequenceForm[ 
          Subscript[ g, 215], 
          Subscript[ g, 235]], Subscript[ g, 244] -> SequenceForm[ 
          Subscript[ g, 175], 
          Subscript[ g, 235]], Subscript[ g, 245] -> SequenceForm[ 
          Subscript[ g, 176], 
          Subscript[ g, 235]], Subscript[ g, 246] -> SequenceForm[ 
          Subscript[ g, 152], 
          Subscript[ g, 235]], Subscript[ g, 247] -> SequenceForm[ 
          Subscript[ g, 153], 
          Subscript[ g, 235]], Subscript[ g, 248] -> SequenceForm[ 
          Subscript[ g, 108], 
          Subscript[ g, 235]], Subscript[ g, 249] -> SequenceForm[ 
          Subscript[ g, 116], 
          Subscript[ g, 235]], Subscript[ g, 250] -> SequenceForm[ 
          Subscript[ g, 92], 
          Subscript[ g, 232]], Subscript[ g, 251] -> SequenceForm[ 
          Subscript[ g, 96], 
          Subscript[ g, 232]], Subscript[ g, 252] -> SequenceForm[ 
          Subscript[ g, 83], 
          Subscript[ g, 232]], Subscript[ g, 253] -> SequenceForm[ 
          Subscript[ g, 87], 
          Subscript[ g, 232]], Subscript[ g, 254] -> SequenceForm[ 
          Subscript[ g, 119], 
          Subscript[ g, 232]], Subscript[ g, 255] -> SequenceForm[ 
          Subscript[ g, 122], 
          Subscript[ g, 232]], Subscript[ g, 256] -> SequenceForm[ 
          Subscript[ g, 188], 
          Subscript[ g, 5], 
          Superscript[ 
            Subscript[ g, 188], -1], 
          Superscript[ 
            Subscript[ g, 23], -1], 
          Superscript[ 
            Subscript[ g, 36], -1], 
          Superscript[ 
            Subscript[ g, 51], -1], 
          Superscript[ 
            Subscript[ g, 130], -1], 
          Superscript[ 
            Subscript[ g, 63], -1]], Subscript[ g, 257] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 256]], Subscript[ g, 258] -> SequenceForm[ 
          Subscript[ g, 85], 
          Subscript[ g, 256]], Subscript[ g, 259] -> SequenceForm[ 
          Subscript[ g, 67], 
          Subscript[ g, 256], 
          Superscript[ 
            Subscript[ g, 162], -1], 
          Superscript[ 
            Subscript[ g, 93], -1], 
          Superscript[ 
            Subscript[ g, 138], -1], 
          Superscript[ 
            Subscript[ g, 112], -1], 
          Superscript[ 
            Subscript[ g, 108], -1], 
          Superscript[ 
            Subscript[ g, 171], -1], 
          Superscript[ 
            Subscript[ g, 175], -1], 
          Superscript[ 
            Subscript[ g, 215], -1], 
          Superscript[ 
            Subscript[ g, 236], -1]], Subscript[ g, 260] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 259]], Subscript[ g, 261] -> SequenceForm[ 
          Subscript[ g, 241], 
          Subscript[ g, 259]], Subscript[ g, 262] -> SequenceForm[ 
          Subscript[ g, 260], 
          Subscript[ g, 259]], Subscript[ g, 263] -> SequenceForm[ 
          Subscript[ g, 261], 
          Subscript[ g, 259]], Subscript[ g, 264] -> SequenceForm[ 
          Subscript[ g, 260], 
          Subscript[ g, 240], 
          Superscript[ 
            Subscript[ g, 261], -1]], Subscript[ g, 265] -> SequenceForm[ 
          Subscript[ g, 0], 
          Subscript[ g, 264]], Subscript[ g, 266] -> SequenceForm[ 
          Subscript[ g, 236], 
          Subscript[ g, 259]], Subscript[ g, 267] -> SequenceForm[ 
          Subscript[ g, 237], 
          Subscript[ g, 259]], Subscript[ g, 268] -> SequenceForm[ 
          Subscript[ g, 214], 
          Subscript[ g, 259]], Subscript[ g, 269] -> SequenceForm[ 
          Subscript[ g, 215], 
          Subscript[ g, 259]], Subscript[ g, 270] -> SequenceForm[ 
          Subscript[ g, 175], 
          Subscript[ g, 259]], Subscript[ g, 271] -> SequenceForm[ 
          Subscript[ g, 176], 
          Subscript[ g, 259]], Subscript[ g, 272] -> SequenceForm[ 
          Subscript[ g, 152], 
          Subscript[ g, 259]], Subscript[ g, 273] -> SequenceForm[ 
          Subscript[ g, 153], 
          Subscript[ g, 259]], Subscript[ g, 274] -> SequenceForm[ 
          Subscript[ g, 108], 
          Subscript[ g, 259]], Subscript[ g, 275] -> SequenceForm[ 
          Subscript[ g, 116], 
          Subscript[ g, 259]], Subscript[ g, 276] -> SequenceForm[ 
          Subscript[ g, 103], 
          Subscript[ g, 259]], Subscript[ g, 277] -> SequenceForm[ 
          Subscript[ g, 105], 
          Subscript[ g, 259]], Subscript[ g, 278] -> SequenceForm[ 
          Subscript[ g, 73], 
          Subscript[ g, 259]], Subscript[ g, 279] -> SequenceForm[ 
          Subscript[ g, 98], 
          Subscript[ g, 259]], Subscript[ g, 280] -> SequenceForm[ 
          Subscript[ g, 64], 
          Subscript[ g, 256]], Subscript[ g, 281] -> SequenceForm[ 
          Subscript[ g, 120], 
          Subscript[ g, 256]]}],
      Editable->False]], "Output"],

Cell["\<\
It seems this is not easy in GAP, and is only possible because we \
have symbolic capabilities.
There are hybrid methods that use Todd-Coxeter rewriting to get some \
equivalent information.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading Basis Buttons", "Section"],

Cell["\<\
Now we can load these buttons explore them. Some of them have the \
very simple actions we have been seeking- just flip edges or twist corners.\
\
\>", "Text"],

Cell["\<\
When the Rubik cube is running, open the \"Rubik Basis Buttons 1.nb\
\" and let it initialize.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using the basis to solve the cube", "Section"],

Cell[CellGroupData[{

Cell["introduction", "Subsubsection"],

Cell["\<\
You can use the basis to solve the cube. Apply a few random moves \
to the cube, and then try to \"solve\" it, that is restore it to its standard \
state.\
\>", "Text"],

Cell["\<\
You can use the basis to solve the cube. The moves they represent \
fix more and more points. There is a diagram explaining the points they fix. \
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basis points graphics", "Subsubsection"],

Cell[TextData[{
  "The basis points have basis number ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"1", "b"}], ",", 
          RowBox[{"2", "b"}], ",", "\[Ellipsis]"}], TraditionalForm]]],
  " and their planar permutation labels are ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L2", ",", "L4", ",", "\[Ellipsis]"}], TraditionalForm]]],
  ". . The button formulae show which basis point they belong to. They may \
move this point and later points, but none above it in the basis list. e.g. \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", "b"}], TraditionalForm]]],
  "=",
  Cell[BoxData[
      ButtonBox[
        FormBox[
          SubscriptBox["g", "2"],
          "TraditionalForm"],
        ButtonFunction:>((DoUserMove[ #, 4]&)[ ]&),
        ButtonEvaluator->Automatic]]],
  " moves the basis point ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", " ", "b"}], TraditionalForm]]],
  " (and also maybe ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"3", "b"}], ",", 
          RowBox[{"5", "b"}], ",", "\[Ellipsis]"}], TraditionalForm]]],
  "),  but leaves ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", " ", "b"}], TraditionalForm]]],
  " fixed. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95457 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
7.36347e-17 1.03526 -0.00015015 1.03526 [
[ 0 0 0 0 ]
[ 1 .95457 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .95457 L
0 .95457 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.45808 .45538 m
.32505 .5555 L
s
.60343 .43964 m
.67915 .59312 L
s
0 1 0 r
.54126 .44179 m
.50087 .4552 L
s
.50087 .4552 m
.50069 .49182 L
s
0 g
.45672 .5306 m
.31701 .69743 L
s
1 1 0 r
.48995 .42477 m
.46748 .39941 L
s
.5303 .41112 m
.48995 .42477 L
s
1 .5 0 r
.46973 .44955 m
.46919 .48621 L
s
.44694 .42448 m
.46973 .44955 L
s
0 1 0 r
.54153 .47852 m
.54126 .44179 L
s
1 1 0 r
.50821 .38539 m
.5303 .41112 L
s
0 g
.41098 .40407 m
.23175 .46624 L
s
0 1 0 r
.50069 .49182 m
.54153 .47852 L
s
1 .5 0 r
.46919 .48621 m
.44614 .46135 L
s
1 1 0 r
.46748 .39941 m
.50821 .38539 L
s
0 1 0 r
.62381 .41437 m
.58224 .42818 L
s
.58224 .42818 m
.58296 .46502 L
s
1 1 0 r
.57124 .39727 m
.54955 .37117 L
s
.61278 .38322 m
.57124 .39727 L
s
1 .5 0 r
.44614 .46135 m
.44694 .42448 L
s
0 1 0 r
.62501 .45133 m
.62381 .41437 L
s
.5418 .51608 m
.5005 .52925 L
s
.5005 .52925 m
.5003 .56754 L
s
1 1 0 r
.59149 .35673 m
.61278 .38322 L
s
1 .5 0 r
.46865 .5237 m
.46809 .56205 L
s
.44532 .49907 m
.46865 .5237 L
s
0 1 0 r
.58296 .46502 m
.62501 .45133 L
s
1 1 0 r
.4444 .37337 m
.42068 .34661 L
s
.48552 .35896 m
.4444 .37337 L
s
.54955 .37117 m
.59149 .35673 L
s
0 1 0 r
.7088 .38613 m
.66599 .40035 L
s
.66599 .40035 m
.66769 .43743 L
s
.54207 .5545 m
.5418 .51608 L
s
1 .5 0 r
.42353 .39872 m
.42246 .43581 L
s
.39948 .37226 m
.42353 .39872 L
s
1 1 0 r
.65493 .36896 m
.63406 .34208 L
s
.69771 .35449 m
.65493 .36896 L
s
0 1 0 r
.5003 .56754 m
.54207 .5545 L
s
0 g
.71153 .37054 m
.85964 .3138 L
s
1 1 0 r
.46219 .3318 m
.48552 .35896 L
s
0 1 0 r
.711 .42332 m
.7088 .38613 L
s
1 .5 0 r
.46809 .56205 m
.44449 .53766 L
s
0 1 0 r
.62625 .48914 m
.58371 .50271 L
s
.58371 .50271 m
.58447 .54126 L
s
1 1 0 r
.67727 .3272 m
.69771 .35449 L
s
1 .5 0 r
.44449 .53766 m
.44532 .49907 L
s
0 1 0 r
.66769 .43743 m
.711 .42332 L
s
0 g
.60747 .59421 m
.68654 .75026 L
s
1 .5 0 r
.42246 .43581 m
.39811 .40956 L
s
1 1 0 r
.42068 .34661 m
.46219 .3318 L
s
.52725 .34435 m
.50433 .31678 L
s
.56961 .32951 m
.52725 .34435 L
s
1 .5 0 r
.39811 .40956 m
.39948 .37226 L
s
0 g
.4553 .60933 m
.30826 .85175 L
s
1 1 0 r
.63406 .34208 m
.67727 .3272 L
s
0 1 0 r
.62751 .52782 m
.62625 .48914 L
s
.54236 .59381 m
.5001 .60671 L
s
.5001 .60671 m
.4999 .64679 L
s
1 0 0 r
.72049 .36553 m
.72285 .40288 L
s
.70018 .33814 m
.72049 .36553 L
s
1 .5 0 r
.46752 .60128 m
.46693 .64142 L
s
.44363 .57716 m
.46752 .60128 L
s
0 1 0 r
.58447 .54126 m
.62751 .52782 L
s
1 1 0 r
.54711 .30152 m
.56961 .32951 L
s
0 1 0 r
.71325 .46138 m
.66942 .47536 L
s
.66942 .47536 m
.6712 .51418 L
s
.54265 .63404 m
.54236 .59381 L
s
1 .5 0 r
.42135 .47376 m
.42023 .5126 L
s
.39671 .44773 m
.42135 .47376 L
s
1 1 0 r
.39631 .3191 m
.37124 .29082 L
s
.43822 .30388 m
.39631 .3191 L
s
.50433 .31678 m
.54711 .30152 L
s
0 1 0 r
.4999 .64679 m
.54265 .63404 L
s
1 .5 0 r
.37476 .34506 m
.37308 .38256 L
s
.34934 .31708 m
.37476 .34506 L
s
1 1 0 r
.61261 .31444 m
.59055 .28603 L
s
.65626 .29915 m
.61261 .31444 L
s
1 0 0 r
.72285 .40288 m
.70234 .37569 L
s
0 1 0 r
.71556 .50033 m
.71325 .46138 L
s
1 .5 0 r
.46693 .64142 m
.44276 .61758 L
s
0 1 0 r
.6288 .56742 m
.58525 .58072 L
s
.58525 .58072 m
.58605 .6211 L
s
1 0 0 r
.70234 .37569 m
.70018 .33814 L
s
0 g
.36123 .34986 m
.12851 .36747 L
s
1 .5 0 r
.44276 .61758 m
.44363 .57716 L
s
1 1 0 r
.41355 .27517 m
.43822 .30388 L
s
0 1 0 r
.6712 .51418 m
.71556 .50033 L
s
1 .5 0 r
.42023 .5126 m
.39527 .48681 L
s
1 1 0 r
.63466 .2703 m
.65626 .29915 L
s
1 .5 0 r
.39527 .48681 m
.39671 .44773 L
s
0 1 0 r
.63012 .60796 m
.6288 .56742 L
s
1 .5 0 r
.37308 .38256 m
.34733 .35479 L
s
1 1 0 r
.37124 .29082 m
.41355 .27517 L
s
0 0 1 r
.48799 .65549 m
.46388 .63163 L
s
.53121 .64265 m
.48799 .65549 L
s
1 0 0 r
.72527 .44111 m
.72775 .48025 L
s
.70455 .41415 m
.72527 .44111 L
s
1 1 0 r
.48077 .28843 m
.45652 .25927 L
s
.52397 .27274 m
.48077 .28843 L
s
1 .5 0 r
.34733 .35479 m
.34934 .31708 L
s
1 1 0 r
.59055 .28603 m
.63466 .2703 L
s
0 1 0 r
.58605 .6211 m
.63012 .60796 L
s
1 0 0 r
.67929 .30996 m
.68123 .34772 L
s
.6578 .28098 m
.67929 .30996 L
s
0 1 0 r
.71792 .54022 m
.67302 .55392 L
s
.67302 .55392 m
.67488 .59462 L
s
1 .5 0 r
.41907 .55235 m
.41789 .59306 L
s
.3938 .52683 m
.41907 .55235 L
s
0 0 1 r
.50753 .61841 m
.53121 .64265 L
s
1 1 0 r
.50017 .24312 m
.52397 .27274 L
s
1 .5 0 r
.37136 .42096 m
.3696 .46028 L
s
.34527 .39341 m
.37136 .42096 L
s
1 0 0 r
.72775 .48025 m
.70681 .45353 L
s
.8 g
.35749 .29497 m
.35556 .33284 L
s
.40026 .27914 m
.35749 .29497 L
s
0 1 0 r
.72034 .58106 m
.71792 .54022 L
s
0 0 1 r
.46388 .63163 m
.50753 .61841 L
s
1 0 0 r
.70681 .45353 m
.70455 .41415 L
s
1 1 0 r
.45652 .25927 m
.50017 .24312 L
s
0 0 1 r
.57509 .62961 m
.55187 .60499 L
s
.61966 .61636 m
.57509 .62961 L
s
1 1 0 r
.56785 .2568 m
.5445 .22672 L
s
.61242 .24061 m
.56785 .2568 L
s
1 0 0 r
.68123 .34772 m
.65951 .31894 L
s
0 1 0 r
.67488 .59462 m
.72034 .58106 L
s
0 g
.66953 .31439 m
.78798 .20407 L
s
1 .5 0 r
.41789 .59306 m
.39229 .56783 L
s
1 0 0 r
.65951 .31894 m
.6578 .28098 L
s
0 g
.40586 .55999 m
.20544 .77063 L
s
.8 g
.39883 .31711 m
.40026 .27914 L
s
1 .5 0 r
.39229 .56783 m
.3938 .52683 L
s
0 0 1 r
.59691 .59135 m
.61966 .61636 L
s
1 .5 0 r
.3696 .46028 m
.34317 .43297 L
s
1 1 0 r
.58954 .21005 m
.61242 .24061 L
s
0 g
.35745 .42689 m
.11044 .51649 L
s
1 0 0 r
.73029 .52034 m
.73288 .5614 L
s
.70912 .49388 m
.73029 .52034 L
s
.8 g
.35556 .33284 m
.39883 .31711 L
s
1 .5 0 r
.34317 .43297 m
.34527 .39341 L
s
.8 g
.44369 .26306 m
.44279 .30114 L
s
.48782 .24673 m
.44369 .26306 L
s
0 0 1 r
.43907 .60707 m
.41353 .58178 L
s
.48316 .59346 m
.43907 .60707 L
s
1 0 0 r
.68321 .3864 m
.68525 .42602 L
s
.66125 .35783 m
.68321 .3864 L
s
0 0 1 r
.55187 .60499 m
.59691 .59135 L
s
1 1 0 r
.5445 .22672 m
.58954 .21005 L
s
0 0 1 r
.66494 .6029 m
.64267 .57749 L
s
.71093 .58923 m
.66494 .6029 L
s
1 0 0 r
.63568 .25115 m
.63714 .2893 L
s
.61291 .22044 m
.63568 .25115 L
s
1 .5 0 r
.36779 .50057 m
.36594 .54184 L
s
.34101 .47352 m
.36779 .50057 L
s
.8 g
.48745 .28491 m
.48782 .24673 L
s
0 0 1 r
.45807 .56777 m
.48316 .59346 L
s
1 0 0 r
.73288 .5614 m
.7115 .53523 L
s
.8 g
.35358 .37162 m
.35155 .41137 L
s
.39737 .35602 m
.35358 .37162 L
s
0 g
.46535 .27387 m
.42124 .15059 L
s
0 0 1 r
.68917 .56342 m
.71093 .58923 L
s
1 0 0 r
.7115 .53523 m
.70912 .49388 L
s
.8 g
.44279 .30114 m
.48745 .28491 L
s
1 0 0 r
.68525 .42602 m
.66304 .39769 L
s
0 0 1 r
.41353 .58178 m
.45807 .56777 L
s
1 0 0 r
.66304 .39769 m
.66125 .35783 L
s
.8 g
.53266 .23013 m
.53284 .26841 L
s
.57821 .21327 m
.53266 .23013 L
s
0 0 1 r
.52796 .57964 m
.50334 .55353 L
s
.57348 .5656 m
.52796 .57964 L
s
.8 g
.39587 .39589 m
.39737 .35602 L
s
0 0 1 r
.64267 .57749 m
.68917 .56342 L
s
1 0 0 r
.63714 .2893 m
.6141 .25877 L
s
1 .5 0 r
.36594 .54184 m
.33879 .51508 L
s
0 g
.62504 .25491 m
.70803 .08164 L
s
.35349 .50772 m
.0906 .68003 L
s
1 0 0 r
.6141 .25877 m
.61291 .22044 L
s
.8 g
.35155 .41137 m
.39587 .39589 L
s
1 .5 0 r
.33879 .51508 m
.34101 .47352 L
s
.8 g
.57897 .25165 m
.57821 .21327 L
s
0 0 1 r
.54934 .53906 m
.57348 .5656 L
s
.8 g
.44186 .34016 m
.44091 .38016 L
s
.48708 .32404 m
.44186 .34016 L
s
1 0 0 r
.68733 .46663 m
.68947 .50826 L
s
.66488 .43856 m
.68733 .46663 L
s
.8 g
.53284 .26841 m
.57897 .25165 L
s
0 0 1 r
.38722 .55574 m
.36012 .5289 L
s
.43222 .5413 m
.38722 .55574 L
s
1 0 0 r
.63863 .32841 m
.64016 .3685 L
s
.61533 .29809 m
.63863 .32841 L
s
0 0 1 r
.50334 .55353 m
.54934 .53906 L
s
.61974 .55132 m
.59611 .52435 L
s
.66676 .53682 m
.61974 .55132 L
s
.8 g
.48669 .36417 m
.48708 .32404 L
s
.34947 .45211 m
.34734 .49389 L
s
.39433 .43677 m
.34947 .45211 L
s
.44091 .38016 m
.48669 .36417 L
s
0 0 1 r
.40558 .51403 m
.43222 .5413 L
s
1 0 0 r
.68947 .50826 m
.66676 .48047 L
s
0 g
.67719 .47345 m
.81508 .50939 L
s
0 0 1 r
.64365 .5094 m
.66676 .53682 L
s
1 0 0 r
.66676 .48047 m
.66488 .43856 L
s
.8 g
.53303 .30766 m
.53323 .34791 L
s
.57975 .29101 m
.53303 .30766 L
s
.39275 .4787 m
.39433 .43677 L
s
1 0 0 r
.64016 .3685 m
.61658 .33841 L
s
0 g
.62776 .33334 m
.71767 .22965 L
s
0 0 1 r
.36012 .5289 m
.40558 .51403 L
s
1 0 0 r
.61658 .33841 m
.61533 .29809 L
s
.8 g
.34734 .49389 m
.39275 .4787 L
s
0 0 1 r
.47796 .52663 m
.4518 .4989 L
s
.52446 .51171 m
.47796 .52663 L
s
.59611 .52435 m
.64365 .5094 L
s
.8 g
.58055 .33138 m
.57975 .29101 L
s
.43993 .42118 m
.43893 .46326 L
s
.48629 .40533 m
.43993 .42118 L
s
.53323 .34791 m
.58055 .33138 L
s
0 0 1 r
.49881 .48351 m
.52446 .51171 L
s
1 0 0 r
.64173 .40962 m
.64335 .45181 L
s
.61787 .37978 m
.64173 .40962 L
s
.8 g
.48588 .44755 m
.48629 .40533 L
s
0 g
.46266 .43423 m
.41625 .30532 L
s
0 0 1 r
.4518 .4989 m
.49881 .48351 L
s
.8 g
.43893 .46326 m
.48588 .44755 L
s
0 0 1 r
.57174 .49655 m
.54661 .46787 L
s
.61982 .48112 m
.57174 .49655 L
s
.8 g
.53343 .3892 m
.53364 .43158 L
s
.58138 .37281 m
.53343 .3892 L
s
1 0 0 r
.64335 .45181 m
.61919 .42224 L
s
0 g
.63062 .41584 m
.72834 .39345 L
s
0 0 1 r
.59524 .45195 m
.61982 .48112 L
s
1 0 0 r
.61919 .42224 m
.61787 .37978 L
s
.8 g
.58222 .41533 m
.58138 .37281 L
s
0 0 1 r
.54661 .46787 m
.59524 .45195 L
s
.8 g
.53364 .43158 m
.58222 .41533 L
s
0 g
gsave
.06021 .69995 -78 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.31115 .56597 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L14) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29223 .87817 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L19) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71752 .06181 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L34) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74017 .39074 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L39) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.87564 .30767 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L47) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69505 .76704 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L32) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72824 .21746 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L37) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80113 .19182 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
69.000 13.000 moveto
(b) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L42) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.10291 .36941 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L1) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.21255 .4729 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L9) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41631 .13683 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L22) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83121 .5136 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L45) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68731 .60966 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L29) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3021 .71523 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L17) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.0826 .52659 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L4) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18297 .79424 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L12) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41107 .29092 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
75.000 13.000 moveto
(b) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L25) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.062, 253.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000490000oA000`40O003h00Oogoo2Woo003oOol:
Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00
ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo002iOol00`00Oomoo`1=Ool00;Yoo`03001oogoo
04aoo`00[Goo0`0000=oo`0000000P001Goo00<007ooOol01@000Woo0`0017oo0`00>goo002^Ool0
1@00Oomoogoo00000Woo00<007ooOol01Woo00H007ooOol007oo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0jOol00:]oo`D0009oo`04001oogoo0008Ool00`00Oomoo`06Ool00`00Ool00004000kOol0
0:]oo`04001oogoo0003Ool01000Oomoo`0027oo00<007ooOol017oo0P000Woo00@007ooOol003ao
o`00[7oo00<007oo00000goo0`002Goo00<007ooOol01Woo00H007ooOol007oo000lOol00:eoo`80
00=oo`03001oogoo00Uoo`03001oogoo009oo`05001oogooOol00003Ool2000lOol00:ioo`03001o
ogoo008000Yoo`<000Aoo`<000Eoo`03001oogoo03Yoo`00^Woo00<007ooOol0C7oo002jOol00`00
Oomoo`1<Ool00;Uoo`03001oogoo04eoo`00^Goo00<007ooOol0CGoo002hOol00`00Oomoo`1>Ool0
0;Qoo`03001oogoo04ioo`00]goo00<007ooOol0Cgoo002gOol00`00Oomoo`1?Ool00;Moo`03001o
ogoo04moo`00]Woo00<007ooOol0D7oo002fOol00`00Oomoo`1@Ool006aoo`03001oogoo04Ioo`03
001oogoo055oo`00KGoo00<007ooOol0AGoo00<007ooOol0DGoo001IOol30002Ool500000goo0000
00020005Ool00`00Oomoo`0500000goo0000000300000goo00000003000cOol00`00Oomoo`1BOol0
05Yoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`00<goo00<007ooOol0DWoo001JOol00`00Oomoo`03Ool00`00Oomoo`02
Ool01000Oomoo`0027oo00<007ooOol017oo00<007ooOol00goo00<007ooOol0<Woo00<007ooOol0
Dgoo001JOol00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol00goo00<007ooOol0<Goo00<007ooOol0Dgoo001JOol01@00Oomoogoo00000goo00<0
07ooOol00`002Goo00<007ooOol00Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0_Ool00`00
Oomoo`1DOol005Uoo`8000=oo`05001oogooOol00002Ool00`00Oomoo`07Ool00`00Ool00004Ool0
1`00Oomoogoo001oo`0000=oo`03001oogoo02moo`03001oogoo05Aoo`00FWoo00<007ooOol00Woo
0`000Woo0P002Goo100017oo0`000goo0`00<Woo00<007ooOol0E7oo001`Ool00`00Oomoo`0nOol0
0`00Oomoo`1EOol0071oo`03001oogoo03ioo`03001oogoo05Eoo`00L7oo00<007ooOol0?Goo00<0
07ooOol0EWoo001aOol00`00Oomoo`0lOol00`00Oomoo`1FOol0075oo`03001oogoo03]oo`03001o
ogoo05Moo`00LGoo00<007ooOol0>goo00<007ooOol07Goo00<007ooOol0=goo001bOol00`00Oomo
o`0iOol00`00Oomoo`0OOol00`00Oomoo`0fOol0079oo`03001oogoo03Uoo`03001oogoo015oo`80
00=oo`@000Eoo`03001oogoo00D000=oo`<00003Ool0000000<002Eoo`00LWoo00<007ooOol0>7oo
00<007ooOol057oo00D007ooOomoo`00009oo`03001oogoo00Ioo`04001oogoo0004Ool01@00Oomo
ogoo00000Woo00<007ooOol08goo001cOol00`00Oomoo`0gOol00`00Oomoo`0EOol01000Oomoo`00
0Woo00<007ooOol01Woo00<007ooOol00Woo1@000goo00<007ooOol09Goo001cOol00`00Oomoo`0g
Ool00`00Oomoo`0BOol40002Ool01000Oomoo`0027oo00<007ooOol00Woo00@007ooOol000Eoo`03
001oogoo02Aoo`00Lgoo00<007ooOol0=Woo00<007ooOol04Woo00D007ooOomoo`00009oo`<000Uo
o`03001oogoo00=oo`03001oo`00009oo`05001oogooOol0000UOol007Aoo`03001oogoo03Eoo`03
001oogoo00eoo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`04Ool20003Ool00`00
Oomoo`04Ool20002Ool01@00Oomoogoo00009Goo001dOol00`00Oomoo`0dOol00`00Oomoo`0?Ool0
0`00Oomoo`02Ool30002Ool20005Ool00`00Oomoo`02Ool30006Ool01000Oomoogoo0`009Woo001d
Ool00`00Oomoo`0SOol2On0?Ool01000Oomoogoo0`000Woo10001Goo00<007ooOol01@000Woo0`00
0goo0P00>Woo001eOol00`00Oomoo`0OOol2IcT00goPOomoh00>Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`03001oogoo00Ioo`06001oogoo001oo`000goo00D007oo001oo`0003Yoo`00MGoo
00<007ooOol077oo0fLi00=oofLiOol00Woo00=oh7ooOol02goo00D007ooOomoo`0000=oo`04001o
ogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`0gOol007Eoo`03001o
ogoo01Uoo`=W>@Aoo`03IcUoogoo009oo`05On1oogooOoml0007Ool00`00Oomoo`03Ool30003Ool0
1000Oomoo`0027oo00<007ooOol017oo0`0017oo00<007ooOol0=goo001fOol00`00Oomoo`0EOol3
IcT7Ool00fLiOomoo`03Ool017oPOomoog`01goo00<007ooOol00Woo00D007ooOomoo`00009oo`<0
00Uoo`03001oogoo00Eoo`8000Eoo`03001oogoo03Ioo`00MWoo00<007ooOol04goo0VLi00=oogoP
Ool01goo00=W>GooOol00goo00=oh7ooOol00W`01Goo00<007ooOol00goo00D007ooOomoo`00009o
o`03001oogoo00Eoo`05001oogooOol00004Ool01`00Ool007oo001oo`0000=oo`03001oogoo03Io
o`00MWoo00<007ooOol04goo00EW>GooOomoogoP00Moo`03IcUoogoo00Aoo`05On1oog`0Ooml0004
Ool00`00Oomoo`04Ool30002Ool20007Ool00`00Oomoo`030004Ool30002Ool5000hOol007Moo`03
001oogoo019oo`03IcUoogoo009oo`03On1oogoo00Aoo`03IcUoogoo00Eoo`05On1l07ooOoml0003
Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`10Ool007Moo`03001oogoo019oo`03IcUo
ogoo00=oo`03On1oogoo00=oo`03IcUoogoo00Eoo`05On1l07ooOoml0002Ool00`00Oomoo`0AOol0
0`00Oomoo`06Ool20013Ool007Moo`03001oogoo00Uoo`9oh0Moo`03IcUoogoo00=oo`03On1oogoo
00=oo`03IcUoogoo009oo`=oh09oo`06O01oogooO01oo`004Woo00<007ooOol01Woo00<007ooOol0
@goo001hOol00`00Oomoo`04Ool2IcT2On000gooOn1oo`06Ool00fLiOomoo`04Ool00goPOomoo`02
Ool00fLiOomoh002On05Ool01G`0Oomoogoo00004Woo00<007ooOol01Woo00<007ooOol0A7oo001h
Ool01000Oomoogoo0fLi00=oh6LiOol00goo00=oh7ooOol017oo00=W>GooOol01Goo00=oh7ooOol0
0VLi00=oh7ooOol01Woo00Il07ooOomoo`00O00@Ool00`00Oomoo`06Ool00`00Oomoo`15Ool007Qo
o`05001W>FLiIcUoh003Ool00fLiOomoo`03Ool00goPOomoo`03Ool00fLiOomoo`05Ool3IcT;Ool0
1W`0Oomoo`00Ooml00moo`03001oogoo00Ioo`03001oogoo04Ioo`00MWoo0fLi00<007ooOol017oo
00=W>GooOol017oo00=oh7ooOol00Woo00=W>GooOol00Woo0fLi3Woo00=l07ooOol00Woo00=l07oo
Ool037oo00<007ooOol01Woo00<007ooOol0Agoo001eOol01FLiOomoogoP00001Woo00=W>GooOol0
1Goo00Ioh7ooOomoofLiOol3IcTAOol00g`0Oomoo`02Ool00g`0Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`18Ool007Eoo`05IcUoogooOol00006Ool00fLiOomoo`06Ool00goPOomoo`02IcTEOol0
1G`0OomoogooO0003Goo00<007ooOol01Goo00<007ooOol0BGoo001eOol00fLiOomoo`02Ool00`00
Oomoo`03Ool00fLiOomoo`06Ool2On0IOol017`0Oomoh7`037oo00<007ooOol01Goo00<007ooOol0
BWoo001[Ool00`00On1oh007Ool00fLiOomoo`02Ool00`00On1oo`03Ool00fLiOomoo`03Ool3On0J
Ool2On0017`0Oomoh7`02Woo00<007ooOol017oo0P00CGoo001XOol2IcT2On000`00On1oo`06Ool0
0fLiOomoo`03Ool00goPOomoo`02Ool016LiOomoogoo0WoP6Woo0goP0Woo00Al07ooOoml00Uoo`03
001oogoo00Aoo`03001oogoo04eoo`00F7oo0`000goo0`000Woo100000=W>GoPIcT00Woo00<007oo
On001@0000=oo`0000000`000Woo0`0000=oofLiOol00WoP6Goo0goP1Woo00Al07ooO01oh0=oo`05
O01oogooOol00006Ool00`00Oomoo`1>Ool005Uoo`05001oogooOol00003Ool02@00IcUW>@00On1o
o`00OomW>@05Ool027oP001oogoo001W>Goo0002Ool02@00Ool007ooOn1oo`00IcUoh00IOol2On0:
Ool2O0001GooOn1oogooO0000Woo00<007ooOol017oo00<007ooOol0Cgoo001IOol01P00Oomoogoo
001oo`9W>@04001oh7oo0002Ool00`00OomW>@06Ool01@00OomoogooIcT00Woo00<007ooOol00Woo
0fLi00<007ooOol05Woo0VLi00=oogoPOol02goo00El07ooOomoh7oo009l0003001oogoo00Aoo`03
001oogoo051oo`00FGoo00<007ooOol00Woo0`0000AoogoPOol0009oo`03001oofLi00Ioo`05001o
ogooOomW>@03Ool01000IcUW>FLi0goo00<007ooOol04goo0fLi00EoofLiOomoogoP00moo`04On1l
0000O005Ool00`00Oomoo`0[Ool00`00Oomoo`0SOol005Uoo`06001oogooOol006Li0Woo00<007oo
On000`000Woo00=W>GooOol017oo00H007oPOomoofLi0003IcT00`00Ool00003000COol3IcT4Ool0
1FLiOomoogooOn0017oo00=l07ooOol01goo00Eoh000Oomoog`000=oo`03001oogoo02eoo`03001o
ogoo029oo`00F7oo0P000goo00D006LiOomoo`00009oo`03001oogoo009oo`03IcUoogoo00Aoo`06
001oogoPOomW>@000goo00<007oo00004goo00=oh6LiIcT01goo00=W>GooOol00Woo00Eoh7ooOomo
og`000Ioo`=oh003Ool007oo009oo`03O01oo`00029oo`<0009oo`@000Eoo`03001oogoo00D000=o
o`<000=oo`03001oogoo015oo`00FGoo00<007ooOol00Woo0`000Woo0P0000Eoh7ooOomoofLi00=o
o`03001oo`000080009oh09oo`<0009oo`D000aoo`05On1W>FLiIcUoh008Ool00fLiOomoo`03Ool0
0goPOomoo`02O002Ool3On03Ool00`00Ooml0003Ool00`00Oomoo`0POol01@00Oomoogoo00000Woo
00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0AOol005ioo`03IcUo
ogoo00Aoo`05On1oogooOomW>@03Ool00`00Oomoh002On0GOol3On000fLiOomoo`02Ool00goPOomo
o`05Ool00fLiOomoo`04Ool01WoPOoml07oPO01oh0Eoo`04001oogooO002Ool00`00Ooml000QOol0
1@00Oomoogoo00000Woo00@007ooOol000Qoo`03001oogoo009oo`D000Aoo`03001oogoo011oo`00
GWoo00=W>GooOol01Goo00Aoh7ooOomW>@9oo`9oh003001oogoo01Eoo`=oh0=oo`03IcUoogoo00=o
o`03On1oogoo00Aoo`03IcUoogoo00Eoo`05On1l07ooOoml0004Ool01`00OomoogooO01oo`00009o
o`03O01oogoo01moo`@000=oo`05001oogoo001oo`020005Ool00`00Oomoo`02Ool01000Oomoo`00
1Goo00<007ooOol047oo001LOol00ggPIcUoo`08Ool00goPIcUW>@02On02Ool00`00Oomoo`0DOol0
0goPOomoo`04Ool00fLiOomoo`04Ool00goPOomoo`03Ool00fLiOomoo`06Ool017`0Oomoog`00goo
00<007ooOol00Woo00=l07ooOol00Woo00=l07ooOol07goo00<007ooOol017oo1@001goo00<007oo
Ool00goo00<007oo00001Woo00<007ooOol03goo001LOol00ggPIcUoo`06Ool3IcT00goPOomoo`03
Ool00`00Oomoo`0DOol00goPOomoo`04Ool00fLiOomoo`05Ool00goPOomoo`02Ool00fLiOomoo`06
Ool01g`0OomoogooO01oo`0000Eoo`03O01oogoo009oo`03O01oogoo021oo`03001oogoo009oo`<0
00Yoo`03001oogoo00Aoo`80009oo`05001oogooOol0000AOol005aoo`03ON1W>Goo00=oo`=W>@Yo
o`03001oogoo00eoo`9W>@Eoo`03On1oogoo00=oo`03IcUoogoo00Ioo`05On1oogooOomW>@08Ool0
0g`0Oomoo`02Ool00`00Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`0QOol6000:Ool30006Ool0
0`00Oomoo`05000AOol005aoo`03ON1W>GgP00=W>@eoo`03001oogoo00Yoo`=W>@03OomW>Goo00Eo
o`03On1oogoo009oo`03IcUoogoo00Ioo`9oh09oo`03IcUoogoo00Ioo`07O01oogooOol007ooO000
1Woo00El07ooOn1oh7`0029oo`<0031oo`00G7oo00Amh6LiIcUmh0moo`03001oogoo00Moo`=W>@Ao
o`03IcUoogoo00Eoo`05On1oogooOomW>@05Ool3On02Ool3IcT8Ool017`0Oomoo`000Woo00=l07oo
Ool00goo0WoP00Al07ooOn1l021oo`8003=oo`00G7oo00Amh7ooOommh11oo`03001oogoo00=oo`=W
>@03Oomoh7oo00Aoo`03IcUoogoo00Ioo`04On1oogooIcT2Ool3On02Ool3IcT;Ool00g`0Oomoo`03
Ool00g`0Oomoo`03On03Ool00g`0Ooml000MOol3000eOol005]oo`03ON1oogoo009oo`03ON1oogoo
00eoo`04001oogooOn02IcT5Ool00goPOomoo`02Ool00fLiOomoo`07Ool00goPOomW>@02On02Ool3
IcT>Ool00g`0Oomoo`03Ool00g`0On1oh006Ool017`0Ooml07oP0goo00=l07ooOol04goo0`00>7oo
001KOol00ggPOomoo`03Ool00ggPOomoo`0<Ool01GoP001oh7ooIcT01goo00Eoh7ooOomoofLi00Yo
o`03On1W>Goo00=W>A5oo`03O01oogoo009oo`03On1l07oo00Qoo`9l0005Oomoh7ooOoml000COol2
000kOol005]oo`03ON1oogoo00Aoo`03ON1oogoo00Yoo`03On1oo`00009oo`03IcUoogoo00Ioo`04
On1oogooIcT;Ool2IcTEOol01W`0OomoogooOn1l00Yoo`05O01oogooOn1oo`02O00?Ool3000mOol0
05Moo`@00003ON0000000080009oo`03ON1oogoo00Yoo`03On1oo`00009oo`03IcUoogoo00Moo`03
On1oofLi02=oo`06O01oogooOomoh7`03Goo00Aoh7`0Ooml00aoo`80041oo`007Goo00<007ooOol0
:7oo3`0017oo00=mh7ooOol017oo00=mh7ooOol00Woo0VLi1goo00Eoh7oo001oofLi00Yoo`03On1W
>Goo02=oo`05O01oogooOoml000=Ool01GoPO01oogooO00027oo0`00@Woo000NOol00`00Oomoo`0G
Ool@000DOol00ggPOomoo`03Ool00ggPOomoo`02IcT00gooIcUoo`07Ool017oP001oofLi2Woo00=o
h6LiOol067oo0goP2Goo00El07ooOoml07oP00=oo`03O01oogoo00=oo`=oh003Ooml07oo009oo`03
O01oogoo009oo`<004Eoo`002Woo0`0017oo0P000Woo10001Goo00<007ooOol01@000Woo40009Goo
00=mh7ooOol00Woo0fLi0goo00=W>GooOol01goo00=oh000IcT01goo0goP00=oofLiOol057oo17oP
0Woo00=oh7ooOol027oo00Al07ooO01oh0=oo`03O01oogoo00=oh0Eoo`06O01oogooOoml07oo0P00
B7oo000;Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Moo`T003Aoo`05ON1oofLi
IcUmh005Ool00fLiOomoo`08Ool00`00IcUoo`03Ool3On03Ool2IcTBOol3On07Ool00goPOomoo`08
Ool2O00017ooOn1oogoo0W`000=oh7ooOol01Woo00=l07ooOol00P0000=l07ooOol0B7oo000;Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Qoo`03001oogoo00Aoo`03001oogoo039o
o`9W>@9oo`03ON1oogoo00=oo`03IcUoogoo00Qoo`03001W>Goo00=oh0=oo`=W>A9oo`9oh0]oo`03
On1oogoo00Qoo`03O01oogoo009oh003O01oog`000Qoo`03O01oo`00009oo`03O01oogoo04Qoo`00
2goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0008Ool00`00Oomoo`04Ool00`00Oomo
o`0aOol01VLiOomooggPOommh0Eoo`03IcUmh7oo00Uoo`03001oh7oo009oo`=W>AEoo`03On1oogoo
00=oo`=W>@Eoo`03On1oogoo00aoo`04O01oogooO007Ool00g`0Oomoo`02Ool00g`0Oomoo`18Ool0
00]oo`03001oogoo009oo`04001oogoo0002Ool30009Ool00`00Oomoo`04Ool00`00Oomoo`0aOol0
16LiOomoogoo0WgP1Goo00=W>GgPOol02Goo00<007ooIcT00VLi6Goo00=oh7ooIcT00VLi0Woo00=W
>GooOol00goo00=oh7ooOol037oo00El07ooOomoog`000Ioo`03O01oogoo009oo`03O00007oo04Qo
o`002Woo0P0017oo00@007ooOol0009oo`03001oogoo00Uoo`03001oogoo00=oo`8003=oo`03IcUo
ogoo009oo`03ON1oogoo00=oo`03IcUmh7gP00Uoo`03001W>Goo01Yoo`=W>@Eoo`03IcUoogoo00Ao
o`04On1oogooO00;Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07oo0000B7oo000;Ool0
0`00Oomoo`03Ool20002Ool2000:Ool30005Ool00`00Oomoo`0aOol00fLiOomoo`08Ool016LiON1o
oggP2Goo00<007ooOol03Goo0WoP1goo0fLi0goo00=oh7ooOol00Woo00=W>GooOol00goo0goP00=o
og`0Ool02Woo00=l07ooOol00`000Woo100000H3h7ooOoml07oo0002Ool50002Ool30003Ool2000g
Ool005eoo`03IcUoogoo00Qoo`05IcUmh7ooOommh008Ool00`00Oomoo`0:Ool3On000gooOn1oo`04
Ool2IcT6Ool00goPOomoo`02Ool00fLiOomoh003On04Ool2O00:Ool00g`0Ool00002Ool027`0001o
o`?P0003h7oo0002Ool00g`0Oomoo`03Ool01P00Oomoo`00Ool000=oo`03001oogoo009oo`03001o
ogoo03Aoo`00Fgoo00=mh7ooIcT02Woo00=W>GgPOol00Woo00=mh7ooOol01Woo00<007ooOol01Woo
0goP1Goo00=oh7ooOol00Woo00=W>GooOol01Woo00Ioh7ooOomoh6LiOn08Ool00g`0Ooml0009Ool0
0g`0Oomoo`02Ool01G`00003h7oo00000Woo00<007`0Ool00`000goo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol0<goo001KOol00ggPIcUoo`09Ool2IcT00ggPOomoo`02Ool00ggPOomoo`05
Ool00`00Oomoo`03Ool3On09Ool01GoPOomoogooIcT02Goo0WoP00=oofLiOol027oo00Al07ooOoml
00Qoo`03O01oo`?P0083h004O00007ooOol600000g`0Oomoo`03Ool00`00Oomoo`04Ool20003Ool4
000eOol005]oo`03ON1W>Goo00Ioo`=W>@9oo`03ON1oogoo00=oo`03ON1oogoo00Aoo`03001oogoo
009oo`03On1oogoo00]oo`04On1oogooIcT<Ool00fLiOomoo`07Ool017`0Oomoog`027oo00=l00?P
00002@0000@3h7ooO01l00Eoo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo03=oo`00Fgoo
00=mh6LiON000goo0fLi1Goo00Amh7oo0000009oo`03ON1oogoo00Eoo`05001oogooOomoh003Ool2
IcT9Ool00goPOomW>@0<Ool00fLiOomoo`07Ool01G`0OomoogooO0001goo00<3h7`000000`000goo
00@007ooOol3h09oo`03O01oogoo00=oo`03001oogoo009oo`07001oogooOol007oo00000goo00<0
07ooOol0<goo001KOol00ggPIcUoo`03IcT7Ool00`00ON000004Ool00ggPOomoo`05Ool00`00Oomo
o`02Ool3IcT00gooIcUoo`09Ool00goPIcUoo`0;Ool00fLiOomoo`07Ool00g`0Oomoo`02Ool017`0
Oomoogoo2P0000=oo`0000000Woo00<3h7ooOol01Goo0`0017oo0`000goo0`00=Woo001KOol01GgP
IcUW>GooON001Goo0`0000=ooggPOol017oo00=mh7ooOol01Woo00H007ooIcUW>GooOn02Ool00fLi
Oomoo`08Ool00goPIcUoo`0;Ool00fLiOomoo`07Ool00g`0Oomoo`02Ool40003Ool00`?POoml0002
Ool00g`0Oomoo`04Ool00`?POomoo`1;Ool005Yoo`03ON1oogoo00=oo`03ON1oo`00008000Aoo`03
ON1oogoo00=oo`03ON1oogoo00Ioo`03001W>Goo00=oo`03On1oofLi00Moo`=oh003OomW>Goo00Uo
o`=W>@Uoo`03O003h7oo00800003Ooml07oo00Aoo`060n1oogooO01oog`01Goo00=l00?POol0C7oo
001JOol00ggPOomoo`03Ool00`00ON1oo`07Ool00ggPOomoo`02Ool00ggPOomoo`03Ool3IcT00`00
Oomoo`04Ool00goPIcUoo`03Ool3On04Ool00fLiOomoo`05Ool3IcT9Ool30n000g`00n1oo`03Ool0
0g`0Oomoo`03Ool01P?POomoog`0Ooml00Eoo`03O003h7oo04aoo`00FWoo00=mh7ooOol00`000Woo
00=mh7ooOol01Woo00Emh7ooOomooggP00Aoo`03IcUoogoo009oo`03001oogoo00Aoo`03IcUoogoP
009oh0Moo`03IcUoogoo009oo`=W>@Uoo`<3h0=oo`03O003h7oo00=oo`03O01oogoo00Aoo`030n1o
ogoo009l00Eoo`9l04eoo`00FWoo00=mh00000000P000goo00=mh7ooOol01goo00Amh7ooOommh0Ao
o`03IcUooggP009oo`03001oogoo00Aoo`03IcUoh7oo00Uoo`03IcUoofLi009W>@Uoo`<3h0Ioo`03
O003h7oo00=oo`03O01oogoo00Aoo`050n1oogooOoml0002Ool30n000g`0Ooml001<Ool005Moo`<0
0003ON00000000Eoo`03ON1oogoo00Qoo`03ON1ooggP00Aoo`06IcUooggPON1oo`001Woo00=W>Goo
Ool02Goo0VLi2goo00<3h7ooOol027oo00=l07ooOol00Woo00=l07ooOol017oo00@3h7ooOomoo`<3
h0=oo`04O01oogooO01;Ool005Aoo`H00003ON1oogoo00Eoo`03ON1oogoo00Uoo`9mh0Aoo`07IcUo
oggPOommh7oo00001Goo00=W>GooOol05Woo00<3h7ooOol027oo00<3h7`0Ool00Woo00=l07ooOol0
17oo10?P1Woo00Al07ooOoml04]oo`00DWoo0P0000=oo`00000017oo00=mh7ooOol017oo00=mh7oo
Ool00Woo0VLi1Woo00=mh7ooOol00Woo00=W>GooON000Woo00=mh7ooOol017oo00=W>GooOol05Woo
00<3h7ooOol02Goo00D3h7`0Oomoog`000Eoo`03O003h7oo00Qoo`05O01oogooOoml001:Ool004mo
o`H000Moo`03ON1oogoo00=oo`03ON1oofLi009W>@03OomW>Goo00Yoo`03IcUooggP00=oo`03ON1o
ogoo00=oo`03IcUoogoo00Yoo`83h0Yoo`030n1oogoo00=oo`03001oogoo00=oo`050n1l07ooOoml
0005Ool00g`0Oomoo`08Ool00g`0Oomoo`02Ool00g`0Oomoo`17Ool004aoo`H000]oo`04ON1oogoo
Ool3IcT4Ool00fLiOomoo`08Ool00fLiOommh005Ool00ggPOomoo`02Ool00fLiOomoo`07Ool30n00
0goo0n1oo`09Ool00`?POomoo`03Ool00`00Oomoo`03Ool01@?POoml07ooO0001Goo0W`02Goo00=l
07ooOol00Woo00=l07ooOol0Agoo0019Ool6000?Ool3IcT00ggPOomoo`04Ool00fLiOomoo`08Ool0
0fLiOommh006Ool00ggPOomW>@02IcT7Ool20n04Ool00`?POomoo`08Ool00`?POomoo`04Ool00`00
Oomoo`02Ool00`?POomoo`02O005Ool00g`0Ooml0008Ool00g`0Oomoo`02Ool00g`0Oomoo`17Ool0
04Moo`800003Ool00000011oo`9W>@04Oommh7ooON06Ool00fLiON1oo`08Ool00fLiOommh005Ool3
IcT7Ool30n06Ool00`?POomoo`08Ool00`?POol07`0201l2Ool00`00Oomoo`030n03Ool00g`0Oomo
o`03Ool017`0Oomoog`01goo00=l07ooOol00Woo00=l07ooOol0Agoo000jOol00`00Oomoo`07Ool6
000BOol016LiOomoogoo0WgP1Woo00=W>GooON0027oo00EW>GooON1oo`0000=W>@03Oommh7oo00Io
o`030n1oogoo00Moo`030n1oogoo00Moo`<07`9oo`0301moo`?P00<3h0aoo`04O01oogooO007Ool0
0g`0Oomoo`02Ool00g`0Oomoo`17Ool003]oo`03001oogoo00=oo`H001Eoo`03IcUoogoo009oo`03
ON1oogoo00=oo`05IcUmh7ooOommh007Ool00fLiOomW>@02IcT4Ool00ggPOomoo`05Ool00`?POomo
o`07Ool00`?POomoo`04Ool301l00goo0n1oo`030n00100OOomoo`003Woo00Al07ooOoml00Moo`05
O003h7ooOoml0019Ool002Moo`<000=oo`<0009oo`@000Eoo`03001oogoo00H00003Ool0000001Eo
o`03IcUoogoo00Qoo`03IcUmh7oo009oo`03ON1oogoo00Aoo`9W>@03ON1oogoo00Aoo`03ON1oogoo
00Eoo`030n1oogoo00Moo`040n1oogooOol301l4Ool20n04Ool0100OOomoo`003Goo00El07ooOomo
og`000=oo`<3h003Ooml07oo009oo`03O01oogoo04Ioo`00:7oo00<007ooOol00goo00<007ooOol0
0Woo00@007ooOol000Ioo`03001oo`0000<000Aoo`03001oogoo019oo`03IcUoogoo00Qoo`03IcUm
h7oo00=oo`03ON1oogoo00=oo`800003Oommh7oo00Aoo`03ON1oogoo00Eoo`030n1oogoo00Moo`04
0n1oo`0O01l>Ool00`0OOol0000=Ool00g`0Oomoo`02Ool00g`00n03h004Ool01@?PO01oogooO000
B7oo000XOol00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`001Goo100027oo00<007ooOol0
3goo00=mh7ooIcT02Woo00=W>GgPOol017oo00Emh7ooOomoo`0000Aoo`05ON1oogooOommh008Ool0
0`?POomoo`07Ool00`?POol07`0@Ool00`0OOol0000<Ool00g`0Ool0000200000g`0Oomoo`04Ool0
1@?POoml07ooO000B7oo000XOol00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo0`00
0goo00<007ooOol00goo10004Goo00=mh6LiOol02Woo00=W>GgPOol01Goo00=mh7oo00001Woo00Am
h7ooOommh0Qoo`030n1oogoo00Moo`040n1oogoo01l@Ool00`0O001oo`0;Ool00g`00n1oo`02Ool4
0003Ool00`?POomoo`02O018Ool002Qoo`03001oogoo00=oo`03001oogoo009oo`<00003Ool00000
00Ioo`03001oogoo009oo`05001oogooOol0000AOol00ggPIcUoo`09Ool2IcT00ggPOomoo`04Ool0
0ggP001oo`07Ool00ggPOommh008Ool00`?POomoo`05Ool30n03Ool00`0OOomoo`0=Ool201l00`00
Oomoo`09Ool00g`0Oomoo`02Ool017`0Oomoogoo0`0000D3h7ooOomoog`004Qoo`009goo0P0017oo
0P0017oo100027oo00<007ooOol00Woo00D007ooOomoo`00015oo`03ON1W>GgP00Ioo`=W>@9oo`03
ON1oogoo00=oo`03001mh7oo00Uoo`9mh0Ioo`807`030n1oogoo009oo`<3h0Moo`0301moogoo00Uo
o`<07`9oo`03001oogoo00Uoo`03O01oogoo009oo`03O01oogoo00Aoo`@004Uoo`00:7oo00<007oo
Ool00goo00<007ooOol00`002Woo0`0017oo0`004Woo00Amh6LiOommh09oo`=W>@Eoo`03ON1oogoo
009oo`03001ooggP00]oo`04ON1oogooOol301l017oo01l3h7oo0`?P2Woo00<07gooOol01Woo0`0O
1Woo00<007ooOol027oo00<3h7`0Ool00Woo00=l07ooOol017oo00@3h7ooOomoo`@004Eoo`00;goo
0P00:Goo00=mh6LiOol00fLi27oo00=mh7ooOol00P000Woo00=mh7ooOol02Woo0`0O1Goo00<07`?P
Ool03Goo00<07gooOol00goo0P0O1goo0`?P2Woo00<3h7ooO0000goo00=l07ooOol00goo00<3h7oo
Ool01Goo0`00@Woo000/Ool3000ZOol017gPOomW>FLi0Woo00=mh7ooOol01goo00=mh000Ool00goo
00=mh7ooOol01goo0`0O2Goo00<07gooOol03Goo00<07goo01l00P0O1Goo10?P0Woo00<3h000Ool0
27oo00@3h7ooOoml009oo`03O01oogoo009oo`03O003h7oo00Uoo`@003ioo`00:Goo0`00;Goo00=m
h7ooOol017oo00=mh7ooOol01Woo00<007gPOol00Woo00=mh7ooOol017oo00Amh7oo01l07`eoo`03
01moogoo00eoo`0301moogoo00=oo`<3h0Ioo`030n0007oo00Uoo`030n1oog`0009oo`03O01oogoo
009oo`03O003h7oo00eoo`@000]oo`03001oogoo02aoo`009Woo0`00<7oo00=mh7ooOol01Goo00=m
h7ooOol00goo0P000Woo00Amh7ooOommh0Ioo`04ON1oogoo01l>Ool00`0OOomoo`0@Ool20n09Ool0
0`?POol00009Ool01P?POomoog`0Ooml00=oo`030n1l07`0019oo`<000Uoo`03001oogoo02]oo`00
97oo0P00<goo00=mh7ooOol01Goo00=mh7ooOol00Woo00<007ooOol00goo00=mh7ooON001Woo0WgP
0Woo00<07gooOol037oo00<07gooOol03goo00<3h7ooOol027oo00<3h7oo00002Goo00@3h7ooOomo
o`9l00<3h004Ooml07ooO009Ool30003Ool30002Ool40005Ool00`00Oomoo`050003Ool30002Ool3
000KOol001Moo`03001oogoo00Moo`<003Eoo`03ON1oogoo008000=oo`03ON1oogoo008000Moo`9m
h0Ioo`03ON1ooggP009oo`0301moogoo00aoo`0301moogoo00ioo`030n1oogoo00Qoo`030n1oogoo
00807`Moo`030n1oo`?P0083h003O01oogoo009oo`04O01oogooO009Ool01@00Oomoogoo00000goo
00@007ooOol0009oo`8000Moo`04001oogoo0004Ool01000Oomoo`000goo00<007ooOol067oo000H
Ool00`00Oomoo`03Ool3000hOol00ggPOol00005Ool00ggPOol00006Ool201l2Ool00ggPOomoo`04
Ool017gPOomooggP0Woo00<07gooOol02Woo0`0O3goo00<3h7ooOol027oo0`0O00<007oo01l01Woo
0P?P27oo00Al07ooOoml00Uoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool50005Ool00`00Oomoo`0HOol000Aoo`<000=oo`<0009oo`@000Eoo`03001oogoo00D0
00=oo`<003=oo`8000Ioo`03ON0007oo00=oo`<07`9oo`0301moogoo00Ioo`05ON1oogooOommh002
Ool00`0OOomoo`05Ool401l5Ool30n0:Ool00`?POomoo`05Ool301l01`?POomoogoo001oo`0O00mo
o`05O01oogooOoml0008Ool00`00Oomoo`03Ool20003Ool01000Oomoo`0027oo00<007ooOol00Woo
00@007ooOol000Ioo`03001oogoo01Qoo`001Goo00D007ooOomoo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`06Ool01000Oomoo`0017oo00<007ooOol0<Goo00<007ooON001Goo00@007gPOomoo`<0
7`Ioo`0301moogoo00Eoo`03ON1oogoo009oo`04ON1oogoo01l2Ool401l5Ool40n02Ool00`?POomo
o`08Ool00`?POomoo`02Ool301l3Ool01@?POomoogoo00000Woo00<07gooOol037oo00=l07ooOol0
0Woo00=l07ooOol01Goo00<007ooOol01Goo00<007ooOol00`002Goo00<007ooOol00goo00<007oo
00000Woo10006goo0005Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00Ioo`03
001oogoo009oo`D0031oo`8000=oo`06ON1oogooOol007gP0`0O2Woo00<07gooOol017oo00=mh7oo
Ool00goo00=mh7ooOol00P0O1Woo0`?P1Woo00<3h7ooOol027oo00<3h7ooOol00P0O1Woo00<3h7oo
Ool00Woo00@007ooOol07`eoo`03O01oogoo009oo`03O01oogoo00Aoo`8000=oo`05001oogooOol0
0002Ool00`00Oomoo`09Ool00`00Oomoo`04Ool20002Ool00`00Oomoo`0LOol000Eoo`04001oogoo
Ool40003Ool01000Oomoo`0027oo00<007ooOol00Woo00@007ooOol002moo`8000Ioo`03ON1oo`00
00807`Ioo`9mh0Ioo`0301moogoo00=oo`03ON1oogoo00=oo`03ON1oogoo00Ioo`83h0Uoo`030n1o
ogoo00Qoo`040n1oogoo01l5Ool30n04Ool01@00Oomoogoo01l037oo00=l07ooOol00Woo00=l07oo
Ool01Goo00<007ooOol00Woo0`000Woo0P002Woo0`001Woo00<007ooOol01@006Woo0005Ool01@00
Oomoogoo00001Woo0`002Goo00<007ooOol00goo00<007oo0000;Woo00<007ooOol01Woo00D007gP
Oomoo`0O00Ioo`03ON1ooggP00Ioo`0301moogoo009oo`04ON1oogoo0002Ool00ggPOomoo`06Ool0
0`?POomoo`08Ool00`?POomoo`08Ool01@?POomoogoo01l010?P27oo00D007ooOomoo`0O00]oo`03
O01oogoo009oo`03O01oogoo04Ioo`0017oo0P0017oo00<007ooOol00goo00<007ooOol02Goo00<0
07ooOol017oo0P00;7oo0P0027oo00L007ooOommh7ooON007`05Ool017gPOomooggP1Woo00D07goo
OomooggP009oo`04001oogooON08Ool00`?POomoo`08Ool00`?POomoo`08Ool00`?POol3h0020n00
0`0OOomoo`09Ool00`00Oomoo`0301l:Ool00g`0Oomoo`02Ool00g`0Oomoo`16Ool000Eoo`03001o
ogoo00=oo`80009oo`8000Yoo`<000Ioo`03001oogoo02Uoo`03001oogoo00Moo`03001oogoo009o
o`9mh003Ool07goo00=oo`05ON1oogooOommh005Ool201l2Ool00ggPOol00003Ool00ggPOomoo`06
Ool00`?POomoo`08Ool301l8Ool20n04Ool00`0OOomoo`08Ool301l=Ool00g`00n03h002Ool00g`0
Oomoo`16Ool004ioo`8000Qoo`8000Ioo`04ON1oogoo01l3Ool00ggPOomoo`02Ool00ggPOol07`02
01l5Ool00ggPOomoo`02Ool00ggPOomoo`06Ool00`?POomoo`05Ool301l00`?POol07`0?Ool00`0O
Oomoo`04Ool301l00goo001oo`0;Ool30n000g`00n1oo`02Ool00g`0Oomoo`15Ool004eoo`03001o
ogoo00Moo`03001oogoo00Yoo`0401moogooON03Ool301l7Ool00`00Oommh003Ool00ggPOomoo`06
Ool00`?POomoo`02Ool301l3Ool010?POomoo`0O3goo00<07gooOol00`0O1Goo00<007ooOol01Woo
0`?P17oo00El07ooOomoog`004Moo`00Bgoo0P0000=oo`00Ool01Woo00<007ooOol037oo00<07goo
ON000`0O0goo00=mh7ooOol00goo00D007ooOomooggP009oo`03ON1oogoo00Ioo`030n1oo`0O0080
7`Ioo`050n1oogooOol07`0?Ool201l8Ool00`00Oomoo`03Ool30n07Ool01@?PO01oogooO000Agoo
001:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool201l6Ool00ggPOomoo`02Ool0
0`00Oomoo`03Ool00ggPOommh008Ool201l7Ool30n04Ool00`0OOomoo`0GOol00`00Oomoo`020n0:
Ool01@?POoml07ooO000Agoo0010Ool500000goo000000020005Ool00`00Oomoo`050002Ool30004
Ool30004Ool01GgPOomoogoo00000Woo00=mh7ooOol00Woo00<007ooOol017oo0WgP27oo00<3h7oo
01l00Woo10?P27oo00<07gooOol05Woo00@007ooOol3h0]oo`030n1oogoo009l04Moo`00@Goo00D0
07ooOol007oo0080009oo`03001oogoo00Ioo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool01GgPOomoogoo00000Woo00Emh7ooOomoo`0000Qoo`03ON1oogoo00Ioo`050n1oo`?P01l3
h00=Ool00`0OOomoo`0FOol00`00Ool3h002Ool201l8Ool010?POomoog`0Agoo0012Ool01P00Oomo
o`00Ool0009oo`03001oogoo00Ioo`03001oogoo00Aoo`04001oogooOol50004Ool017gPOomoo`00
0goo00Amh7ooOol000Eoo`807`]oo`83h09oo`0301moogoo00Yoo`<07`eoo`83h0Qoo`03001oo`0O
00807`03Ool07goo00Moo`030n1oogoo04Qoo`00@goo0P000Woo00@007ooOol000Qoo`03001oogoo
00Aoo`05001oogooOol00002Ool00`00Oomoo`04Ool00ggP001oo`03Ool00ggPOol00003Ool301l2
Ool00`0OOomoo`0=Ool00`0OOomoo`05Ool401l=Ool30n000goo0n1oo`06Ool301l00`?POomoo`02
Ool00`0OOomoo`05Ool00`?POomoo`18Ool0041oo`05001oo`00Ool00002Ool30009Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Ool00006Ool00`00ON1oo`03Ool00ggP001oo`0301l6Ool00`0O
Oomoo`0=Ool00`0OOomoo`0401l>Ool30n04Ool00`?POomoo`02Ool301l2Ool00`000n1oo`04Ool0
0`0OOomoo`04Ool00`?POomoo`18Ool0041oo`80009oo`04001oogoo000;Ool00`00Oomoo`03Ool2
0005Ool20005Ool01000OomooggP0goo0`0O17oo00=mh7ooOol00goo00<07gooOol03Goo0P0O3goo
0`?P1goo00<3h7ooOol00P0O1Woo00<000?POol017oo00<07gooOol00goo00<3h7ooOol0B7oo000o
Ool00`00Ool000020002Ool2000:Ool30005Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool017gPOol07ggP1Woo0WgP1Goo00<07gooOol06goo0P?P2Woo00@3h7ooOol07`Moo`030003
h7oo00Eoo`0301moogoo00<3h4Yoo`00?Goo0P009Woo00<007ooOol017oo00=mh00OON001Woo00=m
h7ooON001Goo00<07gooOol06Woo00<3h7ooOol02Goo00D3h7ooOomoo`0O00Moo`030n1oogoo00=o
o`83h00301l3h7oo04aoo`00?7oo00<007ooOol09Goo00<007ooOol01Goo00<007gP01l01Woo00Am
h7ooOommh0Eoo`0301moogoo01Uoo`030n1oogoo00Uoo`030n1oogoo009oo`0301moogoo00Aoo`03
0n1oo`?P00<3h09oo`807deoo`00>Woo0P009goo00<007ooOol01Goo00D007ooOommh00O00Eoo`05
ON1oogooOommh004Ool201l>Ool20n0:Ool010?P01l07`0O0Woo00<007ooOol00goo00<3h7ooOol0
0goo00<07gooOol00goo0P?P00<007ooOol00`0OCgoo000hOol2000XOol00`00Oomoo`05Ool00`00
Oomoo`03Ool00`0OOomoo`02Ool00ggPOomoo`02Ool017gP01l07`0O3Goo0`?P00=oo`?POol01Woo
100O0goo00<07goo00001Goo00<3h7ooOol017oo00<07gooOol017oo00<07`0001l0DWoo000gOol0
0`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`05Ool0100OOomooggP0goo0`0O00=mh7ooOol0
2Woo0`?P17oo00@3h7ooOomoo`@07`=oo`030n1oogoo009oo`0301moo`000080009oo`030n1oo`00
00800003Ool0000000800006Ool07`0O01moo`000Woo1@0000=oo`0000000`000Woo0P00@Woo000e
Ool2000YOol00`00Oomoo`05Ool00`00Oomoo`07Ool00`0OOommh00301l3Ool00ggPOomoo`07Ool3
0n07Ool010?POol07`0O1goo00<3h7ooOol00goo00<07`0000000goo00@3h7ooOol000=oo`04001o
o`0O0008Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo03moo`00=7oo00<007ooOol0
:7oo00<007ooOol01Woo00<007ooOol027oo0P0O0goo00@007ooOommh0Qoo`030n1oogoo00Qoo`03
0n1oo`0O00Qoo`030n1oogoo00Aoo`0301l007oo0083h0D0009oo`04001oogoo0008Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`0nOol0039oo`8002Yoo`03001oogoo00Ioo`03001oogoo
00Yoo`05ON1oogooOol00002Ool00ggPOomoo`06Ool00`?POomoo`08Ool010?POomoo`0O1goo00<3
h7ooOol00goo0P?P00D000?POomoo`00009oo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool01000Oomoogoo1000@7oo000aOol00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomo
o`0;Ool017gPOomoo`000goo00=mh7ooOol01Woo00<3h7ooOol027oo00D3h7ooOomoo`0O00Ioo`03
0n1oo`?P00<3h09oo`0300007goo009oo`03001oo`0000=oo`<000Uoo`03001oogoo009oo`07001o
ogooOol007oo00000goo00<007ooOol0?Woo000_Ool2000[Ool00`00Oomoo`06Ool00`00Oomoo`0<
Ool2ON000`00Oomoo`02Ool00ggPOomoo`06Ool301l8Ool00`?POomoo`02Ool00`0OOomoo`03Ool2
0n03Ool201l30004Ool20003Ool00`00Oomoo`09Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo03ioo`00;Woo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol03goo00=m
h7ooOol00Woo00=mh7ooOol00Woo100O00@3h7ooOol07`Moo`030n1oogoo00=oo`0301moogoo00Ao
o`<07`=oo`03001oo`0000Aoo`03001oogoo008000Yoo`<000Aoo`<000=oo`<0045oo`00;7oo0P00
;7oo00<007ooOol01Woo00<007ooOol03goo00<007ooON000goo00=mh00O01l00P0O17oo00D3h7oo
Oomoo`0O00Ioo`030n1oogoo00Aoo`0301moogoo00<07`Qoo`03001oogoo069oo`00:Woo0P00;Goo
00<007ooOol01goo00<007ooOol03goo00D007ooOommh7oo00807`Qoo`030n1oogoo009oo`0301mo
ogoo00=oo`030n1oogoo00Eoo`807`aoo`03001oogoo065oo`00:Goo00<007ooOol0;Goo00<007oo
Ool01Woo00<007ooOol03goo00<007ooOol00Woo00=mh00OON0027oo00<3h7ooOol00goo00<07goo
Ool00`?P5Goo00<007ooOol0HGoo000WOol2000_Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00
Oomoo`04Ool00ggP01moo`07Ool00`?POomoo`02Ool20n000`0O0n1oo`0HOol00`00Oomoo`1POol0
02Ioo`03001oogoo02ioo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo00Eoo`03ON007goo
00Ioo`030n1oo`?P0083h09oo`807aUoo`03001oogoo061oo`0097oo0P00<7oo00<007ooOol01Woo
00<007ooOol047oo00<007ooOol027oo00<07gooOol017oo0P?P0Woo0`0O77oo00<007ooOol0Ggoo
000SOol00`00Oomoo`0_Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`0OOomo
o`04Ool301lOOol00`00Oomoo`1OOol0025oo`80035oo`03001oogoo00Moo`03001oogoo011oo`03
001oogoo00]oo`0301moogoo00<07b=oo`03001oogoo05ioo`0087oo00<007ooOol0<7oo00<007oo
Ool01goo00<007ooOol047oo00<007ooOol03Goo0P0O9Woo00<007ooOol0GWoo000NOol2000bOol0
0`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0fOol00`00Oomoo`1MOol001aoo`8003=oo`03
001oogoo00Moo`03001oogoo015oo`03001oogoo03Moo`03001oogoo05eoo`006goo00<007ooOol0
<Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0>7oo00<007ooOol0G7oo000IOol2000d
Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0iOol00`00Oomoo`1LOol001Qoo`03001o
ogoo03=oo`03001oogoo00Moo`03001oogoo019oo`03001oogoo03]oo`03001oogoo05]oo`005goo
00<007ooOol0<goo00<007ooOol027oo00<007ooOol04Woo00<007ooOol0>goo00<007ooOol0Fgoo
000>Ool00`00Oomoo`0kOol00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`0mOol00`00Oomo
o`1JOol000moo`03001oogoo03Uoo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo03eoo`03
001oogoo05Yoo`0000Aoo`000000009oo`@000Eoo`03001oogoo00D0009oo`<002ioo`03001oogoo
00Qoo`03001oogoo01=oo`03001oogoo03moo`03001oogoo05Uoo`000Woo00<007ooOol00Woo00@0
07ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol0:Woo00<007ooOol027oo00<007ooOol0
4goo00<007ooOol0@7oo00<007ooOol0FGoo0002Ool00`00Oomoo`02Ool01000Oomoo`0027oo00<0
07ooOol00Woo00D007ooOomoo`0002]oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Ao
o`03001oogoo045oo`03001oogoo05Qoo`000Woo00<007ooOol00Woo00@007ooOol000Qoo`03001o
ogoo009oo`@002aoo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo049oo`03001oogoo05Qo
o`000Woo00<007ooOol00Woo0`002Goo00<007ooOol00Woo00<007ooOol087oo0`000goo0`000Woo
10001Goo00<007ooOol01@000Woo0`0017oo00<007ooOol01Goo00<007ooOol0A7oo00<007ooOol0
Egoo00000goo00000004Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0POol01@00Oomo
ogoo00000goo00@007oo0000009oo`03001oogoo00Ioo`04001oogoo0003Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`14Ool00`00Oomoo`1GOol0009oo`04001oogooOol2000:Ool30005
Ool2000POol00`00Oomoo`05Ool200001Goo001oogoo000027oo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol0AWoo00<007ooOol0EWoo000lOol00`00Oomoo`05Ool01000
Oomoo`000Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol0AWoo00<007ooOol0EWoo000lOol01000Oomoogoo10000goo0`002Goo00<007ooOol017oo
00<007ooOol01Goo00D007ooOomoo`0004Yoo`03001oogoo05Eoo`00>goo0P000goo00<007oo0000
17oo00<007ooOol02Goo00<007ooOol00goo0P000goo00D007ooOomoo`00009oo`03001oogoo04Uo
o`03001oogoo05Eoo`00?7oo00@007ooOomoo`D00003Ool0000000Yoo`<000Eoo`04001oogooOol5
0002Ool00`00Oomoo`1:Ool00`00Oomoo`1DOol0041oo`03001oogoo025oo`03001oogoo04]oo`03
001oogoo05Aoo`00?goo00<007ooOol08Woo00<007ooOol0C7oo00<007ooOol0Dgoo000nOol00`00
Oomoo`0ROol00`00Oomoo`1=Ool00`00Oomoo`1COol003eoo`03001oogoo029oo`03001oogoo04mo
o`03001oogoo059oo`00?7oo00<007ooOol08goo00<007ooOol0Cgoo00<007ooOol0DWoo000kOol0
0`00Oomoo`0SOol00`00Oomoo`1?Ool00`00Ool0001COol003Yoo`03001oogoo02Aoo`03001oogoo
051oo`03001oogoo059oo`00>Goo00<007ooOol097oo00<007ooOol0A7oo00@007ooOomoo`@000Eo
o`03001oogoo00D0009oo`<0009oo`D0045oo`00>7oo00<007ooOol097oo00<007ooOol0AGoo00<0
07ooOol00Woo00@007ooOol000Qoo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oogoo
03moo`00=goo00<007ooOol09Goo00<007ooOol0AWoo00D007ooOomoo`00009oo`03001oogoo00Io
o`03001oogoo00Ioo`05001oogooOol00013Ool003Ioo`03001oogoo02Eoo`03001oogoo04Moo`05
001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`04Ool20005Ool00`00Oomoo`10Ool005eo
o`03001oogoo04Uoo`03001oogoo00<000Uoo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo
03moo`00;goo00<007ooOol0:goo00<007ooOol0AGoo00D007ooOomoo`00009oo`03001oogoo00Uo
o`03001oogoo009oo`07001oogooOol007oo00000goo00<007ooOol0?goo000`Ool00`00Oomoo`0Y
Ool00`00Oomoo`16Ool500000goo0000000:Ool30004Ool30003Ool30012Ool001aoo`<000Aoo`04
001oogooOol40005Ool00`00Oomoo`050002Ool30002Ool5000HOol00`00Oomoo`2ZOol001eoo`03
001oogoo00=oo`03001oogoo009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo
00@007ooOol001Moo`03001oogoo0:]oo`007Goo00<007ooOol017oo00D007ooOomoo`00009oo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo0:aoo`00
7Goo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo01Eoo`03001oogoo0:aoo`007Goo00<007ooOol01Goo00<007ooOol00`00
2Goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo01=oo`03001oogoo0:eoo`0077oo
0P000goo00D007ooOomoo`00009oo`03001oogoo00Uoo`03001oogoo00=oo`8000=oo`05001oogoo
Ool0000EOol00`00Oomoo`2]Ool001eoo`04001oogooOol500000goo0000000:Ool30005Ool00`00
Oomoo`02Ool3000EOol00`00Oomoo`2^Ool005Moo`03001oogoo0:moo`00Egoo00<007ooOol0[goo
001FOol00`00Oomoo`2`Ool005Ioo`03001oogoo0;1oo`00EGoo00<007ooOol0/Goo001DOol00`00
Oomoo`2bOol005Aoo`03001oogoo0;9oo`00Dgoo00<007ooOol0/goo001COol00`00Oomoo`2cOol0
059oo`03001oogoo0;Aoo`00DGoo00<007ooOol0]Goo003oOol:Ool00?moo`Yoo`00BGoo00<007oo
Ool0_Goo001:Ool00`00Oomoo`2lOol003aoo`<0009oo`@000Eoo`03001oogoo00D0009oo`<000=o
o`800:eoo`00>goo00D007ooOomoo`00009oo`04001oogoo0008Ool01000Oomoo`000goo00<007oo
Ool017oo00<007ooOol0ZWoo000oOol01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol0ZGoo000mOol20003Ool01000Oomoo`0027oo00<007ooOol017oo
00<007ooOol00Woo1000Zgoo000oOol00`00Oomoo`030009Ool00`00Oomoo`04Ool01@00Oomoogoo
00000goo00<007ooOol0ZGoo000kOol01@00Oomoogoo00000Woo00<007ooOol02Goo00<007ooOol0
0goo0P000goo00D007ooOomoo`000:]oo`00?7oo0`000Woo0P002Woo0`001Goo00<007ooOol00Woo
0`00[7oo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:
Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00
ogoo2Woo003oOol:Ool00001\
\>"],
  ImageRangeCache->{{{0, 264.062}, {252.062, 0}} -> {-1.18055*^-5, \
0.000140426, 0.00365809, 0.00365809}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving the cube", "Subsubsection"],

Cell["\<\
To see what a button does, zero the cube and clik the button. You \
can paste the resulting graphics into the button notebook or any other \
notebook and fold it up for reference.\
\>", "Text"],

Cell[TextData[{
  "First you can use all the buttons to move the first face of the basis into \
position any way you like. Note which buttons shift this face, and \
subsequently only the remaining buttons. Now move the second face \"",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", "b"}], TraditionalForm]]],
  "\" into position. Note which buttons shift the second face and \
subsequently just use the remaining buttons. Simply continue in this manner \
and you will have solved the cube. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Extending the Methods", "Section"],

Cell["\<\
Extensions of these notebooks also have animations of conjugation \
and show how to construct the common moves.\
\>", "Text"],

Cell["\<\
We can compute many more convenient bases than that above. \
Augmenting the generators with  their actions on positions we can compute a \
structured base that moves blocks into position then twists and flips them.\
\
\>", "Text"],

Cell["\<\
This is an example of an  \"imprimitivity\" and the groups are \
Wreath products. This reveals that there are in fact moves which twist middle \
faces, yet leave all faces in the same position. We can also get exact \
descriptions of the group structure-explaining  the various ways of solving \
the cube, and randomising it for the \"solving game\".\
\>", "Text"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
CellGrouping->Manual,
WindowSize->{520, 482},
WindowMargins->{{82, Automatic}, {Automatic, 40}},
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[ParentDirectory[]], \
"StylesFolder"}, "Talk Style.nb", CharacterEncoding -> "MacintoshRoman"],
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 28, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1770, 53, 26, 0, 59, "Section"],
Cell[1799, 55, 89, 3, 26, "Text"],
Cell[1891, 60, 174, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[2090, 68, 45, 0, 43, "Subsubsection"],
Cell[2138, 70, 703, 20, 62, "Text"],
Cell[2844, 92, 9135, 208, 446, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[12016, 305, 37, 0, 35, "Subsubsection"],
Cell[12056, 307, 91, 3, 30, "Text"],
Cell[12150, 312, 341, 7, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12528, 324, 47, 0, 35, "Subsubsection"],
Cell[12578, 326, 144, 3, 46, "Text"],
Cell[12725, 331, 2919, 79, 56, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15681, 415, 43, 0, 35, "Subsubsection"],
Cell[15727, 417, 88, 3, 30, "Text"],
Cell[15818, 422, 40851, 813, 1496, "Output"],
Cell[56672, 1237, 61, 0, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[56770, 1242, 39, 0, 35, "Subsubsection"],
Cell[56812, 1244, 58, 0, 30, "Text"],
Cell[56873, 1246, 110790, 2813, 4630, "Output"],
Cell[167666, 4061, 214, 5, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[167929, 4072, 40, 0, 39, "Section"],
Cell[167972, 4074, 169, 4, 42, "Text"],
Cell[168144, 4080, 118, 3, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[168299, 4088, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[168376, 4092, 37, 0, 43, "Subsubsection"],
Cell[168416, 4094, 178, 4, 42, "Text"],
Cell[168597, 4100, 171, 4, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[168805, 4109, 46, 0, 35, "Subsubsection"],
Cell[168854, 4111, 1236, 40, 75, "Text"],
Cell[170093, 4153, 67743, 2381, 262, 34574, 1967, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[237873, 6539, 41, 0, 35, "Subsubsection"],
Cell[237917, 6541, 203, 4, 42, "Text"],
Cell[238123, 6547, 509, 10, 90, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[238681, 6563, 40, 0, 39, "Section"],
Cell[238724, 6565, 135, 3, 42, "Text"],
Cell[238862, 6570, 240, 5, 58, "Text"],
Cell[239105, 6577, 374, 6, 74, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

