(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58573,       1959]*)
(*NotebookOutlinePosition[     59492,       1989]*)
(*  CellTagsIndexPosition[     59448,       1985]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik Geometry", "Title"],

Cell[CellGroupData[{

Cell["Rubik Graphics Overview", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection"],

Cell[TextData[{
  "These notes describe the mathematical framework for the transformations of \
 Rubik's cube and introduce some of the implementation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ."
}], "Text"],

Cell[TextData[{
  "The geometric configurations ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalC]", TraditionalForm]]],
  " consist of an oriented position for each block \nin the cube. The colored \
facial configurations \[ScriptCapitalQ] are sets of colored mini-faces.\n\
Rubik's slice rotations act on both ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalC]", TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalQ]", TraditionalForm]]],
  " and generate Rubik's group ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalG]", TraditionalForm]]],
  ".\nThis is sumarized in the diagram:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {"\[ScriptCapitalG]", "\[LongRightArrow]", 
            RowBox[{"[", 
              RowBox[{
              "\[ScriptCapitalC]", " ", "\[LongRightArrow]", 
                "\[ScriptCapitalC]"}], "]"}]},
          {" ", "\[LowerRightArrow]", " "},
          {" ", " ", 
            RowBox[{"[", 
              RowBox[{"\[ScriptCapitalQ]", "\[Rule]", "\[ScriptCapitalQ]"}], 
              "]"}]}
          }], TraditionalForm]]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["notn", "Subsubsection"],

Cell[TextData[{
  "We use ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalP](X)\)]],
  " for the power set of ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\([\ X\[LongRightArrow]\ Y]\)\)\)]],
  " for the set of functions from ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Im(F)\)]],
  " for the image ( ",
  Cell[BoxData[
      \(TraditionalForm\`F(X)\)]],
  " ) of the function ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ". The arrow ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[
          RowBox[{
            AdjustmentBox[">",
              BoxMargins->{{0.3, -0.1}, {0, 0}}], 
            AdjustmentBox["\[LongRightArrow]",
              BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
          "injection"], TraditionalForm]]],
  " is an injection, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          AdjustmentBox["\[Subset]",
            BoxMargins->{{0.3, -0.1}, {0, 0}},
            BoxBaselineShift->-0.3], 
          AdjustmentBox["\[LongRightArrow]",
            BoxMargins->{{-0.3, 0.1}, {0, 0}}]}], TraditionalForm]]],
  " is inclusion.\nIf ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " is a set, we may write ",
  Cell[BoxData[
      \(TraditionalForm\`S\_X = \([X \[Rule] \ X]\)\)]],
  "  for the symmetric group on ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rectilinear Rotations and orientations", "Subsubsection"],

Cell[TextData[{
  " Let ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalA]\^+\) = {a\_x, a\_y, a\_z}\)]],
  " be our labels for the axis. They are associated with the unit vectors ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_1, \[Epsilon]\_2, \[Epsilon]\_3 \
\[Element] \[DoubleStruckCapitalR]\^3\)]],
  "."
}], "Text"],

Cell[TextData[{
  "When indexing these simple sets we'll assume they are naturally ordered ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["a", "1"], ",", 
            SubscriptBox["a", "2"], ",", 
            SubscriptBox["a", "3"]}], "}"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "We'll use distinct labels ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[ScriptCapitalR]", "3", "+"], "=", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["r", "x"], ",", 
              SubscriptBox["r", "y"], ",", 
              SubscriptBox["r", "z"]}], "}"}]}], TraditionalForm]]],
  " when we are using them as axis for rotations\n (always counter clockwise) \
thru ",
  Cell[BoxData[
      FormBox[
        FractionBox["\[Pi]", "2"], TraditionalForm]]],
  " about the axis.\nNaturally  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[ScriptCapitalA]", "+"], "\[TildeTilde]", 
          SubsuperscriptBox["\[ScriptCapitalR]", "3", "+"]}], 
        TraditionalForm]]],
  ". We will also use the signed labels ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ScriptCapitalA]", "=", 
            RowBox[{"\[PlusMinus]", 
              SuperscriptBox["\[ScriptCapitalA]", "+"]}]}], ",", 
          RowBox[{
            SubscriptBox["\[ScriptCapitalR]", "3"], "=", 
            RowBox[{"\[PlusMinus]", 
              SubsuperscriptBox["\[ScriptCapitalR]", "3", "+"]}]}]}], 
        TraditionalForm]]],
  "(with the natural association).\nThe Euclidean orthogonality induces an \
orthogonality relation between these labels."
}], "Text"],

Cell[TextData[{
  "The symmetries of a cube are generated by the axis rotations. We will call \
these the \"rectogonal\" group  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[ScriptCapitalO]", "3"], TraditionalForm]]],
  "(as a set of matrices). We will overload the action of the axis rotation \
matrices to an action of the rotation labels."
}], "Text"],

Cell[TextData[{
  "Each axis (or vector ",
  Cell[BoxData[
      FormBox["v", TraditionalForm]]],
  ") in space is naturally associated with the (counter clockwise) rotation \
",
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "v"], TraditionalForm]]],
  " about that axis. We can incorporate the magnitude if we use that for the \
angle of rotation."
}], "Text"],

Cell["\<\
This is easy and natural (see the Rofa file). It makes Euler angles obsolete \
as they are just a cover of this Lie map.\
\>", "Text"],

Cell[TextData[{
  "Pairs (dyads) of adjacent faces clearly determine the orientation of a \
block. Let   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["\[ScriptCapitalA]", "a", "2"], "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"u", ",", "v"}], ")"}], ":", "u"}], ",", 
              RowBox[{"v", "\[Element]", "\[ScriptCapitalA]"}], ",", " ", 
              RowBox[{"u", " ", "\[RightAngle]", " ", "v"}]}], "}"}]}], 
        TraditionalForm]]],
  " be this set of adjacent signed axis. These are in exact correspondence \
with ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[ScriptCapitalO]", "3"], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "We denote the unit sphere in ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[DoubleStruckCapitalR]", "3"], TraditionalForm]]],
  "by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["S", "2"], TraditionalForm]]],
  "."
}], "Text"],

Cell["All the relationships are shown in the diagram below.", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\[ScriptCapitalR]\_3\), 
              InterpretationBox[
                RowBox[{
                  AdjustmentBox[">",
                    BoxMargins->{{0.3, -0.1}, {0, 0}}], 
                  AdjustmentBox["\[LongRightArrow]",
                    BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
                
                "injection"], \(\[ScriptG] \[TildeTilde] \
\[DoubleStruckCapitalR]\^3\), " ", " "},
            {" ", " ", "\[DownArrow]", " ", " "},
            {\(\[ScriptCapitalO]\_3\), 
              InterpretationBox[
                InterpretationBox[
                  RowBox[{
                    AdjustmentBox["\[Subset]",
                      BoxMargins->{{0.3, -0.1}, {0, 0}},
                      BoxBaselineShift->-0.3], 
                    AdjustmentBox["\[LongRightArrow]",
                      BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
                  "inclusion"],
                "injection"], \(O(3)\), "  ", " "},
            {" ", " ", "\[DownArrow]", " ", " "},
            {\(\[ScriptCapitalA]\_a\%2\), 
              InterpretationBox[
                RowBox[{
                  AdjustmentBox[">",
                    BoxMargins->{{0.3, -0.1}, {0, 0}}], 
                  AdjustmentBox["\[LongRightArrow]",
                    BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
                "injection"], \(S\_\(2\ \[RightAngle]\)\%2\), 
              InterpretationBox[
                RowBox[{
                  AdjustmentBox["\[Subset]",
                    BoxMargins->{{0.3, -0.1}, {0, 0}},
                    BoxBaselineShift->-0.3], 
                  AdjustmentBox["\[LongRightArrow]",
                    BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
                "inclusion"], \(S\_2\[Times]S\_2\)}
            }], TraditionalForm]]],
  "  via ",
  Cell[BoxData[
      FormBox[GridBox[{
            {"a", " ", "a"},
            {"\[DownArrow]", " ", "\[UpArrow]"},
            {\(R\_a\), " ", \((u, v, u\[Times]v)\)},
            {\(\[DownArrow]\_\(\(first, 
                    second\)\[IndentingNewLine]\(columns\ of\ matrix\)\)\), 
              " ", "\[UpArrow]"},
            {\(\((u, v)\)\ , \ u\ \[RightAngle]\ v\), " ", \((u, v)\)}
            }], TraditionalForm]]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["positions", "Subsubsection"],

Cell[TextData[{
  "For a ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["3", "3"], TraditionalForm]]],
  " cube, we define the domain of coordinate values, and the positions of \
blocks in the cube. We use the initial positions as identifiers or labels for \
the blocks."
}], "Text"],

Cell[TextData[{
  "That is, define: ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalD]", "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], 
        TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            SuperscriptBox["\[ScriptCapitalD]", "3"], "\\", 
            RowBox[{"{", 
              UnderscriptBox["0", "_"], "}"}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalB]", "=", "\[ScriptCapitalP]"}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
To describe how a block has been moved we need where it has moved \
to and how much it has been rotated. This is a \"position with orientation\". \
These are defined as the set:\
\>", "Text"],

Cell[TextData[{
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP]\[ScriptCapitalO]\_3 = \
\[ScriptCapitalP]\[Times]\[ScriptCapitalO]\_3 \[ReverseElement] \ \((p, 
            o)\)\)]],
  "."
}], "Text"],

Cell["\<\
These are \"potential\" positions with orientation since none of \
our operations will turn an interior face into an exterior face.\
\>", \
"SmallText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["faces", "Subsubsection"],

Cell["\<\
Each cubical block has 6 (potential) faces. When the cube is in \
rectilinear 
position these can be labelled by the axis they are normal to and the sign of \

their position along that axis.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Illus:", "SmallText"],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1.0855 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics3D

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.0567234 1.16608 1.1601e-016 1.16608 [

[ 0 0 0 0 ]

[ 1 1.0855 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 1.0855 L

0 1.0855 L

closepath

clip

newpath

.5 Mabswid

[ ] 0 setdash

.50013 .59142 m .65344 .54234 L .65951 .6885 L p .555 .34 .544 r

F P

0 g

s

.65951 .6885 m .49891 .73546 L .50013 .59142 L p .555 .34 .544 r

F P

0 g

s

.63069 .69693 m

.64655 .71424 L

s

.56862 .6292 m

.5768 .63812 L

s

.40437 .47454 m .49199 .56884 L .6452 .51904 L p .663 .743 .91 r

F P

0 g

s

.47464 .73159 m .47694 .58738 L .38833 .49397 L p .957 .688 .483 r

F P

0 g

s

.6452 .51904 m .56371 .41889 L .40437 .47454 L p .663 .743 .91 r

F P

0 g

s

.52632 .3767 m

.52632 .43195 L

s

.52632 .49707 m

.52632 .51107 L

s

.66816 .6746 m .66164 .52783 L .58045 .4274 L p .973 .684 .413 r

F P

0 g

s

.38833 .49397 m .38154 .6421 L .47464 .73159 L p .957 .688 .483 r

F P

0 g

s

.29603 .65677 m

.38213 .6292 L

s

.43168 .61334 m

.44722 .60836 L

s

.39711 .65259 m .49006 .74219 L .65209 .69495 L p .647 .761 .932 r

F P

0 g

s

.55666 .57333 m .3879 .62735 L .39444 .47862 L p .531 .305 .518 r

F P

0 g

s

.39444 .47862 m .55518 .42251 L .55666 .57333 L p .531 .305 .518 r

F P

0 g

s

.58045 .4274 m .58322 .57804 L .66816 .6746 L p .973 .684 .413 r

F P

0 g

s

.62452 .5516 m

.77899 .50215 L

s

.65209 .69495 m .56601 .59946 L .39711 .65259 L p .647 .761 .932 r

F P

0 g

s

.52632 .67405 m

.52632 .82106 L

s

.38358 .42729 m

.47226 .52405 L

s

gsave

.52632 .86433 -66 -10.2813 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 20.5625 translate 1 -1 scale

63.000 12.813 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(z) show

1.000 setlinewidth

grestore

gsave

.52632 .34495 -69.3125 -10.2813 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 20.5625 translate 1 -1 scale

63.000 12.813 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(-) show

69.625 12.813 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(z) show

1.000 setlinewidth

grestore

gsave

.82351 .48789 -66 -10.2813 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 20.5625 translate 1 -1 scale

63.000 12.813 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(x) show

1.000 setlinewidth

grestore

gsave

.25961 .66843 -69.3125 -10.2813 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 20.5625 translate 1 -1 scale

63.000 12.813 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(-) show

69.625 12.813 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(x) show

1.000 setlinewidth

grestore

gsave

.66477 .73412 -66 -10.2813 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 20.5625 translate 1 -1 scale

63.000 12.813 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(y) show

1.000 setlinewidth

grestore

gsave

.35716 .39846 -69.3125 -10.2813 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 20.5625 translate 1 -1 scale

63.000 12.813 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(-) show

69.625 12.813 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000 0.000 0.000 setrgbcolor

(y) show

1.000 setlinewidth

grestore

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
  ImageSize->{288, 312.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001>1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002HOol40024Ool0095oo`@0
00Aoo`03001oo`0008Aoo`00V7oo00<007oo0000QGoo002HOol40024Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Ugoo00<007ooOol0QWoo002G
Ool00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00Igoo0P00;Woo00<007ooOol0QWoo001XOol0
0`00Oomoo`0/Ool00`00Oomoo`26Ool006Uoo`03001oogoo02]oo`03001oogoo08Ioo`00HGoo1000
0goo00<007oo0000;7oo00<007ooOol0QWoo001WOol01000Oomoo`00;7oo00<007ooOol0QWoo001V
Ool300000goo0000000[Ool00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00Ugoo00<007ooOol0
QWoo002GOol00`00Oomoo`26Ool009Moo`03001oogoo00Ioo`8007ioo`00Ugoo00<007ooOol00goo
0`000UKm00<007ooOol0Ngoo002GOol00`00Oomoo`0400000d4`001Fo@02E_d00`00Oomoo`1jOol0
06ioo`03001oogoo02Ioo`@000A1<005001FoEKmE_d00002Ool00`00Oomoo`1gOol006moo`03001o
ogoo02=oo`<000M1<003001FoEKm009Fo@04001oo`00001hOol0071oo`03001oogoo01moo`<000Y1
<003001FoEKm00=Fo@800003OZd007oo07Ioo`00LGoo00<007ooOol06goo1000344`00<005KmE_d0
15Km00<007j]0000Mgoo001bOol00`00Oomoo`0GOol4000?@C000`00E_eFo@04E_d01000OZen[@00
MWoo001cOol00`00Oomoo`0DOol3000B@C000`00E_eFo@04E_d01@00OZen[Gj]0000MGoo001dOol0
0`00Oomoo`0@Ool3000E@C000`00E_eFo@04E_d00`00OZen[@02OZd00`00Oomoo`1bOol007Aoo`03
001oogoo00eoo`<001Q1<003001FoEKm00AFo@03001n[Gj]00=n[@03001oogoo075oo`00MGoo00<0
07ooOol02Goo0`006d4`00<005KmE_d015Km00<007j]OZd017j]00<007ooOol0L7oo001fOol00`00
Oomoo`05Ool3000N@C000`00E_eFo@04E_d00`00OZen[@04OZd00`00Oomoo`1`Ool007Moo`03001o
ogoo009oo`800251<003001FoEKm00AFo@03001n[Gj]00En[@03001oogoo06moo`00N7oo10008d4`
00<005KmE_d015Km00<007j]OZd01Wj]00<007ooOol0KWoo001fOol4000U@C000`00E_eFo@04E_d0
0`00OZen[@07OZd00`00Oomoo`1]Ool007=oo`<000A1<0030011<44`0291<003001FoEKm00AFo@03
001n[Gj]00Qn[@03001oogoo06aoo`00LGoo0P00244`00<0044`@C008D4`00<005KmE_d015Km00<0
07j]OZd027j]00<007ooOol0K7oo001aOol00`00@C11<008@C000`00@C11<00P@C000`00E_eFo@04
E_d00`00OZen[@09OZd00`00Oomoo`0dOol200000goo0000000bOol0075oo`030011<44`00U1<003
0011<44`01m1<003001FoEKm00AFo@03001n[Gj]00Yn[@03001oogoo03Aoo`03001oo`0003=oo`00
LGoo00<0044`@C002T4`00<0044`@C007T4`00<005KmE_d015Km00<007j]OZd02gj]00<007ooOol0
=7oo00<007ooOol0<Woo001aOol00`00@C11<00;@C000`00@C11<00M@C000`00E_eFo@04E_d00`00
OZen[@0<OZd00`00Oomoo`0aOol200000goo0000000bOol006moo`03001oo`0000i1<0030011<44`
01a1<003001FoEKm00AFo@03001n[Gj]00en[@03001oogoo06Moo`00Kgoo0`003d4`00<0044`@C00
6d4`00<005KmE_d015Km00<007j]OZd03Gj]00<007ooOol0Igoo001_Ool00`00N/l0000?@C000`00
@C11<00K@C000`00E_eFo@04E_d00`00OZen[@0>OZd00`00Oomoo`0TOol20010Ool006moo`03001j
c`000111<0030011<44`01Y1<003001FoEKm00EFo@03001n[Gj]00in[@03001oogoo021oo`<0049o
o`00Kgoo00<007[?00004D4`00<0044`@C006D4`00<005KmE_d01EKm00<007j]OZd03gj]00<007oo
Ool077oo0`00AGoo001_Ool00`00N/l0000B@C000`00@C11<00H@C000`00E_eFo@05E_d00`00OZen
[@0@OZd00`00Oomoo`0HOol30018Ool006moo`8001A1<0030011<44`01M1<003001FoEKm00EFo@03
001n[Gj]015n[@03001oogoo01=oo`@004]oo`00Kgoo0P005D4`00<0044`@C005T4`00<005KmE_d0
1EKm00<007j]OZd04Gj]00<007ooOol047oo0`00Cgoo001_Ool2000F@C000`00@C11<00E@C000`00
E_eFo@05E_d00`00OZen[@0BOZd00`00Oomoo`0<Ool3001BOol006moo`8002i1<003001FoEKm00EF
o@03001n[Gj]01=n[@03001oogoo00Qoo`<005Eoo`00Kgoo0P00;T4`00<005KmE_d01EKm00<007j]
OZd04gj]00<007ooOol01Goo0`00F7oo001^Ool00`00N/l0000^@C000`00E_eFo@05E_d00`00OZen
[@0COZd00`00Oomoo`02Ool3001KOol006ioo`03001jc`0002i1<003001FoEKm00EFo@03001n[Gj]
01=n[@03001oo`00008005ioo`00KWoo00<007[?0000;T4`00<005KmE_d00eKm0`004gj]1000HGoo
001^Ool00`00N/l0000^@C000`00E_eFo@030002Ool00`00OZen[@0>OZd30002OZd00`00Oomoo`1P
Ool006ioo`03001jc`0002i1<0<000Eoo`03001n[Gj]00]n[@<000En[@03001oogoo061oo`00KWoo
00<007[?0000;T4`00<007ooOol01Goo00<007j]OZd02Gj]0P0027j]00<007ooOol0H7oo001^Ool0
0`00N/l0000^@C000`00Oomoo`05Ool00`00OZen[@0COZd00`00Oomoo`1POol006ioo`03001jc`00
02i1<003001oogoo00Eoo`03001n[Gj]01=n[@03001oogoo061oo`00KWoo00<007[?0000;T4`00<0
07ooOol01Goo00<007j]OZd04gj]00<007ooOol0H7oo001^Ool00`00N/l0000^@C000`00Oomoo`05
Ool00`00OZen[@0DOZd00`00Oomoo`1OOol006ioo`03001jc`0002i1<003001oogoo009oo`@001In
[@03001oogoo05moo`00KWoo00<007[?0000;D4`0P0000Aoo`00000000=5D@03001n[Gj]01An[@03
001oogoo05moo`00KWoo00<007[?0000:T4`1P001TEA00<007j]OZd057j]00<007ooOol0Ggoo001^
Ool00`00N/l0000W@C060009AE400`00OZen[@0DOZd00`00Oomoo`1OOol006ioo`03001jc`0002A1
<0H000e5D@03001n[Gj]01=n[@03001oogoo05moo`00KWoo00<007[?00008D4`1@004TEA00<007j]
OZd04Wj]00<007ooOol0Ggoo001^Ool00`00N/l0000N@C05000FAE400`00OZen[@0AOZd00`00Oomo
o`1OOol006ioo`8001a1<0D001U5D@03001n[Gj]015n[@03001oogoo05moo`00KWoo0P006D4`0`00
0goo00<004EAAE406DEA00<007j]OZd047j]00<007ooOol0Ggoo001^Ool2000F@C030006Ool00`00
AE55D@0?AE420009AE400`00OZen[@0?OZd00`00Oomoo`1OOol006ioo`8001=1<0<0009jc`03001o
ogoo00Aoo`030015DDEA00a5D@<0009C7@030015DDEA00M5D@03001n[Gj]00in[@03001oogoo05mo
o`00KGoo00<007[?0000444`0`001G[?00<007ooOol017oo00<004EAAE4024EA10001U<M00<004EA
AE401dEA00<007j]OZd03Gj]00<007ooOol0Ggoo001]Ool00`00N/l0000=@C040007N/l00`00Oomo
o`04Ool00`00AE55D@05AE43000;Dad00`00AE55D@07AE400`00OZen[@0<OZd00`00Oomoo`1OOol0
06eoo`03001jc`0000Y1<0@000Yjc`03001oogoo00Aoo`030015DDEA0095D@<000mC7@030015DDEA
00M5D@03001n[Gj]00]n[@03001oogoo05moo`00KGoo00<007[?00001d4`0`003W[?00<007ooOol0
17oo00<004EA00000P004e<M00<004EAAE401TEA00<007j]OZd02gj]00<007ooOol0Ggoo001]Ool0
0`00N/l00004@C03000AN/l00`00Oomoo`02Ool4000GDad00`00AE55D@06AE400`00OZen[@0:OZd0
0`00Oomoo`1OOol006eoo`04001jc`00@C03000DN/l00`00Ool00002000KDad00`00AE55D@07AE40
0`00OZen[@09OZd00`00Oomoo`1OOol006eoo`04001jc`00000FN/l3000ODad00`00AE55D@07AE40
0`00OZen[@08OZd00`00Oomoo`1OOol006aoo`8001Ejc`@002=C7@030015DDEA00M5D@03001n[Gj]
00Mn[@03001oogoo05moo`00J7oo100000=oo`00N/l04G[?0`00:5<M00<004EAAE401dEA00<007j]
OZd01Wj]00<007ooOol0Ggoo001UOol30005Ool00`00N/mjc`0=N/l3000/Dad00`00AE55D@07AE40
0`00OZen[@05OZd00`00Oomoo`1OOol0065oo`@000Qoo`03001jcg[?00Yjc`<0031C7@030015DDEA
00I5D@03001n[Gj]00In[@03001oogoo05ioo`00GGoo10003Goo00<007[?N/l01G[?1000=5<M00<0
04EAAE401TEA00<007j]OZd01Gj]00<007ooOol0GWoo001JOol3000BOol01000N/mjcg[?0`00>E<M
00<004EAAE401TEA00<007j]OZd017j]00<007ooOol0GWoo001FOol4000FOol3000mDad00`00AE55
D@06AE400`00OZen[@03OZd00`00Oomoo`1NOol005Aoo`8001]oo`8003iC7@030015DDEA00I5D@03
001n[Gj]009n[@03001oogoo05ioo`00LWoo0P00?U<M00<004EAAE401TEA00D007j]OZen[@00061o
o`00BWoo0P0000=oo`00000097oo0P00?U<M00<004EAAE401TEA00@007j]OZd0061oo`00AGoo1000
0Woo00<007oo00009Woo0P00?U<M00<004EAAE401DEA00@007j]OZd0061oo`00C7oo00<007ooOol0
9Woo0P00?U<M00<004EAAE401DEA00<007j]0000H7oo001:Ool200000goo0000000WOol2000ODad0
0`00DaeC7@0KDad00`00AE55D@05AE43001POol007Moo`8001iC7@03001C7E<M01aC7@030015DDEA
00A5D@03001oo`00061oo`00N7oo0P007E<M00<005<MDad07E<M00<004EAAE400dEA00<007ooOol0
H7oo001iOol2000LDad00`00DaeC7@0NDad00`00AE55D@02AE400`00Oomoo`1POol007Yoo`8001]C
7@03001C7E<M01mC7@050015DDEAAE40001ROol007aoo`03001C7E<M01QC7@03001C7E<M021C7@04
0015D@00001ROol007eoo`03001C7E<M01MC7@03001C7E<M021C7@8006Aoo`00OWoo0P005e<M00<0
05<MDad075<M1000IWoo001oOol2000FDad00`00DaeC7@0IDad4001YOol0081oo`8001EC7@03001C
7E<M01IC7@<000Aoo`03001oogoo06Ioo`00PGoo0P0055<M00<005<MDad04U<M10001goo00<007oo
Ool0IWoo0022Ool2000CDad00`00DaeC7@0?Dad3000<Ool00`00Oomoo`1UOol008=oo`80019C7@03
001C7E<M00aC7@<0011oo`03001oogoo06Aoo`00Q7oo0P004E<M00<005<MDad025<M1000NWoo0025
Ool2000@Dad00`00DaeC7@05Dad3000JOol2001ROol008Ioo`8000mC7@03001C7E<M009C7@<001io
o`03001oogoo061oo`00Qgoo0P003U<M1@008Woo00<007ooOol0Ggoo0028Ool2000;Dad3000UOol0
0`00Ool0001POol008Yoo`03001C7E<M00EC7@<0009oo`03001oogoo029oo`04001oogoo001POol0
08]oo`03001C7E<M00@000Eoo`03001oogoo025oo`<00003Ool0000005moo`00S7oo0P002Goo00<0
07ooOol0QWoo002GOol00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00Ugoo00<007ooOol0QWoo
002GOol00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00Ugoo00<007ooOol0QWoo002GOol00`00
Oomoo`26Ool009Moo`03001oogoo08Ioo`00Ugoo00<007ooOol0QWoo002GOol00`00Oomoo`26Ool0
09Moo`03001oogoo08Ioo`00Ugoo00<007ooOol0QWoo002GOol00`00Oomoo`26Ool009Moo`03001o
ogoo08Ioo`00Ugoo00<007ooOol0QWoo002GOol00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00
Ugoo00<007ooOol0QWoo002GOol00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00Ugoo00<007oo
Ool0QWoo002GOol00`00Oomoo`26Ool009Moo`03001oogoo08Ioo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00UGoo1000
Qgoo002FOol00`00Ool00027Ool009Eoo`03001oo`0008Qoo`00UGoo1000Qgoo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{80.5, 309.875}, {627.375, 378.375}} -> {-0.252332, \
1.41463, 0.00299102, 0.00299102}}]
}, Closed]],

Cell[TextData[{
  "There are 6 faces of the cube which we label with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalF]\^+\) = {f\_x, f\_y, f\_z}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] = \
\(\[PlusMinus]\(\[ScriptCapitalF]\^+\)\)\)]],
  ". They have the obvious association with (signed) axis labels."
}], "Text"],

Cell[TextData[{
  "The rotations act naturally on the faces (just apply them to the vector \
associated with ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["color", "Subsubsection"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalK]", TraditionalForm]]],
  " be the set of colors (labels). When the cube is solved, each face has one \
color, thus there is an association: ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", ":", 
          RowBox[{"\[ScriptCapitalF]", 
            UnderscriptBox["\[LongRightArrow]", "~"], "\[ScriptCapitalK]"}]}],
         TraditionalForm]]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["face map", "Subsubsection"],

Cell[TextData[{
  "Each block (or position ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalP]", TraditionalForm]]],
  ") in the cube has either 1,2 or 3 faces showing. Define this map from \
positions to sets of exterior faces by:"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"F", ":", 
          RowBox[{
            RowBox[{"p", "\[RightTeeArrow]", 
              RowBox[{"{", 
                RowBox[{
                  SubscriptBox["p", "i"], 
                  RowBox[{
                    SubscriptBox["f", "i"], ":", " ", 
                    RowBox[{
                      SubscriptBox["p", "i"], "\[NotEqual]", "0"}]}]}], " ", 
                "}"}]}], ":", 
            RowBox[{"\[ScriptCapitalP]", 
              InterpretationBox[
                RowBox[{
                  AdjustmentBox[">",
                    BoxMargins->{{0.3, -0.3}, {0, 0}}], 
                  AdjustmentBox["\[LongRightArrow]",
                    BoxMargins->{{-0.3, 0.3}, {0, 0}}]}],
                injection], 
              RowBox[{
              "\[DoubleStruckCapitalP]", "(", "\[ScriptCapitalF]", 
                ")"}]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "For the ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["3", "3"], TraditionalForm]]],
  " cube each position is clearly determined by the faces it has, which \
justifies the injection arrow. This is only an injection in 3 D!"
}], "Text"],

Cell[TextData[{
  "Thus given ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "\[Element]", 
          RowBox[{"Im", "(", "F", ")"}]}], TraditionalForm]]],
  " we can determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", "=", 
          RowBox[{
            SuperscriptBox["F", 
              RowBox[{"-", "1"}]], "(", "A", ")"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "We use this to drop the ",
  Cell[BoxData[
      FormBox["b", TraditionalForm]]],
  " from our ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ScriptCapitalQ]", "\[ReverseElement]", "Q"}], "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"p", ",", "f", ",", "k"}], ")"}], ":"}], "}"}]}], 
        TraditionalForm]]],
  " vs ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"b", ",", "p", ",", "f", ",", "k"}], ")"}], ":"}], 
            "}"}], " "}], TraditionalForm]]],
  "needed in 4 D."
}], "SmallText"],

Cell[TextData[{
  "To exploit this further in the repn we'd need some way of dropping the ",
  Cell[BoxData[
      FormBox["p", TraditionalForm]]],
  " from configuration,\nbut still need to cluster the faces. Could use ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ScriptCapitalQ]", "\[ReverseElement]", "Q"}], "=", 
          RowBox[{"{", " ", 
            RowBox[{"A", "=", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"f", ",", "k"}], ")"}], "=", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"o", ".", 
                            RowBox[{"f", "'"}]}], ",", 
                          RowBox[{"K", "(", 
                            RowBox[{"f", "'"}], ")"}]}], ")"}], ":", 
                      RowBox[{
                        RowBox[{"f", "'"}], "\[Element]", 
                        RowBox[{"F", "(", "b", ")"}]}]}]}], "}"}], ":", " ", 
                "b"}]}], "}"}]}], TraditionalForm]]],
  "."
}], "SmallText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["potential configurations", "Subsubsection"],

Cell[TextData[{
  "If the cube is taken apart, the blocks shuffled and placed back in a cube, \
then the result is described by listing where each block is together with its \
orientation. Thus the potential configurations are just the set of maps ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\([\)\(\[ScriptCapitalB]\[LongRightArrow]\
\[ScriptCapitalP]\[ScriptCapitalO]\_3\)\(]\)\)\)\)]],
  ". We will denote configuration maps by ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ".\nInitially ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_0\) : b \[RightTeeArrow] \((b, I)\)\)]],
  " ( ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(I\)\)\)]],
  " the identity matrix or rotation)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["group", "Subsubsection"],

Cell[TextData[{
  "The basic actions on Rubik's cube, the ",
  StyleBox["generators",
    FontSlant->"Italic"],
  ", each act on one slice. \nEach slice is determined by the axis thru it \
and how far along the axis it is, i.e. ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"s", ",", "r"}], ")"}], "\[Element]", 
          RowBox[{"\[ScriptCapitalD]", "\[Times]", 
            SubscriptBox["\[ScriptCapitalR]", "3"]}]}], TraditionalForm]]],
  ".\nWe will use ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["g", 
          RowBox[{"r", ",", "s"}]], TraditionalForm]]],
  " to label these generators and let ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalR]", TraditionalForm]]],
  " be the set of them. The rotation of the generator is counter clockwise \
about the axis of an outer face or the positive axis for a middle slice. Thus \
the axis of the rotation is ",
  Cell[BoxData[
      FormBox["r", TraditionalForm]]],
  " regarded as an element of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[ScriptCapitalR]", "3"], TraditionalForm]]],
  " and the rotation is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"R", "(", 
            SubscriptBox["g", 
              RowBox[{"r", ",", "s"}]], ")"}], "=", 
          SubscriptBox["R", "r"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The slice of a generator is the domain or set of positions it changes. \
Define these by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"P", "(", 
            SubscriptBox["g", 
              RowBox[{
                SubscriptBox["r", "i"], ",", "s"}]], ")"}], "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"p", "\[Element]", 
                RowBox[{"\[ScriptCapitalP]", ":", 
                  SubscriptBox["p", "i"]}]}], "=", 
              RowBox[{
                RowBox[{"sgn", "(", "r", ")"}], " ", "s"}]}], "}"}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The action of the generator ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{
            SubscriptBox["g", 
              RowBox[{"r", ",", "s"}]], Cell[""]}]}], TraditionalForm]]],
  "on oriented positions is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", " ", ".", 
            RowBox[{"(", " ", 
              RowBox[{"(", 
                RowBox[{"p", ",", "o"}], ")"}], " ", ")"}]}], " ", "=", " ", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"r", ".", "p"}], ",", 
                      RowBox[{"r", 
                        OverscriptBox["\[SmallCircle]", "\[LeftVector]"], 
                        "o"}]}], ")"}], 
                  RowBox[{
                    RowBox[{"p", "\[Element]", 
                      RowBox[{"P", "(", "g", ")"}]}], ",", " ", 
                    RowBox[{"r", "=", 
                      RowBox[{"R", "(", "g", ")"}]}]}]},
                {
                  RowBox[{"(", 
                    RowBox[{"p", ",", "o"}], ")"}], "otherwise"}
                }]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Thus we have a map ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalR]", "\[LongRightArrow]", " ", 
          RowBox[{"[", 
            RowBox[{
              SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"], 
              "\[LongRightArrow]", 
              SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"]}], 
            "]"}]}], TraditionalForm]]],
  " ."
}], "Text"],

Cell[TextData[{
  "Doing operations in succession we build up more complex transformations of \
the cube. We'll denote these by ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalG]", TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Thus we have a map ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalG]", "\[LongRightArrow]", " ", 
          RowBox[{"[", 
            RowBox[{
              SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"], 
              "\[LongRightArrow]", 
              SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"]}], 
            "]"}]}], TraditionalForm]]],
  " . These immediately apply to sets of oriented positions or configurations \
of the cube. We say that \"hom\" or  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"[", 
          RowBox[{"\[ScriptCapitalB]", "\[LongRightArrow]"}], "  ", "]"}], 
        TraditionalForm]]],
  "  induces the interpretation of the operations as acting on cubes by:\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalG]", "\[LongRightArrow]", " ", 
          RowBox[{"[", 
            RowBox[{
              RowBox[{"[", 
                RowBox[{"\[ScriptCapitalB]", "\[LongRightArrow]", 
                  SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"]}], 
                "]"}], "\[LongRightArrow]", 
              RowBox[{"[", 
                RowBox[{"\[ScriptCapitalB]", "\[LongRightArrow]", 
                  SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"]}], 
                "]"}]}], "]"}]}], TraditionalForm]]],
  ".\n"
}], "Text"],

Cell[TextData[{
  "Note if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] : G\[LongRightArrow]S\_X\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(Y, \[Rho]\)\(]\)\) : 
        G\[LongRightArrow]S\_\(\([\)\(Y, X\)\(]\)\)\)]],
  " has ",
  Cell[BoxData[
      \(TraditionalForm\`ker(\([\)\(Y, \[Rho]\)\(]\)) = \({g : \[ForAll] \ \
\(f : Y\) \[Rule] X, \ y, 
            f(y) = \(\((g . f)\) \((y)\) = 
                g . \(f(y)\)\)} = {g : \[ForAll] \ x\ g . x = x}\)\)]],
  ",\nso equally faithfull. In this case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is faithfull by definition of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\)]],
  "."
}], "SmallText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["configurations", "Subsubsection"],

Cell[TextData[{
  "The orbit of a set of operations is the set of elements we can reach. \
Working back from the solved cube, each configuration must be in the orbit \
under the operations ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalG]", TraditionalForm]]],
  " that we can construct."
}], "Text"],

Cell[TextData[{
  " Define the geometric configurations of the cube as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalC]", "=", 
          RowBox[{"\[ScriptCapitalG]", ".", 
            SubscriptBox["c", "0"]}]}], TraditionalForm]]],
  " - the orbit of the initial configuration. "
}], "Text"],

Cell[TextData[{
  "We have the inclusion  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalC]", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                AdjustmentBox["\[Subset]",
                  BoxMargins->{{0.3, -0.1}, {0, 0}},
                  BoxBaselineShift->-0.3], 
                AdjustmentBox["\[LongRightArrow]",
                  BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
              "inclusion"], "    ", "[", 
            RowBox[{"\[ScriptCapitalB]", "\[LongRightArrow]", 
              SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"]}], 
            "]"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Now we can restrict the action to the (allowed) configurations:\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalG]", "\[LongRightArrow]", " ", 
          RowBox[{"[", 
            RowBox[{
            "\[ScriptCapitalC]", "\[LongRightArrow]", "\[ScriptCapitalC]"}], 
            "]"}]}], TraditionalForm]]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["mini/block facial configurations", "Subsubsection"],

Cell[TextData[{
  "The exterior mini/blockfaces of are the same for all configurations, they \
are ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP]\[ScriptCapitalF] = \(\[Union]\+\(p \
\[Element] \[ScriptCapitalP]\)\ {p}\[Times]\(F(p)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Each rubik generator induces an action on these mini-faces: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", "(", " ", 
            RowBox[{"(", 
              RowBox[{"p", ",", "f"}], ")"}], ")"}], "=", 
          RowBox[{"{", " ", GridBox[{
                {
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"r", ".", "p"}], ",", 
                      RowBox[{"r", ".", "f"}]}], ")"}], 
                  RowBox[{
                    RowBox[{"p", "\[Element]", 
                      RowBox[{"P", "(", "g", ")"}]}], ",", " ", 
                    RowBox[{"r", "=", 
                      RowBox[{"r", "(", "g", ")"}]}]}]},
                {
                  RowBox[{"(", 
                    RowBox[{"p", ",", "f"}], ")"}], 
                  RowBox[{"p", "\[NotElement]", 
                    RowBox[{"P", "(", "g", ")"}]}]}
                }]}]}], TraditionalForm]]],
  ",\nand thus an action of ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalG]", TraditionalForm]]],
  "  , since if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["g", 
              RowBox[{"r", ",", "s"}]], "(", 
            RowBox[{"p", ",", "o"}], ")"}], "=", 
          RowBox[{"(", 
            RowBox[{"p", ",", "o"}], ")"}]}], TraditionalForm]]],
  " then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["g", 
              RowBox[{"r", ",", "s"}]], "(", 
            RowBox[{"p", ",", "f"}], ")"}], "=", 
          RowBox[{"(", 
            RowBox[{"p", ",", "f"}], ")"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "This induces an action on mini-face configurations ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\[LongRightArrow]\([\ \ \ \ \([\
\[ScriptCapitalP]\[ScriptCapitalF] \[Rule] \ \[ScriptCapitalP]\
\[ScriptCapitalF]]\)\ \ , \ \ \ \([\[ScriptCapitalP]\[ScriptCapitalF] \[Rule] \
\ \[ScriptCapitalP]\[ScriptCapitalF]]\)\ \ \ ]\)\)]],
  ".\nThe mini-face configurations that can be realized are the orbit of the \
solved cube ( the identity map on ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP]\[ScriptCapitalF]\)]],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM] = \[ScriptCapitalG] . I\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["colored mini/block facial configurations", "Subsubsection"],

Cell["\<\
Finally we will reduce to an action on the colored faces \
alone.\
\>", "Text"],

Cell[TextData[{
  "The colored mini-faces of a configuration are the exterior colored faces \
of all the blocks in it. Define \n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Koppa]", ":", 
          RowBox[{"\[ScriptCapitalC]", "\[LongRightArrow]", 
            RowBox[{"\[DoubleStruckCapitalP]", "(", 
              RowBox[{
              "\[ScriptCapitalP]", "\[Times]", "\[ScriptCapitalF]", 
                "\[Times]", "\[ScriptCapitalK]"}], " ", ")"}]}]}], 
        TraditionalForm]]],
  " by:\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Koppa]", "(", "c", ")"}], "=", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"p", ",", 
                      RowBox[{"o", "(", 
                        RowBox[{"f", "'"}], ")"}], ",", 
                      RowBox[{"K", "(", 
                        RowBox[{"f", "'"}], ")"}]}], ")"}], ":", " ", 
                  RowBox[{"\[Exists]", " ", 
                    RowBox[{"b", "\[Element]", "\[ScriptCapitalB]"}]}]}], ",",
                 
                RowBox[{
                  RowBox[{"f", "'"}], "\[Element]", 
                  RowBox[{"F", "(", "b", ")"}]}], ",", " ", 
                RowBox[{
                  RowBox[{"c", "(", "b", ")"}], "=", 
                  RowBox[{"(", 
                    RowBox[{"p", ",", "o"}], ")"}]}]}], "}"}], "\[Element]", 
            RowBox[{"\[DoubleStruckCapitalP]", "(", 
              RowBox[{
              "\[ScriptCapitalP]", "\[Times]", "\[ScriptCapitalF]", 
                "\[Times]", "\[ScriptCapitalK]"}], " ", ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Define the facial configurations as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalQ]", "=", 
          RowBox[{"Im", " ", "\[Koppa]"}]}], TraditionalForm]]],
  " with elements denoted by ",
  Cell[BoxData[
      FormBox["Q", TraditionalForm]]],
  ". In our implementation we type the colored mini-face or block-face \
triples as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"q", "(", 
          RowBox[{"p", ",", "f", ",", "k"}], ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell["Each generator has a simple action on mini-faces.", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", ".", " ", 
            RowBox[{"(", " ", 
              RowBox[{"(", 
                RowBox[{"p", ",", "f", ",", "k"}], ")"}], " ", ")"}]}], " ", 
          "=", " ", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"r", ".", "p"}], ",", 
                      RowBox[{"r", ".", "f"}], ",", "k"}], ")"}], 
                  RowBox[{
                    RowBox[{"p", "\[Element]", 
                      RowBox[{"P", "(", "g", ")"}]}], ",", 
                    RowBox[{"r", "=", 
                      RowBox[{"R", "(", "g", ")"}]}]}]},
                {
                  RowBox[{"(", 
                    RowBox[{"p", ",", "f", ",", "k"}], ")"}], "otherwise"}
                }]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "This induces an action of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\)]],
  " on colored mini-faces and an action on sets of colored mini-faces, i.e. \
on colored mini-face configurations."
}], "Text"],

Cell[TextData[{
  " These actions agree with those on mini-faces ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP]\[ScriptCapitalF]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Given two mini-faces ",
  Cell[BoxData[
      \(TraditionalForm\`\((b, f, k)\)\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, f', k')\)\)]],
  ", many valid operations will send one to the other . Thus we do not know \
ab-initio what the permutation of mini-faces is. To identify where faces came \
we need not only their own color, but also the color of their neighbours. \
Next we explore the relation between configurations and mini-face \
configurations. This will give us a direct way of determining permutations of \
mini-faces from colored mini-face configurations."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["From configurations to mini-face configurations.", "Subsubsection"],

Cell["Realizing functions as relations we have the map:", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalC]", " ", 
          InterpretationBox[
            RowBox[{
              AdjustmentBox["\[Subset]",
                BoxMargins->{{0.3, -0.1}, {0, 0}},
                BoxBaselineShift->-0.3], 
              AdjustmentBox["\[LongRightArrow]",
                BoxMargins->{{-0.3, 0.1}, {0, 0}}]}],
            "inclusion"], 
          " ", \(\[DoubleStruckCapitalP](\[ScriptCapitalB]\[Times]\
\[ScriptCapitalP]\[ScriptCapitalO]\_3)\)}], TraditionalForm]]],
  "."
}], "Text"],

Cell["Next we extract the minifaces from the relation.", "Text"],

Cell[TextData[{
  "Define  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", ":", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"b", ",", 
                RowBox[{"(", 
                  RowBox[{"p", ",", "o"}], ")"}]}], ")"}], "\[RightTeeArrow]",
             
            RowBox[{"{", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"p", ",", 
                    RowBox[{"o", ".", 
                      RowBox[{"f", "'"}]}], ",", 
                    RowBox[{"K", "(", 
                      RowBox[{"f", "'"}], ")"}]}], ")"}], ":", "  ", 
                RowBox[{
                  RowBox[{"f", "'"}], "\[Element]", 
                  RowBox[{"F", "(", "b", ")"}]}]}], " ", "}"}]}]}], 
        TraditionalForm]]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"p", ",", "f", ",", "k"}], ")"}], ":", " ", 
                RowBox[{"\[Exists]", " ", 
                  RowBox[{
                    RowBox[{"f", "'"}], "\[Element]", 
                    RowBox[{"F", "(", "b", ")"}]}]}]}], ",", "  ", 
              RowBox[{
                RowBox[{"o", ".", 
                  RowBox[{"f", "'"}]}], "=", "f"}], ",", 
              RowBox[{
                RowBox[{"K", "(", 
                  RowBox[{"f", "'"}], ")"}], "=", "k"}]}], " ", "}"}]}], 
        TraditionalForm]]],
  ", so ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", ":", 
          RowBox[{"\[ScriptCapitalB]", "\[Times]", 
            RowBox[{
              RowBox[{"(", 
                SubscriptBox["\[ScriptCapitalP]\[ScriptCapitalO]", "3"], 
                ")"}], "\[LongRightArrow]", 
              RowBox[{"\[DoubleStruckCapitalP]", "(", 
                RowBox[{
                "\[ScriptCapitalP]", "\[Times]", "\[ScriptCapitalF]", 
                  "\[Times]", "\[ScriptCapitalK]"}], ")"}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Thus each element ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"b", ",", 
              RowBox[{"(", 
                RowBox[{"p", ",", "o"}], ")"}]}], ")"}], "\[Element]", "c"}], 
        TraditionalForm]]],
  " of the configuration goes to a cluster of mini-faces. Colored mini-face \
configurations just flatten these clusters. Thus we can decompose ",
  Cell[BoxData[
      FormBox["\[CapitalKoppa]", TraditionalForm]]],
  " as  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalKoppa]", ":", 
          RowBox[{
            RowBox[{"c", "\[RightTeeArrow]", 
              RowBox[{
                UnderscriptBox["\[Union]", 
                  RowBox[{"b", "\[Element]", "\[ScriptCapitalB]"}]], " ", 
                RowBox[{"S", " ", 
                  RowBox[{"(", " ", 
                    RowBox[{"(", 
                      RowBox[{"b", ",", 
                        RowBox[{"c", "(", "b", ")"}]}], ")"}], " ", 
                    ")"}]}]}]}], ":", 
            RowBox[{
            "\[ScriptCapitalC]", "\[LongRightArrow]", 
              "\[ScriptCapitalQ]"}]}]}], TraditionalForm]]],
  ". We will use this to regroup colored mini-faces in a configuration."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
From colored mini-face configurations to mini-face configurations\
\
\>", "Subsubsection"],

Cell[TextData[{
  "First we check that given ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"q", "(", 
            RowBox[{"p", ",", 
              RowBox[{"f", "'"}], ",", 
              RowBox[{"k", "'"}]}], ")"}], "\[Element]", "Q", "\[Element]", 
          "\[ScriptCapitalQ]"}], TraditionalForm]]],
  " we can determine the block it came from."
}], "Text"],

Cell[TextData[{
  "Given ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "=", 
          RowBox[{"S", "(", 
            RowBox[{"(", 
              RowBox[{"b", ",", 
                RowBox[{"(", 
                  RowBox[{"p", ",", "o"}], ")"}]}], ")"}], " ", ")"}]}], 
        TraditionalForm]]],
  ", form (overloading) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"F", "(", "A", ")"}], "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                SuperscriptBox["K", 
                  RowBox[{"-", "1"}]], "(", "k", ")"}], ":", " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"p", ",", "_", ",", "k"}], ")"}], "\[Element]", 
                "A"}]}], "}"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"b", "'"}], "=", 
          RowBox[{
            SuperscriptBox["F", 
              RowBox[{"-", "1"}]], "(", 
            RowBox[{"F", "(", "A", ")"}], ")"}]}], TraditionalForm]]],
  " then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"b", "'"}], "=", "b"}], TraditionalForm]]],
  ". \nNow the mini-face ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"p", ",", 
              RowBox[{"f", "'"}], ",", "k"}], ")"}], "\[Element]", "Q"}], 
        TraditionalForm]]],
  " must be mapped from the initial ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"b", ",", "f", ",", "k"}], ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  " Thus we have the map: ",
  Cell[BoxData[
      \(TraditionalForm\`o : \(F(b)\)\[LongRightArrow]\(F(p)\)\)]],
  ". Thus we have all the images ",
  Cell[BoxData[
      \(TraditionalForm\`\((b, f')\) \[RightTeeArrow] \ \((p, f)\)\)]],
  "  which is exactly a mini-face configuration. Given a min-face \
configuration, we can get the color of each face from ",
  Cell[BoxData[
      \(TraditionalForm\`\((b, f')\) \[RightTeeArrow] \((p, f)\), \ 
      K(f') = k\)]],
  " gives that the mini-face ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, f)\)\)]],
  " must have color ",
  Cell[BoxData[
      \(TraditionalForm\`K(f')\)]],
  ". Thus we have ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalQ] \[TildeTilde] \
\[ScriptCapitalM]\)]],
  "."
}], "Text"],

Cell["This allows us to simply work with colored mini-faces.", "Text"],

Cell[TextData[{
  "NB  This fails for the ",
  Cell[BoxData[
      \(TraditionalForm\`4\^3\)]],
  " cube. There may be two Rubik cube problems- return the cube to the look \
like the solved cube (but middle faces of the same color may be permuted- you \
cant tell), or return the faces of the cube to their solved position ( for \
which you would need marks to distinguish for example the 4 blue middle faces \
from each other). T he group theory methods we develop willl be able to \
determine whether these are in fact different problems."
}], "SmallText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Relation between configurations and mini-face configurations.\
\>", \
"Subsubsection"],

Cell["\<\
Given a colored mini-face configuration (or a mini-face \
configuration since we know they're equivalent), we cant necessarily \
determine the configuration. Look more closely at what we know about the \
orientation of a block. \
\>", "Text"],

Cell[TextData[{
  "Consider ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalLambda](
          A) = {\((\(K\^\(-1\)\)(k), f)\) : \ \((_, f, k)\) \[Element] 
                A} \[SubsetEqual] \
\[ScriptCapitalF]\[Times]\[ScriptCapitalF]\)]],
  " . This is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalLambda](
          A) = \({\((f', o . f')\) : 
              f' \[Element] 
                F(b)} = \[CapitalGamma]\_\(f' \[RightTeeArrow] o . f, \ \(\(|\
\)\(F(b)\)\)\)\)\)]],
  " the graph of ",
  Cell[BoxData[
      \(TraditionalForm\`o\)]],
  " on the faces of ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " s.t. ",
  Cell[BoxData[
      \(TraditionalForm\`# \( F(b)\) \[GreaterEqual] \ 2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_\(f' \[RightTeeArrow] o . f, \ \
\(\(|\)\(F(b)\)\)\)\)]],
  " uniquely determines ",
  Cell[BoxData[
      \(TraditionalForm\`o\)]],
  " (because we have at least a dyad of faces).\nFor ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " s.t. ",
  Cell[BoxData[
      \(TraditionalForm\`# \( F(b)\) = 1\)]],
  ", a cylinder of different ",
  Cell[BoxData[
      \(TraditionalForm\`o\)]],
  "'s determine the same ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " value, i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`S(\((b, \((p, R\_b\%j . o)\))\)), \ 
      j = 0, \[Ellipsis], 3\)]],
  "."
}], "Text"],

Cell["\<\
That is, we can not determine whether a middle block has been \
rotated simply by looking at its one exterior face.\
\>", "Text"],

Cell["\<\
It is possible that the cube looks solved, but in fact some of the \
middle faces have been rotated. Again the group theory methods we develop \
will lets us see if this can really happen.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
CellGrouping->Manual,
WindowSize->{577, 472},
WindowMargins->{{Automatic, 99}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 31, 0, 98, "Title"],

Cell[CellGroupData[{
Cell[1773, 53, 42, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[1840, 57, 37, 0, 42, "Subsubsection"],
Cell[1880, 59, 227, 6, 48, "Text"],
Cell[2110, 67, 626, 16, 78, "Text"],
Cell[2739, 85, 495, 12, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3271, 102, 29, 0, 42, "Subsubsection"],
Cell[3303, 104, 1531, 54, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4871, 163, 63, 0, 42, "Subsubsection"],
Cell[4937, 165, 343, 9, 30, "Text"],
Cell[5283, 176, 332, 10, 30, "Text"],
Cell[5618, 188, 1368, 37, 81, "Text"],
Cell[6989, 227, 366, 8, 62, "Text"],
Cell[7358, 237, 372, 11, 46, "Text"],
Cell[7733, 250, 144, 3, 46, "Text"],
Cell[7880, 255, 765, 21, 62, "Text"],
Cell[8648, 278, 267, 10, 30, "Text"],
Cell[8918, 290, 69, 0, 30, "Text"],
Cell[8990, 292, 2286, 54, 121, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11313, 351, 34, 0, 42, "Subsubsection"],
Cell[11350, 353, 293, 8, 46, "Text"],
Cell[11646, 363, 662, 23, 30, "Text"],
Cell[12311, 388, 201, 4, 46, "Text"],
Cell[12515, 394, 220, 7, 30, "Text"],
Cell[12738, 403, 162, 4, 26, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12937, 412, 30, 0, 42, "Subsubsection"],
Cell[12970, 414, 215, 6, 62, "Text"],

Cell[CellGroupData[{
Cell[13210, 424, 27, 0, 26, "SmallText"],
Cell[13240, 426, 14722, 566, 321, 4575, 436, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[27977, 995, 362, 9, 43, "Text"],
Cell[28342, 1006, 178, 6, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28557, 1017, 30, 0, 42, "Subsubsection"],
Cell[28590, 1019, 440, 13, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29067, 1037, 33, 0, 42, "Subsubsection"],
Cell[29103, 1039, 244, 6, 46, "Text"],
Cell[29350, 1047, 953, 27, 30, "Text"],
Cell[30306, 1076, 266, 7, 46, "Text"],
Cell[30575, 1085, 388, 14, 30, "Text"],
Cell[30966, 1101, 702, 24, 26, "SmallText"],
Cell[31671, 1127, 1136, 28, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32844, 1160, 49, 0, 42, "Subsubsection"],
Cell[32896, 1162, 719, 17, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33652, 1184, 30, 0, 42, "Subsubsection"],
Cell[33685, 1186, 1373, 39, 96, "Text"],
Cell[35061, 1227, 638, 19, 46, "Text"],
Cell[35702, 1248, 1280, 36, 76, "Text"],
Cell[36985, 1286, 422, 12, 30, "Text"],
Cell[37410, 1300, 219, 6, 46, "Text"],
Cell[37632, 1308, 1362, 33, 94, "Text"],
Cell[38997, 1343, 717, 21, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39751, 1369, 39, 0, 42, "Subsubsection"],
Cell[39793, 1371, 302, 7, 46, "Text"],
Cell[40098, 1380, 312, 8, 30, "Text"],
Cell[40413, 1390, 671, 18, 30, "Text"],
Cell[41087, 1410, 363, 10, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41487, 1425, 57, 0, 42, "Subsubsection"],
Cell[41547, 1427, 274, 7, 31, "Text"],
Cell[41824, 1436, 1678, 49, 59, "Text"],
Cell[43505, 1487, 673, 15, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44215, 1507, 65, 0, 42, "Subsubsection"],
Cell[44283, 1509, 89, 3, 30, "Text"],
Cell[44375, 1514, 1713, 43, 62, "Text"],
Cell[46091, 1559, 518, 16, 46, "Text"],
Cell[46612, 1577, 65, 0, 30, "Text"],
Cell[46680, 1579, 965, 27, 43, "Text"],
Cell[47648, 1608, 239, 6, 46, "Text"],
Cell[47890, 1616, 166, 5, 30, "Text"],
Cell[48059, 1623, 618, 13, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48714, 1641, 73, 0, 42, "Subsubsection"],
Cell[48790, 1643, 65, 0, 30, "Text"],
Cell[48858, 1645, 560, 16, 30, "Text"],
Cell[49421, 1663, 64, 0, 30, "Text"],
Cell[49488, 1665, 2029, 58, 46, "Text"],
Cell[51520, 1725, 1260, 33, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52817, 1763, 100, 3, 42, "Subsubsection"],
Cell[52920, 1768, 383, 11, 30, "Text"],
Cell[53306, 1781, 1577, 53, 62, "Text"],
Cell[54886, 1836, 784, 23, 62, "Text"],
Cell[55673, 1861, 70, 0, 30, "Text"],
Cell[55746, 1863, 558, 10, 69, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56341, 1878, 96, 3, 42, "Subsubsection"],
Cell[56440, 1883, 252, 5, 62, "Text"],
Cell[56695, 1890, 646, 21, 46, "Text"],
Cell[57344, 1913, 844, 31, 66, "Text"],
Cell[58191, 1946, 139, 3, 46, "Text"],
Cell[58333, 1951, 212, 4, 46, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

