(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11141,        387]*)
(*NotebookOutlinePosition[     12743,        440]*)
(*  CellTagsIndexPosition[     12673,        434]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik Check Start", "Title",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Presumptions", "Subsection"],

Cell[CellGroupData[{

Cell["Basic parameters.", "Subsubsection"],

Cell["\<\
If called from \"Start Rubik Window\", the Tools Check will already have been \
called, so Tools paths and \"ToolsPathSep\" are set
and the basic utility has been loaded (\"WarningWindowFns.m\"  ).\
\>", "Text"],

Cell["\<\
This must also assume that the caller has set \"RubikPkPathSep\" to  this \
directory path (as this file cannot determine its directory when being read).\
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic utilities", "Subsubsection"],

Cell["\<\
This file also assumes that the particular files listed in the implementation \
notes under \"Location of files\" are in place.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Location of files", "Subsubsection"],

Cell["\<\
Files used: (in addition to the Tools Check and WarningWindow discussed \
above):\
\>", "Text"],

Cell["\<\
ToolsFolder:UtilitiesFolder:SplitString.m
ToolsFolder:NBFolder:NBDirectoryPk/Fns.m
ToolsFolder:Graphics:Rofa.m,DirectDisplayPk/Fns.m\
\>", "Text"],

Cell["\<\
And in the same directory \"RubikPkPathSep\" as this \"Rubik Package.m\" \
file:\
\>", "Text"],

Cell["\<\
RubikGraphicsPk/Fns.m
RubikInterfacePk/Fns.m
RubikUserButtonsPk/Fns.m
RubikMakeWindowPk/Fns.m\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Autonomous Check for basic utilities:must assume loaded!", "SmallText"],

Cell["\<\
But this cant get its own directory when it is being read!-so drop this\
\>", "Text"],

Cell[CellGroupData[{

Cell["Check when direct read (not from the \"Start Rubik Window\")", \
"Subsubsection"],

Cell["\<\
If read directly (and not by \"Start Rubik Window\")
it assumes that the ToolsCheckPk.m  file is in the same directory.\
\>", "Text"],

Cell["\<\
It cannot get its own directory- so it cant set system paths or the \
ToolsPathSep parameter. It could look inside its own directory for these with \
\"Get\" but it cannot use any other file checking as it cant set the \
directory.\
\>", "Text"],

Cell["\<\
The ToolsCheck[ToolsPathSep_] assumes that 
a Tools directory structure with the basic utilities exists in the \
ToolsPathSep folder.\
\>", "Text"],

Cell["\<\
When this has been estabished, $Path is set and we have a valid \
\"ToolsPathSep\" pointing to the requisite tools folder
and the \"Warning Window.m\" is loaded.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Check init tools:when being read", "Subsubsection"],

Cell["\<\
Assume that ToolsCheck.m is in this same folder ,
(else assume this notebook is open so it must be in development when tools \
are 
ok).\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
If 
\tToolsPathSep has not been set 
\t\tor the WarningWindow utility is not loaded, 
\tand this file is being read as input (by a \"Gets\")
then
   Get the ToolsCheck package from where this was read.
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"If", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"Not", "[", 
              RowBox[{"StringQ", "[", "ToolsPathSep", "]"}], "]"}], "||", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"DownValues", "[", "CheckFileExists", "]"}], "===", 
                RowBox[{"{", "}"}]}], ")"}]}], ",", 
          RowBox[{"If", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"StringQ", "[", "$Input", "]"}], "&&", 
                RowBox[{"Not", "[", 
                  RowBox[{
                    RowBox[{"StringPosition", "[", 
                      RowBox[{"$Input", ",", "\"\<RubikCheckStart.m\>\""}], 
                      "]"}], "\[Equal]", 
                    RowBox[{"{", "}"}]}], "]"}]}], ",", 
              RowBox[{"Get", "[", 
                RowBox[{"\"\<ToolsCheckPk.m\>\"", ",", 
                  RowBox[{"Path", "->", 
                    RowBox[{"ToFileName", "[", 
                      RowBox[{"DirectoryName", "[", "$Input", "]"}], 
                      "]"}]}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
        "]"}], ";"}]], "Input"]
}, Closed]],

Cell["Now we should have the minimal tools", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Get this directory:RubikPkPathSep", "Subsubsection"],

Cell["\<\
Assume that the files read below are in this same directory.
Get this global parameter for use in the package.\
\>", "Text"],

Cell["But $Input may only be relative on a nested Get!!!", "SmallText"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RubikPkPathSep", "=", 
        RowBox[{"GetDirPath", "[", "\"\<RubikCheckStart\>\"", "]"}]}], 
      ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Get dir tools", "Subsubsection"],

Cell["\<\
These are needed before/to we construct \"RubikPkPathSep\". (This also uses \
\"Utils folder:SplitString.m\").\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"ToolsPathSep", ",", "\"\<NBFolder\>\""}], "}"}], ",", 
            "\"\<NBDirectory.m\>\""}], "]"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "Needs", "[", "\"\<ToolsFolder`NBFolder`NBDirectory`\>\"", "]"}], 
      ";"}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Check files", "Subsubsection"],

Cell["\<\
Pre check requisite tools (altho each caller will also check for these tools \
on demand):\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"ToolsPathSep", ",", "\"\<GraphicsFolder\>\""}], "}"}], 
            ",", "\"\<Rofa.m\>\""}], "]"}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"ToolsPathSep", ",", "\"\<GraphicsFolder\>\""}], "}"}], 
            ",", "\"\<DirectDisplayPk.m\>\""}], "]"}], "]"}], ";"}]}], "Input",\

  InitializationCell->True,
  CellTags->"init"],

Cell["Check the files for the rubiks package:", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikGraphicsPk.m\>\""}], "]"}],
         "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikGraphicsFns.m\>\""}], 
          "]"}], "]"}], ";", 
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikInterfacePk.m\>\""}], 
          "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikInterfaceFns.m\>\""}], 
          "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikUserButtonsPk.m\>\""}], 
          "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikUserButtonsFns.m\>\""}], 
          "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikMakeWindowPk.m\>\""}], 
          "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"CheckFileExists", "[", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"RubikPkPathSep", ",", "\"\<RubikMakeWindowFns.m\>\""}], 
          "]"}], "]"}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Rubik Geometry/Graphics Package", "Section",
  InitializationCell->True],

Cell["\<\
When this is being read as $Input, \"Get\"'s load from this same directory.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikGraphicsPk.m\>\"", "]"}], ";"}]], "Input",\

  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", 
        RowBox[{"\"\<RubikGraphicsPk.m\>\"", ",", 
          RowBox[{"Path", "\[Rule]", 
            RowBox[{"{", "Global`RubikPkPathSep", "}"}]}]}], "]"}], 
      ";"}]], "Input",
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Rubik User Interface Package", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikInterfacePk.m\>\"", "]"}], ";"}]], "Input",\

  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Rubik User Buttons Package", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikUserButtonsPk.m\>\"", "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Rubik Make Window Package", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikMakeWindowPk.m\>\"", "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{365, 483},
WindowMargins->{{Automatic, 194}, {Automatic, 13}},
ShowCellTags->True,
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "init"->{
    Cell[7265, 259, 657, 18, 167, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[7983, 281, 1753, 41, 407, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[9961, 334, 155, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[10119, 341, 254, 7, 55, "Input",
      CellTags->"init"],
    Cell[10465, 355, 156, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[10711, 367, 163, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[10963, 379, 162, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"init", 11984, 409}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 62, 1, 98, "Title",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1804, 54, 34, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[1863, 58, 42, 0, 42, "Subsubsection"],
Cell[1908, 60, 221, 4, 94, "Text"],
Cell[2132, 66, 179, 4, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2348, 75, 40, 0, 42, "Subsubsection"],
Cell[2391, 77, 151, 3, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2579, 85, 42, 0, 28, "Subsubsection"],
Cell[2624, 87, 105, 3, 46, "Text"],
Cell[2732, 92, 156, 4, 62, "Text"],
Cell[2891, 98, 104, 3, 46, "Text"],
Cell[2998, 103, 117, 5, 78, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3164, 114, 77, 0, 24, "SmallText"],
Cell[3244, 116, 95, 2, 46, "Text"],

Cell[CellGroupData[{
Cell[3364, 122, 87, 1, 58, "Subsubsection"],
Cell[3454, 125, 143, 3, 62, "Text"],
Cell[3600, 130, 255, 5, 78, "Text"],
Cell[3858, 137, 157, 4, 62, "Text"],
Cell[4018, 143, 185, 4, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4240, 152, 57, 0, 28, "Subsubsection"],
Cell[4300, 154, 160, 5, 78, "Text"],

Cell[CellGroupData[{
Cell[4485, 163, 226, 8, 126, "Text"],
Cell[4714, 173, 1162, 27, 187, "Input"]
}, Closed]],
Cell[5891, 203, 52, 0, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5980, 208, 58, 0, 28, "Subsubsection"],
Cell[6041, 210, 134, 3, 46, "Text"],
Cell[6178, 215, 71, 0, 26, "SmallText"],
Cell[6252, 217, 159, 4, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6448, 226, 38, 0, 42, "Subsubsection"],
Cell[6489, 228, 134, 3, 46, "Text"],
Cell[6626, 233, 294, 7, 75, "Input"],
Cell[6923, 242, 137, 4, 59, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7109, 252, 36, 0, 28, "Subsubsection"],
Cell[7148, 254, 114, 3, 46, "Text"],
Cell[7265, 259, 657, 18, 167, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[7925, 279, 55, 0, 30, "Text"],
Cell[7983, 281, 1753, 41, 407, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[9773, 327, 83, 1, 48, "Section",
  InitializationCell->True],
Cell[9859, 330, 99, 2, 46, "Text"],
Cell[9961, 334, 155, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[10119, 341, 254, 7, 55, "Input",
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[10410, 353, 52, 0, 30, "Section"],
Cell[10465, 355, 156, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[10658, 365, 50, 0, 30, "Section"],
Cell[10711, 367, 163, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[10911, 377, 49, 0, 30, "Section"],
Cell[10963, 379, 162, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

