(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59316,       1792]*)
(*NotebookOutlinePosition[     65307,       1977]*)
(*  CellTagsIndexPosition[     65236,       1971]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik Graphics fns", "Title",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"(*", 
      RowBox[{
        RowBox[{"Gerrard", " ", "Liddell"}], ",", 
        RowBox[{"\[Copyright]November", " ", "2001"}]}], "*)"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[CellGroupData[{

Cell["load Rofa, DirectDisplay", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Needs", "[", "\"\<ToolsFolder`GraphicsFolder`Rofa`\>\"", "]"}],
       ";"}], "\n", 
    RowBox[{
      RowBox[{
      "Needs", "[", "\"\<ToolsFolder`GraphicsFolder`DirectDisplayPk`\>\"", 
        "]"}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell[" Id3,Axes", "Section"],

Cell[CellGroupData[{

Cell["Id3", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Id3", "=", 
        RowBox[{"IdentityMatrix", "[", "3", "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AxisLabels,IndexOfAxisLabel,CycleAxesLabelRules,AxisToVectorRules
\
\>", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AxisLabels", "=", 
        RowBox[{"{", 
          RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "IndexOfAxisLabel", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"IndexOfAxisLabel", "[", "a_", "]"}], ":=", 
        RowBox[{
          RowBox[{"Position", "[", 
            RowBox[{"AxisLabels", ",", "a"}], "]"}], "[", 
          RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"CycleAxesLabelRules", "=", 
      RowBox[{"Thread", "[", 
        RowBox[{"AxisLabels", "\[Rule]", 
          RowBox[{"RotateLeft", "[", "AxisLabels", "]"}]}], "]"}]}]], "Input",\

  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ax", "\[Rule]", "ay"}], ",", 
        RowBox[{"ay", "\[Rule]", "az"}], ",", 
        RowBox[{"az", "\[Rule]", "ax"}]}], "}"}]], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{"AxisToVectorRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"AxisLabels", "\[Rule]", "Id3"}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["rot90 group", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
rotation labels:Rot90GenLabels={rx,ry,rz},IndexOfRotLabel[r],
RotLabelToAxisLabelRules,AxisLabelToRotLabelRules\
\>", "Subsubsection"],

Cell["We choose symbols to distinguish rotations from axes.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Rot90GenLabels", "=", 
        RowBox[{"{", 
          RowBox[{"rx", ",", "ry", ",", "rz"}], "}"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["We will also map them to axes and back:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RotLabelsToVectorRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"Rot90GenLabels", "\[Rule]", "Id3"}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"RotLabelToAxisLabelRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"Rot90GenLabels", "->", "AxisLabels"}], "]"}]}], 
      ";"}], "\n", 
    RowBox[{
      RowBox[{"AxisLabelToRotLabelRules", "=", 
        RowBox[{"Reverse", "/@", "RotLabelToAxisLabelRules"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
 \"IndexOfRotLabel\" used to get index of a label (via its \
component index).\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "IndexOfRotLabel", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"IndexOfRotLabel", "[", "r_", "]"}], ":=", 
        RowBox[{
          RowBox[{"Position", "[", 
            RowBox[{"Rot90GenLabels", ",", "r"}], "]"}], "[", 
          RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inv rotation labels -r,AllRot90Labels", "Subsubsection"],

Cell[TextData[{
  "The rotation about ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "r"}], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["R", 
            RowBox[{"-", "r"}]], "=", 
          SubsuperscriptBox["R", "r", 
            RowBox[{"-", "1"}]]}], TraditionalForm]]],
  ". We could use ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Inv", "[", "r", "]"}], TraditionalForm]]],
  " as the symbol, but we can use the systematic (Lie) map of axes to \
rotations and just use ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "r"}], TraditionalForm]]],
  ".\nTo get the inverse of a permutation."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AllRot90Labels", "=", 
        RowBox[{"Rot90GenLabels", "~", "Join", "~", 
          RowBox[{"(", 
            RowBox[{"-", "Rot90GenLabels"}], ")"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "RotLabelToAxisRules/rotsofaxisrules:",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", "\[LeftRightArrow]", " ", "a"}], TraditionalForm]]],
  ",",
  "AllRot90sToAxisPermRules",
  ":",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["r", "\[Delta]"], "\[RightTeeArrow]", 
              "\[Sigma]"}], "\[Element]", " ", 
            SubscriptBox["a", "i"]}], "\[Rule]", " ", 
          SubscriptBox["a", "j"]}], TraditionalForm]]]
}], "Subsubsection"],

Cell["Creation of rectlinear rotations via  permutation of basis.", "Text"],

Cell[TextData[{
  "We could just use ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Rofa", "[", 
          RowBox[{
            FractionBox["\[Pi]", "2"], 
            SubscriptBox["\[Epsilon]", "i"]}], "]"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RotLabelToAxisRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"Rot90GenLabels", "\[Rule]", "Id3"}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[TextData[{
  "Map each rotation label , ",
  Cell[BoxData[
      FormBox["r", TraditionalForm]]],
  " or  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "r"}], TraditionalForm]]],
  " to its permutation of the axes."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AxesRulesOfRot90Gens", "=", 
        RowBox[{"NestList", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"#", "/.", "CycleAxesLabelRules"}], "&"}], ",", 
            RowBox[{"Thread", "[", 
              RowBox[{"AxisLabels", "->", 
                RowBox[{"{", 
                  RowBox[{"ax", ",", "az", ",", 
                    RowBox[{"-", "ay"}]}], "}"}]}], "]"}], ",", "2"}], 
          "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
Now extend to get axis permutations for all axis
Use the inverse of a permutation-but swap the induce negations.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AllRot90sToAxisPermRules", "=", 
        RowBox[{
          RowBox[{"Cases", "[", 
            RowBox[{
              RowBox[{"Thread", "[", 
                RowBox[{"Rot90GenLabels", "->", "AxesRulesOfRot90Gens"}], 
                "]"}], ",", 
              RowBox[{
                RowBox[{"HoldPattern", "[", 
                  RowBox[{"aRule", ":", 
                    RowBox[{"(", 
                      RowBox[{"r_", "\[Rule]", "\[Sigma]_"}], ")"}]}], "]"}], 
                "\[RuleDelayed]", 
                RowBox[{"(*", " ", 
                  RowBox[{
                  "copy", " ", "the", " ", "rule", " ", "and", " ", "its", 
                    " ", "inverse"}], " ", "*)"}], "\[IndentingNewLine]", 
                RowBox[{"{", 
                  RowBox[{"aRule", ",", 
                    RowBox[{
                      RowBox[{"-", "r"}], "\[Rule]", "\[IndentingNewLine]", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{"Reverse", "/@", "\[Sigma]"}], ")"}], "/.",
                           
                          RowBox[{
                            RowBox[{"HoldPattern", "[", 
                              RowBox[{
                                RowBox[{"(", 
                                  RowBox[{"-", "a_"}], ")"}], "\[Rule]", 
                                "b_"}], "]"}], "\[Rule]", 
                            RowBox[{"(", 
                              RowBox[{"a", "\[Rule]", 
                                RowBox[{"-", "b"}]}], ")"}]}]}], ")"}]}]}], 
                  "}"}]}]}], "]"}], "//", "Flatten"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"AllRot90ToMatrixRules", ":", 
        RowBox[{
          SuperscriptBox["r", "\[Delta]"], "\[RightTeeArrow]", " ", 
          SubscriptBox["R", 
            RowBox[{"\[Delta]", " ", "a"}]]}]}], 
      TraditionalForm]]]], "Subsubsection"],

Cell["Map to columns and apply transpose to get matrices:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"{", 
          RowBox[{"Rx", ",", "Ry", ",", "Rz"}], "}"}], "=", 
        RowBox[{"Transpose", "/@", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"AxisLabels", "/.", 
                RowBox[{"(", 
                  RowBox[{
                  "Rot90GenLabels", "/.", "AllRot90sToAxisPermRules"}], 
                  ")"}]}], "/.", "AxisToVectorRules"}], ")"}]}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Rot90ToMatrixRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"Rot90GenLabels", "->", 
            RowBox[{"{", 
              RowBox[{"Rx", ",", "Ry", ",", "Rz"}], "}"}]}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[TextData[{
  "Must map inverses first because of using symbols ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "r"}], TraditionalForm]]],
  " ( ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Inv", "[", "r", "]"}], TraditionalForm]]],
  " would avoid this)."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AllRot90ToMatrixRules", "=", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"Rot90ToMatrixRules", "/.", 
              RowBox[{
                RowBox[{"HoldPattern", "[", 
                  RowBox[{"r_", "\[Rule]", "m_"}], "]"}], "\[RuleDelayed]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"-", "r"}], ")"}], "->", 
                  RowBox[{"Inverse", "[", "m", "]"}]}]}]}], ")"}], "~", 
          "Join", "~", "\[IndentingNewLine]", "Rot90ToMatrixRules"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Posns", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["RubikPosnDom", "Subsubsection"],

Cell[TextData[{
  "The domain( can be generalized for ",
  Cell[BoxData[
      FormBox["n", TraditionalForm]]],
  " slices)"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RubikPosnDom", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], ";"}]], "Input",\

  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Posns:",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", ",", 
                RowBox[{"-", "1"}], ",", "0"}], ")"}], ",", "\[Ellipsis]"}], 
          "}"}], TraditionalForm]]]
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Posns", "=", 
        RowBox[{
          RowBox[{"Flatten", "@", 
            RowBox[{"Outer", "[", 
              RowBox[{
              "p", ",", "RubikPosnDom", ",", "RubikPosnDom", ",", 
                "RubikPosnDom"}], "]"}]}], "/.", 
          RowBox[{"p", "\[Rule]", "List"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["faces", "Section",
  InitializationCell->True],

Cell["Data and Operations on faces", "Subsection"],

Cell[CellGroupData[{

Cell["faces:PosFaceLabels,FaceLabels", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"PosFaceLabels", "=", 
        RowBox[{"{", 
          RowBox[{"fx", ",", "fy", ",", "fz"}], "}"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceLabels", "=", 
        RowBox[{"PosFaceLabels", "~", "Join", "~", 
          RowBox[{"(", 
            RowBox[{"-", "PosFaceLabels"}], ")"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["AllRot90sToFacePermRules", "Subsubsection"],

Cell["Rules to map face labels to rotations (about the face).", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AllRot90sToFacePermRules", "=", 
        RowBox[{"AllRot90sToAxisPermRules", "/.", 
          RowBox[{"Thread", "[", 
            RowBox[{"AxisLabels", "->", "PosFaceLabels"}], "]"}]}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["ColorLabels:kL[i]", "Subsubsection",
  InitializationCell->True],

Cell["\<\

Just choose generic/systematic labels. Actual association with colors can be 
done for graphics (see colorrules).
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ColorLabels", "=", 
        RowBox[{"Table", "[", 
          RowBox[{
            RowBox[{"kL", "[", "i", "]"}], ",", 
            RowBox[{"{", 
              RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["Graphics for faces", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "face graphics:FaceToVectorRules:",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{"fx", "\[Rule]", 
              SubscriptBox["\[Epsilon]", "1"]}], ",", "\[Ellipsis]"}], "}"}], 
        TraditionalForm]]],
  ",\nFaceLabelToPolyRules:",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                SubscriptBox["f", "x"]}], "\[Rule]", " ", 
              RowBox[{"Polygon", "[", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"0.5`", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", 
                            SubscriptBox["f", "x"]}], "+", 
                          SubscriptBox["f", "y"], "+", 
                          SubscriptBox["f", "z"]}], ")"}]}], ",", 
                    "\[Ellipsis]"}], "}"}], "]"}]}], ",", "\[Ellipsis]"}], 
          "}"}], TraditionalForm]]]
}], "Subsubsection",
  InitializationCell->True],

Cell["Map face labels to their associated vectors.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceToVectorRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"PosFaceLabels", "\[Rule]", "Id3"}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceTuples", "=", 
        RowBox[{"Id3", "~", "Join", "~", 
          RowBox[{"(", 
            RowBox[{"-", "Id3"}], ")"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[TextData[{
  "Given a triad of faces ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            SubscriptBox["f", "1"], ",", 
            SubscriptBox["f", "2"], ",", 
            SubscriptBox["f", "3"]}], ")"}], TraditionalForm]]],
  ", create the points around (0) of the face ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["f", "1"], TraditionalForm]]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceTriadToPolyPtsRule", "=", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"f1_", ",", "f2_", ",", "f3_"}], "}"}], "\[RuleDelayed]", 
          "\[IndentingNewLine]", 
          RowBox[{"(", 
            RowBox[{"f1", "->", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", "f2"}], "-", "f3"}], ",", 
                  RowBox[{"f2", "-", "f3"}], ",", 
                  RowBox[{"f2", "+", "f3"}], ",", 
                  RowBox[{
                    RowBox[{"-", "f2"}], "+", "f3"}]}], "}"}]}], ")"}]}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
Rules to map each axes label to the set of points of its perimeter \
(about 0).\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AxisToPolyFacePtsRules", "=", 
        RowBox[{
          RowBox[{"NestList", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"#", "/.", 
                  RowBox[{"Thread", "[", 
                    RowBox[{"FaceLabels", "\[Rule]", 
                      RowBox[{"RotateLeft", "[", 
                        RowBox[{"FaceLabels", ",", "1"}], "]"}]}], "]"}]}], 
                "&"}], ",", "\[IndentingNewLine]", 
              RowBox[{"PosFaceLabels", "/.", "FaceTriadToPolyPtsRule"}], ",", 
              "2"}], "]"}], "/.", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"HoldPattern", "[", 
              RowBox[{"f_", "->", "p_"}], "]"}], "\[RuleDelayed]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"f", "/.", 
                    RowBox[{"Thread", "[", 
                      RowBox[{"PosFaceLabels", "\[Rule]", "AxisLabels"}], 
                      "]"}]}], ")"}], "\[Rule]", "p"}], ")"}]}]}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["Rules to map positive face labels to their polygons.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"PosFaceLabelToPolyRules", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{
            RowBox[{"NestList", "[", 
              RowBox[{"RotateLeft", ",", "PosFaceLabels", ",", "2"}], "]"}], 
            ",", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"f1_", ",", "f2_", ",", "f3_"}], "}"}], 
              "\[RuleDelayed]", "\[IndentingNewLine]", 
              RowBox[{"(", 
                RowBox[{"f1", "->", 
                  RowBox[{"Polygon", "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"0.5", 
                          RowBox[{"(", " ", 
                            RowBox[{"f1", "+", "#"}], ")"}]}], "&"}], "/@", 
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"-", "f2"}], "-", "f3"}], ",", 
                          RowBox[{"f2", "-", "f3"}], ",", 
                          RowBox[{"f2", "+", "f3"}], ",", 
                          RowBox[{
                            RowBox[{"-", "f2"}], "+", "f3"}]}], "}"}]}], 
                    "]"}]}], ")"}]}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["Rules to map all face labels to their polygons.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceLabelToPolyRules", "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"PosFaceLabelToPolyRules", "/.", 
              RowBox[{"Thread", "[", 
                RowBox[{"PosFaceLabels", "\[Rule]", 
                  RowBox[{"-", "PosFaceLabels"}]}], "]"}]}], ")"}], "~", 
          "Join", "~", "PosFaceLabelToPolyRules", "~", "Join", "~", 
          RowBox[{"{", 
            RowBox[{"0", "\[Rule]", 
              RowBox[{"Point", "[", 
                RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], 
            "}"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["coloring:FaceColors", "Subsubsection",
  InitializationCell->True],

Cell["{red,green,blue,orange,white,yellow}", "Text",
  InitializationCell->True],

Cell["{yellow,red,white,orange,blue,green}", "Text",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceColors", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "1", ",", "0"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "1"}], "]"}]}], "}"}]}], 
      ";"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"FaceColors", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", " ", ".5", ",", " ", "0"}], "]"}], ",", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "1", ",", "0"}], "]"}]}], "}"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Configurations; InitialColoredMiniFaceConfiguration", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  "FaceLabelsOfPosn:",
  Cell[BoxData[
      FormBox[
        RowBox[{"Posn", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              SubscriptBox["f", "1"], ",", "\[Ellipsis]"}], "}"}]}], 
        TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "FaceLabelsOfPosn", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"FaceLabelsOfPosn", "[", "Posn_", "]"}], ":=", 
        RowBox[{"DeleteCases", "[", 
          RowBox[{
            RowBox[{"MapIndexed", "[", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{"#1", " ", 
                    RowBox[{"PosFaceLabels", "[", 
                      RowBox[{"[", 
                        RowBox[{"#2", "[", 
                          RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}]}],
                   " ", "&"}], ",", "Posn"}], "]"}], ",", "0"}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["configurations:q[p,f,c]", "Subsubsection"],

Cell[TextData[{
  "The data type ",
  Cell[BoxData[
      FormBox[
        RowBox[{"q", "[", 
          RowBox[{
            RowBox[{"p", ":", "position"}], ",", " ", 
            RowBox[{"f", ":", "face"}], ",", " ", 
            RowBox[{"c", ":", "color"}]}], "]"}], TraditionalForm]]],
  " will be used to denote the face of a block situated in Rubiks cube. A  \
(colored mini-face) configuration ",
  Cell[BoxData[
      FormBox["Q", TraditionalForm]]],
  ",consists of a (full) set of these. Denote the set of possible \
configurations by ",
  Cell[BoxData[
      FormBox["\[ScriptCapitalQ]", TraditionalForm]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["InitialColoredMiniFaceConfiguration", "Subsubsection",
  InitializationCell->True],

Cell["Just used by package.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"InitialColoredMiniFaceConfiguration", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"Posns", ",", 
            RowBox[{"p_", "\[RuleDelayed]", "\[IndentingNewLine]", 
              RowBox[{"Cases", "[", 
                RowBox[{
                  RowBox[{"FaceLabelsOfPosn", "[", "p", "]"}], ",", 
                  RowBox[{"f_", "\[RuleDelayed]", "\[IndentingNewLine]", 
                    RowBox[{"q", "[", 
                      RowBox[{"p", ",", "f", ",", 
                        RowBox[{"f", "/.", 
                          RowBox[{"Thread", "[", 
                            RowBox[{"FaceLabels", "\[Rule]", "ColorLabels"}], 
                            "]"}]}]}], "]"}]}]}], "]"}]}]}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rubik Group", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["RubikGenerators", "Subsection",
  InitializationCell->True],

Cell[TextData[{
  "The generators are the outer slice rotations. \nEach (signed) face/axis \
determines an outer slice, but to allow middle slices use the data type:\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{
            RowBox[{"r", ":", "AllRot90Labels"}], ",", 
            RowBox[{"s", ":", 
              RowBox[{"slice", ":", 
                RowBox[{"\[Element]", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}]}]}]}],
           "]"}], TraditionalForm]]],
  ". e.g. ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{"rx", ",", 
            RowBox[{"-", "1"}]}], "]"}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{
            RowBox[{"-", "ry"}], ",", "0"}], "]"}], TraditionalForm]]],
  ".\nThe \"g\" denotes it is a type of group element.\nThe ",
  Cell[BoxData[
      FormBox["r", TraditionalForm]]],
  " is the rotation (axis) and the ",
  Cell[BoxData[
      FormBox["s", TraditionalForm]]],
  " is the position of the slice along the (signed) axis. For the generators \
on the outer slices ",
  Cell[BoxData[
      FormBox["s", TraditionalForm]]],
  " will always be one.\nThe inverse of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{"rx", ",", "1"}], "]"}], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{
            RowBox[{"-", "rx"}], ",", 
            RowBox[{"-", "1"}]}], "]"}], TraditionalForm]]],
  " ( so ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"g", "[", 
              RowBox[{
                RowBox[{"-", "rx"}], ",", "1"}], "]"}], 
            RowBox[{"-", "1"}]], "=", 
          RowBox[{"g", "[", 
            RowBox[{"rx", ",", 
              RowBox[{"-", "1"}]}], "]"}]}], TraditionalForm]]],
  ")."
}], "Text"],

Cell[TextData[{
  "Note that the actual rotation will be the standard counter clockwise \
around the outer axis of the face, so back faces will have axis ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "r"}], TraditionalForm]]],
  ",\nand slice 1."
}], "Text"],

Cell["\<\
Could promote this to a type, Tgen or TGroupGenerator and use \
notation rules to format i/o.\
\>", "SmallText"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RubikGens", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{
            RowBox[{"Rot90GenLabels", "~", "Join", "~", 
              RowBox[{"(", 
                RowBox[{"-", "Rot90GenLabels"}], ")"}]}], ",", 
            RowBox[{"r_", "\[Rule]", 
              RowBox[{"g", "[", 
                RowBox[{"r", ",", "1"}], "]"}]}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["InvOfRubikGen[gen],pattofrot[gen],qRulesOfRubikGen[g[r_,s_]]", \
"Subsection",
  InitializationCell->True],

Cell["\<\
We will also want to animate inverses of the generators, that will \
be written Inv[g].\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "InvOfRubikGen", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"InvOfRubikGen", "[", 
          RowBox[{"Inv", "[", 
            RowBox[{"g", "[", 
              RowBox[{"r_", ",", "s_"}], "]"}], "]"}], "]"}], ":=", 
        RowBox[{"g", "[", 
          RowBox[{"r", ",", "s"}], "]"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"InvOfRubikGen", "[", 
          RowBox[{"g", "[", 
            RowBox[{"r_", ",", "s_"}], "]"}], "]"}], ":=", 
        RowBox[{"g", "[", 
          RowBox[{
            RowBox[{"-", "r"}], ",", 
            RowBox[{"-", "s"}]}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
For a generator(or its inverse), construct a pattern to select the \
corresponding slice.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "SignOfSignedr", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"SignOfSignedr", "[", 
          RowBox[{"-", "r_"}], "]"}], ":=", 
        RowBox[{"-", "1"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"SignOfSignedr", "[", "r_", "]"}], ":=", "1"}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{
            RowBox[{"-", 
              SubscriptBox["r", "x"]}], ",", "1"}], "]"}], 
        TraditionalForm]]],
  " , the ",
  Cell[BoxData[
      FormBox["x", TraditionalForm]]],
  " coordinate thru the slice is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", "1"}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "AbsoluteSliceOfGen", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"AbsoluteSliceOfGen", "[", 
          RowBox[{
            RowBox[{"Inv", "[", 
              RowBox[{"g", "[", 
                RowBox[{"r_", ",", "s_"}], "]"}], "]"}], "|", 
            RowBox[{"g", "[", 
              RowBox[{"r_", ",", "s_"}], "]"}]}], "]"}], ":=", 
        RowBox[{
          RowBox[{"SignOfSignedr", "[", "r", "]"}], " ", "s"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "PattOfGen", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"PattOfGen", "[", 
          RowBox[{"gop", ":", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"Inv", "[", 
                  RowBox[{"g", "[", 
                    RowBox[{"r_", ",", "s_"}], "]"}], "]"}], "|", 
                RowBox[{"g", "[", 
                  RowBox[{"r_", ",", "s_"}], "]"}]}], ")"}]}], "]"}], ":=", 
        RowBox[{"Insert", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"_", ",", "_"}], "}"}], ",", 
            RowBox[{"AbsoluteSliceOfGen", "[", "gop", "]"}], ",", 
            RowBox[{"IndexOfRotLabel", "[", 
              RowBox[{
                RowBox[{"SignOfSignedr", "[", "r", "]"}], " ", "r"}], "]"}]}],
           "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "RotAxisLabelOfRubikGen", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"RotAxisLabelOfRubikGen", "[", "gop_Inv", "]"}], ":=", 
        RowBox[{"RotAxisLabelOfRubikGen", "[", 
          RowBox[{"InvOfRubikGen", "[", "gop", "]"}], "]"}]}], ";", 
      RowBox[{
        RowBox[{"RotAxisLabelOfRubikGen", "[", 
          RowBox[{"g", "[", 
            RowBox[{"r_", ",", "s_"}], "]"}], "]"}], ":=", "r"}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[TextData[{
  "Each rubik generator induces an action on the colored mini-faces ",
  Cell[BoxData[
      FormBox[
        RowBox[{"q", "[", 
          RowBox[{"p", ",", " ", "f", ",", "c"}], "]"}], TraditionalForm]]],
  "\nwhere \n-",
  Cell[BoxData[
      FormBox["p", TraditionalForm]]],
  " is the (center) of the block, e.g. ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", 
            RowBox[{"-", "1"}]}], ")"}], TraditionalForm]]],
  ",\n-",
  Cell[BoxData[
      FormBox["f", TraditionalForm]]],
  " is a face label\n-",
  Cell[BoxData[
      FormBox["c", TraditionalForm]]],
  " is a color label."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "qRulesOfRubikGen", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"qRulesOfRubikGen", "::", "usage"}], "=", 
        "\"\<qrulesofrubikgen[gop:g[r_,s_]|Inv[g[r_,s_]]] takes the rubik \
operation 'gop' and generates its rule for permuting the colored minifaces of \
the cube.\>\""}], ";", 
      RowBox[{
        RowBox[{"qRulesOfRubikGen", "[", 
          RowBox[{"Inv", "[", "gop_", "]"}], "]"}], ":=", 
        RowBox[{"qRulesOfRubikGen", "[", 
          RowBox[{"InvOfRubikGen", "[", "gop", "]"}], "]"}]}], ";", 
      RowBox[{
        RowBox[{"qRulesOfRubikGen", "[", "gop_g", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"sr", "=", 
                RowBox[{"RotAxisLabelOfRubikGen", "[", "gop", "]"}]}], "}"}], 
            ",", 
            RowBox[{"With", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"R", "=", 
                      RowBox[{"sr", "/.", "AllRot90ToMatrixRules"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"r\[Sigma]", "=", 
                      RowBox[{"sr", "/.", "AllRot90sToFacePermRules"}]}]}], 
                  "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"q", "[", 
                      RowBox[{
                        RowBox[{"Pattern", "@@", 
                          RowBox[{"{", 
                            RowBox[{"v", ",", 
                              RowBox[{"PattOfGen", "[", "gop", "]"}]}], 
                            "}"}]}], ",", "f_", ",", "kLs___"}], "]"}], 
                    "\[RuleDelayed]", "\[IndentingNewLine]", 
                    RowBox[{"q", "[", 
                      RowBox[{
                        RowBox[{"R", ".", "v"}], ",", 
                        RowBox[{"f", "/.", "r\[Sigma]"}], ",", "kLs"}], 
                      "]"}]}], "\[IndentingNewLine]", ")"}]}], 
              "\[IndentingNewLine]", "]"}]}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["qToGraphicsRule", "Subsubsection",
  InitializationCell->True],

Cell[TextData[{
  "Map colored mini faces to actual ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics elements."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"qToGraphicsRule", "=", 
        RowBox[{
          RowBox[{"q", "[", 
            RowBox[{"p_", ",", "af_", ",", "ak_"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"ak", "/.", 
                RowBox[{"Thread", "[", 
                  RowBox[{"ColorLabels", "->", "FaceColors"}], "]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  RowBox[{"af", "/.", "FaceLabelToPolyRules"}], "/.", 
                  "FaceToVectorRules"}], "/.", 
                RowBox[{
                  RowBox[{"v", ":", 
                    RowBox[{"{", 
                      RowBox[{"__", "?", "NumberQ"}], "}"}]}], 
                  "\[RuleDelayed]", 
                  RowBox[{"v", "+", "p"}]}]}]}], "}"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["MirrorOf[CubeGraphics_]", "Subsubsection",
  InitializationCell->True],

Cell["\<\
Mirrors are created by simply peeling the minifaces off the cube.\
\
\>", "Text"],

Cell[TextData[{
  "The three mirrors of the back faces are staggered slightly off the axis to \
aid viewability.\nThe back faces ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"-", 
            SubscriptBox["f", "x"]}], ",", 
          SubscriptBox["f", "y"], ",", 
          RowBox[{"-", 
            SubscriptBox["f", "z"]}]}], TraditionalForm]]],
  " are moved an amount given by the mirror vectors.\nThe back faces are \
those behind the centers of the back cubes (which are one unit back from the \
origin). We test against 1.2. If we adjust signs (the -",
  Cell[BoxData[
      FormBox["y", TraditionalForm]]],
  " face is showing), the back faces are simply those ",
  Cell[BoxData[
      FormBox[
        RowBox[{"<", 
          RowBox[{"-", "1.2"}]}], TraditionalForm]]],
  " along the axis of the face."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"MirrorVects", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"-", "2"}], ",", 
                RowBox[{"-", ".5"}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", "4", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"1", ",", 
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{"MirrorVectRule", "=", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
            RowBox[{"x", ",", 
              RowBox[{"-", "y"}], ",", "z"}], "}"}]}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[TextData[{
  "Test if all the points are behind -1.2 along some axis. Find the max value \
along each axis and see if one is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"<", 
          RowBox[{"-", "1.2"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "BackPointsQ", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"BackPointsQ", "[", "ps_", "]"}], ":=", 
        RowBox[{
          RowBox[{"Min", "[", 
            RowBox[{"Max", "/@", 
              RowBox[{"(", 
                RowBox[{"Transpose", "[", 
                  RowBox[{"ps", "/.", "MirrorVectRule"}], "]"}], ")"}]}], 
            "]"}], "<", 
          RowBox[{"-", "1.2"}]}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
Given these points lie on a back face, find the mirrorvect for the \
face.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "MirrorVectOfBackPoints", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"MirrorVectOfBackPoints", "[", "ps_", "]"}], ":=", 
        RowBox[{"MirrorVects", "[", 
          RowBox[{"[", 
            RowBox[{
              RowBox[{"Position", "[", 
                RowBox[{
                  RowBox[{"Max", "/@", 
                    RowBox[{"(", 
                      RowBox[{"Transpose", "[", 
                        RowBox[{"ps", "/.", "MirrorVectRule"}], "]"}], 
                      ")"}]}], ",", 
                  RowBox[{"r_", "/;", 
                    RowBox[{"r", "<", 
                      RowBox[{"-", "1.2"}]}]}]}], "]"}], "[", 
              RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
Note: cant use local variable to both test pattern and on the rhs \
in a \"Case\" statement.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "MirrorOf", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"MirrorOf", "[", "CubeGraphics_", "]"}], "=", 
        "\"\<mirrorof[cubegraphics_] takes the graphics of the cube and \
creates the graphics for the cube with mirrors.\>\""}], ";", 
      RowBox[{
        RowBox[{"MirrorOf", "[", "CubeGraphics_", "]"}], ":=", 
        RowBox[{"CubeGraphics", "~", "Join", "~", "\[IndentingNewLine]", 
          RowBox[{"Cases", "[", 
            RowBox[{"CubeGraphics", ",", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"aColor_", ",", 
                    RowBox[{"Polygon", "[", 
                      RowBox[{"ps_", "?", "BackPointsQ"}], "]"}]}], "}"}], 
                "\[RuleDelayed]", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  RowBox[{"aColor", ",", 
                    RowBox[{"With", "[", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"v", "=", 
                            RowBox[{
                            "MirrorVectOfBackPoints", "[", "ps", "]"}]}], 
                          "}"}], ",", "\[IndentingNewLine]", 
                        RowBox[{"Polygon", "[", 
                          RowBox[{"Cases", "[", 
                            RowBox[{"ps", ",", 
                              RowBox[{"aPoint_", "\[RuleDelayed]", 
                                RowBox[{"aPoint", "+", "v"}]}]}], "]"}], 
                          "]"}]}], "]"}]}], "}"}]}], ",", "Infinity"}], 
            "]"}]}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["direct display", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Graphics3DOfCube[aCube_,Mirrored_]", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "Graphics3DOfCube", "]"}], ";", 
      RowBox[{
        RowBox[{"Graphics3DOfCube", "::", "usage"}], "=", 
        "\"\<graphics3Dofcube[acube_,mirrored_] creates the graphics of a \
cube configuration.\>\""}], ";", 
      RowBox[{
        RowBox[{"Graphics3DOfCube", "[", 
          RowBox[{"aCube_", ",", "Mirrored_"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"g", "=", 
                RowBox[{"aCube", "/.", "qToGraphicsRule"}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{"Mirrored", ",", "\[IndentingNewLine]", 
                RowBox[{"Graphics3D", "[", 
                  RowBox[{
                    RowBox[{"MirrorOf", "[", "g", "]"}], ",", 
                    RowBox[{"Lighting", "\[Rule]", "False"}], ",", 
                    RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{
                              RowBox[{"-", "4"}], ",", "3"}], "}"}], ",", 
                          RowBox[{"{", 
                            RowBox[{
                              RowBox[{"-", "3"}], ",", "6"}], "}"}], ",", 
                          RowBox[{"{", 
                            RowBox[{
                              RowBox[{"-", "4"}], ",", "3"}], "}"}]}], 
                        "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{"Graphics3D", "[", 
                  RowBox[{"g", ",", 
                    RowBox[{"Lighting", "\[Rule]", "False"}], ",", 
                    RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
                    RowBox[{"PlotRange", "\[Rule]", 
                      RowBox[{"2.2", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"{", 
                              RowBox[{
                                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
                            RowBox[{"{", 
                              RowBox[{
                                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
                            RowBox[{"{", 
                              RowBox[{
                                RowBox[{"-", "1"}], ",", "1"}], "}"}]}], 
                          "}"}]}]}]}], "]"}]}], "]"}]}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["DisplayCube[aCube_,anNB_,tg,Mirrored_]", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "DisplayCube", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"DisplayCube", "[", 
          RowBox[{"aCube_", ",", "anNB_", ",", "tg_", ",", "Mirrored_"}], 
          "]"}], ":=", "\[IndentingNewLine]", 
        RowBox[{"DisplayGraphicsInNotebook", "[", 
          RowBox[{
            RowBox[{"Graphics3DOfCube", "[", 
              RowBox[{"aCube", ",", "Mirrored"}], "]"}], ",", "anNB", ",", 
            "tg"}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation of moves", "Section",
  InitializationCell->True,
  GeneratedCell->True],

Cell[CellGroupData[{

Cell["SplitByRot[aCube_,gop_], FillFacesOf[g[r_,s_]]", "Subsubsection",
  InitializationCell->True,
  GeneratedCell->True],

Cell["\<\
Split off the faces effected by the Rubik generator.
Construct the internal faces that are only seen during the rotation. \
\>", \
"Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "SplitByRot", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"SplitByRot", "[", 
          RowBox[{"aCube_", ",", "gop_"}], "]"}], ":=", "\[IndentingNewLine]",
         
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Patt", "=", 
                RowBox[{"PattOfGen", "[", "gop", "]"}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Cases", "[", 
                  RowBox[{
                    RowBox[{"Flatten", "@", "aCube"}], ",", 
                    RowBox[{"q", "[", 
                      RowBox[{
                        RowBox[{"p", ":", "Patt"}], ",", "f_", ",", "ak_"}], 
                      "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{"DeleteCases", "[", 
                  RowBox[{
                    RowBox[{"Flatten", "@", "aCube"}], ",", 
                    RowBox[{"q", "[", 
                      RowBox[{
                        RowBox[{"p", ":", "Patt"}], ",", "f_", ",", "ak_"}], 
                      "]"}]}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
          "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
Find the inner faces of the slice and construct their \
polygons.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"Clear", "[", "FillFacesOf", "]"}], ";"}], "\n", 
      RowBox[{"(*", 
        RowBox[{
          RowBox[{
            RowBox[{"FillFacesOf", "[", 
              RowBox[{"Inv", "[", "gop_", "]"}], "]"}], ":=", 
            RowBox[{"FillFacesOf", "[", 
              RowBox[{"InvOfRubikGen", "[", "gop", "]"}], "]"}]}], ";"}], 
        "*)"}]}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"FillFacesOf", "[", 
          RowBox[{"g", "[", 
            RowBox[{"r_", ",", "s_"}], "]"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"a", "=", 
                RowBox[{
                  RowBox[{"s", " ", "r"}], "/.", 
                  "RotLabelToAxisLabelRules"}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"With", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"TheFaceVector", "=", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"a", "/.", "AxisToPolyFacePtsRules"}], "/.",
                           "FaceToVectorRules"}], ")"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"va", "=", 
                      RowBox[{"a", "/.", "AxisToVectorRules"}]}]}], "}"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"GrayLevel", "[", ".8", "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                      RowBox[{
                        RowBox[{"s", "\[Equal]", "0"}], ",", 
                        "\[IndentingNewLine]", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"Polygon", "[", 
                              RowBox[{
                                RowBox[{
                                  RowBox[{"(", 
                                    RowBox[{
                                      RowBox[{"1.5", " ", "#"}], "+", 
                                      RowBox[{".5", "  ", "va"}]}], " ", 
                                    ")"}], "&"}], "/@", "TheFaceVector"}], 
                              "]"}], ",", 
                            RowBox[{"Polygon", "[", 
                              RowBox[{
                                RowBox[{
                                  RowBox[{"(", 
                                    RowBox[{
                                      RowBox[{"1.5", " ", "#"}], "-", 
                                      RowBox[{".5", "  ", "va"}]}], " ", 
                                    ")"}], "&"}], "/@", "TheFaceVector"}], 
                              "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
                        RowBox[{"Polygon", "[", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"1.5", " ", "#"}], "+", 
                                  RowBox[{".5", " ", "s", " ", "va"}]}], " ", 
                                ")"}], "&"}], "/@", "TheFaceVector"}], 
                          "]"}]}], "\[IndentingNewLine]", "]"}]}], 
                  "\[IndentingNewLine]", "}"}]}], "]"}]}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animategop[gop_,aCube_,anNB_]", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "Animategop", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Animategop", "[", 
          RowBox[{"gop_Inv", ",", "aCube_", ",", "anNB_"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"Animategop", "[", 
          RowBox[{
            RowBox[{"InvOfRubikGen", "[", "gop", "]"}], ",", "aCube", ",", 
            "anNB"}], "]"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"Animategop", "[", 
          RowBox[{"gop_", ",", "aCube_", ",", "anNB_"}], "]"}], ":=", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"rAxis", "=", 
                  RowBox[{
                    RowBox[{"RotAxisLabelOfRubikGen", "[", "gop", "]"}], "/.",
                     "RotLabelsToVectorRules"}]}], ",", "\[IndentingNewLine]",
                 
                RowBox[{"FillFace", "=", 
                  RowBox[{"FillFacesOf", "[", "gop", "]"}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Replace", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"SplitByRot", "[", 
                    RowBox[{"aCube", ",", "gop"}], "]"}], "/.", 
                  "qToGraphicsRule"}], ",", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"MovePart_", ",", "FixedPart_"}], "}"}], ":>", 
                  RowBox[{"Do", "[", 
                    RowBox[{"(*", 
                      RowBox[{
                        RowBox[{"Pause", "[", ".001", "]"}], ";"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{
                      "DisplayGraphicsInNotebook", "[", "\[IndentingNewLine]",
                         "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{"Graphics3D", "[", 
                            RowBox[{
                              RowBox[{"{", 
                                RowBox[{
                                "FixedPart", ",", "\[IndentingNewLine]", 
                                  RowBox[{"(*", " ", 
                                    RowBox[{
                                      RowBox[{
                                      "show", " ", "the", " ", 
                                        "\"\<fixed part\>\"", " ", "of", " ", 
                                        "the", " ", "internal", " ", "fill", 
                                        " ", "face"}], " ", ",", " ", 
                                      RowBox[{"slightly", " ", "shrunk"}]}], 
                                    " ", "*)"}], "\[IndentingNewLine]", 
                                  RowBox[{"FillFace", "/.", 
                                    RowBox[{
                                      RowBox[{"v", ":", 
                                        RowBox[{"{", 
                                        RowBox[{"__", "?", "NumberQ"}], 
                                        "}"}]}], "\[RuleDelayed]", 
                                      RowBox[{".95", " ", "v"}]}]}], ",", 
                                  "\[IndentingNewLine]", 
                                  RowBox[{"(*", " ", 
                                    RowBox[{
                                    "show", " ", "the", " ", "rotating", " ", 
                                      "part"}], " ", "*)"}], 
                                  "\[IndentingNewLine]", 
                                  RowBox[{"With", "[", 
                                    RowBox[{
                                      RowBox[{"{", 
                                        RowBox[{"Rt", "=", 
                                        RowBox[{"Rofa", "[", 
                                        RowBox[{"t", " ", "rAxis"}], "]"}]}], 
                                        "}"}], ",", "\[IndentingNewLine]", 
                                      RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{"FillFace", ",", "MovePart"}],
                                         "}"}], "/.", 
                                        RowBox[{
                                        RowBox[{"v", ":", 
                                        RowBox[{"{", 
                                        RowBox[{"__", "?", "NumberQ"}], 
                                        "}"}]}], "\[RuleDelayed]", 
                                        RowBox[{"Rt", ".", "v"}]}]}]}], 
                                    "]"}]}], "\[IndentingNewLine]", "}"}], 
                              ",", 
                              RowBox[{"Lighting", "\[Rule]", "False"}], ",", 
                              RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
                              "\[IndentingNewLine]", 
                              RowBox[{"PlotRange", "\[Rule]", 
                                RowBox[{"2.2", 
                                  RowBox[{"{", 
                                    RowBox[{
                                      RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"-", "1"}], ",", "1"}], "}"}],
                                       ",", 
                                      RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"-", "1"}], ",", "1"}], "}"}],
                                       ",", 
                                      RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"-", "1"}], ",", "1"}], 
                                        "}"}]}], "}"}]}]}]}], "]"}], 
                          "\[IndentingNewLine]", "\[IndentingNewLine]", ",", 
                          "anNB", ",", "\"\<drawcell\>\""}], "]"}], 
                      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          RowBox[{
                            RowBox[{"Pi", "/", "2"}], "/", "4"}], ",", 
                          RowBox[{"Pi", "/", "2"}], ",", 
                          RowBox[{
                            RowBox[{"Pi", "/", "2"}], "/", "4"}]}], "}"}]}], 
                    "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{537, 522},
WindowMargins->{{Automatic, 21}, {16, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowCellTags->True,
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "init"->{
    Cell[1783, 52, 221, 6, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[2109, 65, 312, 9, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[2542, 85, 171, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[2852, 100, 204, 6, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3059, 108, 440, 12, 55, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3524, 124, 255, 7, 55, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3998, 141, 225, 6, 36, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[4574, 165, 208, 6, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[4843, 175, 241, 7, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5087, 184, 394, 11, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5589, 202, 442, 12, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[6820, 246, 262, 7, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[7995, 290, 238, 7, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[8480, 310, 529, 14, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[9151, 331, 1758, 39, 151, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[11313, 386, 517, 15, 103, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[11833, 403, 311, 9, 55, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[12435, 426, 657, 16, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[13397, 462, 233, 8, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[13991, 488, 395, 11, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[14651, 515, 207, 6, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[14861, 523, 256, 7, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[15280, 539, 301, 8, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[15833, 562, 308, 9, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[17358, 612, 235, 7, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[17596, 621, 236, 7, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[18253, 646, 700, 19, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[19062, 672, 1122, 27, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[20258, 703, 1270, 30, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[21597, 737, 685, 17, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[23357, 789, 825, 20, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[24625, 831, 732, 19, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[26248, 885, 827, 18, 103, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[29681, 995, 455, 12, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[30402, 1021, 725, 21, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[31246, 1049, 414, 13, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[32084, 1083, 569, 16, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[32656, 1101, 914, 24, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[33573, 1127, 550, 14, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[34797, 1167, 2214, 50, 279, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[37356, 1238, 914, 23, 103, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[39330, 1298, 854, 24, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[40447, 1334, 531, 15, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[41082, 1356, 890, 23, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[42094, 1386, 1670, 36, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[43980, 1435, 2636, 57, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[46747, 1500, 565, 14, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[47762, 1537, 1291, 32, 119, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[49148, 1576, 3526, 79, 279, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[52793, 1663, 6495, 125, 503, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"init", 60212, 1816}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 63, 1, 98, "Title",
  InitializationCell->True],
Cell[1783, 52, 221, 6, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[CellGroupData[{
Cell[2029, 62, 77, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[2109, 65, 312, 9, 71, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[2458, 79, 28, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[2511, 83, 28, 0, 42, "Subsubsection"],
Cell[2542, 85, 171, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[2750, 95, 99, 3, 44, "Subsubsection"],
Cell[2852, 100, 204, 6, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3059, 108, 440, 12, 55, "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[CellGroupData[{
Cell[3524, 124, 255, 7, 55, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3782, 133, 201, 5, 70, "Output"]
}, Closed]],
Cell[3998, 141, 225, 6, 36, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4272, 153, 58, 1, 30, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4355, 158, 144, 3, 58, "Subsubsection"],
Cell[4502, 163, 69, 0, 30, "Text"],
Cell[4574, 165, 208, 6, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[4785, 173, 55, 0, 30, "Text"],
Cell[4843, 175, 241, 7, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[5087, 184, 394, 11, 87, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[5484, 197, 102, 3, 30, "Text"],
Cell[5589, 202, 442, 12, 71, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[6068, 219, 62, 0, 28, "Subsubsection"],
Cell[6133, 221, 684, 23, 62, "Text"],
Cell[6820, 246, 262, 7, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[7119, 258, 541, 17, 43, "Subsubsection"],
Cell[7663, 277, 75, 0, 30, "Text"],
Cell[7741, 279, 251, 9, 33, "Text"],
Cell[7995, 290, 238, 7, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[8236, 299, 241, 9, 30, "Text"],
Cell[8480, 310, 529, 14, 71, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[9012, 326, 136, 3, 46, "Text"],
Cell[9151, 331, 1758, 39, 151, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[10946, 375, 294, 7, 26, "Subsubsection"],
Cell[11243, 384, 67, 0, 30, "Text"],
Cell[11313, 386, 517, 15, 103, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[11833, 403, 311, 9, 55, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[12147, 414, 285, 10, 30, "Text"],
Cell[12435, 426, 657, 16, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13141, 448, 52, 1, 30, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[13218, 453, 37, 0, 42, "Subsubsection"],
Cell[13258, 455, 136, 5, 70, "Text"],
Cell[13397, 462, 233, 8, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[13667, 475, 321, 11, 28, "Subsubsection",
  InitializationCell->True],
Cell[13991, 488, 395, 11, 71, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14435, 505, 52, 1, 30, "Section",
  InitializationCell->True],
Cell[14490, 508, 50, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[14565, 512, 83, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[14651, 515, 207, 6, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[14861, 523, 256, 7, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[15154, 535, 49, 0, 28, "Subsubsection"],
Cell[15206, 537, 71, 0, 70, "Text"],
Cell[15280, 539, 301, 8, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[15618, 552, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[15691, 555, 139, 5, 78, "Text"],
Cell[15833, 562, 308, 9, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[16156, 574, 40, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[16221, 578, 1071, 30, 58, "Subsubsection",
  InitializationCell->True],
Cell[17295, 610, 60, 0, 70, "Text"],
Cell[17358, 612, 235, 7, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[17596, 621, 236, 7, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[17835, 630, 415, 14, 70, "Text"],
Cell[18253, 646, 700, 19, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[18956, 667, 103, 3, 70, "Text"],
Cell[19062, 672, 1122, 27, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[20187, 701, 68, 0, 70, "Text"],
Cell[20258, 703, 1270, 30, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[21531, 735, 63, 0, 70, "Text"],
Cell[21597, 737, 685, 17, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[22319, 759, 72, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[22394, 762, 80, 1, 30, "Text",
  InitializationCell->True],
Cell[22477, 765, 80, 1, 30, "Text",
  InitializationCell->True],
Cell[22560, 768, 794, 19, 59, "Input",
  InitializationCell->True],
Cell[23357, 789, 825, 20, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24231, 815, 98, 1, 30, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[24354, 820, 268, 9, 42, "Subsubsection"],
Cell[24625, 831, 732, 19, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[25394, 855, 48, 0, 28, "Subsubsection"],
Cell[25445, 857, 635, 18, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26117, 880, 88, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[26208, 883, 37, 0, 30, "Text"],
Cell[26248, 885, 827, 18, 103, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27124, 909, 58, 1, 30, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[27207, 914, 65, 1, 46, "Subsection",
  InitializationCell->True],
Cell[27275, 917, 2008, 62, 126, "Text"],
Cell[29286, 981, 267, 7, 62, "Text"],
Cell[29556, 990, 122, 3, 26, "SmallText"],
Cell[29681, 995, 455, 12, 71, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[30173, 1012, 112, 2, 30, "Subsection",
  InitializationCell->True],
Cell[30288, 1016, 111, 3, 30, "Text"],
Cell[30402, 1021, 725, 21, 71, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[31130, 1044, 113, 3, 30, "Text"],
Cell[31246, 1049, 414, 13, 71, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[31663, 1064, 418, 17, 30, "Text"],
Cell[32084, 1083, 569, 16, 71, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[32656, 1101, 914, 24, 87, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[33573, 1127, 550, 14, 87, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[34126, 1143, 668, 22, 94, "Text"],
Cell[34797, 1167, 2214, 50, 279, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37060, 1223, 55, 1, 30, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[37140, 1228, 68, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[37211, 1231, 142, 5, 32, "Text"],
Cell[37356, 1238, 914, 23, 103, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[38307, 1266, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[38386, 1269, 91, 3, 70, "Text"],
Cell[38480, 1274, 847, 22, 70, "Text"],
Cell[39330, 1298, 854, 24, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[40187, 1324, 257, 8, 70, "Text"],
Cell[40447, 1334, 531, 15, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[40981, 1351, 98, 3, 70, "Text"],
Cell[41082, 1356, 890, 23, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[41975, 1381, 116, 3, 70, "Text"],
Cell[42094, 1386, 1670, 36, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[43801, 1427, 64, 1, 30, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[43890, 1432, 87, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[43980, 1435, 2636, 57, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[46653, 1497, 91, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[46747, 1500, 565, 14, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[47373, 1521, 88, 2, 30, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[47486, 1527, 122, 2, 42, "Subsubsection",
  InitializationCell->True],
Cell[47611, 1531, 148, 4, 46, "Text"],
Cell[47762, 1537, 1291, 32, 119, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[49056, 1571, 89, 3, 30, "Text"],
Cell[49148, 1576, 3526, 79, 279, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[52711, 1660, 79, 1, 46, "Subsection",
  InitializationCell->True],
Cell[52793, 1663, 6495, 125, 503, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

