(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5910,        210]*)
(*NotebookOutlinePosition[      8460,        288]*)
(*  CellTagsIndexPosition[      8363,        281]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik Fns Package", "Title"],

Cell[CellGroupData[{

Cell["Set Up", "Subtitle",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "BeginPackage", "[", "\"\<RubikPkFolder`RubikGraphicsPk`\>\"", "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["interface and documentation for Rubik fns", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
          "Rot90GenLabels", ",", "rx", ",", "ry", ",", "rz", ",", 
            "\[IndentingNewLine]", "fx", ",", "fy", ",", "fz", ",", 
            RowBox[{"(*", 
              RowBox[{"face", " ", "labels"}], " ", "*)"}], 
            "\[IndentingNewLine]", "\[IndentingNewLine]", "q", ",", "g", ",", 
            "Inv", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "InitialColoredMiniFaceConfiguration", ",", "qRulesOfRubikGen", 
            ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "Animategop", 
            ",", "DisplayCube"}], "\[IndentingNewLine]", "}"}], 
        ";"}]}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
Rot90GenLabels::usage=\"labels rx,ry,rz of (positive) rectilinear \
rotation axis\";
Posns::usage=\"Positions of centers of blocks\";
InitialColoredMiniFaceConfiguration::usage=\"\";
q::usage=\"q[posn,face,kolor] is a colored mini face\";
g::usage=\" g[r,s] is a Rubik generator\";
Inv::usage=\"Inverse of an operator symbol\";
qRulesOfRubikGen::usage=\"qRulesOfRubikGen[Inv[gop_]|gop_g] gives the colored \
miniface permutation rule of a Rubik generator.\";
DisplayCube::usage=\"DisplayCube[aCube_, anNB_, tg_, Mirrored_] displays a \
cube (colored mini face configuration) in the notebook anNB at the tag tg \
(with mirrors).\";
Animategop::usage=\"Animategop[gop_Inv|gop_, aCube_, anNB_] animates the \
Rubik generator (acting on a cube) in the notebook.\";
\
\>", "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["enter private", "Subsection"],

Cell[CellGroupData[{

Cell["private", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spelling Off", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Off", "[", 
        RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["protection", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Protect", "[", "RubikPkFolder`RubikGraphicsPk", "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Main Function File", "Section",
  InitializationCell->True],

Cell["Should be in same directory.", "Text"],

Cell["\<\
Get[\"RubikFns.m\",Path\[Rule]{Global`RubiksCubePathSep}];\
\>", \
"Text",
  CellTags->"init"],

Cell["ok???", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikGraphicsFns.m\>\"", "]"}], ";"}]], "Input",\

  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", 
        RowBox[{"\"\<RubikGraphicsFns.m\>\"", ",", 
          RowBox[{"Path", "->", 
            RowBox[{"DirectoryName", "[", "$Input", "]"}]}]}], "]"}], 
      ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["finale", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"End", "[", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"EndPackage", "[", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spelling On", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"On", "[", 
        RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{601, 479},
WindowMargins->{{Automatic, 66}, {29, Automatic}},
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "packcells"->{
    Cell[1833, 56, 204, 6, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[3896, 117, 162, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4408, 141, 183, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5361, 185, 139, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5503, 191, 146, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}]},
  "init"->{
    Cell[1833, 56, 204, 6, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[2171, 70, 756, 16, 155, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[2930, 88, 834, 18, 267, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3896, 117, 162, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4135, 128, 170, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[4408, 141, 183, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4760, 157, 104, 4, 30, "Text",
      CellTags->"init"],
    Cell[5361, 185, 139, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5503, 191, 146, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5725, 202, 169, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"packcells", 6737, 231},
  {"init", 7314, 247}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 34, 0, 98, "Title"],

Cell[CellGroupData[{
Cell[1776, 53, 54, 1, 62, "Subtitle",
  InitializationCell->True],
Cell[1833, 56, 204, 6, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[2074, 67, 94, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[2171, 70, 756, 16, 155, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[2930, 88, 834, 18, 267, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[3801, 111, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[3861, 115, 32, 0, 42, "Subsubsection"],
Cell[3896, 117, 162, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4095, 126, 37, 0, 42, "Subsubsection"],
Cell[4135, 128, 170, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[4342, 138, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[4408, 141, 183, 5, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4640, 152, 70, 1, 30, "Section",
  InitializationCell->True],
Cell[4713, 155, 44, 0, 30, "Text"],
Cell[4760, 157, 104, 4, 30, "Text",
  CellTags->"init"],
Cell[4867, 163, 21, 0, 30, "Text"],
Cell[4891, 165, 136, 4, 27, "Input",
  InitializationCell->True],
Cell[5030, 171, 232, 6, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5299, 182, 59, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[5361, 185, 139, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}],
Cell[5503, 191, 146, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[5686, 200, 36, 0, 28, "Subsubsection"],
Cell[5725, 202, 169, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

