(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27386,        892]*)
(*NotebookOutlinePosition[     31412,       1018]*)
(*  CellTagsIndexPosition[     31342,       1012]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubiks Interface Functions", "Title"],

Cell[BoxData[
    RowBox[{"(*", 
      RowBox[{
        RowBox[{"Gerrard", " ", "Liddell"}], ",", 
        RowBox[{"\[Copyright]November", " ", "2001"}]}], "*)"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["Initialization", "Subtitle"],

Cell[CellGroupData[{

Cell["context", "Subsubsection"],

Cell["\<\

Usually called by the Rubik package that sets the context and checks files.
The package also has set RubiksCubePathSep and loaded the Rubik fns.
This file uses RubiksCubePathSep to open Rubiks Window.\
\>", "Text"],

Cell["\<\
For development, this needs the Rubik fns loaded and the \
RubiksCubePathSep 
(as it open Rubiks Window).\
\>", "Text"]
}, Closed]],

Cell["Operations on the cube", "Subtitle"],

Cell[CellGroupData[{

Cell["DoOpAnimate[gop_]", "Subsubsection",
  InitializationCell->True],

Cell["Animate the Rotation of the slice thru the generator gop.", "Text"],

Cell["Updates CurrentLabelCubeFaces.", "Text"],

Cell["Could adapt this to animate any sequence of moves.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "DoOpAnimate", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"DoOpAnimate", "[", 
          RowBox[{"gop", ":", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"g", "[", 
                  RowBox[{"r_", ",", "s_"}], "]"}], "|", 
                RowBox[{"_Inv", "[", 
                  RowBox[{"g", "[", 
                    RowBox[{"r_", ",", "s_"}], "]"}], "]"}]}], ")"}]}], "]"}],
         ":=", "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"NewLabelCubeFaces", "=", 
                RowBox[{"CurrentLabelCubeFaces", "/.", 
                  RowBox[{"(", 
                    RowBox[{"qRulesOfRubikGen", "[", "gop", "]"}], ")"}]}]}], 
              "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"Animategop", "[", 
                RowBox[{
                "gop", ",", "CurrentLabelCubeFaces", ",", "RubikWindowNB"}], 
                "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"CurrentLabelCubeFaces", "=", "NewLabelCubeFaces"}]}]}],
           "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["DoPerm[MiniFacePermRules_]", "Subsubsection"],

Cell["\<\
Performs the operation on the cube and updates \
CurrentLabelCubeFaces.\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "DoPerm", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"DoPerm", "[", "MiniFacePermRules_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"NewLabelCubeFaces", "=", 
                RowBox[{
                "CurrentLabelCubeFaces", "/.", "MiniFacePermRules"}]}], "}"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"DisplayCube", "[", 
                RowBox[{
                "NewLabelCubeFaces", ",", "RubikWindowNB", ",", 
                  "\"\<drawcell\>\"", ",", "ShowMirror"}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"CurrentLabelCubeFaces", "=", "NewLabelCubeFaces"}]}]}],
           "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["DoOpFast[gop_]", "Subsubsection"],

Cell["For the simple generators:", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "DoOpFast", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"DoOpFast", "[", "gop_", "]"}], ":=", "\[IndentingNewLine]", 
        RowBox[{"DoPerm", "[", 
          RowBox[{"qRulesOfRubikGen", "[", "gop", "]"}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["State", "Subtitle"],

Cell[CellGroupData[{

Cell["state mode variables", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"InversesOn", "=", "False"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ShowMirror", "=", "False"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AnimationOn", "=", "True"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["state constraints", "Subsubsection"],

Cell["\<\
 AnimationOn\[DoubleLongRightArrow]MirrorsOff&InversesOff
  need contra MirrorsOn\[DoubleLongRightArrow]AnimationOff, InveresOn\
\[DoubleLongRightArrow]AnimationOff.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["alt states", "SmallText"],

Cell[BoxData["statereact"], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MapThread", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"#1", "\[NotEqual]", "#2"}], ",", "#3"}], "]"}], 
            "&"}], ",", 
          RowBox[{"{", 
            RowBox[{"heldstate", ",", "newstate", ",", "actions"}], "}"}]}], 
        "]"}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["mirror", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["(SetMirror[aBoolean_])", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "SetMirror", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"SetMirror", "[", "aBoolean_", "]"}], ":=", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"ShowMirror", "=", "aBoolean"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{"ShowMirror", ",", 
                RowBox[{
                  RowBox[{"AnimationOn", "=", "False"}], ";", 
                  RowBox[{"InversesOn", "=", "False"}]}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"DisplayCube", "[", 
              RowBox[{
              "CurrentLabelCubeFaces", ",", "RubikWindowNB", ",", 
                "\"\<drawcell\>\"", ",", "ShowMirror"}], "]"}]}], ")"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetMirrorValue[]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "GetMirrorValue"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"GetMirrorValue", "[", "]"}], ":=", "ShowMirror"}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["ToggleMirror[_]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ToggleMirror", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"ToggleMirror", "[", "_", "]"}], ":=", 
        RowBox[{"SetMirror", "[", 
          RowBox[{"Not", "[", "ShowMirror", "]"}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["inverses:InversesOn", "Subsection"],

Cell[CellGroupData[{

Cell["InvOfOp[Op_]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "InvOfOp"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"InvOfOp", "[", 
          RowBox[{"Inv", "[", "Op_", "]"}], "]"}], ":=", "Op"}], ";", 
      RowBox[{
        RowBox[{"InvOfOp", "[", "Op_", "]"}], ":=", 
        RowBox[{"Inv", "[", "Op", "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["WrapInverse[gop_]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "WrapInverse", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"WrapInverse", "[", "gop_", "]"}], ":=", 
        RowBox[{"If", "[", 
          RowBox[{"InversesOn", ",", 
            RowBox[{"InvOfOp", "[", "gop", "]"}], ",", "gop"}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetInverseValue[]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "GetInverseValue"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"GetInverseValue", "[", "]"}], ":=", "InversesOn"}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["ToggleInverse[_]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ToggleInverse", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"ToggleInverse", "[", "_", "]"}], ":=", "\[IndentingNewLine]",
         
        RowBox[{"(", 
          RowBox[{
            RowBox[{"InversesOn", "=", 
              RowBox[{"Not", "[", "InversesOn", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{"InversesOn", ",", 
                RowBox[{"AnimationOn", "=", "False"}]}], "]"}], ";"}], 
          ")"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[CellGroupData[{

Cell["GetAnimationValue[]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "GetAnimationValue"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"GetAnimationValue", "[", "]"}], ":=", "AnimationOn"}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["ToggleAnimation[_]", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ToggleAnimation", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"ToggleAnimation", "[", "_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"AnimationOn", "=", 
              RowBox[{"Not", "[", "AnimationOn", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{"AnimationOn", ",", 
                RowBox[{
                  RowBox[{"SetMirror", "[", "False", "]"}], ";", 
                  RowBox[{"InversesOn", "=", "False"}], ";"}]}], "]"}]}], 
          ")"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ResetCube[]", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ResetCube", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"ResetCube", "[", "]"}], ":=", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
            "CurrentLabelCubeFaces", "=", 
              "InitialColoredMiniFaceConfiguration"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"DisplayCube", "[", 
              RowBox[{
              "CurrentLabelCubeFaces", ",", "RubikWindowNB", ",", 
                "\"\<drawcell\>\"", ",", "ShowMirror"}], 
              RowBox[{"(*", 
                RowBox[{"non", " ", "Mirrored"}], "*)"}], "]"}]}], ")"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["Managing Moves", "Subtitle"],

Cell[CellGroupData[{

Cell["notes", "Subsubsection"],

Cell["Manage the list of current moves.", "Text"],

Cell["\<\
The current moves are used for undo,
so the user can see the operations cumulatively performed,
so the user can define a move from the current moves.
We also want to keep symbolic expressions for the moves defined.\
\>", "Text"],

Cell["\<\
Each move has:
-a formula,
-a function that returns its undo colored mini face permutation.
Use data type TMove[formula,GetUndoPerm].\
\>", "Text"],

Cell["\<\
The current moves display the formula for the moves.
The user buttons also use this formula.\
\>", "Text"],

Cell["\<\
Retaining the symbolic formulae, makes it easy to animate entire \
formulae.\
\>", "Text"],

Cell["Current moves cell is tagged with \"currentmoves\".", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["formulae", "Subsubsection"],

Cell[TextData[{
  "The formulae are built from the basic generators ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "[", 
          RowBox[{
            RowBox[{"\[PlusMinus]", "r"}], ",", "s"}], "]"}], 
        TraditionalForm]]],
  " and user defined moves ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["g", "i"], TraditionalForm]]],
  " via:\n-composition\n-inverses.\n"
}], "Text"],

Cell["\<\
Rules to convert a rotation button content to the associated \
generator.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["BoxesOfFormulae[f_]", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RotIcons", "=", 
        RowBox[{"{", 
          RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FormulaToBoxesRules", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{"g", "[", 
                RowBox[{"r_", ",", "1"}], "]"}], ":>", 
              RowBox[{"(", 
                RowBox[{"r", "/.", 
                  RowBox[{
                    RowBox[{"-", "ar_"}], "\[Rule]", 
                    RowBox[{"RowBox", "[", 
                      RowBox[{"{", 
                        RowBox[{"\"\<-\>\"", ",", "ar"}], "}"}], "]"}]}]}], 
                ")"}]}], ",", 
            RowBox[{
              RowBox[{"g", "[", 
                RowBox[{"r_", ",", "s_"}], "]"}], ":>", 
              RowBox[{"SubscriptBox", "[", 
                RowBox[{
                  RowBox[{"r", "/.", 
                    RowBox[{
                      RowBox[{"-", "ar_"}], "\[Rule]", 
                      RowBox[{"RowBox", "[", 
                        RowBox[{"{", 
                          RowBox[{"\"\<-\>\"", ",", "ar"}], "}"}], "]"}]}]}], 
                  ",", 
                  RowBox[{"s", "/.", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"-", "1"}], "\[Rule]", "\"\<-\>\""}], ",", 
                        RowBox[{"0", "\[Rule]", "\"\<0\>\""}]}], "}"}]}]}], 
                "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"Inv", "[", "aFormula_", "]"}], "\[Rule]", 
              RowBox[{"SuperscriptBox", "[", 
                RowBox[{"aFormula", ",", "\"\<-1\>\""}], "]"}]}], ",", 
            RowBox[{
              RowBox[{"Subscript", "[", 
                RowBox[{"g", ",", "i_"}], "]"}], ":>", 
              RowBox[{"SubscriptBox", "[", 
                RowBox[{
                  RowBox[{"ToString", "@", "g"}], ",", 
                  RowBox[{"ToString", "@", "i"}]}], "]"}]}]}], "}"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "@", "BoxesOfFormulaeAux"}], ";", 
      RowBox[{
        RowBox[{"BoxesOfFormulaeAux", "[", "aFormula_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"aFormula", "/.", 
                RowBox[{"Thread", "[", 
                  RowBox[{"Rot90GenLabels", "\[Rule]", "RotIcons"}], "]"}]}], 
              "//.", 
              RowBox[{
                RowBox[{"{", "Formulas___", "}"}], "\[Rule]", 
                RowBox[{"RowBox", "[", 
                  RowBox[{"SequenceForm", "[", 
                    RowBox[{"\"\<(\>\"", ",", "Formulas", ",", "\"\<)\>\""}], 
                    "]"}], "]"}]}]}], "//.", "FormulaToBoxesRules"}], "/.", 
          RowBox[{"SequenceForm", "\[Rule]", "List"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "@", "BoxesOfFormulae"}], ";", 
      RowBox[{
        RowBox[{"BoxesOfFormulae", "[", "aFormula_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"FormBox", "[", 
          RowBox[{
            RowBox[{"BoxesOfFormulaeAux", "[", "aFormula", "]"}], ",", 
            "TraditionalForm"}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["CurrentMovesList", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"CurrentMovesList", "=", 
        RowBox[{"{", "}"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["CurrentMovesCellExprOf[CurrentFormulas_]", "Subsubsection"],

Cell["\<\
Only display MaxCurrDisplay across the cell at a time.
If too many moves for a line, then scroll back.\
\>", "Text"],

Cell["\<\
Note problems with  forcing correct display in \
TraditionalForm.\
\>", "SmallText"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MaxCurrDisplay", "=", "20"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "CurrentMovesCellExprOf", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"CurrentMovesCellExprOf", "[", "CurrentFormulas_", "]"}], ":=",
         
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"LenCurr", "=", 
                RowBox[{"Length", "[", "CurrentFormulas", "]"}]}], "}"}], ",",
             
            RowBox[{"Cell", "[", 
              RowBox[{
                RowBox[{"TextData", "[", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"Cell", "[", 
                        RowBox[{"BoxData", "[", 
                          RowBox[{"RowBox", "[", 
                            RowBox[{"{", "\"\<\!\(\*
StyleBox[\\\"Current\\\",\\nFontSize->16,\\nFontColor->GrayLevel[0.666667]]\) \
\!\(\*
StyleBox[\\\"Moves\\\",\\nFontSize->16,\\nFontColor->GrayLevel[0.666667]]\) =\
\>\"", "}"}], "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
                      RowBox[{"Cell", "[", 
                        RowBox[{"BoxData", "[", 
                          RowBox[{"If", "[", 
                            RowBox[{
                              RowBox[{"LenCurr", "<", "MaxCurrDisplay"}], 
                              ",", "\"\<\>\"", ",", "\"\<\[Ellipsis]\>\""}], 
                            "]"}], "]"}], "]"}], ",", 
                      RowBox[{"Cell", "[", 
                        RowBox[{"BoxData", "[", 
                          RowBox[{"BoxesOfFormulae", "[", 
                            RowBox[{"Take", "[", 
                              RowBox[{"CurrentFormulas", ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"Max", "[", 
                                      RowBox[{"1", ",", 
                                        RowBox[{
                                        "LenCurr", "-", "MaxCurrDisplay"}]}], 
                                      "]"}], ",", "LenCurr"}], "}"}]}], "]"}],
                             "]"}], "\[IndentingNewLine]", "]"}], "]"}]}], 
                    "}"}], "]"}], ",", "\"\<Text\>\"", ",", 
                RowBox[{"CellTags", "\[Rule]", "\"\<currentlist\>\""}]}], 
              "]"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["WriteCurrentMoves[CurrentMovesList_]", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "[", "WriteCurrentMoves", "]"}], ";", 
      RowBox[{
        RowBox[{"WriteCurrentMoves", "[", "CurrentMovesList_", "]"}], ":=", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"NotebookFind", "[", 
              RowBox[{
              "RubikWindowNB", ",", "\"\<currentlist\>\"", ",", "All", ",", 
                RowBox[{"{", "CellTags", "}"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"NotebookWrite", "[", 
              RowBox[{"RubikWindowNB", ",", "\[IndentingNewLine]", 
                RowBox[{"CurrentMovesCellExprOf", "[", 
                  RowBox[{"First", "/@", "CurrentMovesList"}], "]"}]}], 
              "]"}]}], ")"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["AddCurrentMove[TMove[aFormula_,GetInvPerm_]]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "AddCurrentMove", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{"AddCurrentMove", "[", 
        RowBox[{"m", ":", 
          RowBox[{"TMove", "[", 
            RowBox[{"aFormula_", ",", "GetInvPerm_"}], "]"}]}], "]"}], ":=", 
      "\[IndentingNewLine]", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"AppendTo", "[", 
            RowBox[{"CurrentMovesList", ",", "m"}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"WriteCurrentMoves", "[", "CurrentMovesList", "]"}]}], 
        ")"}]}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["ClearMovesButtonFn[]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "ClearCurrentMoves", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"ClearCurrentMoves", "[", "]"}], ":=", "\[IndentingNewLine]", 
        
        RowBox[{"(", 
          RowBox[{
            RowBox[{"CurrentMovesList", "=", 
              RowBox[{"{", "}"}]}], ";", 
            RowBox[{"WriteCurrentMoves", "[", "CurrentMovesList", "]"}], 
            ";"}], ")"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"ClearMovesButtonFn", "[", "_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"ClearCurrentMoves", "[", "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ResetCube", "[", "]"}]}], ")"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["UndoTransformation[TMove[_,GetUndoPerm_]]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "UndoTransformation", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"UndoTransformation", "[", 
          RowBox[{"TMove", "[", 
            RowBox[{"_", ",", "GetUndoPerm_"}], "]"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"CurrentLabelCubeFaces", "=", 
              RowBox[{"CurrentLabelCubeFaces", "/.", 
                RowBox[{"GetUndoPerm", "[", "]"}]}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"DisplayCube", "[", 
              RowBox[{
              "CurrentLabelCubeFaces", ",", "RubikWindowNB", ",", 
                "\"\<drawcell\>\"", ",", "ShowMirror"}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"CurrentMovesList", "=", 
              RowBox[{"Drop", "[", 
                RowBox[{"CurrentMovesList", ",", 
                  RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"WriteCurrentMoves", "[", "CurrentMovesList", "]"}], 
            ";"}], "\[IndentingNewLine]", ")"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["UndoMoveButtonFn[_]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "UndoMoveButtonFn", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"UndoMoveButtonFn", "[", "_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"Length", "[", "CurrentMovesList", "]"}], ">=", "1"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"UndoTransformation", "[", 
                RowBox[{"CurrentMovesList", "[", 
                  RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"WriteCurrentMoves", "[", "]"}]}]}], "]"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["Rubik Generator Buttons", "Subtitle"],

Cell[CellGroupData[{

Cell["RubikGenMoveButtonFn[bc_,gop_]", "Subsubsection"],

Cell["\<\
WrapInverse@
  (RotAxisLabelOfRubikGen[rawgop]/.Thread[AxisLabels\[Rule] RotIcons])\
\>", \
"Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "RubikGenMoveButtonFn", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"RubikGenMoveButtonFn", "[", 
          RowBox[{"bc_", ",", "Buttongop_"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"gop", "=", 
                RowBox[{"WrapInverse", "@", "Buttongop"}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"If", "[", 
                RowBox[{"AnimationOn", ",", 
                  RowBox[{"DoOpAnimate", "[", "gop", "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"DoOpFast", "[", "gop", "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"AddCurrentMove", "[", 
                RowBox[{"TMove", "[", 
                  RowBox[{"gop", ",", "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{"qRulesOfRubikGen", "[", 
                        RowBox[{"InvOfOp", "[", "gop", "]"}], "]"}], "&"}]}], 
                  "\[IndentingNewLine]", "]"}], "]"}]}]}], 
          "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{512, 575},
WindowMargins->{{Automatic, 73}, {Automatic, 3}},
ShowCellTags->True,
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "init"->{
    Cell[1763, 51, 221, 6, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[2787, 92, 1246, 31, 167, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[4222, 135, 912, 23, 151, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5258, 167, 365, 10, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5736, 186, 135, 4, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5874, 192, 135, 4, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[6012, 198, 135, 4, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[7079, 245, 864, 22, 135, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[8024, 274, 258, 8, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[8362, 289, 337, 9, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[8854, 310, 391, 11, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[9327, 328, 389, 11, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[9798, 346, 260, 8, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[10139, 361, 621, 17, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[10912, 390, 265, 8, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[11288, 406, 722, 19, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[12126, 434, 734, 20, 119, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[14367, 521, 230, 7, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[14600, 530, 1980, 48, 135, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[16583, 580, 894, 21, 119, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[17480, 603, 426, 11, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[17987, 621, 161, 5, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[18479, 643, 136, 4, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[18618, 649, 2405, 50, 247, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[21124, 706, 799, 18, 135, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[22032, 731, 635, 17, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[22752, 755, 510, 14, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[23265, 771, 392, 11, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[23763, 789, 1185, 27, 167, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[25032, 823, 802, 21, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[26087, 859, 1283, 30, 167, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"init", 28227, 914}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 43, 0, 98, "Title"],
Cell[1763, 51, 221, 6, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[1987, 59, 34, 0, 62, "Subtitle"],

Cell[CellGroupData[{
Cell[2046, 63, 32, 0, 42, "Subsubsection"],
Cell[2081, 65, 225, 5, 70, "Text"],
Cell[2309, 72, 129, 4, 70, "Text"]
}, Closed]],
Cell[2453, 79, 42, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[2520, 83, 70, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[2593, 86, 73, 0, 30, "Text"],
Cell[2669, 88, 46, 0, 30, "Text"],
Cell[2718, 90, 66, 0, 30, "Text"],
Cell[2787, 92, 1246, 31, 167, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[4070, 128, 51, 0, 28, "Subsubsection"],
Cell[4124, 130, 95, 3, 30, "Text"],
Cell[4222, 135, 912, 23, 151, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[5171, 163, 39, 0, 28, "Subsubsection"],
Cell[5213, 165, 42, 0, 30, "Text"],
Cell[5258, 167, 365, 10, 71, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[5638, 180, 25, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[5688, 184, 45, 0, 42, "Subsubsection"],
Cell[5736, 186, 135, 4, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[5874, 192, 135, 4, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[6012, 198, 135, 4, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[6184, 207, 42, 0, 28, "Subsubsection"],
Cell[6229, 209, 189, 4, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6455, 218, 31, 0, 24, "SmallText"],
Cell[6489, 220, 36, 0, 27, "Input"],
Cell[6528, 222, 383, 11, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6948, 238, 56, 1, 30, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[7029, 243, 47, 0, 42, "Subsubsection"],
Cell[7079, 245, 864, 22, 135, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[7980, 272, 41, 0, 42, "Subsubsection"],
Cell[8024, 274, 258, 8, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[8319, 287, 40, 0, 28, "Subsubsection"],
Cell[8362, 289, 337, 9, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8748, 304, 41, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[8814, 308, 37, 0, 70, "Subsubsection"],
Cell[8854, 310, 391, 11, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[9282, 326, 42, 0, 70, "Subsubsection"],
Cell[9327, 328, 389, 11, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[9753, 344, 42, 0, 70, "Subsubsection"],
Cell[9798, 346, 260, 8, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[10095, 359, 41, 0, 70, "Subsubsection"],
Cell[10139, 361, 621, 17, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10809, 384, 31, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[10865, 388, 44, 0, 70, "Subsubsection"],
Cell[10912, 390, 265, 8, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[11214, 403, 71, 1, 70, "Subsubsection",
  InitializationCell->True],
Cell[11288, 406, 722, 19, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12059, 431, 64, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[12126, 434, 734, 20, 119, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[12875, 457, 34, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[12934, 461, 30, 0, 42, "Subsubsection"],
Cell[12967, 463, 49, 0, 30, "Text"],
Cell[13019, 465, 238, 5, 78, "Text"],
Cell[13260, 472, 157, 5, 78, "Text"],
Cell[13420, 479, 116, 3, 46, "Text"],
Cell[13539, 484, 100, 3, 30, "Text"],
Cell[13642, 489, 67, 0, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13746, 494, 33, 0, 28, "Subsubsection"],
Cell[13782, 496, 401, 13, 70, "Text"],
Cell[14186, 511, 97, 3, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14320, 519, 44, 0, 28, "Subsubsection"],
Cell[14367, 521, 230, 7, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[14600, 530, 1980, 48, 135, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[16583, 580, 894, 21, 119, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[17480, 603, 426, 11, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[17943, 619, 41, 0, 28, "Subsubsection"],
Cell[17987, 621, 161, 5, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[18185, 631, 65, 0, 28, "Subsubsection"],
Cell[18253, 633, 126, 3, 46, "Text"],
Cell[18382, 638, 94, 3, 26, "SmallText"],
Cell[18479, 643, 136, 4, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[18618, 649, 2405, 50, 247, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[21060, 704, 61, 0, 28, "Subsubsection"],
Cell[21124, 706, 799, 18, 135, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[21960, 729, 69, 0, 28, "Subsubsection"],
Cell[22032, 731, 635, 17, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[22704, 753, 45, 0, 28, "Subsubsection"],
Cell[22752, 755, 510, 14, 70, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[23265, 771, 392, 11, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[23694, 787, 66, 0, 28, "Subsubsection"],
Cell[23763, 789, 1185, 27, 167, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[24985, 821, 44, 0, 28, "Subsubsection"],
Cell[25032, 823, 802, 21, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[25849, 847, 43, 0, 51, "Subtitle"],

Cell[CellGroupData[{
Cell[25917, 851, 55, 0, 42, "Subsubsection"],
Cell[25975, 853, 109, 4, 46, "Text"],
Cell[26087, 859, 1283, 30, 167, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

