(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6849,        215]*)
(*NotebookOutlinePosition[      9335,        291]*)
(*  CellTagsIndexPosition[      9238,        284]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik Fns Package", "Title"],

Cell[CellGroupData[{

Cell["Set Up", "Subtitle",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"BeginPackage", "[", 
        RowBox[{
        "\"\<RubikPkFolder`RubikInterfacePk`\>\"", ",", 
          "\[IndentingNewLine]", "\"\<RubikPkFolder`RubikGraphicsPk`\>\""}], 
        "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["interface and documentation for Rubik fns", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{"{", 
        RowBox[{
        "CurrentLabelCubeFaces", ",", "DoPerm", ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "GetMirrorValue", ",", "ToggleMirror", ",", 
          "InvOfOp", ",", "WrapInverse", ",", "GetInverseValue", ",", 
          "ToggleInverse", ",", "GetAnimationValue", ",", "ToggleAnimation", 
          ",", "\[IndentingNewLine]", "\[IndentingNewLine]", "ResetCube", ",",
           "\[IndentingNewLine]", "\[IndentingNewLine]", "TMove", ",", 
          "BoxesOfFormulae", ",", "CurrentMovesList", ",", 
          "CurrentMovesCellExprOf", ",", "AddCurrentMove", ",", 
          "\[IndentingNewLine]", "ClearMovesButtonFn", ",", 
          "UndoMoveButtonFn", ",", "RubikGenMoveButtonFn", ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "RubikWindowNB"}], 
        "}"}]}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
CurrentLabelCubeFaces::usage=\"\";
RubikWindowNB::usage=\"\";
DoPerm::usage=\"DoPerm[MiniFacePermRules_]\";
GetMirrorValue::usage=\"GetMirrorValue[] gets the boolean value of the mirror \
state variable.\";
ToggleMirror::usage=\"ToggleMirror[_] toggles the mirror state variable and \
sets other state variables consistently ( no display of state variables is \
involved, but graphics will be altered)\";
InvOfOp::usage=\"InvOfOp[Inv[Op_]|Op_] takes the symbolic inverse (wraps or \
removes the Inv symbol)\";
WrapInverse::usage=\"WrapInverse[gop_] takes the inverse if the inverse state \
variable is on.\";
GetInverseValue::usage=\"GetInverseValue[]\";
ToggleInverse::usage=\"ToggleInverse[_]  toggles the inverse state variable \
and sets other state variables consistently.\";
GetAnimationValue::usage=\"GetAnimationValue[]\";
ToggleAnimation::usage=\"ToggleAnimation[_]  toggles the animation state \
variable and sets other state variables consistently.\";
ResetCube::usage=\"ResetCube[] sets current cube to the standard initial \
configuration and displays it.\";
BoxesOfFormulae::usage=\"BoxesOfFormulae[aFormula_] makes boxes for a formula\
\";
CurrentMovesList::usage=\"The list of currently performed moves.\";
CurrentMovesCellExprOf::usage=\"CurrentMovesCellExprOf[CurrentFormulas_] \
creates the cell displaying the formulas for the current moves. \";
AddCurrentMove::usage=\"AddCurrentMove[m:TMove[aFormula_, GetInvPerm_]] adds \
a move to the current list and displays them.\";
TMove::usage=\"TMove[formula,GetUndoPerm] is a move with a formula and a \
method for getting colored mini face permutations for undo.\";
ClearMovesButtonFn::usage=\"ClearMovesButtonFn[_]\";
UndoMoveButtonFn::usage=\"UndoMoveButtonFn[_]\";
RubikGenMoveButtonFn::usage=\"RubikGenMoveButtonFn[bc_, Buttongop_]\";
\
\>", "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["enter private", "Subsection"],

Cell[CellGroupData[{

Cell["private", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spelling Off", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Off", "[", 
        RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["protection", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Protect", "[", "RubikPkFolder`RubikInterfacePk", "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Main Function File", "Section",
  InitializationCell->True],

Cell["On $Path", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikInterfaceFns.m\>\"", "]"}], 
      ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["finale", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"End", "[", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"EndPackage", "[", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spelling On", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"On", "[", 
        RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{520, 482},
WindowMargins->{{Automatic, 31}, {Automatic, 32}},
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "packcells"->{
    Cell[1833, 56, 309, 8, 43, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5214, 138, 162, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5726, 162, 184, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[6300, 190, 139, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[6442, 196, 146, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}]},
  "init"->{
    Cell[1833, 56, 309, 8, 43, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[2276, 72, 925, 17, 235, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3204, 91, 1878, 36, 627, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5214, 138, 162, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[5453, 149, 170, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5726, 162, 184, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[6300, 190, 139, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[6442, 196, 146, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[6664, 207, 169, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"packcells", 7676, 236},
  {"init", 8253, 252}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 34, 0, 98, "Title"],

Cell[CellGroupData[{
Cell[1776, 53, 54, 1, 62, "Subtitle",
  InitializationCell->True],
Cell[1833, 56, 309, 8, 43, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[2179, 69, 94, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[2276, 72, 925, 17, 235, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3204, 91, 1878, 36, 627, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[5119, 132, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[5179, 136, 32, 0, 42, "Subsubsection"],
Cell[5214, 138, 162, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[5413, 147, 37, 0, 42, "Subsubsection"],
Cell[5453, 149, 170, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[5660, 159, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[5726, 162, 184, 5, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5959, 173, 70, 1, 30, "Section",
  InitializationCell->True],
Cell[6032, 176, 24, 0, 30, "Text"],
Cell[6059, 178, 142, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6238, 187, 59, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[6300, 190, 139, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}],
Cell[6442, 196, 146, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[6625, 205, 36, 0, 28, "Subsubsection"],
Cell[6664, 207, 169, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

