(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28502,        780]*)
(*NotebookOutlinePosition[     31438,        873]*)
(*  CellTagsIndexPosition[     31368,        867]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["User Buttons", "Title"],

Cell[BoxData[
    RowBox[{"(*", 
      RowBox[{
        RowBox[{"Gerrard", " ", "Liddell"}], ",", 
        RowBox[{"\[Copyright]November", " ", "2001"}]}], "*)"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["Permutation Actions on mini-faces", "Subtitle"],

Cell[CellGroupData[{

Cell["Uses", "Subsubsection"],

Cell["\<\
RubikGraphics`
\tInitialColoredMiniFaceConfiguration,Inv,
\tInvOfOp,q, Posns, g
RubikInterface`
\tDoPerm,TMove,WrapInverse
\tBoxesOfFormulae,CurrentLabelCubeFaces,
\tCurrentMovesList,AddCurrentMove,
\tRubikWindowNB\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Notes", "Subsubsection"],

Cell["\<\
We use mini-face index permutations for the actions,
but colored mini-face permutations for the geometry.
Here are the translations.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MiniFaceLabels,MiniFaceIndices,MiniFaceLabels\[LeftRightArrow]\
MiniFaceIndexRules\
\>", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MiniFaceLabels", "=", 
        RowBox[{"Flatten", "[", 
          RowBox[{"InitialColoredMiniFaceConfiguration", "/.", 
            RowBox[{
              RowBox[{"q", "[", 
                RowBox[{"p_", ",", "f_", ",", "_"}], "]"}], "\[Rule]", 
              RowBox[{"q", "[", 
                RowBox[{"p", ",", "f"}], "]"}]}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MiniFaceIndices", "=", 
        RowBox[{"Range", "[", 
          RowBox[{"Length", "[", "MiniFaceLabels", "]"}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MiniFaceLabelsToMiniFaceIndexRules", "=", 
        RowBox[{"Thread", "[", 
          RowBox[{"MiniFaceLabels", "->", "MiniFaceIndices"}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"MiniFaceIndexToMiniFaceRules", "=", 
        RowBox[{"Reverse", "/@", "MiniFaceLabelsToMiniFaceIndexRules"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["kMiniFacePermRulesOfMiniFaceIndexPerm[Perm]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "kMiniFacePermRulesOfMiniFaceIndexPerm"}], ";", 
      RowBox[{
        RowBox[{"kMiniFacePermRulesOfMiniFaceIndexPerm", "[", 
          RowBox[{"Inv", "[", "\[Sigma]_", "]"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"kMiniFacePermRulesOfMiniFaceIndexPerm", "[", 
          RowBox[{"Reverse", "/@", "\[Sigma]"}], "]"}]}], ";"}], "\n", 
    RowBox[{
      RowBox[{
      "kMiniFacePermRulesOfMiniFaceIndexPerm", "[", "\[Sigma]_", "]"}], ":=", 
      
      RowBox[{
        RowBox[{"\[Sigma]", "/.", "MiniFaceIndexToMiniFaceRules"}], "/.", 
        RowBox[{
          RowBox[{"HoldPattern", "[", 
            RowBox[{
              RowBox[{"q", "[", 
                RowBox[{"p1_", ",", "f1_"}], "]"}], "\[Rule]", 
              RowBox[{"q", "[", 
                RowBox[{"p2_", ",", "f2_"}], "]"}]}], "]"}], "\[RuleDelayed]",
           "\[IndentingNewLine]", 
          RowBox[{"(", 
            RowBox[{"Rule", "@@", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"q", "[", 
                    RowBox[{"p1", ",", "f1", ",", "k_"}], "]"}], ",", 
                  RowBox[{"q", "[", 
                    RowBox[{"p2", ",", "f2", ",", "k"}], "]"}]}], "}"}]}], 
            ")"}]}]}]}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["ColorsToBlockRule,BlockToColorToFaceRules", "Subsubsection"],

Cell["\<\
Use initial configuration to relate blocks to sets of faces and \
colors.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ColorsToBlockRule", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"Posns", ",", 
            RowBox[{"b_", "\[RuleDelayed]", "\[IndentingNewLine]", 
              RowBox[{"Rule", "@@", 
                RowBox[{"(*", " ", 
                  RowBox[{"because", " ", "of", " ", "scoping"}], " ", "*)"}],
                 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Sort", "[", 
                      RowBox[{"Cases", "[", 
                        RowBox[{"InitialColoredMiniFaceConfiguration", ",", 
                          RowBox[{
                            RowBox[{"q", "[", 
                              RowBox[{"b", ",", "f_", ",", "k_"}], "]"}], "->",
                             "k"}], " ", ",", "Infinity"}], "]"}], "]"}], ",",
                     "b"}], "}"}]}]}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"BlockToColorToFaceRules", "=", 
        RowBox[{"Cases", "[", 
          RowBox[{"Posns", ",", 
            RowBox[{"b_", "\[RuleDelayed]", "\[IndentingNewLine]", 
              RowBox[{"(", 
                RowBox[{"b", "->", 
                  RowBox[{"Cases", "[", 
                    RowBox[{"InitialColoredMiniFaceConfiguration", ",", 
                      RowBox[{
                        RowBox[{"q", "[", 
                          RowBox[{"b", ",", "f_", ",", "k_"}], "]"}], 
                        "\[Rule]", 
                        RowBox[{"(", 
                          RowBox[{"k", "\[Rule]", "f"}], ")"}]}], ",", 
                      "Infinity"}], "]"}]}], ")"}]}]}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["IndexPermOfColorFacialConfig[akMiniFaceConfiguration_]:", \
"Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "IndexPermOfColorFacialConfig", "]"}], 
      ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
          "IndexPermOfColorFacialConfig", "[", "akMiniFaceConfiguration_", 
            "]"}], ":=", "\[IndentingNewLine]", 
          RowBox[{"DeleteCases", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"Flatten", "[", 
                  RowBox[{"Cases", "[", 
                    RowBox[{"Posns", ",", 
                      RowBox[{"p_", "\[RuleDelayed]", "\[IndentingNewLine]", 
                        RowBox[{"With", "[", 
                          RowBox[{
                            RowBox[{"{", 
                              RowBox[{"kfRules", "=", 
                                RowBox[{"Cases", "[", 
                                  RowBox[{"akMiniFaceConfiguration", ",", 
                                    RowBox[{
                                      RowBox[{"q", "[", 
                                        RowBox[{"p", ",", "f_", ",", "k_"}], 
                                        "]"}], "\[Rule]", 
                                      RowBox[{"(", 
                                        RowBox[{"k", "\[Rule]", " ", "f"}], 
                                        ")"}]}], ",", "Infinity"}], "]"}]}], 
                              "}"}], ",", "\[IndentingNewLine]", 
                            RowBox[{"With", "[", 
                              RowBox[{
                                RowBox[{"{", 
                                  RowBox[{"aBlock", "=", 
                                    RowBox[{
                                      RowBox[{"Sort", "[", 
                                        RowBox[{"First", "/@", "kfRules"}], 
                                        "]"}], "/.", "ColorsToBlockRule"}]}], 
                                  "}"}], ",", "\[IndentingNewLine]", 
                                RowBox[{"With", "[", 
                                  RowBox[{
                                    RowBox[{"{", 
                                      RowBox[{
                                      "TheBlockColorToFaceRules", "=", 
                                        RowBox[{
                                        "aBlock", "/.", 
                                        "BlockToColorToFaceRules"}]}], "}"}], 
                                    ",", "\[IndentingNewLine]", 
                                    RowBox[{"kfRules", "/.", 
                                      RowBox[{
                                        RowBox[{"(", 
                                        RowBox[{"k_", "\[Rule]", "_"}], ")"}],
                                         "\[RuleDelayed]", 
                                        "\[IndentingNewLine]", 
                                        RowBox[{"(", 
                                        RowBox[{
                                        RowBox[{"q", "[", 
                                        RowBox[{"aBlock", ",", 
                                        RowBox[{
                                        "k", "/.", 
                                        "TheBlockColorToFaceRules"}]}], "]"}],
                                         "\[Rule]", "\[IndentingNewLine]", 
                                        RowBox[{"q", "[", 
                                        RowBox[{"p", ",", 
                                        RowBox[{"k", "/.", "kfRules"}]}], 
                                        "]"}]}], ")"}]}]}]}], 
                                  "\[IndentingNewLine]", "]"}]}], "]"}]}], 
                          "]"}]}]}], "]"}], "]"}], "/.", 
                "MiniFaceLabelsToMiniFaceIndexRules"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"HoldPattern", "[", 
                RowBox[{"x_", "\[Rule]", "x_"}], "]"}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["User Buttons", "Subtitle"],

Cell["User button function", "Section"],

Cell[CellGroupData[{

Cell["notes", "Subsubsection"],

Cell[TextData[{
  "Usermoves is a list of formulae and actions associated with user buttons \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", ",", "\[Ellipsis]", ",", "n"}], TraditionalForm]]],
  ".\nThe actions are e.g. ",
  Cell[BoxData[
      FormBox[
        RowBox[{"TFormLPerm", "[", 
          RowBox[{"f", ",", 
            RowBox[{"LPerm", "[", 
              RowBox[{
                SubscriptBox["g", "2"], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"3", "\[Rule]", " ", "4"}], ",", 
                    RowBox[{"4", "\[Rule]", " ", "3"}]}], "}"}]}], "]"}]}], 
          "]"}], TraditionalForm]]],
  " where the permutation is of the miniface indices.\nThe button may display \
the formula defining the action in terms of other (previous) actions."
}], "Text"],

Cell[TextData[{
  "Use the same head ",
  Cell[BoxData[
      FormBox["g", TraditionalForm]]],
  " as for rubik generators, but embedded in a subscript."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["data initialization", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"UserMovesList", "=", 
        RowBox[{"{", "}"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell["\<\
User button window (default to RubikWindow), Tag for cell after \
user buttons.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"UserButtonNB", "=", "RubikWindowNB"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData[
    RowBox[{
      RowBox[{"AfterUserButtonsTag", "=", "\"\<After User Buttons\>\""}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["DoUserMove[bd_,i_]", "Subsubsection"],

Cell["i is parameter fixed in button.", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "[", "DoUserMove", "]"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"DoUserMove", "[", 
          RowBox[{"bd_", ",", "i_"}], "]"}], ":=", "\[IndentingNewLine]", 
        RowBox[{"Replace", "[", 
          RowBox[{
            RowBox[{"WrapInverse", "/@", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"UserMovesList", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "/.", 
                  RowBox[{
                    RowBox[{"TFormLPerm", "[", 
                      RowBox[{"aFormula_", ",", "anLPerm_"}], "]"}], 
                    "\[Rule]", "anLPerm"}]}], ")"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"LPerm", "[", 
                RowBox[{"gName_", ",", "Perm_"}], "]"}], "\[RuleDelayed]", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{"DoPerm", "[", 
                    RowBox[{
                    "kMiniFacePermRulesOfMiniFaceIndexPerm", "[", "Perm", 
                      "]"}], "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"AddCurrentMove", "[", 
                    RowBox[{"TMove", "[", 
                      RowBox[{"gName", ",", "\[IndentingNewLine]", 
                        RowBox[{
                          RowBox[{
                          "kMiniFacePermRulesOfMiniFaceIndexPerm", "[", 
                            RowBox[{"InvOfOp", "[", "Perm", "]"}], "]"}], 
                          "&"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
                ")"}]}]}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["Creating buttons", "Section"],

Cell[CellGroupData[{

Cell["notes", "Subsubsection"],

Cell["\<\
Create a button for the CurrentMovesList by:
Compute the composed permutation from the current colored mini-face \
configuration (relative to initial one).
Append the action to the UserMovesList.
Turn the moves list into a formula to go by the button.
Create the button cell and append in the userbutton notebook.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeUserMoveButtonCell[FormulaBoxes_,ButtonOpExpr_,ButtonFn_]\
\>", \
"Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "@", "MakeUserMoveButtonCell"}], ";", 
      RowBox[{
        RowBox[{"MakeUserMoveButtonCell", "[", 
          RowBox[{"FormulaBoxes_", ",", "ButtonOpExpr_", ",", "ButtonFn_"}], 
          "]"}], ":=", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
          RowBox[{
          "Put", " ", "in", " ", "TextData", " ", "separately", " ", "to", 
            " ", "get", " ", "better", " ", "display"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"Cell", "[", 
          RowBox[{
            RowBox[{"TextData", "[", 
              RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{"Cell", "[", 
                    RowBox[{"BoxData", "[", "FormulaBoxes", "]"}], "]"}], 
                  ",", "\"\<=\>\"", ",", 
                  RowBox[{"Cell", "[", 
                    RowBox[{"BoxData", "[", 
                      RowBox[{"ButtonBox", "[", 
                        RowBox[{
                          RowBox[{"FormBox", "[", 
                            RowBox[{
                              RowBox[{"ToBoxes", "[", "ButtonOpExpr", "]"}], 
                              ",", "TraditionalForm"}], "]"}], ",", 
                          "\[IndentingNewLine]", 
                          RowBox[{"ButtonEvaluator", "\[Rule]", "Automatic"}],
                           ",", "\[IndentingNewLine]", 
                          RowBox[{"ButtonFunction", "\[Rule]", 
                            RowBox[{"(", 
                              RowBox[{
                                RowBox[{"ButtonFn", "[", "  ", "]"}], "&"}], 
                              ")"}]}]}], "\[IndentingNewLine]", 
                        "\[IndentingNewLine]", "]"}], "]"}], "]"}]}], "}"}], 
              "]"}], ",", "\"\<Text\>\"", ",", 
            RowBox[{"CellTags", "\[Rule]", "\"\<amovelist\>\""}], ",", 
            RowBox[{"CellMargins", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", 
            RowBox[{"Active", "\[Rule]", "True"}]}], "]"}]}], ";"}]], "Input",\

  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["AddMoveButton[FormulaBoxes_,ButtonOpExpr_,MoveIndex_]", "Subsubsection"],

Cell[TextData[{
  "Creates button cell with formula for the current moves and button for ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["g", "i"], TraditionalForm]]],
  ",\nand button function DoUserMove[_,i_].\nWrites cell into UserButton",
  "NB",
  "."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "AddMoveButton"}], ";"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"AddMoveButton", "[", 
          RowBox[{"FormulaBoxes_", ",", 
            RowBox[{
              FormBox["ButtonOpExpr",
                "InputForm"], "_"}], ",", "MoveIndex_"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"NotebookFind", "[", 
              RowBox[{
              "UserButtonNB", ",", "AfterUserButtonsTag", ",", "All", ",", 
                RowBox[{"{", "CellTags", "}"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"SelectionMove", "[", 
              RowBox[{"UserButtonNB", ",", "Before", ",", "Cell"}], "]"}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"NotebookWrite", "[", 
              RowBox[{"UserButtonNB", ",", "\[IndentingNewLine]", 
                RowBox[{"MakeUserMoveButtonCell", "[", 
                  RowBox[{"FormulaBoxes", ",", 
                    FormBox["ButtonOpExpr",
                      "InputForm"], ",", 
                    RowBox[{
                      RowBox[{"DoUserMove", "[", 
                        RowBox[{"#", ",", "MoveIndex"}], "]"}], "&"}]}], 
                  "]"}]}], "\[IndentingNewLine]", "]"}]}], ")"}]}], 
      ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["CreateUserButtonButtonFn[_]", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"CreateUserButtonButtonFn", "[", "_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"ThePerm", "=", 
                  RowBox[{
                  "IndexPermOfColorFacialConfig", "[", 
                    "CurrentLabelCubeFaces", "]"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"TheFormula", "=", 
                  RowBox[{"First", "/@", "CurrentMovesList"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"MoveIndex", "=", 
                  RowBox[{
                    RowBox[{"Length", "[", "UserMovesList", "]"}], "+", 
                    "1"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"With", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    FormBox["ButtonOpExpr",
                      "InputForm"], "=", 
                    RowBox[{"Subscript", "[", 
                      RowBox[{"g", ",", "MoveIndex"}], "]"}]}], "}"}], ",", 
                RowBox[{
                  RowBox[{"AppendTo", "[", 
                    RowBox[{"UserMovesList", ",", 
                      RowBox[{"TFormLPerm", "[", 
                        RowBox[{"TheFormula", ",", 
                          RowBox[{"LPerm", "[", 
                            RowBox[{
                              FormBox["ButtonOpExpr",
                                "InputForm"], ",", "ThePerm"}], "]"}]}], 
                        "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"AddMoveButton", "[", 
                    RowBox[{
                      RowBox[{"BoxesOfFormulae", "[", "TheFormula", "]"}], 
                      ",", 
                      FormBox["ButtonOpExpr",
                        "InputForm"], ",", "MoveIndex"}], "]"}]}]}], 
              "\[IndentingNewLine]", "]"}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell["User Button Windows", "Section"],

Cell[CellGroupData[{

Cell["note", "Subsubsection"],

Cell["\<\
Make a notebook that has the buttons and its UserMovesList and \
initializes itself , or\
\>", "Text"],

Cell["\<\
Save a UserMovesList with e.g. Save[\"Macintosh \
HD:...usermoveegs2.m\",UserMovesList].
Load with functions below.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["AfterButtonsCell", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"AfterButtonsCell", "=", 
          RowBox[{"Cell", "[", 
            RowBox[{
              RowBox[{"BoxData", "[", 
                RowBox[{"FrameBox", "[", "\"\<End of Buttons\>\"", "]"}], 
                "]"}], ",", "\"\<Text\>\"", ",", 
              RowBox[{"CellTags", "\[Rule]", "AfterUserButtonsTag"}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["UserButtonCellsOf[aUserMovesList_]", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "@", "UserButtonCellsOf"}], ";", 
      RowBox[{
        RowBox[{"UserButtonCellsOf", "[", "aUserMovesList_", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"MapIndexed", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"Replace", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"#1", ",", "#2"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{"TFormLPerm", "[", 
                            RowBox[{"TheFormula_", ",", 
                              RowBox[{"LPerm", "[", 
                                RowBox[{
                                  RowBox[{
                                    FormBox["ButtonOpExpr",
                                      "InputForm"], "_"}], ",", "_"}], 
                                "]"}]}], "]"}], ",", 
                          RowBox[{"{", "MoveIndex_", "}"}]}], "}"}], 
                      "\[RuleDelayed]", "\[IndentingNewLine]", 
                      "\[IndentingNewLine]", 
                      RowBox[{"MakeUserMoveButtonCell", "[", 
                        RowBox[{
                          RowBox[{"BoxesOfFormulae", "[", "TheFormula", "]"}],
                           ",", 
                          FormBox["ButtonOpExpr",
                            "InputForm"], ",", 
                          RowBox[{
                            RowBox[{"DoUserMove", "[", 
                              RowBox[{"#", ",", "MoveIndex"}], "]"}], "&"}]}],
                         "]"}]}]}], "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", "]"}], "&"}], ",", 
              "\[IndentingNewLine]", "aUserMovesList"}], 
            "\[IndentingNewLine]", "]"}], "~", "Join", "~", 
          RowBox[{"{", "AfterButtonsCell", "}"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["CreateUserButtonWindow[wname_,aUserMovesList_]", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Clear", "@", "CreateUserButtonWindow"}], ";", 
      RowBox[{
        RowBox[{"CreateUserButtonWindow", "[", 
          RowBox[{"wname_", ",", "aUserMovesList_"}], "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"UserButtonNB", "=", 
          RowBox[{"NotebookPut", "[", 
            RowBox[{"Notebook", "[", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"Cell", "[", 
                      RowBox[{
                      "\"\<User Move Buttons\>\"", ",", "\"\<Subtitle\>\"", 
                        ",", "\[IndentingNewLine]", 
                        RowBox[{"TextAlignment", "\[Rule]", "Center"}], ",", 
                        RowBox[{"CellMargins", "\[Rule]", 
                          RowBox[{"{", 
                            RowBox[{
                              RowBox[{"{", 
                                RowBox[{"0", ",", "0"}], "}"}], ",", 
                              RowBox[{"{", 
                                RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}]}], 
                      "]"}], "}"}], "~", "Join", "~", 
                  RowBox[{"UserButtonCellsOf", "[", "aUserMovesList", "]"}]}],
                 ",", "\[IndentingNewLine]", 
                RowBox[{"WindowTitle", "\[Rule]", "wname"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"WindowSize", "\[Rule]", 
                  RowBox[{"{", 
                    RowBox[{"150", ",", "300"}], "}"}]}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"WindowMargins", "\[Rule]", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{"10", ",", "Automatic"}], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{"Automatic", ",", "10"}], "}"}]}], "}"}]}]}], 
              "]"}], "\[IndentingNewLine]", "]"}]}]}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["LoadUserButtons[aFileName_String]", "Subsubsection"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Clear", "@", "LoadUserButtons"}], ";"}], "\[IndentingNewLine]",
   
    RowBox[{
      RowBox[{
        RowBox[{"LoadUserButtons", "[", "aFileName_String", "]"}], ":=", 
        "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"aStream", "=", 
                RowBox[{"OpenRead", "[", "aFileName", "]"}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"UserMovesList", "=", 
                RowBox[{"Read", "[", "aStream", "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"Close", "[", "aStream", "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"CreateUserButtonWindow", "[", "\n", 
                RowBox[{"(*", " ", 
                  RowBox[{"strip", " ", "off", " ", "filename", " ", 
                    RowBox[{"or", ":"}]}], " ", "*)"}], 
                RowBox[{"\"\<User Buttons\>\"", ",", "UserMovesList"}], 
                "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{522, 535},
WindowMargins->{{Automatic, 55}, {Automatic, 5}},
ShowCellTags->True,
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "init"->{
    Cell[1749, 51, 221, 6, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[2702, 95, 446, 11, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3151, 108, 235, 7, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3389, 117, 260, 7, 55, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3652, 126, 225, 6, 55, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3985, 139, 1355, 33, 70, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[5546, 184, 946, 21, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[6495, 207, 811, 19, 71, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[7428, 234, 3996, 75, 295, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[12649, 355, 158, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[12916, 367, 145, 4, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[13064, 373, 172, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[13369, 387, 1762, 39, 263, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[15712, 452, 2315, 49, 279, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[18423, 518, 1394, 33, 183, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[19909, 558, 2075, 47, 231, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[22429, 630, 484, 12, 87, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[23012, 649, 2058, 44, 231, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[25181, 700, 2051, 43, 199, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[27330, 750, 1156, 27, 167, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"init", 29343, 802}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 29, 0, 98, "Title"],
Cell[1749, 51, 221, 6, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[1973, 59, 53, 0, 62, "Subtitle"],

Cell[CellGroupData[{
Cell[2051, 63, 29, 0, 42, "Subsubsection"],
Cell[2083, 65, 238, 9, 142, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2358, 79, 30, 0, 28, "Subsubsection"],
Cell[2391, 81, 156, 4, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2584, 90, 115, 3, 28, "Subsubsection"],
Cell[2702, 95, 446, 11, 71, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3151, 108, 235, 7, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3389, 117, 260, 7, 55, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3652, 126, 225, 6, 55, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[3914, 137, 68, 0, 28, "Subsubsection"],
Cell[3985, 139, 1355, 33, 70, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[5377, 177, 66, 0, 28, "Subsubsection"],
Cell[5446, 179, 97, 3, 30, "Text"],
Cell[5546, 184, 946, 21, 87, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[6495, 207, 811, 19, 71, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[7343, 231, 82, 1, 28, "Subsubsection"],
Cell[7428, 234, 3996, 75, 295, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[11439, 312, 32, 0, 51, "Subtitle"],
Cell[11474, 314, 39, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[11538, 318, 30, 0, 42, "Subsubsection"],
Cell[11571, 320, 826, 21, 78, "Text"],
Cell[12400, 343, 165, 5, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12602, 353, 44, 0, 28, "Subsubsection"],
Cell[12649, 355, 158, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[12810, 362, 103, 3, 30, "Text"],
Cell[12916, 367, 145, 4, 39, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[13064, 373, 172, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[13273, 383, 43, 0, 28, "Subsubsection"],
Cell[13319, 385, 47, 0, 30, "Text"],
Cell[13369, 387, 1762, 39, 263, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[15146, 429, 35, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[15206, 433, 30, 0, 42, "Subsubsection"],
Cell[15239, 435, 337, 7, 110, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15613, 447, 96, 3, 28, "Subsubsection"],
Cell[15712, 452, 2315, 49, 279, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[18064, 506, 78, 0, 28, "Subsubsection"],
Cell[18145, 508, 275, 8, 62, "Text"],
Cell[18423, 518, 1394, 33, 183, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[19854, 556, 52, 0, 28, "Subsubsection"],
Cell[19909, 558, 2075, 47, 231, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],
Cell[21999, 608, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[22062, 612, 29, 0, 42, "Subsubsection"],
Cell[22094, 614, 112, 3, 30, "Text"],
Cell[22209, 619, 139, 4, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[22385, 628, 41, 0, 28, "Subsubsection"],
Cell[22429, 630, 484, 12, 87, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[22950, 647, 59, 0, 28, "Subsubsection"],
Cell[23012, 649, 2058, 44, 231, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[25107, 698, 71, 0, 28, "Subsubsection"],
Cell[25181, 700, 2051, 43, 199, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[27269, 748, 58, 0, 28, "Subsubsection"],
Cell[27330, 750, 1156, 27, 167, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

