(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4938,        183]*)
(*NotebookOutlinePosition[      7326,        256]*)
(*  CellTagsIndexPosition[      7229,        249]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Rubik User Buttons Package", "Title"],

Cell[CellGroupData[{

Cell["Set Up", "Subtitle",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"BeginPackage", "[", 
        RowBox[{"\"\<RubikPkFolder`RubikUserButtonsPk`\>\"", ",", 
          RowBox[{"{", 
            RowBox[{
            "\"\<RubikPkFolder`RubikGraphicsPk`\>\"", ",", 
              "\[IndentingNewLine]", 
              "\"\<RubikPkFolder`RubikInterfacePk`\>\""}], "}"}]}], "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["interface and documentation for Rubik fns", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{"DoUserMove", ",", "CreateUserButtonButtonFn"}], "}"}], 
      ";"}]], "Input",
  InitializationCell->True],

Cell["\<\
LPerm::usage=\"LPerm[label,permrules] are labelled permutation \
rules\";
TFormLPerm::usage=\"TFormLPerm[formula,LPerm[sym,perm]]  (data type) is a \
permutation action with the formula that constructed it.\";
DoUserMove::usage=\"DoUserMove[bd_,i_] does user move with symbol g_i\";
CreateUserButtonButtonFn::usage=\"CreateUserButtonButtonFn[_]\";
UserMovesList::usage=\"List of user button moves\";
AfterUserButtonsTag::usage=\"Cell Tag after user buttons\";
UserButtonNB::usage=\"The current user button window\";
\
\>", "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["enter private", "Subsection"],

Cell[CellGroupData[{

Cell["private", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spelling Off", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Off", "[", 
        RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{

Cell["protection", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Protect", "[", "RubikPkFolder`UserButtonsPk", "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Main Function File", "Section",
  InitializationCell->True],

Cell["On $Path", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", "\"\<RubikUserButtonsFns.m\>\"", "]"}], 
      ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["finale", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"End", "[", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"EndPackage", "[", "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spelling On", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"On", "[", 
        RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
WindowSize->{671, 498},
WindowMargins->{{Automatic, 72}, {27, Automatic}},
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "packcells"->{
    Cell[1842, 56, 434, 11, 59, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[3304, 106, 162, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[3816, 130, 181, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4389, 158, 139, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4531, 164, 146, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}]},
  "init"->{
    Cell[1842, 56, 434, 11, 59, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[2583, 82, 589, 13, 147, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3304, 106, 162, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[3543, 117, 170, 5, 27, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3816, 130, 181, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4389, 158, 139, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4531, 164, 146, 4, 27, "Input",
      InitializationCell->True,
      CellTags->{"packcells", "init"}],
    Cell[4753, 175, 169, 5, 39, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"packcells", 5765, 204},
  {"init", 6343, 220}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 43, 0, 98, "Title"],

Cell[CellGroupData[{
Cell[1785, 53, 54, 1, 62, "Subtitle",
  InitializationCell->True],
Cell[1842, 56, 434, 11, 59, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[2313, 72, 94, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[2410, 75, 170, 5, 27, "Input",
  InitializationCell->True],
Cell[2583, 82, 589, 13, 147, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[3209, 100, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[3269, 104, 32, 0, 42, "Subsubsection"],
Cell[3304, 106, 162, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[3503, 115, 37, 0, 28, "Subsubsection"],
Cell[3543, 117, 170, 5, 27, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]],

Cell[CellGroupData[{
Cell[3750, 127, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[3816, 130, 181, 5, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4046, 141, 70, 1, 30, "Section",
  InitializationCell->True],
Cell[4119, 144, 24, 0, 30, "Text"],
Cell[4146, 146, 144, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4327, 155, 59, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[4389, 158, 139, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}],
Cell[4531, 164, 146, 4, 27, "Input",
  InitializationCell->True,
  CellTags->{"packcells", "init"}]
}, Closed]],

Cell[CellGroupData[{
Cell[4714, 173, 36, 0, 28, "Subsubsection"],
Cell[4753, 175, 169, 5, 39, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

