(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5072,        160]*)
(*NotebookOutlinePosition[      6325,        202]*)
(*  CellTagsIndexPosition[      6256,        196]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Talk Control", "Title"],

Cell[CellGroupData[{

Cell["initialization", "SmallText"],

Cell["\<\
Just get the directory path to \"This folder:\"
for use by the buttons.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Get this directory:TalkPath", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Replace", "[", 
        RowBox[{
          RowBox[{"\"\<FileName\>\"", "/.", 
            RowBox[{"NotebookInformation", " ", "@", 
              RowBox[{"InputNotebook", "[", "]"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"FrontEnd`FileName", "[", 
              RowBox[{"diraslist_", ",", "\"\<Start Talk.nb\>\"", ",", "_"}], 
              "]"}], "\[RuleDelayed]", 
            RowBox[{"(", 
              RowBox[{"TalkPath", "=", 
                RowBox[{"ToFileName", "[", 
                  RowBox[{"FrontEnd`FileName", "[", "diraslist", "]"}], 
                  "]"}]}], ")"}]}]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Open  ]],

Cell["RubikPath is just used for the buttons in the talk  file.  ", \
"SmallText"],

Cell["\<\
Linux systems do not return the correct notebook in nested \
\"NotebookInformation @InputNotebook[]\" calls, so set the path for \
\"StartRubik\" manually as in the \"start\" file within the package.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RubikStartPathSep", "=", 
      RowBox[{"ToFileName", "[", 
        RowBox[{"{", 
          RowBox[{"TalkPath", ",", "\"\<RubikFolder\>\""}], "}"}], 
        "]"}]}]], "Input",
  InitializationCell->True,
  CellTags->"init"],

Cell[BoxData["\<\"Macintosh HD:envs folder:Gerrards folder:MathC 3 Data:Dev \
confs Folder:DevConfTalkFolder:RubikFolder:\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"RubikPkPathSep", "=", 
        RowBox[{"ToFileName", "[", 
          RowBox[{"{", 
            RowBox[{"RubikStartPathSep", ",", 
              RowBox[{"\"\<RubikPkFolder\>\"", "<>", "$PathnameSeparator"}]}],
             "}"}], "]"}]}], ";"}]], "Input",
  InitializationCell->True],

Cell["\<\
The tools for the talk are where they are for the Rubik Package, \
inside the  RubikPkFolder.
This is also set autonomously by the  Rubik package, but we set them here i n \
case the talk  is  used to call e.g. \"Dihedral  Group\" out of sequence or \
for system idiosyncracies.\
\>", "SmallText"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Get", "[", 
        RowBox[{"\"\<ToolsCheckPk.m\>\"", ",", 
          RowBox[{"Path", "->", "RubikPkPathSep"}]}], "]"}], ";"}]], "Input",
  InitializationCell->True],

Cell["\<\
Now call the tools check with the full path that only we as a \
Notebook know, so Tools check can put it on the $Path.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ToolsCheck", "[", "RubikPkPathSep", "]"}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox[
              FrameBox[
                RowBox[{"Start", " ", "Talk"}],
                BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}],
              Background->RGBColor[0, 1, 0]],
            ButtonFunction:>(NotebookOpen[ 
                ToFileName[ TalkPath, "Schreier Rubik Presention.nb"]]&),
            ButtonEvaluator->Automatic,
            Active->True]}
        }]], "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->Automatic,
InitializationCellEvaluation->True,
InitializationCellWarning->True,
CellGrouping->Manual,
WindowSize->{435, 454},
WindowMargins->{{26, Automatic}, {Automatic, 17}},
PrivateNotebookOptions->{"ShortBoxForm"->False},
MacintoshSystemPageSetup->"\<\
AVU/I@1804P00@180`[`P?oQon82n@9608dE40;gW2P0AP1Y06`0I@1^06432_20
0`]M`1000000SAC`0_NL:4IYK6E^HFeU0:000@<;GL032egP4000002=5=02mi`X
O=gj53R000201@0l0`]M`82S0020IP00\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "init"->{
    Cell[1975, 64, 746, 18, 107, "Input",
      InitializationCell->True,
      CellTags->"init"],
    Cell[3071, 97, 251, 7, 43, "Input",
      InitializationCell->True,
      CellTags->"init"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"init", 6034, 185}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 29, 0, 98, "Title"],

Cell[CellGroupData[{
Cell[1771, 53, 35, 0, 26, "SmallText"],
Cell[1809, 55, 95, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[1929, 62, 43, 0, 30, "Text"],
Cell[1975, 64, 746, 18, 107, "Input",
  InitializationCell->True,
  CellTags->"init"]
}, Open  ]],
Cell[2736, 85, 82, 1, 26, "SmallText"],
Cell[2821, 88, 225, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[3071, 97, 251, 7, 43, "Input",
  InitializationCell->True,
  CellTags->"init"],
Cell[3325, 106, 138, 1, 70, "Output"]
}, Open  ]],
Cell[3478, 110, 324, 8, 59, "Input",
  InitializationCell->True],
Cell[3805, 120, 307, 6, 54, "SmallText"],
Cell[4115, 128, 207, 5, 43, "Input",
  InitializationCell->True],
Cell[4325, 135, 142, 3, 46, "Text"],
Cell[4470, 140, 129, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],
Cell[4614, 146, 454, 12, 36, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

