(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43622,       1860]*)
(*NotebookOutlinePosition[     44467,       1887]*)
(*  CellTagsIndexPosition[     44423,       1883]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Subsection"],

Cell[StyleData[All, "Working"],
  CellBracketOptions->{"Thickness"->1,
  "Color"->RGBColor[0.500008, 0.6, 1]},
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  CellMargins->{{Inherited, 120}, {Inherited, Inherited}},
  ScriptMinSize->9],

Cell[StyleData[All, "Markup"],
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  Hyphenation->True,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook Options", "Subsection"],

Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  DefaultNewCellStyle->"Text",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
  StyleMenuListing->None],

Cell[StyleData["Notebook", "Presentation"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellMargins->{{Inherited, 120}, {Inherited, Inherited}},
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  DefaultNewCellStyle->"Text",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
              FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
  StyleMenuListing->None,
  Background->RGBColor[0.959991, 0.908461, 0.825605]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Style Menu Shortcuts", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{12, 12}, {3, 24}},
  CellGroupingRules->{"SectionGrouping", 10},
  PageBreakBelow->False,
  ParagraphIndent->-25,
  TabSpacings->2.1,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}},
  StyleMenuListing->"Head1",
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{72, 120}, {3, 28}},
  CellFrameMargins->{{8, 1}, {1, 1}},
  FontFamily->"Arial",
  FontSize->18,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.258061, 0.387091, 0.612909]],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{2, 12}, {3, 18}},
  FontSize->12,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SectionDingbat"],
  CellSize->{24, Inherited},
  TextAlignment->Left,
  StyleMenuListing->None],

Cell[StyleData["SectionDingbat", "Printout"],
  CellSize->{19, Inherited}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SectionNumber"],
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["SectionNumber", "Printout"],
  StyleMenuListing->None,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->None,
  CellMargins->{{12, 12}, {3, 12}},
  CellElementSpacings->{"ClosedGroupTopMargin"->12},
  CellGroupingRules->{"SectionGrouping", 20},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  ParagraphIndent->-18,
  TabSpacings->1.7,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->"Head2",
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{72, 120}, {2, 15}},
  FontFamily->"Arial",
  FontSize->18,
  FontColor->RGBColor[0.161288, 0.258061, 0.419348]],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{2, 12}, {2, 5}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsectionDingbat"],
  CellSize->{18, Inherited},
  TextAlignment->Left,
  StyleMenuListing->None],

Cell[StyleData["SubsectionDingbat", "Printout"],
  CellSize->{12, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsectionNumber"],
  StyleMenuListing->None,
  FontSize->10,
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}],

Cell[StyleData["SubsectionNumber", "Printout"],
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{12, 12}, {3, 6}},
  CellElementSpacings->{"ClosedGroupTopMargin"->12},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  CounterAssignments->{{"Subsubsubsection", 0}},
  StyleMenuListing->"Head3",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.300008],
  CounterBoxOptions->{CounterFunction:>Identity}],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{2, 12}, {1, 4}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{72, 120}, {1, 4}},
  FontFamily->"Arial",
  FontSize->14,
  FontColor->RGBColor[0.3608, 0.3608, 0.439994]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsubsection"],
  CellMargins->{{12, 12}, {3, 6}},
  CellGroupingRules->{"SectionGrouping", 40},
  CounterIncrements->"Subsubsubsection",
  StyleMenuListing->"Head4",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->GrayLevel[0.300008]],

Cell[StyleData["Subsubsubsection", "Presentation"],
  CellMargins->{{72, 120}, {1, 4}},
  FontFamily->"Arial",
  FontColor->RGBColor[0.500206, 0.500206, 0.609995]],

Cell[StyleData["Subsubsubsection", "Printout"],
  CellMargins->{{2, 12}, {1, 4}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["EquationNumbered"],
  CellMargins->{{36, 6}, {7, 7}},
  CellHorizontalScrolling->True,
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "Equation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  InputAutoReplacements->{},
  ShowAutoStyles->False,
  CounterIncrements->"Equation",
  FormatTypeAutoConvert->False],

Cell[StyleData["EquationNumbered", "Presentation"],
  CellMargins->{{72, 120}, {15, 15}},
  FontSize->18],

Cell[StyleData["EquationNumbered", "Printout"],
  CellMargins->{{21, 6}, {5, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Equation"],
  CellMargins->{{36, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  InputAutoReplacements->{},
  ShowAutoStyles->False,
  CounterIncrements->"Equation"],

Cell[StyleData["Equation", "Presentation"],
  CellMargins->{{72, 120}, {15, 15}},
  FontSize->18,
  FontVariations->{"CompatibilityType"->0}],

Cell[StyleData["Equation", "Printout"],
  CellMargins->{{21, 6}, {5, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {3, 5}},
  TextAlignment->Left,
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{72, 120}, {1, 4}},
  FontFamily->"Arial",
  FontSize->15,
  FontWeight->"Bold"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 10}, {1, 4}},
  TextJustification->1,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InputNumbered"],
  CellMargins->{{36, 10}, {6, 8}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellFrameLabels->{{None, Cell[ 
          BoxData[ 
            FormBox[ 
              StyleBox[ 
                RowBox[ {"(", 
                  CounterBox[ "Equation"], ")"}], FontWeight -> "Plain"], 
              TraditionalForm]]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  InputAutoReplacements->{},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["InputNumbered", "Presentation"],
  CellMargins->{{72, 120}, {10, 10}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->14],

Cell[StyleData["InputNumbered", "Printout"],
  CellMargins->{{21, 6}, {3, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{36, 10}, {6, 8}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  InputAutoReplacements->{},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{108, 120}, {10, 10}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->16,
  FontVariations->{"CompatibilityType"->0}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{21, 6}, {3, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Frontmatter", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{36, 54}, {1, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  ParagraphSpacing->{0, 0},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Author", "Presentation"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {20, 0}},
  CellFrameMargins->{{73, 4}, {2, 6}},
  CellFrameLabelMargins->False,
  FontFamily->"Arial",
  FontSize->18,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0.4, 0.6]],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{21, 10}, {0, 18}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Address"],
  CellMargins->{{36, 54}, {0, 3}},
  CounterIncrements->"Address",
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12,
  FontColor->GrayLevel[0.2]],

Cell[StyleData["Address", "Printout"],
  CellMargins->{{21, 10}, {0, 2}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Email"],
  CellMargins->{{36, 54}, {0, 0}},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0.2]],

Cell[StyleData["Email", "Printout"],
  CellMargins->{{21, 10}, {0, 0}},
  LineSpacing->{1, 1},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AbstractText"],
  CellFrame->{{0, 0}, {0.25, 0.25}},
  CellMargins->{{36, 54}, {3, 24}},
  CellGroupingRules->{"SectionGrouping", 50},
  CellFrameMargins->5,
  TextAlignment->Left,
  LineSpacing->{1, 1},
  StyleMenuListing->None,
  FontSize->12,
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["AbstractText", "Printout"],
  CellMargins->{{21, 86}, {2, 14}},
  CellFrameMargins->3,
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Date"],
  CellMargins->{{36, 54}, {6, 3}},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Date", "Printout"],
  CellMargins->{{21, 10}, {3, 2}},
  LineSpacing->{1, 1},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Text", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  CellMargins->{{12, 10}, {3, 5}},
  LineSpacing->{1, 3},
  CounterIncrements->"Theorem"],

Cell[StyleData["Theorem", "Printout"],
  CellMargins->{{2, 2}, {1, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Lemma"],
  CellMargins->{{12, 10}, {3, 5}},
  LineSpacing->{1, 3},
  CounterIncrements->"Lemma"],

Cell[StyleData["Lemma", "Printout"],
  CellMargins->{{2, 2}, {1, 4}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {1, 1}},
  CellMargins->{{36, 0}, {7, 7}},
  CellFrameMargins->{{12, 10}, {7, 5}},
  InputAutoReplacements->{},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{21, 0}, {5, 5}},
  FontSize->9.5]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Item1"],
  CellMargins->{{12, 4}, {2, 4}},
  ParagraphIndent->-24,
  CounterIncrements->"Item1"],

Cell[StyleData["Item1", "Printout"],
  CellMargins->{{3, 0}, {1, 3}},
  ParagraphIndent->-18,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item1Paragraph"],
  CellMargins->{{36, 4}, {4, 2}}],

Cell[StyleData["Item1Paragraph", "Printout"],
  CellMargins->{{21, 0}, {3, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item2"],
  CellMargins->{{21, 4}, {2, 4}},
  ParagraphIndent->-24,
  CounterIncrements->"Item2"],

Cell[StyleData["Item2", "Printout"],
  CellMargins->{{12, 0}, {1, 3}},
  ParagraphIndent->-18,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item2Paragraph"],
  CellMargins->{{45, 4}, {4, 2}},
  StyleMenuListing->None],

Cell[StyleData["Item2Paragraph", "Printout"],
  CellMargins->{{30, 0}, {3, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item3"],
  CellMargins->{{31, 4}, {2, 4}},
  ParagraphIndent->-24,
  CounterIncrements->"Item3"],

Cell[StyleData["Item3", "Printout"],
  CellMargins->{{21, 0}, {1, 3}},
  ParagraphIndent->-18,
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item3Paragraph"],
  CellMargins->{{55, 4}, {4, 2}},
  StyleMenuListing->None],

Cell[StyleData["Item3Paragraph", "Printout"],
  CellMargins->{{39, 0}, {3, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemDingbat"],
  CellSize->{24, Inherited},
  TextAlignment->Right,
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["ItemDingbat", "Printout"],
  CellSize->{18, Inherited},
  FontSize->10]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Input/Output", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{36, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  InputAutoReplacements->{},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{117, 0}, {6, 3}},
  FontSize->16],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{21, 0}, {6, 3}},
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{36, 0}, {8, 6}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  InputAutoReplacements->{},
  LanguageCategory->None,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{0, 0}, {0, 0}},
  StyleMenuListing->None,
  FontSize->12],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{27, 0}, {6, 3}},
  ImageMargins->{{0, 0}, {0, 0}},
  FontSize->14,
  Magnification->0.8],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{27, 0}, {6, 3}},
  ImageMargins->{{0, 0}, {0, 0}},
  Magnification->0.8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure, Picture, and Tables", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["TableHead"],
  PageWidth->530,
  CellMargins->{{38, 10}, {1, 7}},
  LineSpacing->{1, 2},
  CounterIncrements->"TableHead",
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  GridBoxOptions->{ColumnWidths->40,
  ColumnAlignments->{Left}}],

Cell[StyleData["TableHead", "Printout"],
  CellMargins->{{23, 10}, {1, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Table"],
  PageWidth->530,
  CellMargins->{{36, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.503,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["Table", "Printout"],
  CellMargins->{{21, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TablePlain"],
  PageWidth->530,
  CellMargins->{{36, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.503,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["TablePlain", "Printout"],
  CellMargins->{{21, 10}, {5, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  PageWidth->530,
  CellMargins->{{36, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.336,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{21, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTablePlain"],
  PageWidth->530,
  CellMargins->{{36, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.336,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["3ColumnTablePlain", "Printout"],
  CellMargins->{{21, 10}, {5, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnTable"],
  PageWidth->530,
  CellMargins->{{36, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.251,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["4ColumnTable", "Printout"],
  CellMargins->{{21, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnTablePlain"],
  PageWidth->530,
  CellMargins->{{36, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.251,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["4ColumnTablePlain", "Printout"],
  CellMargins->{{21, 10}, {5, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnTable"],
  PageWidth->530,
  CellMargins->{{36, 10}, {1, 1}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.201,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["5ColumnTable", "Printout"],
  CellMargins->{{21, 10}, {1, 1}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnTablePlain"],
  PageWidth->530,
  CellMargins->{{36, 10}, {7, 7}},
  CellHorizontalScrolling->True,
  CounterIncrements->"Table",
  StyleMenuListing->None,
  GridBoxOptions->{ColumnWidths->0.201,
  RowAlignments->Center,
  ColumnAlignments->{Left, Center},
  GridFrame->{{0, 0}, {0.5, 2}},
  RowLines->{True, False},
  ColumnLines->False,
  GridDefaultElement:>Cell[ "Your Data", "TableText"]}],

Cell[StyleData["5ColumnTablePlain", "Printout"],
  CellMargins->{{21, 10}, {5, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableNote"],
  PageWidth->530,
  CellMargins->{{38, 10}, {7, 1}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0.3, 0},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10],

Cell[StyleData["TableNote", "Printout"],
  CellMargins->{{23, 10}, {5, 1}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Figure"],
  CellMargins->{{36, Inherited}, {0, 7}},
  CellHorizontalScrolling->True],

Cell[StyleData["Figure", "Printout"],
  CellMargins->{{27, Inherited}, {0, 5}},
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{36, Inherited}, {0, 7}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Presentation"],
  CellMargins->{{72, 120}, {0, 5}},
  Magnification->1.5],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{27, Inherited}, {0, 5}},
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{36, 10}, {10, 3}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{21, 10}, {4, 0}},
  TextJustification->1,
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GraphicHeader"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameMargins->{{55, 20}, {0, 0}},
  CellFrameLabelMargins->False,
  StyleMenuListing->None,
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[StyleData["GraphicHeader", "Printout"],
  CellFrameMargins->{{5, 20}, {0, 0}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inline Styles for Tables", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["TableHeadText"],
  CounterIncrements->"TableHead",
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain"],

Cell[StyleData["TableHeadText", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ColumnHead"],
  CounterIncrements->"Table",
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSlant->"Italic"],

Cell[StyleData["ColumnHead", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableText"],
  TextAlignment->Left,
  LineSpacing->{1, 1},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["TableText", "Printout"],
  FontSize->10]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Endmatter", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["AcknowledgementsHead"],
  CellMargins->{{12, 12}, {10, 24}},
  CellGroupingRules->{"SectionGrouping", 10},
  PageBreakBelow->False,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.300008]],

Cell[StyleData["AcknowledgementsHead", "Printout"],
  CellMargins->{{12, 12}, {10, 18}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["AppendixHead"],
  CellMargins->{{12, 12}, {10, 24}},
  CellGroupingRules->{"SectionGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Appendix",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[0.300008]],

Cell[StyleData["AppendixHead", "Printout"],
  CellMargins->{{12, 12}, {10, 18}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AppendixEquation"],
  CellMargins->{{36, 6}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(A", 
            CounterBox[ "Appendix"], ".", 
            CounterBox[ "AppendixEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  InputAutoReplacements->{},
  CounterIncrements->"AppendixEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["AppendixEquation", "Printout"],
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference Elements", "Subsection"],

Cell[StyleData["ReferencesHead"],
  CellFrame->{{0, 0}, {0.25, 0}},
  CellMargins->{{12, 8}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 10},
  CounterAssignments->{{"Endnote", 0}},
  StyleMenuListing->None,
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["EndNote"],
  CellMargins->{{24, 8}, {0, 0}},
  ParagraphSpacing->{0, 0},
  ParagraphIndent->-36,
  TabSpacings->5.5,
  CounterIncrements->"EndNote",
  StyleMenuListing->None],

Cell[CellGroupData[{

Cell[StyleData["RefDingbat"],
  CellSize->{36, Inherited},
  TextAlignment->Right,
  CounterIncrements->"RefDingbat",
  StyleMenuListing->None],

Cell[StyleData["RefDingbat", "Printout"]]
}, Closed]],

Cell[StyleData["ReferencesEnd"],
  StyleMenuListing->None],

Cell[CellGroupData[{

Cell[StyleData["Citation"],
  StyleMenuListing->None,
  FontColor->RGBColor[0.300008, 0, 0]],

Cell[StyleData["Citation", "Markup"],
  CellSize->{60, 18},
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Citation", "Printout"],
  StyleMenuListing->None,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell["References Entity Styles", "Subsubsection"],

Cell[CellGroupData[{

Cell[StyleData["RefAddressCity"],
  StyleMenuListing->None],

Cell[StyleData["RefAddressCity", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefAddressState"],
  StyleMenuListing->None],

Cell[StyleData["RefAddressState", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefArticleTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefArticleTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefAuthorFN"],
  StyleMenuListing->None],

Cell[StyleData["RefAuthorFN", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefAuthorLN"],
  StyleMenuListing->None],

Cell[StyleData["RefAuthorLN", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefAuthorMN"],
  StyleMenuListing->None],

Cell[StyleData["RefAuthorMN", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefBookTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefBookTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefChapterTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefChapterTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefCollectionTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefCollectionTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefConferenceName"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefConferenceName", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefDay"],
  StyleMenuListing->None],

Cell[StyleData["RefDay", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefEdition"],
  StyleMenuListing->None],

Cell[StyleData["RefEdition", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefEditorFN"],
  StyleMenuListing->None],

Cell[StyleData["RefEditorFN", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefEditorMN"],
  StyleMenuListing->None],

Cell[StyleData["RefEditorMN", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefEditorLN"],
  StyleMenuListing->None],

Cell[StyleData["RefEditorLN", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefElectronicTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefElectronicTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefEprint"],
  StyleMenuListing->None],

Cell[StyleData["RefEprint", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefFPage"],
  StyleMenuListing->None],

Cell[StyleData["RefFPage", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefHowPublished"],
  StyleMenuListing->None],

Cell[StyleData["RefHowPublished", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefIssue"],
  StyleMenuListing->None],

Cell[StyleData["RefIssue", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefInstitution"],
  StyleMenuListing->None],

Cell[StyleData["RefInstitution", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefJournal"],
  StyleMenuListing->None],

Cell[StyleData["RefJournal", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefLPage"],
  StyleMenuListing->None],

Cell[StyleData["RefLPage", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefMisc"],
  StyleMenuListing->None],

Cell[StyleData["RefMisc", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefMiscTitle"],
  StyleMenuListing->None],

Cell[StyleData["RefMiscTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefMonth"],
  StyleMenuListing->None],

Cell[StyleData["RefMonth", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefNote"],
  StyleMenuListing->None],

Cell[StyleData["RefNote", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefOrganization"],
  StyleMenuListing->None],

Cell[StyleData["RefOrganization", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefProceedingsTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefProceedingsTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefPublisher"],
  StyleMenuListing->None],

Cell[StyleData["RefPublisher", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefReportTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefReportTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefSchool"],
  StyleMenuListing->None],

Cell[StyleData["RefSchool", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefSchoolDept"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefSchoolDept", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefSeries"],
  StyleMenuListing->None],

Cell[StyleData["RefSeries", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefThesisTitle"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["RefThesisTitle", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefURL"],
  StyleMenuListing->None],

Cell[StyleData["RefURL", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefVolume"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["RefVolume", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefYear"],
  StyleMenuListing->None],

Cell[StyleData["RefYear", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefKind"],
  StyleMenuListing->None,
  FontSize->0.5,
  FontTracking->"Narrow"],

Cell[StyleData["RefKind", "Markup"],
  FontSize->12,
  FontWeight->"Bold",
  FontTracking->"Plain",
  Background->RGBColor[0.408103, 0.769985, 0.757885]],

Cell[StyleData["RefKind", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefType"],
  CellSize->{0, 12},
  StyleMenuListing->None],

Cell[StyleData["RefType", "Markup"],
  CellSize->{60, 18},
  FontWeight->"Bold",
  FontColor->RGBColor[0.8, 0.2, 0.2]],

Cell[StyleData["RefType", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefMarker"],
  CellSize->{0, 12},
  StyleMenuListing->None],

Cell[StyleData["RefMarker", "Markup"],
  CellSize->{6, 12}],

Cell[StyleData["RefMarker", "Printout"],
  CellSize->{0, 12}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Titles", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, 12}, {4, 36}},
  CellGroupingRules->{"SectionGrouping", 10},
  PageBreakBelow->False,
  LineSpacing->{1, 2},
  FontSize->30,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Presentation"],
  CellFrame->False,
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  CellGroupingRules->{"SectionGrouping", 10},
  PageBreakBelow->False,
  CellFrameMargins->{{73, 120}, {10, 25}},
  CellFrameColor->RGBColor[0.356863, 0.529412, 0.94902],
  CellFrameLabelMargins->6,
  LineSpacing->{1, 2},
  FontFamily->"Arial",
  FontSize->30,
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.12903, 0.548394, 0.774197]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {2, 36}},
  FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, 12}, {4, 6}},
  PageBreakBelow->False,
  LineSpacing->{1, 0},
  FontFamily->"Times",
  FontSize->20,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Subtitle", "Presentation"],
  CellFrame->False,
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  CellFrameMargins->{{73, 0}, {15, 0}},
  CellFrameColor->RGBColor[0.356863, 0.529412, 0.94902],
  LineSpacing->{1, 0},
  FontSize->24,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.12903, 0.548394, 0.774197]],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {2, 8}},
  FontSize->16,
  FontWeight->"Plain",
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, 12}, {2, 6}},
  PageBreakBelow->False,
  FontFamily->"Times",
  FontSize->15,
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {2, 8}},
  FontSize->13,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlinks", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["GoBackLink"],
  ConversionRules:>{"TeX" -> {"", CompoundExpression[ #, ""]&, ""}},
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 0.8],
  ButtonBoxOptions->{ButtonFunction:>FrontEndExecute[ {
      FrontEndToken[ 
        FrontEnd`InputNotebook[ ], "HyperlinkGoBack"]}],
  Active->True,
  ButtonFrame->"None",
  ButtonNote->"Jump back"}],

Cell[StyleData["GoBackLink", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["GoBackLink", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 0.8],
  ButtonBoxOptions->{ButtonFunction:>Null,
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefLink", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["RefLink", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["XRefLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 0.8],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["XRefLink", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["XRefLink", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefReadEdit"],
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 0.500008],
  ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
      Needs[ "arXiv`arXivUtilities`"], 
      Symbol[ "arXiv`arXivUtilities`EditCiteSuper"][ #]]&),
  ButtonEvaluator->Automatic,
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefReadEdit", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["RefReadEdit", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefReadEditInline"],
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 0.500008],
  ButtonBoxOptions->{ButtonFunction:>(CompoundExpression[ 
      Needs[ "arXiv`arXivUtilities`"], 
      Symbol[ "arXiv`arXivUtilities`EditCiteInline"][ #]]&),
  ButtonEvaluator->Automatic,
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefReadEditInline", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["RefReadEditInline", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Conformance", "Subsection"],

Cell[CellGroupData[{

Cell[StyleData["BibliographyHead"],
  CellMargins->{{12, 12}, {10, 24}},
  CellGroupingRules->{"SectionGrouping", 10},
  PageBreakBelow->False,
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["BibliographyHead", "Printout"],
  CellMargins->{{12, 12}, {10, 18}},
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ReferenceText"],
  CellMargins->{{12, 10}, {0, 0}},
  LineSpacing->{1, 2},
  ParagraphIndent->-38,
  CounterIncrements->"ReferenceText",
  StyleMenuListing->None],

Cell[StyleData["ReferenceText", "Printout"],
  CellMargins->{{2, 2}, {0, 0}},
  ParagraphIndent->-32]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item"],
  CellMargins->{{18, 4}, {4, 4}},
  ParagraphIndent->-24,
  CounterIncrements->"Item1",
  StyleMenuListing->None],

Cell[StyleData["Item", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemParagraph"],
  CellMargins->{{40, 4}, {2, 2}},
  CounterIncrements->"Item1Continued",
  StyleMenuListing->None],

Cell[StyleData["ItemParagraph", "Printout"],
  CellMargins->{{12, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BibLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["BibLink", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["BibLink", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AuthorNoteLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Helvetica",
  FontColor->RGBColor[0, 0, 0.700008],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AuthorNoteLink", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["AuthorNoteLink", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FootnoteLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 0.8],
  ButtonBoxOptions->{ButtonFunction:>Null,
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["FootnoteLink", "Markup"],
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["FootnoteLink", "Printout"],
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Tex"],
  StyleMenuListing->None],

Cell[StyleData["Tex", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Thanks"],
  CellMargins->{{54, 54}, {0, 3}},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Thanks", "Printout"],
  CellMargins->{{2, 10}, {3, 3}},
  LineSpacing->{1, 1},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Homepage"],
  CellMargins->{{54, 54}, {0, 3}},
  ParagraphSpacing->{0, 8},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Homepage", "Printout"],
  CellMargins->{{2, 10}, {3, 3}},
  LineSpacing->{1, 1},
  FontSize->10]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowSize->{520, 482},
WindowMargins->{{149, Automatic}, {Automatic, 46}},
MacintoshSystemPageSetup->"\<\
00`0001804P000000_X2@?oaonh32@9B:P85:0?l0@00004/0B`0000036L9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
okD<Y@V[00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 37, 0, 62, "Subtitle"],
Cell[1779, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1997, 61, 45, 0, 46, "Subsection"],
Cell[2045, 63, 130, 3, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2178, 68, 115, 2, 36, 36, 0, "StyleData", "All", "Presentation"],
Cell[2296, 72, 50, 1, 36, 30, 0, "StyleData", "All", "Markup"],
Cell[2349, 75, 151, 4, 36, 32, 0, "StyleData", "All", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2537, 84, 38, 0, 46, "Subsection"],
Cell[2578, 86, 105, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[2708, 93, 1300, 31, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None],
Cell[4011, 126, 1429, 33, 70, 43, 0, "StyleData", "Notebook", "Presentation",
  StyleMenuListing->None]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5489, 165, 42, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[5556, 169, 346, 11, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}},
  StyleMenuListing->"Head1"],
Cell[5905, 182, 237, 6, 70, 42, 0, "StyleData", "Section", "Presentation"],
Cell[6145, 190, 116, 3, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6298, 198, 111, 3, 70, 33, 0, "StyleData", "SectionDingbat", "All",
  StyleMenuListing->None],
Cell[6412, 203, 74, 1, 70, 45, 0, "StyleData", "SectionDingbat", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6523, 209, 74, 2, 70, 32, 0, "StyleData", "SectionNumber", "All",
  StyleMenuListing->None],
Cell[6600, 213, 86, 2, 70, 44, 0, "StyleData", "SectionNumber", "Printout",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[6723, 220, 457, 14, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->"Head2"],
Cell[7183, 236, 174, 4, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[7360, 242, 118, 3, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7515, 250, 114, 3, 70, 36, 0, "StyleData", "SubsectionDingbat", "All",
  StyleMenuListing->None],
Cell[7632, 255, 77, 1, 70, 48, 0, "StyleData", "SubsectionDingbat", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7746, 261, 164, 4, 70, 35, 0, "StyleData", "SubsectionNumber", "All",
  StyleMenuListing->None],
Cell[7913, 267, 62, 1, 70, 47, 0, "StyleData", "SubsectionNumber", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8012, 273, 429, 11, 70, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection",
  CounterAssignments->{{"Subsubsubsection", 0}},
  StyleMenuListing->"Head3"],
Cell[8444, 286, 121, 3, 70, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[8568, 291, 172, 4, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"]
}, Closed]],

Cell[CellGroupData[{
Cell[8777, 300, 265, 7, 70, 35, 0, "StyleData", "Subsubsubsection", "All",
  CounterIncrements->"Subsubsubsection",
  StyleMenuListing->"Head4"],
Cell[9045, 309, 163, 3, 70, 51, 0, "StyleData", "Subsubsubsection", \
"Presentation"],
Cell[9211, 314, 124, 3, 70, 47, 0, "StyleData", "Subsubsubsection", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9372, 322, 388, 10, 70, 35, 0, "StyleData", "EquationNumbered", "All",
  CounterIncrements->"Equation"],
Cell[9763, 334, 105, 2, 70, 51, 0, "StyleData", "EquationNumbered", \
"Presentation"],
Cell[9871, 338, 97, 2, 70, 47, 0, "StyleData", "EquationNumbered", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10005, 345, 227, 6, 70, 27, 0, "StyleData", "Equation", "All",
  CounterIncrements->"Equation"],
Cell[10235, 353, 141, 3, 70, 43, 0, "StyleData", "Equation", "Presentation"],
Cell[10379, 358, 89, 2, 70, 39, 0, "StyleData", "Equation", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10505, 365, 172, 6, 70, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[10680, 373, 136, 4, 70, 39, 0, "StyleData", "Text", "Presentation"],
Cell[10819, 379, 109, 3, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10965, 387, 841, 24, 70, 32, 0, "StyleData", "InputNumbered", "All",
  CounterIncrements->"Input"],
Cell[11809, 413, 147, 3, 70, 48, 0, "StyleData", "InputNumbered", \
"Presentation"],
Cell[11959, 418, 138, 3, 70, 44, 0, "StyleData", "InputNumbered", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12134, 426, 576, 17, 70, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[12713, 445, 184, 4, 70, 40, 0, "StyleData", "Input", "Presentation"],
Cell[12900, 451, 130, 3, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[13079, 460, 47, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[13151, 464, 226, 7, 70, 25, 0, "StyleData", "Author", "All",
  StyleMenuListing->None],
Cell[13380, 473, 277, 8, 70, 41, 0, "StyleData", "Author", "Presentation"],
Cell[13660, 483, 89, 2, 70, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13786, 490, 187, 6, 70, 26, 0, "StyleData", "Address", "All",
  CounterIncrements->"Address",
  StyleMenuListing->None],
Cell[13976, 498, 89, 2, 70, 38, 0, "StyleData", "Address", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14102, 505, 183, 6, 70, 24, 0, "StyleData", "Email", "All",
  StyleMenuListing->None],
Cell[14288, 513, 109, 3, 70, 36, 0, "StyleData", "Email", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14434, 521, 300, 9, 70, 31, 0, "StyleData", "AbstractText", "All",
  StyleMenuListing->None],
Cell[14737, 532, 117, 3, 70, 43, 0, "StyleData", "AbstractText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14891, 540, 154, 5, 70, 23, 0, "StyleData", "Date", "All",
  StyleMenuListing->None],
Cell[15048, 547, 108, 3, 70, 35, 0, "StyleData", "Date", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15205, 556, 40, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[15270, 560, 116, 3, 70, 26, 0, "StyleData", "Theorem", "All",
  CounterIncrements->"Theorem"],
Cell[15389, 565, 71, 1, 70, 38, 0, "StyleData", "Theorem", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15497, 571, 112, 3, 70, 24, 0, "StyleData", "Lemma", "All",
  CounterIncrements->"Lemma"],
Cell[15612, 576, 69, 1, 70, 36, 0, "StyleData", "Lemma", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15718, 582, 185, 5, 70, 26, 0, "StyleData", "Program", "All"],
Cell[15906, 589, 89, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16032, 596, 112, 3, 70, 24, 0, "StyleData", "Item1", "All",
  CounterIncrements->"Item1"],
Cell[16147, 601, 109, 3, 70, 36, 0, "StyleData", "Item1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16293, 609, 67, 1, 70, 33, 0, "StyleData", "Item1Paragraph", "All"],
Cell[16363, 612, 95, 2, 70, 45, 0, "StyleData", "Item1Paragraph", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16495, 619, 112, 3, 70, 24, 0, "StyleData", "Item2", "All",
  CounterIncrements->"Item2"],
Cell[16610, 624, 110, 3, 70, 36, 0, "StyleData", "Item2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16757, 632, 93, 2, 70, 33, 0, "StyleData", "Item2Paragraph", "All",
  StyleMenuListing->None],
Cell[16853, 636, 95, 2, 70, 45, 0, "StyleData", "Item2Paragraph", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16985, 643, 112, 3, 70, 24, 0, "StyleData", "Item3", "All",
  CounterIncrements->"Item3"],
Cell[17100, 648, 110, 3, 70, 36, 0, "StyleData", "Item3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17247, 656, 93, 2, 70, 33, 0, "StyleData", "Item3Paragraph", "All",
  StyleMenuListing->None],
Cell[17343, 660, 95, 2, 70, 45, 0, "StyleData", "Item3Paragraph", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17475, 667, 131, 4, 70, 30, 0, "StyleData", "ItemDingbat", "All",
  StyleMenuListing->None],
Cell[17609, 673, 87, 2, 70, 42, 0, "StyleData", "ItemDingbat", "Printout"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17745, 681, 48, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[17818, 685, 544, 16, 70, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[18365, 703, 92, 2, 70, 41, 0, "StyleData", "Output", "Presentation"],
Cell[18460, 707, 86, 2, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18583, 714, 470, 15, 70, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[19056, 731, 149, 4, 70, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[19208, 737, 129, 3, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19386, 746, 49, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[19460, 750, 275, 9, 70, 28, 0, "StyleData", "TableHead", "All",
  CounterIncrements->"TableHead",
  StyleMenuListing->None],
Cell[19738, 761, 91, 2, 70, 40, 0, "StyleData", "TableHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19866, 768, 405, 12, 70, 24, 0, "StyleData", "Table", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[20274, 782, 87, 2, 70, 36, 0, "StyleData", "Table", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20398, 789, 410, 12, 70, 29, 0, "StyleData", "TablePlain", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[20811, 803, 92, 2, 70, 41, 0, "StyleData", "TablePlain", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20940, 810, 412, 12, 70, 31, 0, "StyleData", "3ColumnTable", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[21355, 824, 94, 2, 70, 43, 0, "StyleData", "3ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21486, 831, 417, 12, 70, 36, 0, "StyleData", "3ColumnTablePlain", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[21906, 845, 99, 2, 70, 48, 0, "StyleData", "3ColumnTablePlain", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22042, 852, 412, 12, 70, 31, 0, "StyleData", "4ColumnTable", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[22457, 866, 94, 2, 70, 43, 0, "StyleData", "4ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22588, 873, 417, 12, 70, 36, 0, "StyleData", "4ColumnTablePlain", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[23008, 887, 99, 2, 70, 48, 0, "StyleData", "4ColumnTablePlain", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23144, 894, 412, 12, 70, 31, 0, "StyleData", "5ColumnTable", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[23559, 908, 94, 2, 70, 43, 0, "StyleData", "5ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23690, 915, 417, 12, 70, 36, 0, "StyleData", "5ColumnTablePlain", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[24110, 929, 99, 2, 70, 48, 0, "StyleData", "5ColumnTablePlain", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24246, 936, 199, 7, 70, 28, 0, "StyleData", "TableNote", "All",
  StyleMenuListing->None],
Cell[24448, 945, 90, 2, 70, 40, 0, "StyleData", "TableNote", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24575, 952, 100, 2, 70, 25, 0, "StyleData", "Figure", "All"],
Cell[24678, 956, 101, 2, 70, 37, 0, "StyleData", "Figure", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24816, 963, 101, 2, 70, 26, 0, "StyleData", "Picture", "All"],
Cell[24920, 967, 100, 2, 70, 42, 0, "StyleData", "Picture", "Presentation"],
Cell[25023, 971, 102, 2, 70, 38, 0, "StyleData", "Picture", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25162, 978, 129, 4, 70, 26, 0, "StyleData", "Caption", "All"],
Cell[25294, 984, 112, 3, 70, 38, 0, "StyleData", "Caption", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25443, 992, 244, 7, 70, 32, 0, "StyleData", "GraphicHeader", "All",
  StyleMenuListing->None],
Cell[25690, 1001, 83, 1, 70, 44, 0, "StyleData", "GraphicHeader", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25810, 1007, 49, 0, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[25884, 1011, 138, 4, 70, 32, 0, "StyleData", "TableHeadText", "All",
  CounterIncrements->"TableHead",
  StyleMenuListing->None],
Cell[26025, 1017, 60, 1, 70, 44, 0, "StyleData", "TableHeadText", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26122, 1023, 131, 4, 70, 29, 0, "StyleData", "ColumnHead", "All",
  CounterIncrements->"Table",
  StyleMenuListing->None],
Cell[26256, 1029, 57, 1, 70, 41, 0, "StyleData", "ColumnHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26350, 1035, 139, 5, 70, 28, 0, "StyleData", "TableText", "All",
  StyleMenuListing->None],
Cell[26492, 1042, 56, 1, 70, 40, 0, "StyleData", "TableText", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26609, 1050, 45, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[26679, 1054, 272, 8, 70, 39, 0, "StyleData", "AcknowledgementsHead", \
"All",
  StyleMenuListing->None],
Cell[26954, 1064, 131, 3, 70, 51, 0, "StyleData", "AcknowledgementsHead", \
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27122, 1072, 297, 9, 70, 31, 0, "StyleData", "AppendixHead", "All",
  CounterIncrements->"Appendix",
  StyleMenuListing->None],
Cell[27422, 1083, 123, 3, 70, 43, 0, "StyleData", "AppendixHead", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27582, 1091, 390, 9, 70, 35, 0, "StyleData", "AppendixEquation", "All",
  CounterIncrements->"AppendixEquation"],
Cell[27975, 1102, 63, 1, 70, 47, 0, "StyleData", "AppendixEquation", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28087, 1109, 40, 0, 30, "Subsection"],
Cell[28130, 1111, 275, 8, 70, 33, 0, "StyleData", "ReferencesHead", "All",
  CounterAssignments->{{"Endnote", 0}},
  StyleMenuListing->None],
Cell[28408, 1121, 190, 6, 70, 26, 0, "StyleData", "EndNote", "All",
  CounterIncrements->"EndNote",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[28623, 1131, 143, 4, 70, 29, 0, "StyleData", "RefDingbat", "All",
  CounterIncrements->"RefDingbat",
  StyleMenuListing->None],
Cell[28769, 1137, 41, 0, 70, 41, 0, "StyleData", "RefDingbat", "Printout"]
}, Closed]],
Cell[28825, 1140, 58, 1, 70, 32, 0, "StyleData", "ReferencesEnd", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[28908, 1145, 92, 2, 70, 27, 0, "StyleData", "Citation", "All",
  StyleMenuListing->None],
Cell[29003, 1149, 113, 3, 70, 37, 0, "StyleData", "Citation", "Markup"],
Cell[29119, 1154, 92, 2, 70, 39, 0, "StyleData", "Citation", "Printout",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[29248, 1161, 49, 0, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[29322, 1165, 59, 1, 70, 33, 0, "StyleData", "RefAddressCity", "All",
  StyleMenuListing->None],
Cell[29384, 1168, 45, 0, 70, 45, 0, "StyleData", "RefAddressCity", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29466, 1173, 60, 1, 70, 34, 0, "StyleData", "RefAddressState", "All",
  StyleMenuListing->None],
Cell[29529, 1176, 46, 0, 70, 46, 0, "StyleData", "RefAddressState", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29612, 1181, 83, 2, 70, 34, 0, "StyleData", "RefArticleTitle", "All",
  StyleMenuListing->None],
Cell[29698, 1185, 46, 0, 70, 46, 0, "StyleData", "RefArticleTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29781, 1190, 56, 1, 70, 30, 0, "StyleData", "RefAuthorFN", "All",
  StyleMenuListing->None],
Cell[29840, 1193, 42, 0, 70, 42, 0, "StyleData", "RefAuthorFN", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29919, 1198, 56, 1, 70, 30, 0, "StyleData", "RefAuthorLN", "All",
  StyleMenuListing->None],
Cell[29978, 1201, 42, 0, 70, 42, 0, "StyleData", "RefAuthorLN", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30057, 1206, 56, 1, 70, 30, 0, "StyleData", "RefAuthorMN", "All",
  StyleMenuListing->None],
Cell[30116, 1209, 42, 0, 70, 42, 0, "StyleData", "RefAuthorMN", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30195, 1214, 80, 2, 70, 31, 0, "StyleData", "RefBookTitle", "All",
  StyleMenuListing->None],
Cell[30278, 1218, 43, 0, 70, 43, 0, "StyleData", "RefBookTitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30358, 1223, 83, 2, 70, 34, 0, "StyleData", "RefChapterTitle", "All",
  StyleMenuListing->None],
Cell[30444, 1227, 46, 0, 70, 46, 0, "StyleData", "RefChapterTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30527, 1232, 86, 2, 70, 37, 0, "StyleData", "RefCollectionTitle", "All",
  StyleMenuListing->None],
Cell[30616, 1236, 49, 0, 70, 49, 0, "StyleData", "RefCollectionTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30702, 1241, 85, 2, 70, 36, 0, "StyleData", "RefConferenceName", "All",
  StyleMenuListing->None],
Cell[30790, 1245, 48, 0, 70, 48, 0, "StyleData", "RefConferenceName", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30875, 1250, 51, 1, 70, 25, 0, "StyleData", "RefDay", "All",
  StyleMenuListing->None],
Cell[30929, 1253, 37, 0, 70, 37, 0, "StyleData", "RefDay", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31003, 1258, 55, 1, 70, 29, 0, "StyleData", "RefEdition", "All",
  StyleMenuListing->None],
Cell[31061, 1261, 41, 0, 70, 41, 0, "StyleData", "RefEdition", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31139, 1266, 56, 1, 70, 30, 0, "StyleData", "RefEditorFN", "All",
  StyleMenuListing->None],
Cell[31198, 1269, 42, 0, 70, 42, 0, "StyleData", "RefEditorFN", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31277, 1274, 56, 1, 70, 30, 0, "StyleData", "RefEditorMN", "All",
  StyleMenuListing->None],
Cell[31336, 1277, 42, 0, 70, 42, 0, "StyleData", "RefEditorMN", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31415, 1282, 56, 1, 70, 30, 0, "StyleData", "RefEditorLN", "All",
  StyleMenuListing->None],
Cell[31474, 1285, 42, 0, 70, 42, 0, "StyleData", "RefEditorLN", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31553, 1290, 86, 2, 70, 37, 0, "StyleData", "RefElectronicTitle", "All",
  StyleMenuListing->None],
Cell[31642, 1294, 49, 0, 70, 49, 0, "StyleData", "RefElectronicTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31728, 1299, 54, 1, 70, 28, 0, "StyleData", "RefEprint", "All",
  StyleMenuListing->None],
Cell[31785, 1302, 40, 0, 70, 40, 0, "StyleData", "RefEprint", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31862, 1307, 53, 1, 70, 27, 0, "StyleData", "RefFPage", "All",
  StyleMenuListing->None],
Cell[31918, 1310, 39, 0, 70, 39, 0, "StyleData", "RefFPage", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31994, 1315, 60, 1, 70, 34, 0, "StyleData", "RefHowPublished", "All",
  StyleMenuListing->None],
Cell[32057, 1318, 46, 0, 70, 46, 0, "StyleData", "RefHowPublished", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32140, 1323, 53, 1, 70, 27, 0, "StyleData", "RefIssue", "All",
  StyleMenuListing->None],
Cell[32196, 1326, 39, 0, 70, 39, 0, "StyleData", "RefIssue", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32272, 1331, 59, 1, 70, 33, 0, "StyleData", "RefInstitution", "All",
  StyleMenuListing->None],
Cell[32334, 1334, 45, 0, 70, 45, 0, "StyleData", "RefInstitution", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32416, 1339, 55, 1, 70, 29, 0, "StyleData", "RefJournal", "All",
  StyleMenuListing->None],
Cell[32474, 1342, 41, 0, 70, 41, 0, "StyleData", "RefJournal", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32552, 1347, 53, 1, 70, 27, 0, "StyleData", "RefLPage", "All",
  StyleMenuListing->None],
Cell[32608, 1350, 39, 0, 70, 39, 0, "StyleData", "RefLPage", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32684, 1355, 52, 1, 70, 26, 0, "StyleData", "RefMisc", "All",
  StyleMenuListing->None],
Cell[32739, 1358, 38, 0, 70, 38, 0, "StyleData", "RefMisc", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32814, 1363, 57, 1, 70, 31, 0, "StyleData", "RefMiscTitle", "All",
  StyleMenuListing->None],
Cell[32874, 1366, 43, 0, 70, 43, 0, "StyleData", "RefMiscTitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32954, 1371, 53, 1, 70, 27, 0, "StyleData", "RefMonth", "All",
  StyleMenuListing->None],
Cell[33010, 1374, 39, 0, 70, 39, 0, "StyleData", "RefMonth", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33086, 1379, 52, 1, 70, 26, 0, "StyleData", "RefNote", "All",
  StyleMenuListing->None],
Cell[33141, 1382, 38, 0, 70, 38, 0, "StyleData", "RefNote", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33216, 1387, 60, 1, 70, 34, 0, "StyleData", "RefOrganization", "All",
  StyleMenuListing->None],
Cell[33279, 1390, 46, 0, 70, 46, 0, "StyleData", "RefOrganization", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33362, 1395, 87, 2, 70, 38, 0, "StyleData", "RefProceedingsTitle", "All",
  
  StyleMenuListing->None],
Cell[33452, 1399, 50, 0, 70, 50, 0, "StyleData", "RefProceedingsTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33539, 1404, 57, 1, 70, 31, 0, "StyleData", "RefPublisher", "All",
  StyleMenuListing->None],
Cell[33599, 1407, 43, 0, 70, 43, 0, "StyleData", "RefPublisher", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33679, 1412, 82, 2, 70, 33, 0, "StyleData", "RefReportTitle", "All",
  StyleMenuListing->None],
Cell[33764, 1416, 45, 0, 70, 45, 0, "StyleData", "RefReportTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33846, 1421, 54, 1, 70, 28, 0, "StyleData", "RefSchool", "All",
  StyleMenuListing->None],
Cell[33903, 1424, 40, 0, 70, 40, 0, "StyleData", "RefSchool", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33980, 1429, 81, 2, 70, 32, 0, "StyleData", "RefSchoolDept", "All",
  StyleMenuListing->None],
Cell[34064, 1433, 44, 0, 70, 44, 0, "StyleData", "RefSchoolDept", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34145, 1438, 54, 1, 70, 28, 0, "StyleData", "RefSeries", "All",
  StyleMenuListing->None],
Cell[34202, 1441, 40, 0, 70, 40, 0, "StyleData", "RefSeries", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34279, 1446, 82, 2, 70, 33, 0, "StyleData", "RefThesisTitle", "All",
  StyleMenuListing->None],
Cell[34364, 1450, 45, 0, 70, 45, 0, "StyleData", "RefThesisTitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34446, 1455, 51, 1, 70, 25, 0, "StyleData", "RefURL", "All",
  StyleMenuListing->None],
Cell[34500, 1458, 37, 0, 70, 37, 0, "StyleData", "RefURL", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34574, 1463, 76, 2, 70, 28, 0, "StyleData", "RefVolume", "All",
  StyleMenuListing->None],
Cell[34653, 1467, 40, 0, 70, 40, 0, "StyleData", "RefVolume", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34730, 1472, 52, 1, 70, 26, 0, "StyleData", "RefYear", "All",
  StyleMenuListing->None],
Cell[34785, 1475, 38, 0, 70, 38, 0, "StyleData", "RefYear", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[34860, 1480, 95, 3, 70, 26, 0, "StyleData", "RefKind", "All",
  StyleMenuListing->None],
Cell[34958, 1485, 153, 4, 70, 36, 0, "StyleData", "RefKind", "Markup"],
Cell[35114, 1491, 38, 0, 70, 38, 0, "StyleData", "RefKind", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35189, 1496, 73, 2, 70, 26, 0, "StyleData", "RefType", "All",
  StyleMenuListing->None],
Cell[35265, 1500, 118, 3, 70, 36, 0, "StyleData", "RefType", "Markup"],
Cell[35386, 1505, 38, 0, 70, 38, 0, "StyleData", "RefType", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[35461, 1510, 75, 2, 70, 28, 0, "StyleData", "RefMarker", "All",
  StyleMenuListing->None],
Cell[35539, 1514, 59, 1, 70, 38, 0, "StyleData", "RefMarker", "Markup"],
Cell[35601, 1517, 61, 1, 70, 40, 0, "StyleData", "RefMarker", "Printout"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[35723, 1525, 28, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[35776, 1529, 192, 6, 70, 24, 0, "StyleData", "Title", "All"],
Cell[35971, 1537, 482, 14, 70, 40, 0, "StyleData", "Title", "Presentation"],
Cell[36456, 1553, 87, 2, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36580, 1560, 211, 7, 70, 27, 0, "StyleData", "Subtitle", "All"],
Cell[36794, 1569, 363, 10, 70, 43, 0, "StyleData", "Subtitle", \
"Presentation"],
Cell[37160, 1581, 139, 4, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37336, 1590, 168, 5, 70, 30, 0, "StyleData", "Subsubtitle", "All"],
Cell[37507, 1597, 119, 3, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37675, 1606, 32, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[37732, 1610, 397, 10, 70, 29, 0, "StyleData", "GoBackLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38132, 1622, 71, 1, 70, 39, 0, "StyleData", "GoBackLink", "Markup"],
Cell[38206, 1625, 68, 1, 70, 41, 0, "StyleData", "GoBackLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38311, 1631, 229, 7, 70, 26, 0, "StyleData", "RefLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38543, 1640, 68, 1, 70, 36, 0, "StyleData", "RefLink", "Markup"],
Cell[38614, 1643, 65, 1, 70, 38, 0, "StyleData", "RefLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38716, 1649, 284, 8, 70, 27, 0, "StyleData", "XRefLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39003, 1659, 69, 1, 70, 37, 0, "StyleData", "XRefLink", "Markup"],
Cell[39075, 1662, 66, 1, 70, 39, 0, "StyleData", "XRefLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39178, 1668, 324, 8, 70, 30, 0, "StyleData", "RefReadEdit", "All",
  StyleMenuListing->None],
Cell[39505, 1678, 72, 1, 70, 40, 0, "StyleData", "RefReadEdit", "Markup"],
Cell[39580, 1681, 69, 1, 70, 42, 0, "StyleData", "RefReadEdit", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39686, 1687, 331, 8, 70, 36, 0, "StyleData", "RefReadEditInline", "All",
  StyleMenuListing->None],
Cell[40020, 1697, 78, 1, 70, 46, 0, "StyleData", "RefReadEditInline", \
"Markup"],
Cell[40101, 1700, 75, 1, 70, 48, 0, "StyleData", "RefReadEditInline", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40225, 1707, 33, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[40283, 1711, 234, 7, 70, 35, 0, "StyleData", "BibliographyHead", "All",
  StyleMenuListing->None],
Cell[40520, 1720, 127, 3, 70, 47, 0, "StyleData", "BibliographyHead", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40684, 1728, 178, 5, 70, 32, 0, "StyleData", "ReferenceText", "All",
  CounterIncrements->"ReferenceText",
  StyleMenuListing->None],
Cell[40865, 1735, 101, 2, 70, 44, 0, "StyleData", "ReferenceText", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41003, 1742, 137, 4, 70, 23, 0, "StyleData", "Item", "All",
  CounterIncrements->"Item1",
  StyleMenuListing->None],
Cell[41143, 1748, 69, 1, 70, 35, 0, "StyleData", "Item", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41249, 1754, 131, 3, 70, 32, 0, "StyleData", "ItemParagraph", "All",
  CounterIncrements->"Item1Continued",
  StyleMenuListing->None],
Cell[41383, 1759, 78, 1, 70, 44, 0, "StyleData", "ItemParagraph", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41498, 1765, 258, 7, 70, 26, 0, "StyleData", "BibLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[41759, 1774, 68, 1, 70, 36, 0, "StyleData", "BibLink", "Markup"],
Cell[41830, 1777, 65, 1, 70, 38, 0, "StyleData", "BibLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[41932, 1783, 299, 8, 70, 33, 0, "StyleData", "AuthorNoteLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42234, 1793, 75, 1, 70, 43, 0, "StyleData", "AuthorNoteLink", "Markup"],
Cell[42312, 1796, 72, 1, 70, 45, 0, "StyleData", "AuthorNoteLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42421, 1802, 234, 7, 70, 31, 0, "StyleData", "FootnoteLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[42658, 1811, 73, 1, 70, 41, 0, "StyleData", "FootnoteLink", "Markup"],
Cell[42734, 1814, 70, 1, 70, 43, 0, "StyleData", "FootnoteLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42841, 1820, 48, 1, 70, 22, 0, "StyleData", "Tex", "All",
  StyleMenuListing->None],
Cell[42892, 1823, 34, 0, 70, 34, 0, "StyleData", "Tex", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[42963, 1828, 176, 6, 70, 25, 0, "StyleData", "Thanks", "All",
  StyleMenuListing->None],
Cell[43142, 1836, 110, 3, 70, 37, 0, "StyleData", "Thanks", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[43289, 1844, 178, 6, 70, 27, 0, "StyleData", "Homepage", "All",
  StyleMenuListing->None],
Cell[43470, 1852, 112, 3, 70, 39, 0, "StyleData", "Homepage", "Printout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

